/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerafocuscontrol.sip"
#include <qcamerafocuscontrol.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerafocus.sip"
#include <qcamerafocus.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerafocus.sip"
#include <qcamerafocus.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerafocus.sip"
#include <qcamerafocus.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusControl.cpp"


class sipQCameraFocusControl : public ::QCameraFocusControl
{
public:
    sipQCameraFocusControl(::QObject*);
    virtual ~sipQCameraFocusControl();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QCameraFocusZoneList focusZones() const SIP_OVERRIDE;
    void setCustomFocusPoint(const ::QPointF&) SIP_OVERRIDE;
    ::QPointF customFocusPoint() const SIP_OVERRIDE;
    bool isFocusPointModeSupported(::QCameraFocus::FocusPointMode) const SIP_OVERRIDE;
    void setFocusPointMode(::QCameraFocus::FocusPointMode) SIP_OVERRIDE;
    ::QCameraFocus::FocusPointMode focusPointMode() const SIP_OVERRIDE;
    bool isFocusModeSupported(::QCameraFocus::FocusModes) const SIP_OVERRIDE;
    void setFocusMode(::QCameraFocus::FocusModes) SIP_OVERRIDE;
    ::QCameraFocus::FocusModes focusMode() const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQCameraFocusControl(const sipQCameraFocusControl &);
    sipQCameraFocusControl &operator = (const sipQCameraFocusControl &);

    char sipPyMethods[16];
};

sipQCameraFocusControl::sipQCameraFocusControl(::QObject*a0): ::QCameraFocusControl(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCameraFocusControl::~sipQCameraFocusControl()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQCameraFocusControl::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QCameraFocusControl);

    return ::QCameraFocusControl::metaObject();
}

int sipQCameraFocusControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QCameraFocusControl::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QCameraFocusControl, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQCameraFocusControl::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QCameraFocusControl, _clname, &sipCpp) ? sipCpp : ::QCameraFocusControl::qt_metacast(_clname));
}

::QCameraFocusZoneList sipQCameraFocusControl::focusZones() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraFocusControl, sipName_focusZones);

    if (!sipMeth)
        return ::QCameraFocusZoneList();

    extern ::QCameraFocusZoneList sipVH_QtMultimedia_73(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_73(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQCameraFocusControl::setCustomFocusPoint(const ::QPointF& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, sipName_QCameraFocusControl, sipName_setCustomFocusPoint);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_72(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPointF&);

    sipVH_QtMultimedia_72(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPointF sipQCameraFocusControl::customFocusPoint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraFocusControl, sipName_customFocusPoint);

    if (!sipMeth)
        return ::QPointF();

    extern ::QPointF sipVH_QtMultimedia_71(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_71(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQCameraFocusControl::isFocusPointModeSupported(::QCameraFocus::FocusPointMode a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraFocusControl, sipName_isFocusPointModeSupported);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_70(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCameraFocus::FocusPointMode);

    return sipVH_QtMultimedia_70(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraFocusControl::setFocusPointMode(::QCameraFocus::FocusPointMode a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, sipName_QCameraFocusControl, sipName_setFocusPointMode);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_69(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCameraFocus::FocusPointMode);

    sipVH_QtMultimedia_69(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QCameraFocus::FocusPointMode sipQCameraFocusControl::focusPointMode() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraFocusControl, sipName_focusPointMode);

    if (!sipMeth)
        return ::QCameraFocus::FocusPointAuto;

    extern ::QCameraFocus::FocusPointMode sipVH_QtMultimedia_68(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_68(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQCameraFocusControl::isFocusModeSupported(::QCameraFocus::FocusModes a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraFocusControl, sipName_isFocusModeSupported);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_67(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCameraFocus::FocusModes);

    return sipVH_QtMultimedia_67(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraFocusControl::setFocusMode(::QCameraFocus::FocusModes a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, sipName_QCameraFocusControl, sipName_setFocusMode);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_66(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCameraFocus::FocusModes);

    sipVH_QtMultimedia_66(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QCameraFocus::FocusModes sipQCameraFocusControl::focusMode() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraFocusControl, sipName_focusMode);

    if (!sipMeth)
        return ::QCameraFocus::FocusModes();

    extern ::QCameraFocus::FocusModes sipVH_QtMultimedia_65(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_65(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQCameraFocusControl::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QCameraFocusControl::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraFocusControl::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QCameraFocusControl::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraFocusControl::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QCameraFocusControl::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraFocusControl::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QCameraFocusControl::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraFocusControl::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QCameraFocusControl::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCameraFocusControl::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QCameraFocusControl::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQCameraFocusControl::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QCameraFocusControl::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QCameraFocusControl_focusMode, "focusMode(self) -> QCameraFocus.FocusModes");

extern "C" {static PyObject *meth_QCameraFocusControl_focusMode(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocusControl_focusMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QCameraFocusControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocusControl, &sipCpp))
        {
            ::QCameraFocus::FocusModes*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraFocusControl, sipName_focusMode);
                return SIP_NULLPTR;
            }

            sipRes = new ::QCameraFocus::FocusModes(sipCpp->focusMode());

            return sipConvertFromNewType(sipRes, sipType_QCameraFocus_FocusModes, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocusControl, sipName_focusMode, doc_QCameraFocusControl_focusMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocusControl_setFocusMode, "setFocusMode(self, mode: Union[QCameraFocus.FocusModes, QCameraFocus.FocusMode])");

extern "C" {static PyObject *meth_QCameraFocusControl_setFocusMode(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocusControl_setFocusMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCameraFocus::FocusModes* a0;
        int a0State = 0;
        ::QCameraFocusControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCameraFocusControl, &sipCpp, sipType_QCameraFocus_FocusModes, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraFocusControl, sipName_setFocusMode);
                return SIP_NULLPTR;
            }

            sipCpp->setFocusMode(*a0);
            sipReleaseType(a0, sipType_QCameraFocus_FocusModes, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocusControl, sipName_setFocusMode, doc_QCameraFocusControl_setFocusMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocusControl_isFocusModeSupported, "isFocusModeSupported(self, mode: Union[QCameraFocus.FocusModes, QCameraFocus.FocusMode]) -> bool");

extern "C" {static PyObject *meth_QCameraFocusControl_isFocusModeSupported(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocusControl_isFocusModeSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCameraFocus::FocusModes* a0;
        int a0State = 0;
        const ::QCameraFocusControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCameraFocusControl, &sipCpp, sipType_QCameraFocus_FocusModes, &a0, &a0State))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraFocusControl, sipName_isFocusModeSupported);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isFocusModeSupported(*a0);
            sipReleaseType(a0, sipType_QCameraFocus_FocusModes, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocusControl, sipName_isFocusModeSupported, doc_QCameraFocusControl_isFocusModeSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocusControl_focusPointMode, "focusPointMode(self) -> QCameraFocus.FocusPointMode");

extern "C" {static PyObject *meth_QCameraFocusControl_focusPointMode(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocusControl_focusPointMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QCameraFocusControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocusControl, &sipCpp))
        {
            ::QCameraFocus::FocusPointMode sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraFocusControl, sipName_focusPointMode);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->focusPointMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCameraFocus_FocusPointMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocusControl, sipName_focusPointMode, doc_QCameraFocusControl_focusPointMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocusControl_setFocusPointMode, "setFocusPointMode(self, mode: QCameraFocus.FocusPointMode)");

extern "C" {static PyObject *meth_QCameraFocusControl_setFocusPointMode(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocusControl_setFocusPointMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCameraFocus::FocusPointMode a0;
        ::QCameraFocusControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraFocusControl, &sipCpp, sipType_QCameraFocus_FocusPointMode, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraFocusControl, sipName_setFocusPointMode);
                return SIP_NULLPTR;
            }

            sipCpp->setFocusPointMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocusControl, sipName_setFocusPointMode, doc_QCameraFocusControl_setFocusPointMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocusControl_isFocusPointModeSupported, "isFocusPointModeSupported(self, mode: QCameraFocus.FocusPointMode) -> bool");

extern "C" {static PyObject *meth_QCameraFocusControl_isFocusPointModeSupported(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocusControl_isFocusPointModeSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCameraFocus::FocusPointMode a0;
        const ::QCameraFocusControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraFocusControl, &sipCpp, sipType_QCameraFocus_FocusPointMode, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraFocusControl, sipName_isFocusPointModeSupported);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isFocusPointModeSupported(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocusControl, sipName_isFocusPointModeSupported, doc_QCameraFocusControl_isFocusPointModeSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocusControl_customFocusPoint, "customFocusPoint(self) -> QPointF");

extern "C" {static PyObject *meth_QCameraFocusControl_customFocusPoint(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocusControl_customFocusPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QCameraFocusControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocusControl, &sipCpp))
        {
            ::QPointF*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraFocusControl, sipName_customFocusPoint);
                return SIP_NULLPTR;
            }

            sipRes = new ::QPointF(sipCpp->customFocusPoint());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocusControl, sipName_customFocusPoint, doc_QCameraFocusControl_customFocusPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocusControl_setCustomFocusPoint, "setCustomFocusPoint(self, point: Union[QPointF, QPoint])");

extern "C" {static PyObject *meth_QCameraFocusControl_setCustomFocusPoint(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocusControl_setCustomFocusPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QPointF* a0;
        int a0State = 0;
        ::QCameraFocusControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCameraFocusControl, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraFocusControl, sipName_setCustomFocusPoint);
                return SIP_NULLPTR;
            }

            sipCpp->setCustomFocusPoint(*a0);
            sipReleaseType(const_cast< ::QPointF *>(a0), sipType_QPointF, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocusControl, sipName_setCustomFocusPoint, doc_QCameraFocusControl_setCustomFocusPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocusControl_focusZones, "focusZones(self) -> list[QCameraFocusZone]");

extern "C" {static PyObject *meth_QCameraFocusControl_focusZones(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocusControl_focusZones(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QCameraFocusControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocusControl, &sipCpp))
        {
            ::QCameraFocusZoneList*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraFocusControl, sipName_focusZones);
                return SIP_NULLPTR;
            }

            sipRes = new ::QCameraFocusZoneList(sipCpp->focusZones());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QCameraFocusZone, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocusControl, sipName_focusZones, doc_QCameraFocusControl_focusZones);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QCameraFocusControl(void *, const sipTypeDef *);}
static void *cast_QCameraFocusControl(void *sipCppV, const sipTypeDef *targetType)
{
    ::QCameraFocusControl *sipCpp = reinterpret_cast< ::QCameraFocusControl *>(sipCppV);

    if (targetType == sipType_QCameraFocusControl)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaControl)->ctd_cast(static_cast< ::QMediaControl *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QCameraFocusControl(void *, int);}
static void release_QCameraFocusControl(void *sipCppV, int)
{
    ::QCameraFocusControl *sipCpp = reinterpret_cast< ::QCameraFocusControl *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QCameraFocusControl(sipSimpleWrapper *);}
static void dealloc_QCameraFocusControl(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQCameraFocusControl *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QCameraFocusControl(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QCameraFocusControl(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QCameraFocusControl(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQCameraFocusControl *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQCameraFocusControl(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QCameraFocusControl[] = {{104, 255, 1}};


static PyMethodDef methods_QCameraFocusControl[] = {
    {sipName_customFocusPoint, meth_QCameraFocusControl_customFocusPoint, METH_VARARGS, doc_QCameraFocusControl_customFocusPoint},
    {sipName_focusMode, meth_QCameraFocusControl_focusMode, METH_VARARGS, doc_QCameraFocusControl_focusMode},
    {sipName_focusPointMode, meth_QCameraFocusControl_focusPointMode, METH_VARARGS, doc_QCameraFocusControl_focusPointMode},
    {sipName_focusZones, meth_QCameraFocusControl_focusZones, METH_VARARGS, doc_QCameraFocusControl_focusZones},
    {sipName_isFocusModeSupported, meth_QCameraFocusControl_isFocusModeSupported, METH_VARARGS, doc_QCameraFocusControl_isFocusModeSupported},
    {sipName_isFocusPointModeSupported, meth_QCameraFocusControl_isFocusPointModeSupported, METH_VARARGS, doc_QCameraFocusControl_isFocusPointModeSupported},
    {sipName_setCustomFocusPoint, meth_QCameraFocusControl_setCustomFocusPoint, METH_VARARGS, doc_QCameraFocusControl_setCustomFocusPoint},
    {sipName_setFocusMode, meth_QCameraFocusControl_setFocusMode, METH_VARARGS, doc_QCameraFocusControl_setFocusMode},
    {sipName_setFocusPointMode, meth_QCameraFocusControl_setFocusPointMode, METH_VARARGS, doc_QCameraFocusControl_setFocusPointMode}
};

PyDoc_STRVAR(doc_QCameraFocusControl, "\1QCameraFocusControl(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QCameraFocusControl[] = {
    {"focusZonesChanged()", "\1focusZonesChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"customFocusPointChanged(QPointF)", "\1customFocusPointChanged(self, point: Union[QPointF, QPoint])", SIP_NULLPTR, SIP_NULLPTR},
    {"focusPointModeChanged(QCameraFocus::FocusPointMode)", "\1focusPointModeChanged(self, mode: QCameraFocus.FocusPointMode)", SIP_NULLPTR, SIP_NULLPTR},
    {"focusModeChanged(QCameraFocus::FocusModes)", "\1focusModeChanged(self, mode: Union[QCameraFocus.FocusModes, QCameraFocus.FocusMode])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QCameraFocusControl = {
    &::QCameraFocusControl::staticMetaObject,
    0,
    signals_QCameraFocusControl,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QCameraFocusControl = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCameraFocusControl,
        SIP_NULLPTR,
        &plugin_QCameraFocusControl,
    },
    {
        sipNameNr_QCameraFocusControl,
        {0, 0, 1},
        9, methods_QCameraFocusControl,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QCameraFocusControl,
    -1,
    -1,
    supers_QCameraFocusControl,
    SIP_NULLPTR,
    init_type_QCameraFocusControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QCameraFocusControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QCameraFocusControl,
    cast_QCameraFocusControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QCameraFocusControl),
};
