/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudioinput.sip"
#include <qaudioinput.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudioformat.sip"
#include <qaudioformat.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudiodeviceinfo.sip"
#include <qaudiodeviceinfo.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudio.sip"
#include <qaudio.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioInput.cpp"


class sipQAudioInput : public ::QAudioInput
{
public:
    sipQAudioInput(const ::QAudioFormat&, ::QObject*);
    sipQAudioInput(const ::QAudioDeviceInfo&, const ::QAudioFormat&, ::QObject*);
    virtual ~sipQAudioInput();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAudioInput(const sipQAudioInput &);
    sipQAudioInput &operator = (const sipQAudioInput &);

    char sipPyMethods[7];
};

sipQAudioInput::sipQAudioInput(const ::QAudioFormat& a0, ::QObject*a1): ::QAudioInput(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAudioInput::sipQAudioInput(const ::QAudioDeviceInfo& a0, const ::QAudioFormat& a1, ::QObject*a2): ::QAudioInput(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAudioInput::~sipQAudioInput()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQAudioInput::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QAudioInput);

    return ::QAudioInput::metaObject();
}

int sipQAudioInput::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QAudioInput::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QAudioInput, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQAudioInput::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QAudioInput, _clname, &sipCpp) ? sipCpp : ::QAudioInput::qt_metacast(_clname));
}

bool sipQAudioInput::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QAudioInput::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAudioInput::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QAudioInput::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQAudioInput::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QAudioInput::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioInput::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QAudioInput::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioInput::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QAudioInput::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioInput::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QAudioInput::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioInput::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QAudioInput::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QAudioInput_format, "format(self) -> QAudioFormat");

extern "C" {static PyObject *meth_QAudioInput_format(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_format(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioInput, &sipCpp))
        {
            ::QAudioFormat*sipRes;

            sipRes = new ::QAudioFormat(sipCpp->format());

            return sipConvertFromNewType(sipRes, sipType_QAudioFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_format, doc_QAudioInput_format);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_start, "start(self, device: Optional[QIODevice])\n"
"start(self) -> Optional[QIODevice]");

extern "C" {static PyObject *meth_QAudioInput_start(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_start(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QIODevice* a0;
        ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QAudioInput, &sipCpp, sipType_QIODevice, &a0))
        {
            sipCpp->start(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioInput, &sipCpp))
        {
            ::QIODevice*sipRes;

            sipRes = sipCpp->start();

            return sipConvertFromType(sipRes, sipType_QIODevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_start, doc_QAudioInput_start);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_stop, "stop(self)");

extern "C" {static PyObject *meth_QAudioInput_stop(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioInput, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_stop, doc_QAudioInput_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_reset, "reset(self)");

extern "C" {static PyObject *meth_QAudioInput_reset(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_reset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioInput, &sipCpp))
        {
            sipCpp->reset();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_reset, doc_QAudioInput_reset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_suspend, "suspend(self)");

extern "C" {static PyObject *meth_QAudioInput_suspend(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_suspend(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioInput, &sipCpp))
        {
            sipCpp->suspend();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_suspend, doc_QAudioInput_suspend);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_resume, "resume(self)");

extern "C" {static PyObject *meth_QAudioInput_resume(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_resume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioInput, &sipCpp))
        {
            sipCpp->resume();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_resume, doc_QAudioInput_resume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_setBufferSize, "setBufferSize(self, bytes: int)");

extern "C" {static PyObject *meth_QAudioInput_setBufferSize(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_setBufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QAudioInput, &sipCpp, &a0))
        {
            sipCpp->setBufferSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_setBufferSize, doc_QAudioInput_setBufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_bufferSize, "bufferSize(self) -> int");

extern "C" {static PyObject *meth_QAudioInput_bufferSize(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_bufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioInput, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->bufferSize();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_bufferSize, doc_QAudioInput_bufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_bytesReady, "bytesReady(self) -> int");

extern "C" {static PyObject *meth_QAudioInput_bytesReady(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_bytesReady(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioInput, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->bytesReady();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_bytesReady, doc_QAudioInput_bytesReady);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_periodSize, "periodSize(self) -> int");

extern "C" {static PyObject *meth_QAudioInput_periodSize(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_periodSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioInput, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->periodSize();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_periodSize, doc_QAudioInput_periodSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_setNotifyInterval, "setNotifyInterval(self, milliSeconds: int)");

extern "C" {static PyObject *meth_QAudioInput_setNotifyInterval(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_setNotifyInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QAudioInput, &sipCpp, &a0))
        {
            sipCpp->setNotifyInterval(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_setNotifyInterval, doc_QAudioInput_setNotifyInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_notifyInterval, "notifyInterval(self) -> int");

extern "C" {static PyObject *meth_QAudioInput_notifyInterval(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_notifyInterval(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioInput, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->notifyInterval();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_notifyInterval, doc_QAudioInput_notifyInterval);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_processedUSecs, "processedUSecs(self) -> int");

extern "C" {static PyObject *meth_QAudioInput_processedUSecs(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_processedUSecs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioInput, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->processedUSecs();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_processedUSecs, doc_QAudioInput_processedUSecs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_elapsedUSecs, "elapsedUSecs(self) -> int");

extern "C" {static PyObject *meth_QAudioInput_elapsedUSecs(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_elapsedUSecs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioInput, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->elapsedUSecs();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_elapsedUSecs, doc_QAudioInput_elapsedUSecs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_error, "error(self) -> QAudio.Error");

extern "C" {static PyObject *meth_QAudioInput_error(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioInput, &sipCpp))
        {
            ::QAudio::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAudio_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_error, doc_QAudioInput_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_state, "state(self) -> QAudio.State");

extern "C" {static PyObject *meth_QAudioInput_state(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioInput, &sipCpp))
        {
            ::QAudio::State sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAudio_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_state, doc_QAudioInput_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_setVolume, "setVolume(self, volume: float)");

extern "C" {static PyObject *meth_QAudioInput_setVolume(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_setVolume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QAudioInput, &sipCpp, &a0))
        {
            sipCpp->setVolume(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_setVolume, doc_QAudioInput_setVolume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioInput_volume, "volume(self) -> float");

extern "C" {static PyObject *meth_QAudioInput_volume(PyObject *, PyObject *);}
static PyObject *meth_QAudioInput_volume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioInput *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioInput, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->volume();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioInput, sipName_volume, doc_QAudioInput_volume);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAudioInput(void *, const sipTypeDef *);}
static void *cast_QAudioInput(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAudioInput *sipCpp = reinterpret_cast< ::QAudioInput *>(sipCppV);

    if (targetType == sipType_QAudioInput)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAudioInput(void *, int);}
static void release_QAudioInput(void *sipCppV, int)
{
    ::QAudioInput *sipCpp = reinterpret_cast< ::QAudioInput *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QAudioInput(Py_ssize_t);}
static void *array_QAudioInput(Py_ssize_t sipNrElem)
{
    return new ::QAudioInput[sipNrElem];
}


extern "C" {static void array_delete_QAudioInput(void *);}
static void array_delete_QAudioInput(void *sipCpp)
{
    delete[] reinterpret_cast< ::QAudioInput *>(sipCpp);
}


extern "C" {static void dealloc_QAudioInput(sipSimpleWrapper *);}
static void dealloc_QAudioInput(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAudioInput *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAudioInput(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAudioInput(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAudioInput(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQAudioInput *sipCpp = SIP_NULLPTR;

    {
        const ::QAudioFormat& a0def = QAudioFormat();
        const ::QAudioFormat* a0 = &a0def;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            sipName_format,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|J9JH", sipType_QAudioFormat, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQAudioInput(*a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QAudioDeviceInfo* a0;
        const ::QAudioFormat& a1def = QAudioFormat();
        const ::QAudioFormat* a1 = &a1def;
        ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9|J9JH", sipType_QAudioDeviceInfo, &a0, sipType_QAudioFormat, &a1, sipType_QObject, &a2, sipOwner))
        {
            sipCpp = new sipQAudioInput(*a0, *a1, a2);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAudioInput[] = {{9, 0, 1}};


static PyMethodDef methods_QAudioInput[] = {
    {sipName_bufferSize, meth_QAudioInput_bufferSize, METH_VARARGS, doc_QAudioInput_bufferSize},
    {sipName_bytesReady, meth_QAudioInput_bytesReady, METH_VARARGS, doc_QAudioInput_bytesReady},
    {sipName_elapsedUSecs, meth_QAudioInput_elapsedUSecs, METH_VARARGS, doc_QAudioInput_elapsedUSecs},
    {sipName_error, meth_QAudioInput_error, METH_VARARGS, doc_QAudioInput_error},
    {sipName_format, meth_QAudioInput_format, METH_VARARGS, doc_QAudioInput_format},
    {sipName_notifyInterval, meth_QAudioInput_notifyInterval, METH_VARARGS, doc_QAudioInput_notifyInterval},
    {sipName_periodSize, meth_QAudioInput_periodSize, METH_VARARGS, doc_QAudioInput_periodSize},
    {sipName_processedUSecs, meth_QAudioInput_processedUSecs, METH_VARARGS, doc_QAudioInput_processedUSecs},
    {sipName_reset, meth_QAudioInput_reset, METH_VARARGS, doc_QAudioInput_reset},
    {sipName_resume, meth_QAudioInput_resume, METH_VARARGS, doc_QAudioInput_resume},
    {sipName_setBufferSize, meth_QAudioInput_setBufferSize, METH_VARARGS, doc_QAudioInput_setBufferSize},
    {sipName_setNotifyInterval, meth_QAudioInput_setNotifyInterval, METH_VARARGS, doc_QAudioInput_setNotifyInterval},
    {sipName_setVolume, meth_QAudioInput_setVolume, METH_VARARGS, doc_QAudioInput_setVolume},
    {sipName_start, meth_QAudioInput_start, METH_VARARGS, doc_QAudioInput_start},
    {sipName_state, meth_QAudioInput_state, METH_VARARGS, doc_QAudioInput_state},
    {sipName_stop, meth_QAudioInput_stop, METH_VARARGS, doc_QAudioInput_stop},
    {sipName_suspend, meth_QAudioInput_suspend, METH_VARARGS, doc_QAudioInput_suspend},
    {sipName_volume, meth_QAudioInput_volume, METH_VARARGS, doc_QAudioInput_volume}
};

PyDoc_STRVAR(doc_QAudioInput, "\1QAudioInput(format: QAudioFormat = QAudioFormat(), parent: Optional[QObject] = None)\n"
"QAudioInput(audioDevice: QAudioDeviceInfo, format: QAudioFormat = QAudioFormat(), parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QAudioInput[] = {
    {"notify()", "\1notify(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QAudio::State)", "\1stateChanged(self, a0: QAudio.State)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QAudioInput = {
    &::QAudioInput::staticMetaObject,
    0,
    signals_QAudioInput,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QAudioInput = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAudioInput,
        SIP_NULLPTR,
        &plugin_QAudioInput,
    },
    {
        sipNameNr_QAudioInput,
        {0, 0, 1},
        18, methods_QAudioInput,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAudioInput,
    -1,
    -1,
    supers_QAudioInput,
    SIP_NULLPTR,
    init_type_QAudioInput,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAudioInput,
    SIP_NULLPTR,
    array_QAudioInput,
    SIP_NULLPTR,
    release_QAudioInput,
    cast_QAudioInput,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QAudioInput,
    sizeof (::QAudioInput),
};
