/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediarecordercontrol.sip"
#include <qmediarecordercontrol.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediarecorder.sip"
#include <qmediarecorder.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaRecorderControl.cpp"


class sipQMediaRecorderControl : public ::QMediaRecorderControl
{
public:
    sipQMediaRecorderControl(::QObject*);
    virtual ~sipQMediaRecorderControl();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void setVolume(::qreal) SIP_OVERRIDE;
    void setMuted(bool) SIP_OVERRIDE;
    void setState(::QMediaRecorder::State) SIP_OVERRIDE;
    void applySettings() SIP_OVERRIDE;
    ::qreal volume() const SIP_OVERRIDE;
    bool isMuted() const SIP_OVERRIDE;
    ::qint64 duration() const SIP_OVERRIDE;
    ::QMediaRecorder::Status status() const SIP_OVERRIDE;
    ::QMediaRecorder::State state() const SIP_OVERRIDE;
    bool setOutputLocation(const ::QUrl&) SIP_OVERRIDE;
    ::QUrl outputLocation() const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQMediaRecorderControl(const sipQMediaRecorderControl &);
    sipQMediaRecorderControl &operator = (const sipQMediaRecorderControl &);

    char sipPyMethods[18];
};

sipQMediaRecorderControl::sipQMediaRecorderControl(::QObject*a0): ::QMediaRecorderControl(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQMediaRecorderControl::~sipQMediaRecorderControl()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQMediaRecorderControl::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QMediaRecorderControl);

    return ::QMediaRecorderControl::metaObject();
}

int sipQMediaRecorderControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QMediaRecorderControl::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QMediaRecorderControl, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQMediaRecorderControl::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QMediaRecorderControl, _clname, &sipCpp) ? sipCpp : ::QMediaRecorderControl::qt_metacast(_clname));
}

void sipQMediaRecorderControl::setVolume(::qreal a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, sipName_QMediaRecorderControl, sipName_setVolume);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_98(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::qreal);

    sipVH_QtMultimedia_98(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaRecorderControl::setMuted(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, sipName_QMediaRecorderControl, sipName_setMuted);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_106(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtMultimedia_106(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaRecorderControl::setState(::QMediaRecorder::State a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, sipName_QMediaRecorderControl, sipName_setState);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_114(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMediaRecorder::State);

    sipVH_QtMultimedia_114(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaRecorderControl::applySettings()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, sipName_QMediaRecorderControl, sipName_applySettings);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::qreal sipQMediaRecorderControl::volume() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaRecorderControl, sipName_volume);

    if (!sipMeth)
        return 0;

    extern ::qreal sipVH_QtMultimedia_91(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_91(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQMediaRecorderControl::isMuted() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaRecorderControl, sipName_isMuted);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_16(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::qint64 sipQMediaRecorderControl::duration() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaRecorderControl, sipName_duration);

    if (!sipMeth)
        return 0;

    extern ::qint64 sipVH_QtMultimedia_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_29(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QMediaRecorder::Status sipQMediaRecorderControl::status() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaRecorderControl, sipName_status);

    if (!sipMeth)
        return ::QMediaRecorder::UnavailableStatus;

    extern ::QMediaRecorder::Status sipVH_QtMultimedia_113(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_113(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QMediaRecorder::State sipQMediaRecorderControl::state() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaRecorderControl, sipName_state);

    if (!sipMeth)
        return ::QMediaRecorder::StoppedState;

    extern ::QMediaRecorder::State sipVH_QtMultimedia_112(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_112(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQMediaRecorderControl::setOutputLocation(const ::QUrl& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, sipName_QMediaRecorderControl, sipName_setOutputLocation);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_111(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QUrl&);

    return sipVH_QtMultimedia_111(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QUrl sipQMediaRecorderControl::outputLocation() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaRecorderControl, sipName_outputLocation);

    if (!sipMeth)
        return ::QUrl();

    extern ::QUrl sipVH_QtMultimedia_110(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_110(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQMediaRecorderControl::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QMediaRecorderControl::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaRecorderControl::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QMediaRecorderControl::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaRecorderControl::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QMediaRecorderControl::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaRecorderControl::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QMediaRecorderControl::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaRecorderControl::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QMediaRecorderControl::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQMediaRecorderControl::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QMediaRecorderControl::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQMediaRecorderControl::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QMediaRecorderControl::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QMediaRecorderControl_outputLocation, "outputLocation(self) -> QUrl");

extern "C" {static PyObject *meth_QMediaRecorderControl_outputLocation(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorderControl_outputLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaRecorderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorderControl, &sipCpp))
        {
            ::QUrl*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaRecorderControl, sipName_outputLocation);
                return SIP_NULLPTR;
            }

            sipRes = new ::QUrl(sipCpp->outputLocation());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorderControl, sipName_outputLocation, doc_QMediaRecorderControl_outputLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorderControl_setOutputLocation, "setOutputLocation(self, location: QUrl) -> bool");

extern "C" {static PyObject *meth_QMediaRecorderControl_setOutputLocation(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorderControl_setOutputLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QUrl* a0;
        ::QMediaRecorderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QMediaRecorderControl, &sipCpp, sipType_QUrl, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaRecorderControl, sipName_setOutputLocation);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->setOutputLocation(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorderControl, sipName_setOutputLocation, doc_QMediaRecorderControl_setOutputLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorderControl_state, "state(self) -> QMediaRecorder.State");

extern "C" {static PyObject *meth_QMediaRecorderControl_state(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorderControl_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaRecorderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorderControl, &sipCpp))
        {
            ::QMediaRecorder::State sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaRecorderControl, sipName_state);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaRecorder_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorderControl, sipName_state, doc_QMediaRecorderControl_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorderControl_status, "status(self) -> QMediaRecorder.Status");

extern "C" {static PyObject *meth_QMediaRecorderControl_status(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorderControl_status(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaRecorderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorderControl, &sipCpp))
        {
            ::QMediaRecorder::Status sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaRecorderControl, sipName_status);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->status();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaRecorder_Status);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorderControl, sipName_status, doc_QMediaRecorderControl_status);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorderControl_duration, "duration(self) -> int");

extern "C" {static PyObject *meth_QMediaRecorderControl_duration(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorderControl_duration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaRecorderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorderControl, &sipCpp))
        {
            ::qint64 sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaRecorderControl, sipName_duration);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->duration();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorderControl, sipName_duration, doc_QMediaRecorderControl_duration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorderControl_isMuted, "isMuted(self) -> bool");

extern "C" {static PyObject *meth_QMediaRecorderControl_isMuted(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorderControl_isMuted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaRecorderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorderControl, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaRecorderControl, sipName_isMuted);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isMuted();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorderControl, sipName_isMuted, doc_QMediaRecorderControl_isMuted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorderControl_volume, "volume(self) -> float");

extern "C" {static PyObject *meth_QMediaRecorderControl_volume(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorderControl_volume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaRecorderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorderControl, &sipCpp))
        {
            ::qreal sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaRecorderControl, sipName_volume);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->volume();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorderControl, sipName_volume, doc_QMediaRecorderControl_volume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorderControl_applySettings, "applySettings(self)");

extern "C" {static PyObject *meth_QMediaRecorderControl_applySettings(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorderControl_applySettings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QMediaRecorderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaRecorderControl, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaRecorderControl, sipName_applySettings);
                return SIP_NULLPTR;
            }

            sipCpp->applySettings();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorderControl, sipName_applySettings, doc_QMediaRecorderControl_applySettings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorderControl_setState, "setState(self, state: QMediaRecorder.State)");

extern "C" {static PyObject *meth_QMediaRecorderControl_setState(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorderControl_setState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QMediaRecorder::State a0;
        ::QMediaRecorderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QMediaRecorderControl, &sipCpp, sipType_QMediaRecorder_State, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaRecorderControl, sipName_setState);
                return SIP_NULLPTR;
            }

            sipCpp->setState(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorderControl, sipName_setState, doc_QMediaRecorderControl_setState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorderControl_setMuted, "setMuted(self, muted: bool)");

extern "C" {static PyObject *meth_QMediaRecorderControl_setMuted(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorderControl_setMuted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        bool a0;
        ::QMediaRecorderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QMediaRecorderControl, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaRecorderControl, sipName_setMuted);
                return SIP_NULLPTR;
            }

            sipCpp->setMuted(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorderControl, sipName_setMuted, doc_QMediaRecorderControl_setMuted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaRecorderControl_setVolume, "setVolume(self, volume: float)");

extern "C" {static PyObject *meth_QMediaRecorderControl_setVolume(PyObject *, PyObject *);}
static PyObject *meth_QMediaRecorderControl_setVolume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::qreal a0;
        ::QMediaRecorderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QMediaRecorderControl, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaRecorderControl, sipName_setVolume);
                return SIP_NULLPTR;
            }

            sipCpp->setVolume(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaRecorderControl, sipName_setVolume, doc_QMediaRecorderControl_setVolume);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QMediaRecorderControl(void *, const sipTypeDef *);}
static void *cast_QMediaRecorderControl(void *sipCppV, const sipTypeDef *targetType)
{
    ::QMediaRecorderControl *sipCpp = reinterpret_cast< ::QMediaRecorderControl *>(sipCppV);

    if (targetType == sipType_QMediaRecorderControl)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaControl)->ctd_cast(static_cast< ::QMediaControl *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QMediaRecorderControl(void *, int);}
static void release_QMediaRecorderControl(void *sipCppV, int)
{
    ::QMediaRecorderControl *sipCpp = reinterpret_cast< ::QMediaRecorderControl *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QMediaRecorderControl(sipSimpleWrapper *);}
static void dealloc_QMediaRecorderControl(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQMediaRecorderControl *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QMediaRecorderControl(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QMediaRecorderControl(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QMediaRecorderControl(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQMediaRecorderControl *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQMediaRecorderControl(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QMediaRecorderControl[] = {{104, 255, 1}};


static PyMethodDef methods_QMediaRecorderControl[] = {
    {sipName_applySettings, meth_QMediaRecorderControl_applySettings, METH_VARARGS, doc_QMediaRecorderControl_applySettings},
    {sipName_duration, meth_QMediaRecorderControl_duration, METH_VARARGS, doc_QMediaRecorderControl_duration},
    {sipName_isMuted, meth_QMediaRecorderControl_isMuted, METH_VARARGS, doc_QMediaRecorderControl_isMuted},
    {sipName_outputLocation, meth_QMediaRecorderControl_outputLocation, METH_VARARGS, doc_QMediaRecorderControl_outputLocation},
    {sipName_setMuted, meth_QMediaRecorderControl_setMuted, METH_VARARGS, doc_QMediaRecorderControl_setMuted},
    {sipName_setOutputLocation, meth_QMediaRecorderControl_setOutputLocation, METH_VARARGS, doc_QMediaRecorderControl_setOutputLocation},
    {sipName_setState, meth_QMediaRecorderControl_setState, METH_VARARGS, doc_QMediaRecorderControl_setState},
    {sipName_setVolume, meth_QMediaRecorderControl_setVolume, METH_VARARGS, doc_QMediaRecorderControl_setVolume},
    {sipName_state, meth_QMediaRecorderControl_state, METH_VARARGS, doc_QMediaRecorderControl_state},
    {sipName_status, meth_QMediaRecorderControl_status, METH_VARARGS, doc_QMediaRecorderControl_status},
    {sipName_volume, meth_QMediaRecorderControl_volume, METH_VARARGS, doc_QMediaRecorderControl_volume}
};

PyDoc_STRVAR(doc_QMediaRecorderControl, "\1QMediaRecorderControl(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QMediaRecorderControl[] = {
    {"error(int,QString)", "\1error(self, error: int, errorString: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"actualLocationChanged(QUrl)", "\1actualLocationChanged(self, location: QUrl)", SIP_NULLPTR, SIP_NULLPTR},
    {"volumeChanged(qreal)", "\1volumeChanged(self, volume: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"mutedChanged(bool)", "\1mutedChanged(self, muted: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"durationChanged(qint64)", "\1durationChanged(self, position: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"statusChanged(QMediaRecorder::Status)", "\1statusChanged(self, status: QMediaRecorder.Status)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QMediaRecorder::State)", "\1stateChanged(self, state: QMediaRecorder.State)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QMediaRecorderControl = {
    &::QMediaRecorderControl::staticMetaObject,
    0,
    signals_QMediaRecorderControl,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QMediaRecorderControl = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QMediaRecorderControl,
        SIP_NULLPTR,
        &plugin_QMediaRecorderControl,
    },
    {
        sipNameNr_QMediaRecorderControl,
        {0, 0, 1},
        11, methods_QMediaRecorderControl,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QMediaRecorderControl,
    -1,
    -1,
    supers_QMediaRecorderControl,
    SIP_NULLPTR,
    init_type_QMediaRecorderControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QMediaRecorderControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QMediaRecorderControl,
    cast_QMediaRecorderControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QMediaRecorderControl),
};
