/*
 * Module code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtSerialPort.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSerialPort/sipQtSerialPortcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSerialPort/qserialport.sip"
#include <qserialport.h>
#line 32 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSerialPort/sipQtSerialPortcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 35 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSerialPort/sipQtSerialPortcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSerialPort/sipQtSerialPortcmodule.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSerialPort/sipQtSerialPortcmodule.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSerialPort/sipQtSerialPortcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSerialPort/sipQtSerialPortcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSerialPort/qserialport.sip"
#include <qserialport.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSerialPort/sipQtSerialPortcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSerialPort/qserialport.sip"
#include <qserialport.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSerialPort/sipQtSerialPortcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSerialPort/qserialportinfo.sip"
#include <qserialportinfo.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSerialPort/sipQtSerialPortcmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtSerialPort[] = {
    'S', 'e', 'c', 'o', 'n', 'd', 'a', 'r', 'y', 'T', 'r', 'a', 'n', 's', 'm', 'i', 't', 't', 'e', 'd', 'D', 'a', 't', 'a', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    's', 'e', 't', 't', 'i', 'n', 'g', 's', 'R', 'e', 's', 't', 'o', 'r', 'e', 'd', 'O', 'n', 'C', 'l', 'o', 's', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', ':', ':', 'D', 'a', 't', 'a', 'E', 'r', 'r', 'o', 'r', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'Q', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', ':', ':', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'S', 'e', 'c', 'o', 'n', 'd', 'a', 'r', 'y', 'R', 'e', 'c', 'e', 'i', 'v', 'e', 'd', 'D', 'a', 't', 'a', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    'Q', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', ':', ':', 'P', 'i', 'n', 'o', 'u', 't', 'S', 'i', 'g', 'n', 'a', 'l', 's', 0,
    's', 'e', 't', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'R', 'e', 's', 't', 'o', 'r', 'e', 'd', 'O', 'n', 'C', 'l', 'o', 's', 'e', 0,
    'Q', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', ':', ':', 'P', 'i', 'n', 'o', 'u', 't', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    'U', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', ':', ':', 'F', 'l', 'o', 'w', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'd', 'a', 't', 'a', 'T', 'e', 'r', 'm', 'i', 'n', 'a', 'l', 'R', 'e', 'a', 'd', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'D', 'a', 't', 'a', 'C', 'a', 'r', 'r', 'i', 'e', 'r', 'D', 'e', 't', 'e', 'c', 't', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    'D', 'a', 't', 'a', 'T', 'e', 'r', 'm', 'i', 'n', 'a', 'l', 'R', 'e', 'a', 'd', 'y', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    'Q', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', ':', ':', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 't', 'i', 'n', 'g', 's', 'R', 'e', 's', 't', 'o', 'r', 'e', 'd', 'O', 'n', 'C', 'l', 'o', 's', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', 'I', 'n', 'f', 'o', '>', 0,
    'Q', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', ':', ':', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'd', 'a', 't', 'a', 'E', 'r', 'r', 'o', 'r', 'P', 'o', 'l', 'i', 'c', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', ':', ':', 'B', 'a', 'u', 'd', 'R', 'a', 't', 'e', 0,
    'Q', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', ':', ':', 'D', 'a', 't', 'a', 'B', 'i', 't', 's', 0,
    'Q', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', ':', ':', 'S', 't', 'o', 'p', 'B', 'i', 't', 's', 0,
    'h', 'a', 's', 'P', 'r', 'o', 'd', 'u', 'c', 't', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'T', 'o', 'S', 'e', 'n', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 'T', 'e', 'r', 'm', 'i', 'n', 'a', 'l', 'R', 'e', 'a', 'd', 'y', 0,
    'B', 'r', 'e', 'a', 'k', 'C', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'D', 'e', 'v', 'i', 'c', 'e', 'N', 'o', 't', 'F', 'o', 'u', 'n', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', ':', ':', 'P', 'a', 'r', 'i', 't', 'y', 0,
    'R', 'e', 'q', 'u', 'e', 's', 't', 'T', 'o', 'S', 'e', 'n', 'd', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    'R', 'i', 'n', 'g', 'I', 'n', 'd', 'i', 'c', 'a', 't', 'o', 'r', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    'S', 't', 'o', 'p', 'R', 'e', 'c', 'e', 'i', 'v', 'i', 'n', 'g', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'b', 'r', 'e', 'a', 'k', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'h', 'a', 's', 'V', 'e', 'n', 'd', 'o', 'r', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    'i', 's', 'D', 'a', 't', 'a', 'T', 'e', 'r', 'm', 'i', 'n', 'a', 'l', 'R', 'e', 'a', 'd', 'y', 0,
    'w', 'a', 'i', 't', 'F', 'o', 'r', 'B', 'y', 't', 'e', 's', 'W', 'r', 'i', 't', 't', 'e', 'n', 0,
    'D', 'a', 't', 'a', 'S', 'e', 't', 'R', 'e', 'a', 'd', 'y', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'F', 'l', 'o', 'w', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'f', 'l', 'o', 'w', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 'E', 'r', 'r', 'o', 'r', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'C', 'l', 'e', 'a', 'r', 'T', 'o', 'S', 'e', 'n', 'd', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    'p', 'r', 'o', 'd', 'u', 'c', 't', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    's', 'e', 't', 'R', 'e', 'a', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    's', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'B', 'a', 'u', 'd', 'R', 'a', 't', 'e', 's', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    's', 'e', 't', 'R', 'e', 'q', 'u', 'e', 's', 't', 'T', 'o', 'S', 'e', 'n', 'd', 0,
    'v', 'e', 'n', 'd', 'o', 'r', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    'w', 'a', 'i', 't', 'F', 'o', 'r', 'R', 'e', 'a', 'd', 'y', 'R', 'e', 'a', 'd', 0,
    'H', 'a', 'r', 'd', 'w', 'a', 'r', 'e', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'P', 'e', 'r', 'm', 'i', 's', 's', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', 'I', 'n', 'f', 'o', 0,
    'S', 'o', 'f', 't', 'w', 'a', 'r', 'e', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'D', 'a', 't', 'a', 'B', 'i', 't', 's', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'S', 't', 'o', 'p', 'B', 'i', 't', 's', 0,
    'b', 'a', 'u', 'd', 'R', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'a', 't', 'a', 'B', 'i', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'a', 't', 'a', 'E', 'r', 'r', 'o', 'r', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'i', 's', 'R', 'e', 'q', 'u', 'e', 's', 't', 'T', 'o', 'S', 'e', 'n', 'd', 0,
    's', 'e', 't', 'B', 'r', 'e', 'a', 'k', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 't', 'o', 'p', 'B', 'i', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'O', 'n', 'e', 'A', 'n', 'd', 'H', 'a', 'l', 'f', 'S', 't', 'o', 'p', 0,
    'P', 'a', 's', 's', 'Z', 'e', 'r', 'o', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'P', 'o', 'r', 't', 's', 0,
    'b', 'y', 't', 'e', 's', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'B', 'r', 'e', 'a', 'k', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'r', 'e', 'a', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'F', 'l', 'o', 'w', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    's', 'y', 's', 't', 'e', 'm', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'A', 'l', 'l', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 's', 0,
    'N', 'o', 'F', 'l', 'o', 'w', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'P', 'a', 'r', 'i', 't', 'y', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'e', 'r', 'r', 'o', 'r', 'O', 'c', 'c', 'u', 'r', 'r', 'e', 'd', 0,
    'p', 'a', 'r', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'i', 'n', 'o', 'u', 't', 'S', 'i', 'g', 'n', 'a', 'l', 's', 0,
    'F', 'r', 'a', 'm', 'i', 'n', 'g', 'E', 'r', 'r', 'o', 'r', 0,
    'I', 'g', 'n', 'o', 'r', 'e', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'N', 'o', 't', 'O', 'p', 'e', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'T', 'i', 'm', 'e', 'o', 'u', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'b', 'y', 't', 'e', 's', 'T', 'o', 'W', 'r', 'i', 't', 'e', 0,
    'i', 's', 'S', 'e', 'q', 'u', 'e', 'n', 't', 'i', 'a', 'l', 0,
    'm', 'a', 'n', 'u', 'f', 'a', 'c', 't', 'u', 'r', 'e', 'r', 0,
    'r', 'e', 'a', 'd', 'L', 'i', 'n', 'e', 'D', 'a', 't', 'a', 0,
    's', 'e', 'r', 'i', 'a', 'l', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'P', 'a', 'r', 'i', 't', 'y', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'S', 'e', 'r', 'i', 'a', 'l', 'P', 'o', 'r', 't', 0,
    'S', 'p', 'a', 'c', 'e', 'P', 'a', 'r', 'i', 't', 'y', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'B', 'a', 'u', 'd', 0,
    'c', 'a', 'n', 'R', 'e', 'a', 'd', 'L', 'i', 'n', 'e', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'f', 'l', 'o', 'w', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    's', 'e', 't', 'B', 'a', 'u', 'd', 'R', 'a', 't', 'e', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 'B', 'i', 't', 's', 0,
    's', 'e', 't', 'P', 'o', 'r', 't', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'S', 't', 'o', 'p', 'B', 'i', 't', 's', 0,
    'B', 'a', 'u', 'd', '1', '1', '5', '2', '0', '0', 0,
    'E', 'v', 'e', 'n', 'P', 'a', 'r', 'i', 't', 'y', 0,
    'M', 'a', 'r', 'k', 'P', 'a', 'r', 'i', 't', 'y', 0,
    'S', 'k', 'i', 'p', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'W', 'r', 'i', 't', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    '_', '_', 'i', 'n', 'v', 'e', 'r', 't', '_', '_', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'l', 'e', 'a', 'r', 'E', 'r', 'r', 'o', 'r', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'B', 'a', 'u', 'd', '1', '9', '2', '0', '0', 0,
    'B', 'a', 'u', 'd', '3', '8', '4', '0', '0', 0,
    'B', 'a', 'u', 'd', '5', '7', '6', '0', '0', 0,
    'O', 'd', 'd', 'P', 'a', 'r', 'i', 't', 'y', 0,
    'R', 'e', 'a', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    '_', '_', 'i', 'n', 'd', 'e', 'x', '_', '_', 0,
    's', 'e', 'n', 'd', 'B', 'r', 'e', 'a', 'k', 0,
    's', 'e', 't', 'P', 'a', 'r', 'i', 't', 'y', 0,
    'w', 'r', 'i', 't', 'e', 'D', 'a', 't', 'a', 0,
    'B', 'a', 'u', 'd', '1', '2', '0', '0', 0,
    'B', 'a', 'u', 'd', '2', '4', '0', '0', 0,
    'B', 'a', 'u', 'd', '4', '8', '0', '0', 0,
    'B', 'a', 'u', 'd', '9', '6', '0', '0', 0,
    'N', 'o', 'P', 'a', 'r', 'i', 't', 'y', 0,
    'N', 'o', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    'b', 'a', 'u', 'd', 'R', 'a', 't', 'e', 0,
    'd', 'a', 't', 'a', 'B', 'i', 't', 's', 0,
    'd', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'p', 'o', 'r', 't', 'N', 'a', 'm', 'e', 0,
    'r', 'e', 'a', 'd', 'D', 'a', 't', 'a', 0,
    's', 't', 'o', 'p', 'B', 'i', 't', 's', 0,
    'N', 'o', 'E', 'r', 'r', 'o', 'r', 0,
    'O', 'n', 'e', 'S', 't', 'o', 'p', 0,
    'T', 'w', 'o', 'S', 't', 'o', 'p', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    's', 'e', 't', 'P', 'o', 'r', 't', 0,
    'O', 'u', 't', 'p', 'u', 't', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    'h', 'a', 'n', 'd', 'l', 'e', 0,
    'i', 's', 'B', 'u', 's', 'y', 0,
    'i', 's', 'N', 'u', 'l', 'l', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'p', 'a', 'r', 'i', 't', 'y', 0,
    'p', 'o', 'l', 'i', 'c', 'y', 0,
    'D', 'a', 't', 'a', '5', 0,
    'D', 'a', 't', 'a', '6', 0,
    'D', 'a', 't', 'a', '7', 0,
    'D', 'a', 't', 'a', '8', 0,
    'I', 'n', 'p', 'u', 't', 0,
    'a', 't', 'E', 'n', 'd', 0,
    'c', 'l', 'e', 'a', 'r', 0,
    'c', 'l', 'o', 's', 'e', 0,
    'e', 'r', 'r', 'o', 'r', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'f', 'l', 'u', 's', 'h', 0,
    'm', 's', 'e', 'c', 's', 0,
    'r', 'e', 's', 'e', 't', 0,
    'o', 'p', 'e', 'n', 0,
    's', 'e', 'e', 'k', 0,
    's', 'i', 'z', 'e', 0,
    's', 'w', 'a', 'p', 0,
    'd', 'i', 'r', 0,
    'p', 'o', 's', 0,
};

void sipVH_QtSerialPort_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}

void sipVH_QtSerialPort_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtSerialPort_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtSerialPort_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

bool sipVH_QtSerialPort_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSerialPort_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSerialPort_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QIODevice::OpenMode a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QIODevice::OpenMode(a0), sipType_QIODevice_OpenMode, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtSerialPort_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

bool sipVH_QtSerialPort_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::qint64 a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "n", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::qint64 sipVH_QtSerialPort_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::qint64 sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "n", &sipRes);

    return sipRes;
}

bool sipVH_QtSerialPort_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSerialPort_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::qint64 sipVH_QtSerialPort_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, char*a0, ::qint64 a1)
{
    ::qint64 sipRes = 0;
    int sipIsErr = 0;

#line 206 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qiodevice.sip"
        PyObject *result = sipCallMethod(&sipIsErr, sipMethod, "n", a1);
        
        if (result != NULL)
        {
            PyObject *buf;
        
            sipParseResult(&sipIsErr, sipMethod, result, "O", &buf);
        
            if (buf == Py_None)
                sipRes = -1L;
            else if (!SIPBytes_Check(buf))
            {
                sipBadCatcherResult(sipMethod);
                sipIsErr = 1;
            }
            else
            {
                memcpy(a0, SIPBytes_AsString(buf), SIPBytes_Size(buf));
                sipRes = SIPBytes_Size(buf);
            }
        
            Py_DECREF(buf);
            Py_DECREF(result);
        }
#line 359 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSerialPort/sipQtSerialPortcmodule.cpp"

    Py_DECREF(sipMethod);

    if (sipIsErr)
        sipCallErrorHandler(sipErrorHandler, sipPySelf, sipGILState);

    SIP_RELEASE_GIL(sipGILState)

    return sipRes;
}

::qint64 sipVH_QtSerialPort_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, char*a0, ::qint64 a1)
{
    ::qint64 sipRes = 0;
    int sipIsErr = 0;

#line 271 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qiodevice.sip"
        PyObject *result = sipCallMethod(&sipIsErr, sipMethod, "n", a1);
        
        if (result != NULL)
        {
            PyObject *buf;
        
            sipParseResult(&sipIsErr, sipMethod, result, "O", &buf);
        
            if (buf == Py_None)
                sipRes = -1L;
            else if (!SIPBytes_Check(buf))
            {
                sipBadCatcherResult(sipMethod);
                sipIsErr = 1;
            }
            else
            {
                memcpy(a0, SIPBytes_AsString(buf), SIPBytes_Size(buf));
                sipRes = SIPBytes_Size(buf);
            }
        
            Py_DECREF(buf);
            Py_DECREF(result);
        }
#line 401 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSerialPort/sipQtSerialPortcmodule.cpp"

    Py_DECREF(sipMethod);

    if (sipIsErr)
        sipCallErrorHandler(sipErrorHandler, sipPySelf, sipGILState);

    SIP_RELEASE_GIL(sipGILState)

    return sipRes;
}

::qint64 sipVH_QtSerialPort_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const char*a0, long long a1)
{
    ::qint64 sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "g", a0, (Py_ssize_t)a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "n", &sipRes);

    return sipRes;
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QSerialPort(void **);}
static const sipTypeDef *sipSubClass_QSerialPort(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 32 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSerialPort/qserialport.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
        {sipName_QSerialPort, &sipType_QSerialPort, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 457 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSerialPort/sipQtSerialPortcmodule.cpp"

    return sipType;
}


extern "C" {static PyObject *slot_QSerialPort_PinoutSignal___or__(PyObject *, PyObject *);}
static PyObject *slot_QSerialPort_PinoutSignal___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSerialPort::PinoutSignal a0;
        ::QSerialPort::PinoutSignals* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSerialPort_PinoutSignal, &a0, sipType_QSerialPort_PinoutSignals, &a1, &a1State))
        {
            ::QSerialPort::PinoutSignals*sipRes;

            sipRes = new ::QSerialPort::PinoutSignals((a0 | *a1));
            sipReleaseType(a1, sipType_QSerialPort_PinoutSignals, a1State);

            return sipConvertFromNewType(sipRes, sipType_QSerialPort_PinoutSignals, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSerialPort_PinoutSignal[] = {
    {(void *)slot_QSerialPort_PinoutSignal___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QSerialPort_Direction___or__(PyObject *, PyObject *);}
static PyObject *slot_QSerialPort_Direction___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSerialPort::Direction a0;
        ::QSerialPort::Directions* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSerialPort_Direction, &a0, sipType_QSerialPort_Directions, &a1, &a1State))
        {
            ::QSerialPort::Directions*sipRes;

            sipRes = new ::QSerialPort::Directions((a0 | *a1));
            sipReleaseType(a1, sipType_QSerialPort_Directions, a1State);

            return sipConvertFromNewType(sipRes, sipType_QSerialPort_Directions, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSerialPort_Direction[] = {
    {(void *)slot_QSerialPort_Direction___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};

static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSerialPort__BaudRate, SIP_NULLPTR, 0}, sipNameNr_BaudRate, 1, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSerialPort__DataBits, SIP_NULLPTR, 0}, sipNameNr_DataBits, 1, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSerialPort__DataErrorPolicy, SIP_NULLPTR, 0}, sipNameNr_DataErrorPolicy, 1, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSerialPort__Direction, SIP_NULLPTR, 0}, sipNameNr_Direction, 1, slots_QSerialPort_Direction},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSerialPort__FlowControl, SIP_NULLPTR, 0}, sipNameNr_FlowControl, 1, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSerialPort__Parity, SIP_NULLPTR, 0}, sipNameNr_Parity, 1, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSerialPort__PinoutSignal, SIP_NULLPTR, 0}, sipNameNr_PinoutSignal, 1, slots_QSerialPort_PinoutSignal},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSerialPort__SerialPortError, SIP_NULLPTR, 0}, sipNameNr_SerialPortError, 1, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSerialPort__StopBits, SIP_NULLPTR, 0}, sipNameNr_StopBits, 1, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtSerialPort[] = {
    &sipTypeDef_QtSerialPort_QList_0100QSerialPortInfo.mtd_base,
    &sipTypeDef_QtSerialPort_QSerialPort.ctd_base,
    &enumTypes[0].etd_base,
    &enumTypes[1].etd_base,
    &enumTypes[2].etd_base,
    &enumTypes[3].etd_base,
    &sipTypeDef_QtSerialPort_QSerialPort_Directions.ctd_base,
    &enumTypes[4].etd_base,
    &enumTypes[5].etd_base,
    &enumTypes[6].etd_base,
    &sipTypeDef_QtSerialPort_QSerialPort_PinoutSignals.ctd_base,
    &enumTypes[7].etd_base,
    &enumTypes[8].etd_base,
    &sipTypeDef_QtSerialPort_QSerialPortInfo.ctd_base,
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtSerialPort_QtCore[] = {
    {"QChildEvent"},
    {"QEvent"},
    {"QIODevice"},
    {"QIODevice::OpenMode"},
    {"QList<int>"},
    {"QMetaMethod"},
    {"QObject"},
    {"QString"},
    {"QTimerEvent"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtSerialPort_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_QtSerialPort_QtCore, sipImportedVirtErrorHandlers_QtSerialPort_QtCore, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QSerialPort, {6, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtSerialPort = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_QtSerialPort,
    0,
    sipStrings_QtSerialPort,
    importsTable,
    SIP_NULLPTR,
    14,
    sipExportedTypes_QtSerialPort,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtSerialPort;

sip_qt_metaobject_func sip_QtSerialPort_qt_metaobject;
sip_qt_metacall_func sip_QtSerialPort_qt_metacall;
sip_qt_metacast_func sip_QtSerialPort_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtSerialPort()
#else
PyMODINIT_FUNC PyInit_QtSerialPort()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.QtSerialPort",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtSerialPort = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_QtSerialPort == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtSerialPort, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtSerialPort_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtSerialPort_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtSerialPort_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtSerialPort_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtSerialPort, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    return sipModule;
}
