/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKitWidgets.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 378 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPageViewportAttributes.cpp"

#line 103 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 35 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPageViewportAttributes.cpp"


PyDoc_STRVAR(doc_QWebPage_ViewportAttributes_initialScaleFactor, "initialScaleFactor(self) -> float");

extern "C" {static PyObject *meth_QWebPage_ViewportAttributes_initialScaleFactor(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_ViewportAttributes_initialScaleFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage::ViewportAttributes *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage_ViewportAttributes, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->initialScaleFactor();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_ViewportAttributes, sipName_initialScaleFactor, doc_QWebPage_ViewportAttributes_initialScaleFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_ViewportAttributes_minimumScaleFactor, "minimumScaleFactor(self) -> float");

extern "C" {static PyObject *meth_QWebPage_ViewportAttributes_minimumScaleFactor(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_ViewportAttributes_minimumScaleFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage::ViewportAttributes *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage_ViewportAttributes, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->minimumScaleFactor();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_ViewportAttributes, sipName_minimumScaleFactor, doc_QWebPage_ViewportAttributes_minimumScaleFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_ViewportAttributes_maximumScaleFactor, "maximumScaleFactor(self) -> float");

extern "C" {static PyObject *meth_QWebPage_ViewportAttributes_maximumScaleFactor(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_ViewportAttributes_maximumScaleFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage::ViewportAttributes *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage_ViewportAttributes, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->maximumScaleFactor();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_ViewportAttributes, sipName_maximumScaleFactor, doc_QWebPage_ViewportAttributes_maximumScaleFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_ViewportAttributes_devicePixelRatio, "devicePixelRatio(self) -> float");

extern "C" {static PyObject *meth_QWebPage_ViewportAttributes_devicePixelRatio(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_ViewportAttributes_devicePixelRatio(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage::ViewportAttributes *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage_ViewportAttributes, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->devicePixelRatio();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_ViewportAttributes, sipName_devicePixelRatio, doc_QWebPage_ViewportAttributes_devicePixelRatio);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_ViewportAttributes_isUserScalable, "isUserScalable(self) -> bool");

extern "C" {static PyObject *meth_QWebPage_ViewportAttributes_isUserScalable(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_ViewportAttributes_isUserScalable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage::ViewportAttributes *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage_ViewportAttributes, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isUserScalable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_ViewportAttributes, sipName_isUserScalable, doc_QWebPage_ViewportAttributes_isUserScalable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_ViewportAttributes_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QWebPage_ViewportAttributes_isValid(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_ViewportAttributes_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage::ViewportAttributes *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage_ViewportAttributes, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_ViewportAttributes, sipName_isValid, doc_QWebPage_ViewportAttributes_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_ViewportAttributes_size, "size(self) -> QSizeF");

extern "C" {static PyObject *meth_QWebPage_ViewportAttributes_size(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_ViewportAttributes_size(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage::ViewportAttributes *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage_ViewportAttributes, &sipCpp))
        {
            ::QSizeF*sipRes;

            sipRes = new ::QSizeF(sipCpp->size());

            return sipConvertFromNewType(sipRes, sipType_QSizeF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_ViewportAttributes, sipName_size, doc_QWebPage_ViewportAttributes_size);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebPage_ViewportAttributes(void *, int);}
static void release_QWebPage_ViewportAttributes(void *sipCppV, int)
{
    delete reinterpret_cast< ::QWebPage::ViewportAttributes *>(sipCppV);
}


extern "C" {static void *array_QWebPage_ViewportAttributes(Py_ssize_t);}
static void *array_QWebPage_ViewportAttributes(Py_ssize_t sipNrElem)
{
    return new ::QWebPage::ViewportAttributes[sipNrElem];
}


extern "C" {static void array_delete_QWebPage_ViewportAttributes(void *);}
static void array_delete_QWebPage_ViewportAttributes(void *sipCpp)
{
    delete[] reinterpret_cast< ::QWebPage::ViewportAttributes *>(sipCpp);
}


extern "C" {static void assign_QWebPage_ViewportAttributes(void *, Py_ssize_t, void *);}
static void assign_QWebPage_ViewportAttributes(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QWebPage::ViewportAttributes *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QWebPage::ViewportAttributes *>(sipSrc);
}


extern "C" {static void *copy_QWebPage_ViewportAttributes(const void *, Py_ssize_t);}
static void *copy_QWebPage_ViewportAttributes(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QWebPage::ViewportAttributes(reinterpret_cast<const ::QWebPage::ViewportAttributes *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QWebPage_ViewportAttributes(sipSimpleWrapper *);}
static void dealloc_QWebPage_ViewportAttributes(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWebPage_ViewportAttributes(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QWebPage_ViewportAttributes(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWebPage_ViewportAttributes(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QWebPage::ViewportAttributes *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QWebPage::ViewportAttributes();

            return sipCpp;
        }
    }

    {
        const ::QWebPage::ViewportAttributes* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QWebPage_ViewportAttributes, &a0))
        {
            sipCpp = new ::QWebPage::ViewportAttributes(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QWebPage_ViewportAttributes[] = {
    {sipName_devicePixelRatio, meth_QWebPage_ViewportAttributes_devicePixelRatio, METH_VARARGS, doc_QWebPage_ViewportAttributes_devicePixelRatio},
    {sipName_initialScaleFactor, meth_QWebPage_ViewportAttributes_initialScaleFactor, METH_VARARGS, doc_QWebPage_ViewportAttributes_initialScaleFactor},
    {sipName_isUserScalable, meth_QWebPage_ViewportAttributes_isUserScalable, METH_VARARGS, doc_QWebPage_ViewportAttributes_isUserScalable},
    {sipName_isValid, meth_QWebPage_ViewportAttributes_isValid, METH_VARARGS, doc_QWebPage_ViewportAttributes_isValid},
    {sipName_maximumScaleFactor, meth_QWebPage_ViewportAttributes_maximumScaleFactor, METH_VARARGS, doc_QWebPage_ViewportAttributes_maximumScaleFactor},
    {sipName_minimumScaleFactor, meth_QWebPage_ViewportAttributes_minimumScaleFactor, METH_VARARGS, doc_QWebPage_ViewportAttributes_minimumScaleFactor},
    {sipName_size, meth_QWebPage_ViewportAttributes_size, METH_VARARGS, doc_QWebPage_ViewportAttributes_size}
};

PyDoc_STRVAR(doc_QWebPage_ViewportAttributes, "\1QWebPage.ViewportAttributes()\n"
"QWebPage.ViewportAttributes(other: QWebPage.ViewportAttributes)");


static pyqt5ClassPluginDef plugin_QWebPage_ViewportAttributes = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebPage_ViewportAttributes = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebPage__ViewportAttributes,
        SIP_NULLPTR,
        &plugin_QWebPage_ViewportAttributes,
    },
    {
        sipNameNr_ViewportAttributes,
        {9, 255, 0},
        7, methods_QWebPage_ViewportAttributes,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWebPage_ViewportAttributes,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QWebPage_ViewportAttributes,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWebPage_ViewportAttributes,
    assign_QWebPage_ViewportAttributes,
    array_QWebPage_ViewportAttributes,
    copy_QWebPage_ViewportAttributes,
    release_QWebPage_ViewportAttributes,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QWebPage_ViewportAttributes,
    sizeof (::QWebPage::ViewportAttributes),
};
