/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qradiodatacontrol.sip"
#include <qradiodatacontrol.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qradiodata.sip"
#include <qradiodata.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioDataControl.cpp"


class sipQRadioDataControl : public ::QRadioDataControl
{
public:
    sipQRadioDataControl(::QObject*);
    virtual ~sipQRadioDataControl();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QString errorString() const SIP_OVERRIDE;
    ::QRadioData::Error error() const SIP_OVERRIDE;
    bool isAlternativeFrequenciesEnabled() const SIP_OVERRIDE;
    void setAlternativeFrequenciesEnabled(bool) SIP_OVERRIDE;
    ::QString radioText() const SIP_OVERRIDE;
    ::QString stationName() const SIP_OVERRIDE;
    ::QString programTypeName() const SIP_OVERRIDE;
    ::QRadioData::ProgramType programType() const SIP_OVERRIDE;
    ::QString stationId() const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQRadioDataControl(const sipQRadioDataControl &);
    sipQRadioDataControl &operator = (const sipQRadioDataControl &);

    char sipPyMethods[16];
};

sipQRadioDataControl::sipQRadioDataControl(::QObject*a0): ::QRadioDataControl(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQRadioDataControl::~sipQRadioDataControl()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQRadioDataControl::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QRadioDataControl);

    return ::QRadioDataControl::metaObject();
}

int sipQRadioDataControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QRadioDataControl::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QRadioDataControl, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQRadioDataControl::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QRadioDataControl, _clname, &sipCpp) ? sipCpp : ::QRadioDataControl::qt_metacast(_clname));
}

::QString sipQRadioDataControl::errorString() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioDataControl, sipName_errorString);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtMultimedia_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_22(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QRadioData::Error sipQRadioDataControl::error() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioDataControl, sipName_error);

    if (!sipMeth)
        return ::QRadioData::NoError;

    extern ::QRadioData::Error sipVH_QtMultimedia_124(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_124(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQRadioDataControl::isAlternativeFrequenciesEnabled() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioDataControl, sipName_isAlternativeFrequenciesEnabled);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_16(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQRadioDataControl::setAlternativeFrequenciesEnabled(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, sipName_QRadioDataControl, sipName_setAlternativeFrequenciesEnabled);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_106(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtMultimedia_106(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QString sipQRadioDataControl::radioText() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioDataControl, sipName_radioText);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtMultimedia_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_22(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QString sipQRadioDataControl::stationName() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioDataControl, sipName_stationName);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtMultimedia_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_22(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QString sipQRadioDataControl::programTypeName() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioDataControl, sipName_programTypeName);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtMultimedia_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_22(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QRadioData::ProgramType sipQRadioDataControl::programType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioDataControl, sipName_programType);

    if (!sipMeth)
        return ::QRadioData::Undefined;

    extern ::QRadioData::ProgramType sipVH_QtMultimedia_123(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_123(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QString sipQRadioDataControl::stationId() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioDataControl, sipName_stationId);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtMultimedia_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_22(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQRadioDataControl::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QRadioDataControl::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioDataControl::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QRadioDataControl::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioDataControl::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QRadioDataControl::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioDataControl::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QRadioDataControl::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioDataControl::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QRadioDataControl::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQRadioDataControl::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QRadioDataControl::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQRadioDataControl::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QRadioDataControl::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QRadioDataControl_stationId, "stationId(self) -> str");

extern "C" {static PyObject *meth_QRadioDataControl_stationId(PyObject *, PyObject *);}
static PyObject *meth_QRadioDataControl_stationId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioDataControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioDataControl, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioDataControl, sipName_stationId);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->stationId());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioDataControl, sipName_stationId, doc_QRadioDataControl_stationId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioDataControl_programType, "programType(self) -> QRadioData.ProgramType");

extern "C" {static PyObject *meth_QRadioDataControl_programType(PyObject *, PyObject *);}
static PyObject *meth_QRadioDataControl_programType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioDataControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioDataControl, &sipCpp))
        {
            ::QRadioData::ProgramType sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioDataControl, sipName_programType);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->programType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QRadioData_ProgramType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioDataControl, sipName_programType, doc_QRadioDataControl_programType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioDataControl_programTypeName, "programTypeName(self) -> str");

extern "C" {static PyObject *meth_QRadioDataControl_programTypeName(PyObject *, PyObject *);}
static PyObject *meth_QRadioDataControl_programTypeName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioDataControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioDataControl, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioDataControl, sipName_programTypeName);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->programTypeName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioDataControl, sipName_programTypeName, doc_QRadioDataControl_programTypeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioDataControl_stationName, "stationName(self) -> str");

extern "C" {static PyObject *meth_QRadioDataControl_stationName(PyObject *, PyObject *);}
static PyObject *meth_QRadioDataControl_stationName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioDataControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioDataControl, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioDataControl, sipName_stationName);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->stationName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioDataControl, sipName_stationName, doc_QRadioDataControl_stationName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioDataControl_radioText, "radioText(self) -> str");

extern "C" {static PyObject *meth_QRadioDataControl_radioText(PyObject *, PyObject *);}
static PyObject *meth_QRadioDataControl_radioText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioDataControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioDataControl, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioDataControl, sipName_radioText);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->radioText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioDataControl, sipName_radioText, doc_QRadioDataControl_radioText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioDataControl_setAlternativeFrequenciesEnabled, "setAlternativeFrequenciesEnabled(self, enabled: bool)");

extern "C" {static PyObject *meth_QRadioDataControl_setAlternativeFrequenciesEnabled(PyObject *, PyObject *);}
static PyObject *meth_QRadioDataControl_setAlternativeFrequenciesEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        bool a0;
        ::QRadioDataControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QRadioDataControl, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioDataControl, sipName_setAlternativeFrequenciesEnabled);
                return SIP_NULLPTR;
            }

            sipCpp->setAlternativeFrequenciesEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioDataControl, sipName_setAlternativeFrequenciesEnabled, doc_QRadioDataControl_setAlternativeFrequenciesEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioDataControl_isAlternativeFrequenciesEnabled, "isAlternativeFrequenciesEnabled(self) -> bool");

extern "C" {static PyObject *meth_QRadioDataControl_isAlternativeFrequenciesEnabled(PyObject *, PyObject *);}
static PyObject *meth_QRadioDataControl_isAlternativeFrequenciesEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioDataControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioDataControl, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioDataControl, sipName_isAlternativeFrequenciesEnabled);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isAlternativeFrequenciesEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioDataControl, sipName_isAlternativeFrequenciesEnabled, doc_QRadioDataControl_isAlternativeFrequenciesEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioDataControl_error, "error(self) -> QRadioData.Error");

extern "C" {static PyObject *meth_QRadioDataControl_error(PyObject *, PyObject *);}
static PyObject *meth_QRadioDataControl_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioDataControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioDataControl, &sipCpp))
        {
            ::QRadioData::Error sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioDataControl, sipName_error);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QRadioData_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioDataControl, sipName_error, doc_QRadioDataControl_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioDataControl_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QRadioDataControl_errorString(PyObject *, PyObject *);}
static PyObject *meth_QRadioDataControl_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioDataControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioDataControl, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioDataControl, sipName_errorString);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioDataControl, sipName_errorString, doc_QRadioDataControl_errorString);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QRadioDataControl(void *, const sipTypeDef *);}
static void *cast_QRadioDataControl(void *sipCppV, const sipTypeDef *targetType)
{
    ::QRadioDataControl *sipCpp = reinterpret_cast< ::QRadioDataControl *>(sipCppV);

    if (targetType == sipType_QRadioDataControl)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaControl)->ctd_cast(static_cast< ::QMediaControl *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QRadioDataControl(void *, int);}
static void release_QRadioDataControl(void *sipCppV, int)
{
    ::QRadioDataControl *sipCpp = reinterpret_cast< ::QRadioDataControl *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QRadioDataControl(sipSimpleWrapper *);}
static void dealloc_QRadioDataControl(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQRadioDataControl *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QRadioDataControl(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QRadioDataControl(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QRadioDataControl(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQRadioDataControl *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQRadioDataControl(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QRadioDataControl[] = {{104, 255, 1}};


static PyMethodDef methods_QRadioDataControl[] = {
    {sipName_error, meth_QRadioDataControl_error, METH_VARARGS, doc_QRadioDataControl_error},
    {sipName_errorString, meth_QRadioDataControl_errorString, METH_VARARGS, doc_QRadioDataControl_errorString},
    {sipName_isAlternativeFrequenciesEnabled, meth_QRadioDataControl_isAlternativeFrequenciesEnabled, METH_VARARGS, doc_QRadioDataControl_isAlternativeFrequenciesEnabled},
    {sipName_programType, meth_QRadioDataControl_programType, METH_VARARGS, doc_QRadioDataControl_programType},
    {sipName_programTypeName, meth_QRadioDataControl_programTypeName, METH_VARARGS, doc_QRadioDataControl_programTypeName},
    {sipName_radioText, meth_QRadioDataControl_radioText, METH_VARARGS, doc_QRadioDataControl_radioText},
    {sipName_setAlternativeFrequenciesEnabled, meth_QRadioDataControl_setAlternativeFrequenciesEnabled, METH_VARARGS, doc_QRadioDataControl_setAlternativeFrequenciesEnabled},
    {sipName_stationId, meth_QRadioDataControl_stationId, METH_VARARGS, doc_QRadioDataControl_stationId},
    {sipName_stationName, meth_QRadioDataControl_stationName, METH_VARARGS, doc_QRadioDataControl_stationName}
};

PyDoc_STRVAR(doc_QRadioDataControl, "\1QRadioDataControl(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QRadioDataControl[] = {
    {"alternativeFrequenciesEnabledChanged(bool)", "\1alternativeFrequenciesEnabledChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"radioTextChanged(QString)", "\1radioTextChanged(self, radioText: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"stationNameChanged(QString)", "\1stationNameChanged(self, stationName: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"programTypeNameChanged(QString)", "\1programTypeNameChanged(self, programTypeName: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"programTypeChanged(QRadioData::ProgramType)", "\1programTypeChanged(self, programType: QRadioData.ProgramType)", SIP_NULLPTR, SIP_NULLPTR},
    {"stationIdChanged(QString)", "\1stationIdChanged(self, stationId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QRadioData::Error)", "\1error(self, err: QRadioData.Error)", &methods_QRadioDataControl[0], SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QRadioDataControl = {
    &::QRadioDataControl::staticMetaObject,
    0,
    signals_QRadioDataControl,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QRadioDataControl = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QRadioDataControl,
        SIP_NULLPTR,
        &plugin_QRadioDataControl,
    },
    {
        sipNameNr_QRadioDataControl,
        {0, 0, 1},
        9, methods_QRadioDataControl,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QRadioDataControl,
    -1,
    -1,
    supers_QRadioDataControl,
    SIP_NULLPTR,
    init_type_QRadioDataControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QRadioDataControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QRadioDataControl,
    cast_QRadioDataControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QRadioDataControl),
};
