/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qsoundeffect.sip"
#include <qsoundeffect.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudiodeviceinfo.sip"
#include <qaudiodeviceinfo.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQSoundEffect.cpp"


class sipQSoundEffect : public ::QSoundEffect
{
public:
    sipQSoundEffect(::QObject*);
    sipQSoundEffect(const ::QAudioDeviceInfo&, ::QObject*);
    virtual ~sipQSoundEffect();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSoundEffect(const sipQSoundEffect &);
    sipQSoundEffect &operator = (const sipQSoundEffect &);

    char sipPyMethods[7];
};

sipQSoundEffect::sipQSoundEffect(::QObject*a0): ::QSoundEffect(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSoundEffect::sipQSoundEffect(const ::QAudioDeviceInfo& a0, ::QObject*a1): ::QSoundEffect(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSoundEffect::~sipQSoundEffect()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQSoundEffect::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QSoundEffect);

    return ::QSoundEffect::metaObject();
}

int sipQSoundEffect::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QSoundEffect::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QSoundEffect, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQSoundEffect::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QSoundEffect, _clname, &sipCpp) ? sipCpp : ::QSoundEffect::qt_metacast(_clname));
}

bool sipQSoundEffect::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QSoundEffect::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSoundEffect::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QSoundEffect::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQSoundEffect::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QSoundEffect::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSoundEffect::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QSoundEffect::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSoundEffect::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QSoundEffect::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSoundEffect::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QSoundEffect::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSoundEffect::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QSoundEffect::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QSoundEffect_supportedMimeTypes, "supportedMimeTypes() -> list[str]");

extern "C" {static PyObject *meth_QSoundEffect_supportedMimeTypes(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_supportedMimeTypes(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(::QSoundEffect::supportedMimeTypes());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_supportedMimeTypes, doc_QSoundEffect_supportedMimeTypes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_source, "source(self) -> QUrl");

extern "C" {static PyObject *meth_QSoundEffect_source(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_source(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSoundEffect, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->source());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_source, doc_QSoundEffect_source);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_setSource, "setSource(self, url: QUrl)");

extern "C" {static PyObject *meth_QSoundEffect_setSource(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_setSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSoundEffect, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setSource(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_setSource, doc_QSoundEffect_setSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_loopCount, "loopCount(self) -> int");

extern "C" {static PyObject *meth_QSoundEffect_loopCount(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_loopCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSoundEffect, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->loopCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_loopCount, doc_QSoundEffect_loopCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_loopsRemaining, "loopsRemaining(self) -> int");

extern "C" {static PyObject *meth_QSoundEffect_loopsRemaining(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_loopsRemaining(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSoundEffect, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->loopsRemaining();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_loopsRemaining, doc_QSoundEffect_loopsRemaining);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_setLoopCount, "setLoopCount(self, loopCount: int)");

extern "C" {static PyObject *meth_QSoundEffect_setLoopCount(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_setLoopCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSoundEffect, &sipCpp, &a0))
        {
            sipCpp->setLoopCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_setLoopCount, doc_QSoundEffect_setLoopCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_volume, "volume(self) -> float");

extern "C" {static PyObject *meth_QSoundEffect_volume(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_volume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSoundEffect, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->volume();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_volume, doc_QSoundEffect_volume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_setVolume, "setVolume(self, volume: float)");

extern "C" {static PyObject *meth_QSoundEffect_setVolume(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_setVolume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QSoundEffect, &sipCpp, &a0))
        {
            sipCpp->setVolume(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_setVolume, doc_QSoundEffect_setVolume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_isMuted, "isMuted(self) -> bool");

extern "C" {static PyObject *meth_QSoundEffect_isMuted(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_isMuted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSoundEffect, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isMuted();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_isMuted, doc_QSoundEffect_isMuted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_setMuted, "setMuted(self, muted: bool)");

extern "C" {static PyObject *meth_QSoundEffect_setMuted(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_setMuted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QSoundEffect, &sipCpp, &a0))
        {
            sipCpp->setMuted(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_setMuted, doc_QSoundEffect_setMuted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_isLoaded, "isLoaded(self) -> bool");

extern "C" {static PyObject *meth_QSoundEffect_isLoaded(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_isLoaded(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSoundEffect, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isLoaded();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_isLoaded, doc_QSoundEffect_isLoaded);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_isPlaying, "isPlaying(self) -> bool");

extern "C" {static PyObject *meth_QSoundEffect_isPlaying(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_isPlaying(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSoundEffect, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isPlaying();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_isPlaying, doc_QSoundEffect_isPlaying);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_status, "status(self) -> QSoundEffect.Status");

extern "C" {static PyObject *meth_QSoundEffect_status(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_status(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSoundEffect, &sipCpp))
        {
            ::QSoundEffect::Status sipRes;

            sipRes = sipCpp->status();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSoundEffect_Status);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_status, doc_QSoundEffect_status);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_category, "category(self) -> str");

extern "C" {static PyObject *meth_QSoundEffect_category(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_category(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSoundEffect, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->category());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_category, doc_QSoundEffect_category);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_setCategory, "setCategory(self, category: Optional[str])");

extern "C" {static PyObject *meth_QSoundEffect_setCategory(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_setCategory(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSoundEffect, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCategory(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_setCategory, doc_QSoundEffect_setCategory);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_play, "play(self)");

extern "C" {static PyObject *meth_QSoundEffect_play(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_play(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSoundEffect, &sipCpp))
        {
            sipCpp->play();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_play, doc_QSoundEffect_play);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSoundEffect_stop, "stop(self)");

extern "C" {static PyObject *meth_QSoundEffect_stop(PyObject *, PyObject *);}
static PyObject *meth_QSoundEffect_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSoundEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSoundEffect, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSoundEffect, sipName_stop, doc_QSoundEffect_stop);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSoundEffect(void *, const sipTypeDef *);}
static void *cast_QSoundEffect(void *sipCppV, const sipTypeDef *targetType)
{
    ::QSoundEffect *sipCpp = reinterpret_cast< ::QSoundEffect *>(sipCppV);

    if (targetType == sipType_QSoundEffect)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSoundEffect(void *, int);}
static void release_QSoundEffect(void *sipCppV, int)
{
    ::QSoundEffect *sipCpp = reinterpret_cast< ::QSoundEffect *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QSoundEffect(Py_ssize_t);}
static void *array_QSoundEffect(Py_ssize_t sipNrElem)
{
    return new ::QSoundEffect[sipNrElem];
}


extern "C" {static void array_delete_QSoundEffect(void *);}
static void array_delete_QSoundEffect(void *sipCpp)
{
    delete[] reinterpret_cast< ::QSoundEffect *>(sipCpp);
}


extern "C" {static void dealloc_QSoundEffect(sipSimpleWrapper *);}
static void dealloc_QSoundEffect(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSoundEffect *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSoundEffect(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSoundEffect(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSoundEffect(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQSoundEffect *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQSoundEffect(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QAudioDeviceInfo* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9|JH", sipType_QAudioDeviceInfo, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQSoundEffect(*a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSoundEffect[] = {{9, 0, 1}};


static PyMethodDef methods_QSoundEffect[] = {
    {sipName_category, meth_QSoundEffect_category, METH_VARARGS, doc_QSoundEffect_category},
    {sipName_isLoaded, meth_QSoundEffect_isLoaded, METH_VARARGS, doc_QSoundEffect_isLoaded},
    {sipName_isMuted, meth_QSoundEffect_isMuted, METH_VARARGS, doc_QSoundEffect_isMuted},
    {sipName_isPlaying, meth_QSoundEffect_isPlaying, METH_VARARGS, doc_QSoundEffect_isPlaying},
    {sipName_loopCount, meth_QSoundEffect_loopCount, METH_VARARGS, doc_QSoundEffect_loopCount},
    {sipName_loopsRemaining, meth_QSoundEffect_loopsRemaining, METH_VARARGS, doc_QSoundEffect_loopsRemaining},
    {sipName_play, meth_QSoundEffect_play, METH_VARARGS, doc_QSoundEffect_play},
    {sipName_setCategory, meth_QSoundEffect_setCategory, METH_VARARGS, doc_QSoundEffect_setCategory},
    {sipName_setLoopCount, meth_QSoundEffect_setLoopCount, METH_VARARGS, doc_QSoundEffect_setLoopCount},
    {sipName_setMuted, meth_QSoundEffect_setMuted, METH_VARARGS, doc_QSoundEffect_setMuted},
    {sipName_setSource, meth_QSoundEffect_setSource, METH_VARARGS, doc_QSoundEffect_setSource},
    {sipName_setVolume, meth_QSoundEffect_setVolume, METH_VARARGS, doc_QSoundEffect_setVolume},
    {sipName_source, meth_QSoundEffect_source, METH_VARARGS, doc_QSoundEffect_source},
    {sipName_status, meth_QSoundEffect_status, METH_VARARGS, doc_QSoundEffect_status},
    {sipName_stop, meth_QSoundEffect_stop, METH_VARARGS, doc_QSoundEffect_stop},
    {sipName_supportedMimeTypes, meth_QSoundEffect_supportedMimeTypes, METH_VARARGS, doc_QSoundEffect_supportedMimeTypes},
    {sipName_volume, meth_QSoundEffect_volume, METH_VARARGS, doc_QSoundEffect_volume}
};

static sipEnumMemberDef enummembers_QSoundEffect[] = {
    {sipName_Error, static_cast<int>(::QSoundEffect::Error), 153},
    {sipName_Infinite, static_cast<int>(::QSoundEffect::Infinite), 152},
    {sipName_Loading, static_cast<int>(::QSoundEffect::Loading), 153},
    {sipName_Null, static_cast<int>(::QSoundEffect::Null), 153},
    {sipName_Ready, static_cast<int>(::QSoundEffect::Ready), 153},
};

PyDoc_STRVAR(doc_QSoundEffect, "\1QSoundEffect(parent: Optional[QObject] = None)\n"
"QSoundEffect(audioDevice: QAudioDeviceInfo, parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QSoundEffect[] = {
    {"categoryChanged()", "\1categoryChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"statusChanged()", "\1statusChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"playingChanged()", "\1playingChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"loadedChanged()", "\1loadedChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"mutedChanged()", "\1mutedChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"volumeChanged()", "\1volumeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"loopsRemainingChanged()", "\1loopsRemainingChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"loopCountChanged()", "\1loopCountChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"sourceChanged()", "\1sourceChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QSoundEffect = {
    &::QSoundEffect::staticMetaObject,
    0,
    signals_QSoundEffect,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QSoundEffect = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSoundEffect,
        SIP_NULLPTR,
        &plugin_QSoundEffect,
    },
    {
        sipNameNr_QSoundEffect,
        {0, 0, 1},
        17, methods_QSoundEffect,
        5, enummembers_QSoundEffect,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSoundEffect,
    -1,
    -1,
    supers_QSoundEffect,
    SIP_NULLPTR,
    init_type_QSoundEffect,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSoundEffect,
    SIP_NULLPTR,
    array_QSoundEffect,
    SIP_NULLPTR,
    release_QSoundEffect,
    cast_QSoundEffect,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QSoundEffect,
    sizeof (::QSoundEffect),
};
