/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 94 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qdnslookup.sip"
#include <qdnslookup.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQDnsTextRecord.cpp"

#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQDnsTextRecord.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQDnsTextRecord.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQDnsTextRecord.cpp"


PyDoc_STRVAR(doc_QDnsTextRecord_swap, "swap(self, other: QDnsTextRecord)");

extern "C" {static PyObject *meth_QDnsTextRecord_swap(PyObject *, PyObject *);}
static PyObject *meth_QDnsTextRecord_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDnsTextRecord* a0;
        ::QDnsTextRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QDnsTextRecord, &sipCpp, sipType_QDnsTextRecord, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsTextRecord, sipName_swap, doc_QDnsTextRecord_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsTextRecord_name, "name(self) -> str");

extern "C" {static PyObject *meth_QDnsTextRecord_name(PyObject *, PyObject *);}
static PyObject *meth_QDnsTextRecord_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDnsTextRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsTextRecord, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsTextRecord, sipName_name, doc_QDnsTextRecord_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsTextRecord_timeToLive, "timeToLive(self) -> int");

extern "C" {static PyObject *meth_QDnsTextRecord_timeToLive(PyObject *, PyObject *);}
static PyObject *meth_QDnsTextRecord_timeToLive(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDnsTextRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsTextRecord, &sipCpp))
        {
            ::quint32 sipRes;

            sipRes = sipCpp->timeToLive();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsTextRecord, sipName_timeToLive, doc_QDnsTextRecord_timeToLive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDnsTextRecord_values, "values(self) -> list[QByteArray]");

extern "C" {static PyObject *meth_QDnsTextRecord_values(PyObject *, PyObject *);}
static PyObject *meth_QDnsTextRecord_values(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDnsTextRecord *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDnsTextRecord, &sipCpp))
        {
            QList< ::QByteArray>*sipRes;

            sipRes = new QList< ::QByteArray>(sipCpp->values());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDnsTextRecord, sipName_values, doc_QDnsTextRecord_values);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDnsTextRecord(void *, int);}
static void release_QDnsTextRecord(void *sipCppV, int)
{
    delete reinterpret_cast< ::QDnsTextRecord *>(sipCppV);
}


extern "C" {static void *array_QDnsTextRecord(Py_ssize_t);}
static void *array_QDnsTextRecord(Py_ssize_t sipNrElem)
{
    return new ::QDnsTextRecord[sipNrElem];
}


extern "C" {static void array_delete_QDnsTextRecord(void *);}
static void array_delete_QDnsTextRecord(void *sipCpp)
{
    delete[] reinterpret_cast< ::QDnsTextRecord *>(sipCpp);
}


extern "C" {static void assign_QDnsTextRecord(void *, Py_ssize_t, void *);}
static void assign_QDnsTextRecord(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QDnsTextRecord *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QDnsTextRecord *>(sipSrc);
}


extern "C" {static void *copy_QDnsTextRecord(const void *, Py_ssize_t);}
static void *copy_QDnsTextRecord(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QDnsTextRecord(reinterpret_cast<const ::QDnsTextRecord *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QDnsTextRecord(sipSimpleWrapper *);}
static void dealloc_QDnsTextRecord(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDnsTextRecord(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QDnsTextRecord(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDnsTextRecord(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QDnsTextRecord *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QDnsTextRecord();

            return sipCpp;
        }
    }

    {
        const ::QDnsTextRecord* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QDnsTextRecord, &a0))
        {
            sipCpp = new ::QDnsTextRecord(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QDnsTextRecord[] = {
    {sipName_name, meth_QDnsTextRecord_name, METH_VARARGS, doc_QDnsTextRecord_name},
    {sipName_swap, meth_QDnsTextRecord_swap, METH_VARARGS, doc_QDnsTextRecord_swap},
    {sipName_timeToLive, meth_QDnsTextRecord_timeToLive, METH_VARARGS, doc_QDnsTextRecord_timeToLive},
    {sipName_values, meth_QDnsTextRecord_values, METH_VARARGS, doc_QDnsTextRecord_values}
};

PyDoc_STRVAR(doc_QDnsTextRecord, "\1QDnsTextRecord()\n"
"QDnsTextRecord(other: QDnsTextRecord)");


static pyqt5ClassPluginDef plugin_QDnsTextRecord = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNetwork_QDnsTextRecord = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDnsTextRecord,
        SIP_NULLPTR,
        &plugin_QDnsTextRecord,
    },
    {
        sipNameNr_QDnsTextRecord,
        {0, 0, 1},
        4, methods_QDnsTextRecord,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDnsTextRecord,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QDnsTextRecord,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDnsTextRecord,
    assign_QDnsTextRecord,
    array_QDnsTextRecord,
    copy_QDnsTextRecord,
    release_QDnsTextRecord,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QDnsTextRecord,
    sizeof (::QDnsTextRecord),
};
