/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceattribute.sip"
#include <qplaceattribute.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceAttribute.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceAttribute.cpp"


class sipQPlaceAttribute : public ::QPlaceAttribute
{
public:
    sipQPlaceAttribute();
    sipQPlaceAttribute(const ::QPlaceAttribute&);
    ~sipQPlaceAttribute();

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPlaceAttribute(const sipQPlaceAttribute &);
    sipQPlaceAttribute &operator = (const sipQPlaceAttribute &);
};

sipQPlaceAttribute::sipQPlaceAttribute(): ::QPlaceAttribute(), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceAttribute::sipQPlaceAttribute(const ::QPlaceAttribute& a0): ::QPlaceAttribute(a0), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceAttribute::~sipQPlaceAttribute()
{
    sipInstanceDestroyedEx(&sipPySelf);
}


PyDoc_STRVAR(doc_QPlaceAttribute_label, "label(self) -> str");

extern "C" {static PyObject *meth_QPlaceAttribute_label(PyObject *, PyObject *);}
static PyObject *meth_QPlaceAttribute_label(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceAttribute, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->label());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceAttribute, sipName_label, doc_QPlaceAttribute_label);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceAttribute_setLabel, "setLabel(self, label: Optional[str])");

extern "C" {static PyObject *meth_QPlaceAttribute_setLabel(PyObject *, PyObject *);}
static PyObject *meth_QPlaceAttribute_setLabel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceAttribute, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setLabel(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceAttribute, sipName_setLabel, doc_QPlaceAttribute_setLabel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceAttribute_text, "text(self) -> str");

extern "C" {static PyObject *meth_QPlaceAttribute_text(PyObject *, PyObject *);}
static PyObject *meth_QPlaceAttribute_text(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceAttribute, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->text());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceAttribute, sipName_text, doc_QPlaceAttribute_text);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceAttribute_setText, "setText(self, text: Optional[str])");

extern "C" {static PyObject *meth_QPlaceAttribute_setText(PyObject *, PyObject *);}
static PyObject *meth_QPlaceAttribute_setText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceAttribute, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceAttribute, sipName_setText, doc_QPlaceAttribute_setText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceAttribute_isEmpty, "isEmpty(self) -> bool");

extern "C" {static PyObject *meth_QPlaceAttribute_isEmpty(PyObject *, PyObject *);}
static PyObject *meth_QPlaceAttribute_isEmpty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceAttribute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceAttribute, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEmpty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceAttribute, sipName_isEmpty, doc_QPlaceAttribute_isEmpty);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QPlaceAttribute___ne__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceAttribute___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceAttribute *sipCpp = reinterpret_cast< ::QPlaceAttribute *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceAttribute));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceAttribute* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceAttribute, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceAttribute::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, ne_slot, sipType_QPlaceAttribute, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QPlaceAttribute___eq__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceAttribute___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceAttribute *sipCpp = reinterpret_cast< ::QPlaceAttribute *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceAttribute));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceAttribute* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceAttribute, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceAttribute::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, eq_slot, sipType_QPlaceAttribute, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QPlaceAttribute(void *, int);}
static void release_QPlaceAttribute(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQPlaceAttribute *>(sipCppV);
    else
        delete reinterpret_cast< ::QPlaceAttribute *>(sipCppV);
}


extern "C" {static void *array_QPlaceAttribute(Py_ssize_t);}
static void *array_QPlaceAttribute(Py_ssize_t sipNrElem)
{
    return new ::QPlaceAttribute[sipNrElem];
}


extern "C" {static void array_delete_QPlaceAttribute(void *);}
static void array_delete_QPlaceAttribute(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPlaceAttribute *>(sipCpp);
}


extern "C" {static void assign_QPlaceAttribute(void *, Py_ssize_t, void *);}
static void assign_QPlaceAttribute(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPlaceAttribute *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPlaceAttribute *>(sipSrc);
}


extern "C" {static void *copy_QPlaceAttribute(const void *, Py_ssize_t);}
static void *copy_QPlaceAttribute(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPlaceAttribute(reinterpret_cast<const ::QPlaceAttribute *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPlaceAttribute(sipSimpleWrapper *);}
static void dealloc_QPlaceAttribute(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPlaceAttribute *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPlaceAttribute(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPlaceAttribute(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPlaceAttribute(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQPlaceAttribute *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQPlaceAttribute();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QPlaceAttribute* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPlaceAttribute, &a0))
        {
            sipCpp = new sipQPlaceAttribute(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QPlaceAttribute[] = {
    {(void *)slot_QPlaceAttribute___ne__, ne_slot},
    {(void *)slot_QPlaceAttribute___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QPlaceAttribute[] = {
    {sipName_isEmpty, meth_QPlaceAttribute_isEmpty, METH_VARARGS, doc_QPlaceAttribute_isEmpty},
    {sipName_label, meth_QPlaceAttribute_label, METH_VARARGS, doc_QPlaceAttribute_label},
    {sipName_setLabel, meth_QPlaceAttribute_setLabel, METH_VARARGS, doc_QPlaceAttribute_setLabel},
    {sipName_setText, meth_QPlaceAttribute_setText, METH_VARARGS, doc_QPlaceAttribute_setText},
    {sipName_text, meth_QPlaceAttribute_text, METH_VARARGS, doc_QPlaceAttribute_text}
};


extern "C" {static PyObject *varget_QPlaceAttribute_OpeningHours(void *, PyObject *, PyObject *);}
static PyObject *varget_QPlaceAttribute_OpeningHours(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QPlaceAttribute::OpeningHours);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QPlaceAttribute_Payment(void *, PyObject *, PyObject *);}
static PyObject *varget_QPlaceAttribute_Payment(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QPlaceAttribute::Payment);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QPlaceAttribute_Provider(void *, PyObject *, PyObject *);}
static PyObject *varget_QPlaceAttribute_Provider(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QPlaceAttribute::Provider);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}

sipVariableDef variables_QPlaceAttribute[] = {
    {ClassVariable, sipName_OpeningHours, (PyMethodDef *)varget_QPlaceAttribute_OpeningHours, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Payment, (PyMethodDef *)varget_QPlaceAttribute_Payment, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Provider, (PyMethodDef *)varget_QPlaceAttribute_Provider, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QPlaceAttribute, "\1QPlaceAttribute()\n"
"QPlaceAttribute(other: QPlaceAttribute)");


static pyqt5ClassPluginDef plugin_QPlaceAttribute = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QPlaceAttribute = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPlaceAttribute,
        SIP_NULLPTR,
        &plugin_QPlaceAttribute,
    },
    {
        sipNameNr_QPlaceAttribute,
        {0, 0, 1},
        5, methods_QPlaceAttribute,
        0, SIP_NULLPTR,
        3, variables_QPlaceAttribute,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPlaceAttribute,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QPlaceAttribute,
    init_type_QPlaceAttribute,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPlaceAttribute,
    assign_QPlaceAttribute,
    array_QPlaceAttribute,
    copy_QPlaceAttribute,
    release_QPlaceAttribute,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPlaceAttribute,
    sizeof (::QPlaceAttribute),
};
