/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 553 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStyleOptionDockWidget.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStyleOptionDockWidget.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStyleOptionDockWidget.cpp"


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QStyleOptionDockWidget(void *, const sipTypeDef *);}
static void *cast_QStyleOptionDockWidget(void *sipCppV, const sipTypeDef *targetType)
{
    ::QStyleOptionDockWidget *sipCpp = reinterpret_cast< ::QStyleOptionDockWidget *>(sipCppV);

    if (targetType == sipType_QStyleOptionDockWidget)
        return sipCppV;

    if (targetType == sipType_QStyleOption)
        return static_cast< ::QStyleOption *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QStyleOptionDockWidget(void *, int);}
static void release_QStyleOptionDockWidget(void *sipCppV, int)
{
    delete reinterpret_cast< ::QStyleOptionDockWidget *>(sipCppV);
}


extern "C" {static void *array_QStyleOptionDockWidget(Py_ssize_t);}
static void *array_QStyleOptionDockWidget(Py_ssize_t sipNrElem)
{
    return new ::QStyleOptionDockWidget[sipNrElem];
}


extern "C" {static void array_delete_QStyleOptionDockWidget(void *);}
static void array_delete_QStyleOptionDockWidget(void *sipCpp)
{
    delete[] reinterpret_cast< ::QStyleOptionDockWidget *>(sipCpp);
}


extern "C" {static void assign_QStyleOptionDockWidget(void *, Py_ssize_t, void *);}
static void assign_QStyleOptionDockWidget(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QStyleOptionDockWidget *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QStyleOptionDockWidget *>(sipSrc);
}


extern "C" {static void *copy_QStyleOptionDockWidget(const void *, Py_ssize_t);}
static void *copy_QStyleOptionDockWidget(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QStyleOptionDockWidget(reinterpret_cast<const ::QStyleOptionDockWidget *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QStyleOptionDockWidget(sipSimpleWrapper *);}
static void dealloc_QStyleOptionDockWidget(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QStyleOptionDockWidget(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QStyleOptionDockWidget(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QStyleOptionDockWidget(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QStyleOptionDockWidget *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QStyleOptionDockWidget();

            return sipCpp;
        }
    }

    {
        const ::QStyleOptionDockWidget* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QStyleOptionDockWidget, &a0))
        {
            sipCpp = new ::QStyleOptionDockWidget(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QStyleOptionDockWidget[] = {{315, 255, 1}};

static sipEnumMemberDef enummembers_QStyleOptionDockWidget[] = {
    {sipName_Type, static_cast<int>(::QStyleOptionDockWidget::Type), 331},
    {sipName_Version, static_cast<int>(::QStyleOptionDockWidget::Version), 332},
};


extern "C" {static PyObject *varget_QStyleOptionDockWidget_closable(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionDockWidget_closable(void *sipSelf, PyObject *, PyObject *)
{
    bool sipVal;
    ::QStyleOptionDockWidget *sipCpp = reinterpret_cast< ::QStyleOptionDockWidget *>(sipSelf);

    sipVal = sipCpp->closable;

    return PyBool_FromLong(sipVal);
}


extern "C" {static int varset_QStyleOptionDockWidget_closable(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionDockWidget_closable(void *sipSelf, PyObject *sipPy, PyObject *)
{
    int sipVal;
    ::QStyleOptionDockWidget *sipCpp = reinterpret_cast< ::QStyleOptionDockWidget *>(sipSelf);

    sipVal = sipConvertToBool(sipPy);

    if (sipVal < 0)
        return -1;

    sipCpp->closable = static_cast<bool>(sipVal);

    return 0;
}


extern "C" {static PyObject *varget_QStyleOptionDockWidget_floatable(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionDockWidget_floatable(void *sipSelf, PyObject *, PyObject *)
{
    bool sipVal;
    ::QStyleOptionDockWidget *sipCpp = reinterpret_cast< ::QStyleOptionDockWidget *>(sipSelf);

    sipVal = sipCpp->floatable;

    return PyBool_FromLong(sipVal);
}


extern "C" {static int varset_QStyleOptionDockWidget_floatable(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionDockWidget_floatable(void *sipSelf, PyObject *sipPy, PyObject *)
{
    int sipVal;
    ::QStyleOptionDockWidget *sipCpp = reinterpret_cast< ::QStyleOptionDockWidget *>(sipSelf);

    sipVal = sipConvertToBool(sipPy);

    if (sipVal < 0)
        return -1;

    sipCpp->floatable = static_cast<bool>(sipVal);

    return 0;
}


extern "C" {static PyObject *varget_QStyleOptionDockWidget_movable(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionDockWidget_movable(void *sipSelf, PyObject *, PyObject *)
{
    bool sipVal;
    ::QStyleOptionDockWidget *sipCpp = reinterpret_cast< ::QStyleOptionDockWidget *>(sipSelf);

    sipVal = sipCpp->movable;

    return PyBool_FromLong(sipVal);
}


extern "C" {static int varset_QStyleOptionDockWidget_movable(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionDockWidget_movable(void *sipSelf, PyObject *sipPy, PyObject *)
{
    int sipVal;
    ::QStyleOptionDockWidget *sipCpp = reinterpret_cast< ::QStyleOptionDockWidget *>(sipSelf);

    sipVal = sipConvertToBool(sipPy);

    if (sipVal < 0)
        return -1;

    sipCpp->movable = static_cast<bool>(sipVal);

    return 0;
}


extern "C" {static PyObject *varget_QStyleOptionDockWidget_title(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionDockWidget_title(void *sipSelf, PyObject *, PyObject *)
{
    ::QString*sipVal;
    ::QStyleOptionDockWidget *sipCpp = reinterpret_cast< ::QStyleOptionDockWidget *>(sipSelf);

    sipVal = &sipCpp->title;

    return sipConvertFromType(sipVal, sipType_QString, SIP_NULLPTR);
}


extern "C" {static int varset_QStyleOptionDockWidget_title(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionDockWidget_title(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QString*sipVal;
    ::QStyleOptionDockWidget *sipCpp = reinterpret_cast< ::QStyleOptionDockWidget *>(sipSelf);

    int sipIsErr = 0;
    int sipValState;
    sipVal = reinterpret_cast< ::QString *>(sipForceConvertToType(sipPy, sipType_QString, SIP_NULLPTR, SIP_NOT_NONE, &sipValState, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->title = *sipVal;

    sipReleaseType(sipVal, sipType_QString, sipValState);

    return 0;
}


extern "C" {static PyObject *varget_QStyleOptionDockWidget_verticalTitleBar(void *, PyObject *, PyObject *);}
static PyObject *varget_QStyleOptionDockWidget_verticalTitleBar(void *sipSelf, PyObject *, PyObject *)
{
    bool sipVal;
    ::QStyleOptionDockWidget *sipCpp = reinterpret_cast< ::QStyleOptionDockWidget *>(sipSelf);

    sipVal = sipCpp->verticalTitleBar;

    return PyBool_FromLong(sipVal);
}


extern "C" {static int varset_QStyleOptionDockWidget_verticalTitleBar(void *, PyObject *, PyObject *);}
static int varset_QStyleOptionDockWidget_verticalTitleBar(void *sipSelf, PyObject *sipPy, PyObject *)
{
    int sipVal;
    ::QStyleOptionDockWidget *sipCpp = reinterpret_cast< ::QStyleOptionDockWidget *>(sipSelf);

    sipVal = sipConvertToBool(sipPy);

    if (sipVal < 0)
        return -1;

    sipCpp->verticalTitleBar = static_cast<bool>(sipVal);

    return 0;
}

sipVariableDef variables_QStyleOptionDockWidget[] = {
    {InstanceVariable, sipName_closable, (PyMethodDef *)varget_QStyleOptionDockWidget_closable, (PyMethodDef *)varset_QStyleOptionDockWidget_closable, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_floatable, (PyMethodDef *)varget_QStyleOptionDockWidget_floatable, (PyMethodDef *)varset_QStyleOptionDockWidget_floatable, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_movable, (PyMethodDef *)varget_QStyleOptionDockWidget_movable, (PyMethodDef *)varset_QStyleOptionDockWidget_movable, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_title, (PyMethodDef *)varget_QStyleOptionDockWidget_title, (PyMethodDef *)varset_QStyleOptionDockWidget_title, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_verticalTitleBar, (PyMethodDef *)varget_QStyleOptionDockWidget_verticalTitleBar, (PyMethodDef *)varset_QStyleOptionDockWidget_verticalTitleBar, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QStyleOptionDockWidget, "\1QStyleOptionDockWidget()\n"
"QStyleOptionDockWidget(other: QStyleOptionDockWidget)");


static pyqt5ClassPluginDef plugin_QStyleOptionDockWidget = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionDockWidget = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QStyleOptionDockWidget,
        SIP_NULLPTR,
        &plugin_QStyleOptionDockWidget,
    },
    {
        sipNameNr_QStyleOptionDockWidget,
        {0, 0, 1},
        0, SIP_NULLPTR,
        2, enummembers_QStyleOptionDockWidget,
        5, variables_QStyleOptionDockWidget,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QStyleOptionDockWidget,
    -1,
    -1,
    supers_QStyleOptionDockWidget,
    SIP_NULLPTR,
    init_type_QStyleOptionDockWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QStyleOptionDockWidget,
    assign_QStyleOptionDockWidget,
    array_QStyleOptionDockWidget,
    copy_QStyleOptionDockWidget,
    release_QStyleOptionDockWidget,
    cast_QStyleOptionDockWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QStyleOptionDockWidget,
    sizeof (::QStyleOptionDockWidget),
};
