/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerazoomcontrol.sip"
#include <qcamerazoomcontrol.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraZoomControl.cpp"


class sipQCameraZoomControl : public ::QCameraZoomControl
{
public:
    sipQCameraZoomControl(::QObject*);
    virtual ~sipQCameraZoomControl();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void zoomTo(::qreal, ::qreal) SIP_OVERRIDE;
    ::qreal currentDigitalZoom() const SIP_OVERRIDE;
    ::qreal currentOpticalZoom() const SIP_OVERRIDE;
    ::qreal requestedDigitalZoom() const SIP_OVERRIDE;
    ::qreal requestedOpticalZoom() const SIP_OVERRIDE;
    ::qreal maximumDigitalZoom() const SIP_OVERRIDE;
    ::qreal maximumOpticalZoom() const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQCameraZoomControl(const sipQCameraZoomControl &);
    sipQCameraZoomControl &operator = (const sipQCameraZoomControl &);

    char sipPyMethods[14];
};

sipQCameraZoomControl::sipQCameraZoomControl(::QObject*a0): ::QCameraZoomControl(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCameraZoomControl::~sipQCameraZoomControl()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQCameraZoomControl::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QCameraZoomControl);

    return ::QCameraZoomControl::metaObject();
}

int sipQCameraZoomControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QCameraZoomControl::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QCameraZoomControl, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQCameraZoomControl::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QCameraZoomControl, _clname, &sipCpp) ? sipCpp : ::QCameraZoomControl::qt_metacast(_clname));
}

void sipQCameraZoomControl::zoomTo(::qreal a0, ::qreal a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, sipName_QCameraZoomControl, sipName_zoomTo);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_92(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::qreal, ::qreal);

    sipVH_QtMultimedia_92(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::qreal sipQCameraZoomControl::currentDigitalZoom() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraZoomControl, sipName_currentDigitalZoom);

    if (!sipMeth)
        return 0;

    extern ::qreal sipVH_QtMultimedia_91(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_91(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::qreal sipQCameraZoomControl::currentOpticalZoom() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraZoomControl, sipName_currentOpticalZoom);

    if (!sipMeth)
        return 0;

    extern ::qreal sipVH_QtMultimedia_91(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_91(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::qreal sipQCameraZoomControl::requestedDigitalZoom() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraZoomControl, sipName_requestedDigitalZoom);

    if (!sipMeth)
        return 0;

    extern ::qreal sipVH_QtMultimedia_91(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_91(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::qreal sipQCameraZoomControl::requestedOpticalZoom() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraZoomControl, sipName_requestedOpticalZoom);

    if (!sipMeth)
        return 0;

    extern ::qreal sipVH_QtMultimedia_91(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_91(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::qreal sipQCameraZoomControl::maximumDigitalZoom() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraZoomControl, sipName_maximumDigitalZoom);

    if (!sipMeth)
        return 0;

    extern ::qreal sipVH_QtMultimedia_91(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_91(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::qreal sipQCameraZoomControl::maximumOpticalZoom() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraZoomControl, sipName_maximumOpticalZoom);

    if (!sipMeth)
        return 0;

    extern ::qreal sipVH_QtMultimedia_91(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_91(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQCameraZoomControl::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QCameraZoomControl::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraZoomControl::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QCameraZoomControl::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraZoomControl::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QCameraZoomControl::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraZoomControl::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QCameraZoomControl::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraZoomControl::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QCameraZoomControl::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCameraZoomControl::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QCameraZoomControl::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQCameraZoomControl::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QCameraZoomControl::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QCameraZoomControl_maximumOpticalZoom, "maximumOpticalZoom(self) -> float");

extern "C" {static PyObject *meth_QCameraZoomControl_maximumOpticalZoom(PyObject *, PyObject *);}
static PyObject *meth_QCameraZoomControl_maximumOpticalZoom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QCameraZoomControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraZoomControl, &sipCpp))
        {
            ::qreal sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraZoomControl, sipName_maximumOpticalZoom);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->maximumOpticalZoom();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraZoomControl, sipName_maximumOpticalZoom, doc_QCameraZoomControl_maximumOpticalZoom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraZoomControl_maximumDigitalZoom, "maximumDigitalZoom(self) -> float");

extern "C" {static PyObject *meth_QCameraZoomControl_maximumDigitalZoom(PyObject *, PyObject *);}
static PyObject *meth_QCameraZoomControl_maximumDigitalZoom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QCameraZoomControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraZoomControl, &sipCpp))
        {
            ::qreal sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraZoomControl, sipName_maximumDigitalZoom);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->maximumDigitalZoom();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraZoomControl, sipName_maximumDigitalZoom, doc_QCameraZoomControl_maximumDigitalZoom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraZoomControl_requestedOpticalZoom, "requestedOpticalZoom(self) -> float");

extern "C" {static PyObject *meth_QCameraZoomControl_requestedOpticalZoom(PyObject *, PyObject *);}
static PyObject *meth_QCameraZoomControl_requestedOpticalZoom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QCameraZoomControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraZoomControl, &sipCpp))
        {
            ::qreal sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraZoomControl, sipName_requestedOpticalZoom);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->requestedOpticalZoom();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraZoomControl, sipName_requestedOpticalZoom, doc_QCameraZoomControl_requestedOpticalZoom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraZoomControl_requestedDigitalZoom, "requestedDigitalZoom(self) -> float");

extern "C" {static PyObject *meth_QCameraZoomControl_requestedDigitalZoom(PyObject *, PyObject *);}
static PyObject *meth_QCameraZoomControl_requestedDigitalZoom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QCameraZoomControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraZoomControl, &sipCpp))
        {
            ::qreal sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraZoomControl, sipName_requestedDigitalZoom);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->requestedDigitalZoom();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraZoomControl, sipName_requestedDigitalZoom, doc_QCameraZoomControl_requestedDigitalZoom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraZoomControl_currentOpticalZoom, "currentOpticalZoom(self) -> float");

extern "C" {static PyObject *meth_QCameraZoomControl_currentOpticalZoom(PyObject *, PyObject *);}
static PyObject *meth_QCameraZoomControl_currentOpticalZoom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QCameraZoomControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraZoomControl, &sipCpp))
        {
            ::qreal sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraZoomControl, sipName_currentOpticalZoom);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->currentOpticalZoom();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraZoomControl, sipName_currentOpticalZoom, doc_QCameraZoomControl_currentOpticalZoom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraZoomControl_currentDigitalZoom, "currentDigitalZoom(self) -> float");

extern "C" {static PyObject *meth_QCameraZoomControl_currentDigitalZoom(PyObject *, PyObject *);}
static PyObject *meth_QCameraZoomControl_currentDigitalZoom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QCameraZoomControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraZoomControl, &sipCpp))
        {
            ::qreal sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraZoomControl, sipName_currentDigitalZoom);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->currentDigitalZoom();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraZoomControl, sipName_currentDigitalZoom, doc_QCameraZoomControl_currentDigitalZoom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraZoomControl_zoomTo, "zoomTo(self, optical: float, digital: float)");

extern "C" {static PyObject *meth_QCameraZoomControl_zoomTo(PyObject *, PyObject *);}
static PyObject *meth_QCameraZoomControl_zoomTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::qreal a0;
        ::qreal a1;
        ::QCameraZoomControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QCameraZoomControl, &sipCpp, &a0, &a1))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraZoomControl, sipName_zoomTo);
                return SIP_NULLPTR;
            }

            sipCpp->zoomTo(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraZoomControl, sipName_zoomTo, doc_QCameraZoomControl_zoomTo);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QCameraZoomControl(void *, const sipTypeDef *);}
static void *cast_QCameraZoomControl(void *sipCppV, const sipTypeDef *targetType)
{
    ::QCameraZoomControl *sipCpp = reinterpret_cast< ::QCameraZoomControl *>(sipCppV);

    if (targetType == sipType_QCameraZoomControl)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaControl)->ctd_cast(static_cast< ::QMediaControl *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QCameraZoomControl(void *, int);}
static void release_QCameraZoomControl(void *sipCppV, int)
{
    ::QCameraZoomControl *sipCpp = reinterpret_cast< ::QCameraZoomControl *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QCameraZoomControl(sipSimpleWrapper *);}
static void dealloc_QCameraZoomControl(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQCameraZoomControl *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QCameraZoomControl(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QCameraZoomControl(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QCameraZoomControl(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQCameraZoomControl *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQCameraZoomControl(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QCameraZoomControl[] = {{104, 255, 1}};


static PyMethodDef methods_QCameraZoomControl[] = {
    {sipName_currentDigitalZoom, meth_QCameraZoomControl_currentDigitalZoom, METH_VARARGS, doc_QCameraZoomControl_currentDigitalZoom},
    {sipName_currentOpticalZoom, meth_QCameraZoomControl_currentOpticalZoom, METH_VARARGS, doc_QCameraZoomControl_currentOpticalZoom},
    {sipName_maximumDigitalZoom, meth_QCameraZoomControl_maximumDigitalZoom, METH_VARARGS, doc_QCameraZoomControl_maximumDigitalZoom},
    {sipName_maximumOpticalZoom, meth_QCameraZoomControl_maximumOpticalZoom, METH_VARARGS, doc_QCameraZoomControl_maximumOpticalZoom},
    {sipName_requestedDigitalZoom, meth_QCameraZoomControl_requestedDigitalZoom, METH_VARARGS, doc_QCameraZoomControl_requestedDigitalZoom},
    {sipName_requestedOpticalZoom, meth_QCameraZoomControl_requestedOpticalZoom, METH_VARARGS, doc_QCameraZoomControl_requestedOpticalZoom},
    {sipName_zoomTo, meth_QCameraZoomControl_zoomTo, METH_VARARGS, doc_QCameraZoomControl_zoomTo}
};

PyDoc_STRVAR(doc_QCameraZoomControl, "\1QCameraZoomControl(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QCameraZoomControl[] = {
    {"currentDigitalZoomChanged(qreal)", "\1currentDigitalZoomChanged(self, digitalZoom: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"currentOpticalZoomChanged(qreal)", "\1currentOpticalZoomChanged(self, opticalZoom: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"requestedDigitalZoomChanged(qreal)", "\1requestedDigitalZoomChanged(self, digitalZoom: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"requestedOpticalZoomChanged(qreal)", "\1requestedOpticalZoomChanged(self, opticalZoom: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"maximumDigitalZoomChanged(qreal)", "\1maximumDigitalZoomChanged(self, a0: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"maximumOpticalZoomChanged(qreal)", "\1maximumOpticalZoomChanged(self, a0: float)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QCameraZoomControl = {
    &::QCameraZoomControl::staticMetaObject,
    0,
    signals_QCameraZoomControl,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QCameraZoomControl = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCameraZoomControl,
        SIP_NULLPTR,
        &plugin_QCameraZoomControl,
    },
    {
        sipNameNr_QCameraZoomControl,
        {0, 0, 1},
        7, methods_QCameraZoomControl,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QCameraZoomControl,
    -1,
    -1,
    supers_QCameraZoomControl,
    SIP_NULLPTR,
    init_type_QCameraZoomControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QCameraZoomControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QCameraZoomControl,
    cast_QCameraZoomControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QCameraZoomControl),
};
