/*
 * Module code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPrintSupport.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qabstractprintdialog.sip"
#include <qabstractprintdialog.h>
#line 32 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 35 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 205 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 253 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 363 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 384 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 398 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 412 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 425 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 438 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 482 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 302 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 675 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 608 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 592 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 619 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 570 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 460 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 471 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 509 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qprintengine.sip"
#include <qprintengine.h>
#line 122 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qprinter.sip"
#include <qprinter.h>
#line 125 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpagedpaintdevice.sip"
#include <qpagedpaintdevice.h>
#line 374 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpagedpaintdevice.sip"
#include <qpagedpaintdevice.h>
#line 130 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 103 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 133 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpagedpaintdevice.sip"
#include <qpagedpaintdevice.h>
#line 136 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qabstractprintdialog.sip"
#include <qabstractprintdialog.h>
#line 139 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qpagesetupdialog.sip"
#include <qpagesetupdialog.h>
#line 142 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qprintdialog.sip"
#include <qprintdialog.h>
#line 145 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qprinterinfo.sip"
#include <qprinterinfo.h>
#line 148 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qprintpreviewdialog.sip"
#include <qprintpreviewdialog.h>
#line 151 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qprintpreviewwidget.sip"
#include <qprintpreviewwidget.h>
#line 154 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtPrintSupport[] = {
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'P', 'r', 'i', 'n', 't', 'D', 'i', 'a', 'l', 'o', 'g', ':', ':', 'P', 'r', 'i', 'n', 't', 'D', 'i', 'a', 'l', 'o', 'g', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'P', 'r', 'i', 'n', 't', 'D', 'i', 'a', 'l', 'o', 'g', ':', ':', 'P', 'r', 'i', 'n', 't', 'D', 'i', 'a', 'l', 'o', 'g', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'P', 'r', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'K', 'e', 'y', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'a', 'g', 'e', 'd', 'P', 'a', 'i', 'n', 't', 'D', 'e', 'v', 'i', 'c', 'e', ':', ':', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', '>', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'P', 'r', 'i', 'n', 't', 'D', 'i', 'a', 'l', 'o', 'g', ':', ':', 'P', 'r', 'i', 'n', 't', 'R', 'a', 'n', 'g', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'a', 'i', 'r', '<', 'Q', 'S', 't', 'r', 'i', 'n', 'g', ',', 'Q', 'S', 'i', 'z', 'e', 'F', '>', ' ', '>', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'P', 'r', 'e', 'v', 'i', 'e', 'w', 'W', 'i', 'd', 'g', 'e', 't', ':', ':', 'V', 'i', 'e', 'w', 'M', 'o', 'd', 'e', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'P', 'r', 'e', 'v', 'i', 'e', 'w', 'W', 'i', 'd', 'g', 'e', 't', ':', ':', 'Z', 'o', 'o', 'm', 'M', 'o', 'd', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'r', 'i', 'n', 't', 'e', 'r', ':', ':', 'D', 'u', 'p', 'l', 'e', 'x', 'M', 'o', 'd', 'e', '>', 0,
    'P', 'P', 'K', '_', 'S', 'u', 'p', 'p', 'o', 'r', 't', 's', 'M', 'u', 'l', 't', 'i', 'p', 'l', 'e', 'C', 'o', 'p', 'i', 'e', 's', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'r', 'i', 'n', 't', 'e', 'r', ':', ':', 'C', 'o', 'l', 'o', 'r', 'M', 'o', 'd', 'e', '>', 0,
    's', 'e', 't', 'P', 'r', 'i', 'n', 't', 'e', 'r', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'P', 'P', 'K', '_', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 's', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'P', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'P', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 'E', 'm', 'b', 'e', 'd', 'd', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'L', 'a', 'n', 'd', 's', 'c', 'a', 'p', 'e', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'S', 'i', 'z', 'e', 's', 'W', 'i', 't', 'h', 'N', 'a', 'm', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'C', 'u', 's', 't', 'o', 'm', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 's', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'e', 'r', ':', ':', 'O', 'u', 't', 'p', 'u', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'e', 'r', ':', ':', 'P', 'r', 'i', 'n', 't', 'e', 'r', 'S', 't', 'a', 't', 'e', 0,
    'p', 'r', 'i', 'n', 't', 'e', 'r', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'D', 'o', 'u', 'b', 'l', 'e', 'S', 'i', 'd', 'e', 'd', 'P', 'r', 'i', 'n', 't', 'i', 'n', 'g', 0,
    's', 'e', 't', 'F', 'a', 'c', 'i', 'n', 'g', 'P', 'a', 'g', 'e', 's', 'V', 'i', 'e', 'w', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'P', 'o', 'r', 't', 'r', 'a', 'i', 't', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'M', 'u', 'l', 't', 'i', 'p', 'l', 'e', 'C', 'o', 'p', 'i', 'e', 's', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'e', 'r', ':', ':', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'e', 'r', ':', ':', 'P', 'a', 'p', 'e', 'r', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'e', 'r', ':', ':', 'P', 'r', 'i', 'n', 't', 'e', 'r', 'M', 'o', 'd', 'e', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'P', 'r', 'i', 'n', 't', 'e', 'r', 'N', 'a', 'm', 'e', 's', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'S', 'i', 'n', 'g', 'l', 'e', 'P', 'a', 'g', 'e', 'V', 'i', 'e', 'w', 'M', 'o', 'd', 'e', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', 'P', 'r', 'i', 'n', 't', 'S', 'u', 'p', 'p', 'o', 'r', 't', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'P', 'r', 'i', 'n', 't', 'D', 'i', 'a', 'l', 'o', 'g', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'e', 'r', ':', ':', 'D', 'u', 'p', 'l', 'e', 'x', 'M', 'o', 'd', 'e', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'e', 'r', ':', ':', 'P', 'r', 'i', 'n', 't', 'R', 'a', 'n', 'g', 'e', 0,
    'f', 'o', 'n', 't', 'E', 'm', 'b', 'e', 'd', 'd', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'D', 'u', 'p', 'l', 'e', 'x', 'M', 'o', 'd', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 's', 0,
    'P', 'P', 'K', '_', 'C', 'u', 's', 't', 'o', 'm', 'P', 'a', 'p', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'P', 'P', 'K', '_', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'P', 'P', 'K', '_', 'W', 'i', 'n', 'd', 'o', 'w', 's', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'r', 'i', 'n', 't', 'e', 'r', 'I', 'n', 'f', 'o', '>', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'P', 'r', 'e', 'v', 'i', 'e', 'w', 'D', 'i', 'a', 'l', 'o', 'g', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'P', 'r', 'e', 'v', 'i', 'e', 'w', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'e', 'r', ':', ':', 'C', 'o', 'l', 'o', 'r', 'M', 'o', 'd', 'e', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'e', 'r', ':', ':', 'P', 'a', 'g', 'e', 'O', 'r', 'd', 'e', 'r', 0,
    'd', 'o', 'u', 'b', 'l', 'e', 'S', 'i', 'd', 'e', 'd', 'P', 'r', 'i', 'n', 't', 'i', 'n', 'g', 0,
    's', 'e', 't', 'A', 'l', 'l', 'P', 'a', 'g', 'e', 's', 'V', 'i', 'e', 'w', 'M', 'o', 'd', 'e', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'C', 'o', 'l', 'o', 'r', 'M', 'o', 'd', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'P', 'a', 'p', 'e', 'r', 'S', 'i', 'z', 'e', 's', 0,
    'P', 'P', 'K', '_', 'N', 'u', 'm', 'b', 'e', 'r', 'O', 'f', 'C', 'o', 'p', 'i', 'e', 's', 0,
    'P', 'P', 'K', '_', 'O', 'u', 't', 'p', 'u', 't', 'F', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'P', 'P', 'K', '_', 'P', 'r', 'i', 'n', 't', 'e', 'r', 'P', 'r', 'o', 'g', 'r', 'a', 'm', 0,
    'P', 'r', 'i', 'n', 't', 'C', 'o', 'l', 'l', 'a', 't', 'e', 'C', 'o', 'p', 'i', 'e', 's', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'P', 'r', 'i', 'n', 't', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    'f', 'o', 'c', 'u', 's', 'N', 'e', 'x', 't', 'P', 'r', 'e', 'v', 'C', 'h', 'i', 'l', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 's', 0,
    'P', 'P', 'K', '_', 'C', 'o', 'l', 'l', 'a', 't', 'e', 'C', 'o', 'p', 'i', 'e', 's', 0,
    'P', 'P', 'K', '_', 'F', 'o', 'n', 't', 'E', 'm', 'b', 'e', 'd', 'd', 'i', 'n', 'g', 0,
    'P', 'r', 'i', 'n', 't', 'S', 'h', 'o', 'w', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    'P', 'r', 'i', 'n', 't', 'e', 'r', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'P', 'r', 'i', 'n', 't', 'e', 'r', 's', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'D', 'u', 'p', 'l', 'e', 'x', 'M', 'o', 'd', 'e', 0,
    'h', 'a', 's', 'H', 'e', 'i', 'g', 'h', 't', 'F', 'o', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'm', 'o', 'u', 's', 'e', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'O', 'u', 't', 'p', 'u', 't', 'F', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    'P', 'P', 'K', '_', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'N', 'a', 'm', 'e', 0,
    'P', 'P', 'K', '_', 'P', 'a', 'p', 'e', 'r', 'S', 'o', 'u', 'r', 'c', 'e', 's', 0,
    'P', 'P', 'K', '_', 'Q', 'P', 'a', 'g', 'e', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'P', 'r', 'i', 'n', 't', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'P', 'a', 'g', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', '>', 0,
    'Q', 'P', 'a', 'g', 'e', 'S', 'e', 't', 'u', 'p', 'D', 'i', 'a', 'l', 'o', 'g', 0,
    'S', 'c', 'r', 'e', 'e', 'n', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'o', 'l', 'o', 'r', 'M', 'o', 'd', 'e', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'i', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'i', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'Q', 'u', 'e', 'r', 'y', 0,
    's', 'e', 't', 'C', 'o', 'l', 'l', 'a', 't', 'e', 'C', 'o', 'p', 'i', 'e', 's', 0,
    'D', 'u', 'p', 'l', 'e', 'x', 'S', 'h', 'o', 'r', 't', 'S', 'i', 'd', 'e', 0,
    'F', 'a', 'c', 'i', 'n', 'g', 'P', 'a', 'g', 'e', 's', 'V', 'i', 'e', 'w', 0,
    'L', 'a', 's', 't', 'P', 'a', 'p', 'e', 'r', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'P', 'P', 'K', '_', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'P', 'P', 'K', '_', 'P', 'a', 'g', 'e', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'P', 'P', 'K', '_', 'P', 'a', 'p', 'e', 'r', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'P', 'P', 'K', '_', 'P', 'r', 'i', 'n', 't', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    'P', 'P', 'K', '_', 'Q', 'P', 'a', 'g', 'e', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    'k', 'e', 'y', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'S', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    'm', 'o', 'u', 's', 'e', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'O', 'u', 't', 'p', 'u', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'P', 'r', 'i', 'n', 't', 'P', 'r', 'o', 'g', 'r', 'a', 'm', 0,
    'D', 'u', 'p', 'l', 'e', 'x', 'L', 'o', 'n', 'g', 'S', 'i', 'd', 'e', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'M', 'a', 'n', 'u', 'a', 'l', 0,
    'F', 'i', 'r', 's', 't', 'P', 'a', 'g', 'e', 'F', 'i', 'r', 's', 't', 0,
    'H', 'i', 'g', 'h', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    'P', 'P', 'K', '_', 'C', 'u', 's', 't', 'o', 'm', 'B', 'a', 's', 'e', 0,
    'P', 'P', 'K', '_', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    'P', 'r', 'i', 'n', 't', 'P', 'a', 'g', 'e', 'R', 'a', 'n', 'g', 'e', 0,
    'P', 'r', 'i', 'n', 't', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'e', 'r', ':', ':', 'U', 'n', 'i', 't', 0,
    'S', 'i', 'n', 'g', 'l', 'e', 'P', 'a', 'g', 'e', 'V', 'i', 'e', 'w', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'P', 'r', 'i', 'n', 't', 'e', 'r', 0,
    'd', 'r', 'a', 'g', 'E', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'r', 'a', 'g', 'L', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'd', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'g', 'e', 't', 'P', 'a', 'g', 'e', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'F', 'o', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'm', 'o', 'u', 's', 'e', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'o', 'u', 't', 'p', 'u', 't', 'F', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'p', 'a', 'i', 'n', 't', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    'p', 'r', 'e', 'v', 'i', 'e', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'P', 'a', 'g', 'e', 0,
    's', 'e', 't', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    's', 'e', 't', 'P', 'a', 'p', 'e', 'r', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    's', 'e', 't', 'P', 'r', 'i', 'n', 't', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    'L', 'a', 'r', 'g', 'e', 'C', 'a', 'p', 'a', 'c', 'i', 't', 'y', 0,
    'L', 'a', 's', 't', 'P', 'a', 'g', 'e', 'F', 'i', 'r', 's', 't', 0,
    'M', 'a', 'x', 'P', 'a', 'g', 'e', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'P', 'P', 'K', '_', 'C', 'o', 'l', 'o', 'r', 'M', 'o', 'd', 'e', 0,
    'P', 'P', 'K', '_', 'C', 'o', 'p', 'y', 'C', 'o', 'u', 'n', 't', 0,
    'P', 'P', 'K', '_', 'P', 'a', 'g', 'e', 'O', 'r', 'd', 'e', 'r', 0,
    'P', 'P', 'K', '_', 'P', 'a', 'p', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    'P', 'P', 'K', '_', 'P', 'a', 'p', 'e', 'r', 'R', 'e', 'c', 't', 0,
    'P', 'P', 'K', '_', 'P', 'a', 'p', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'P', 'P', 'K', '_', 'Q', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    'c', 'o', 'l', 'l', 'a', 't', 'e', 'C', 'o', 'p', 'i', 'e', 's', 0,
    'd', 'r', 'a', 'g', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'u', 't', 'E', 'v', 'e', 'n', 't', 0,
    'k', 'e', 'y', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 'T', 'a', 'b', 's', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 'M', 'M', 0,
    's', 'e', 't', 'P', 'd', 'f', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'r', 'i', 'n', 't', 'R', 'a', 'n', 'g', 'e', 0,
    's', 'e', 't', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'Z', 'o', 'o', 'm', 'F', 'a', 'c', 't', 'o', 'r', 0,
    's', 'h', 'a', 'r', 'e', 'd', 'P', 'a', 'i', 'n', 't', 'e', 'r', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'P', 'r', 'e', 'v', 'i', 'e', 'w', 0,
    'A', 'l', 'l', 'P', 'a', 'g', 'e', 's', 'V', 'i', 'e', 'w', 0,
    'C', 'u', 's', 't', 'o', 'm', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'N', 'a', 't', 'i', 'v', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'P', 'P', 'K', '_', 'F', 'u', 'l', 'l', 'P', 'a', 'g', 'e', 0,
    'P', 'P', 'K', '_', 'P', 'a', 'g', 'e', 'R', 'e', 'c', 't', 0,
    'P', 'P', 'K', '_', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'D', 'i', 'a', 'l', 'o', 'g', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'e', 'r', 'I', 'n', 'f', 'o', 0,
    'f', 'o', 'c', 'u', 's', 'I', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'a', 'k', 'e', 'A', 'n', 'd', 'M', 'o', 'd', 'e', 'l', 0,
    'o', 'u', 't', 'p', 'u', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'p', 'r', 'i', 'n', 't', 'P', 'r', 'o', 'g', 'r', 'a', 'm', 0,
    'p', 'r', 'i', 'n', 't', 'e', 'r', 'S', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'C', 'o', 'p', 'y', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'O', 'r', 'd', 'e', 'r', 0,
    's', 'e', 't', 'P', 'a', 'p', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'P', 'a', 'p', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'D', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 0,
    'L', 'a', 'r', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'P', 'P', 'K', '_', 'C', 'r', 'e', 'a', 't', 'o', 'r', 0,
    'P', 'r', 'i', 'n', 't', 'T', 'o', 'F', 'i', 'l', 'e', 0,
    'S', 'm', 'a', 'l', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'a', 'c', 't', 'i', 'o', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'h', 'a', 'n', 'g', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'P', 'a', 'g', 'e', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'i', 'n', 'i', 't', 'P', 'a', 'i', 'n', 't', 'e', 'r', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'p', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'p', 'a', 'p', 'e', 'r', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'p', 'r', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'p', 'r', 'i', 'n', 't', 'e', 'r', 'I', 'n', 'f', 'o', 0,
    'p', 'r', 'i', 'n', 't', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'F', 'u', 'l', 'l', 'P', 'a', 'g', 'e', 0,
    's', 'e', 't', 'P', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'Z', 'o', 'o', 'm', 'M', 'o', 'd', 'e', 0,
    't', 'a', 'b', 'l', 'e', 't', 'E', 'v', 'e', 'n', 't', 0,
    'C', 'u', 's', 't', 'o', 'm', 'Z', 'o', 'o', 'm', 0,
    'D', 'u', 'p', 'l', 'e', 'x', 'A', 'u', 't', 'o', 0,
    'D', 'u', 'p', 'l', 'e', 'x', 'N', 'o', 'n', 'e', 0,
    'F', 'i', 't', 'T', 'o', 'W', 'i', 'd', 't', 'h', 0,
    'F', 'o', 'r', 'm', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'M', 'i', 'l', 'l', 'i', 'm', 'e', 't', 'e', 'r', 0,
    'P', 'P', 'K', '_', 'D', 'u', 'p', 'l', 'e', 'x', 0,
    '_', '_', 'i', 'n', 'v', 'e', 'r', 't', '_', '_', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'l', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'i', 't', 'T', 'o', 'W', 'i', 'd', 't', 'h', 0,
    'l', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'a', 'i', 'n', 't', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'd', 'f', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'p', 'r', 'i', 'n', 't', 'R', 'a', 'n', 'g', 'e', 0,
    'r', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'C', 'r', 'e', 'a', 't', 'o', 'r', 0,
    's', 'e', 't', 'D', 'o', 'c', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'E', 'n', 'g', 'i', 'n', 'e', 's', 0,
    's', 'e', 't', 'M', 'a', 'r', 'g', 'i', 'n', 's', 0,
    's', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    't', 'e', 's', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'w', 'h', 'e', 'e', 'l', 'E', 'v', 'e', 'n', 't', 0,
    'z', 'o', 'o', 'm', 'F', 'a', 'c', 't', 'o', 'r', 0,
    'F', 'i', 't', 'I', 'n', 'V', 'i', 'e', 'w', 0,
    'G', 'r', 'a', 'y', 'S', 'c', 'a', 'l', 'e', 0,
    'L', 'a', 'n', 'd', 's', 'c', 'a', 'p', 'e', 0,
    'P', 'd', 'f', 'F', 'o', 'r', 'm', 'a', 't', 0,
    '_', '_', 'i', 'n', 'd', 'e', 'x', '_', '_', 0,
    'c', 'o', 'l', 'o', 'r', 'M', 'o', 'd', 'e', 0,
    'c', 'o', 'p', 'y', 'C', 'o', 'u', 'n', 't', 0,
    'd', 'r', 'o', 'p', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'i', 't', 'I', 'n', 'V', 'i', 'e', 'w', 0,
    'h', 'i', 'd', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    'm', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'a', 'g', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'p', 'a', 'g', 'e', 'O', 'r', 'd', 'e', 'r', 0,
    'p', 'a', 'p', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    'p', 'a', 'p', 'e', 'r', 'R', 'e', 'c', 't', 0,
    'p', 'a', 'p', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'D', 'u', 'p', 'l', 'e', 'x', 0,
    's', 'e', 't', 'F', 'r', 'o', 'm', 'T', 'o', 0,
    's', 'e', 't', 'M', 'i', 'n', 'M', 'a', 'x', 0,
    's', 'e', 't', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'h', 'o', 'w', 'E', 'v', 'e', 'n', 't', 0,
    'A', 'l', 'l', 'P', 'a', 'g', 'e', 's', 0,
    'C', 'a', 's', 's', 'e', 't', 't', 'e', 0,
    'E', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 0,
    'P', 'o', 'r', 't', 'r', 'a', 'i', 't', 0,
    'Q', 'P', 'r', 'i', 'n', 't', 'e', 'r', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    'a', 'c', 'c', 'e', 'p', 't', 'e', 'd', 0,
    'f', 'r', 'o', 'm', 'P', 'a', 'g', 'e', 0,
    'f', 'u', 'l', 'l', 'P', 'a', 'g', 'e', 0,
    'i', 's', 'R', 'e', 'm', 'o', 't', 'e', 0,
    'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'p', 'a', 'g', 'e', 'R', 'e', 'c', 't', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    'v', 'i', 'e', 'w', 'M', 'o', 'd', 'e', 0,
    'z', 'o', 'o', 'm', 'M', 'o', 'd', 'e', 0,
    'A', 'b', 'o', 'r', 't', 'e', 'd', 0,
    'O', 'n', 'l', 'y', 'O', 'n', 'e', 0,
    'T', 'r', 'a', 'c', 't', 'o', 'r', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    'c', 'r', 'e', 'a', 't', 'o', 'r', 0,
    'd', 'e', 'v', 'T', 'y', 'p', 'e', 0,
    'd', 'o', 'c', 'N', 'a', 'm', 'e', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    'm', 'a', 'x', 'P', 'a', 'g', 'e', 0,
    'm', 'i', 'n', 'P', 'a', 'g', 'e', 0,
    'n', 'e', 'w', 'P', 'a', 'g', 'e', 0,
    'o', 'p', 't', 'i', 'o', 'n', 's', 0,
    'p', 'r', 'i', 'n', 't', 'e', 'r', 0,
    'z', 'o', 'o', 'm', 'O', 'u', 't', 0,
    'A', 'c', 't', 'i', 'v', 'e', 0,
    'C', 'i', 'c', 'e', 'r', 'o', 0,
    'M', 'i', 'd', 'd', 'l', 'e', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    'a', 'c', 'c', 'e', 'p', 't', 0,
    'd', 'u', 'p', 'l', 'e', 'x', 0,
    'f', 'a', 'c', 't', 'o', 'r', 0,
    'i', 's', 'N', 'u', 'l', 'l', 0,
    'm', 'e', 't', 'r', 'i', 'c', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'p', 'r', 'i', 'n', 't', '_', 0,
    'r', 'e', 'j', 'e', 'c', 't', 0,
    't', 'o', 'P', 'a', 'g', 'e', 0,
    'z', 'o', 'o', 'm', 'I', 'n', 0,
    'C', 'o', 'l', 'o', 'r', 0,
    'D', 'i', 'd', 'o', 't', 0,
    'E', 'r', 'r', 'o', 'r', 0,
    'L', 'o', 'w', 'e', 'r', 0,
    'N', 'o', 'n', 'e', '_', 0,
    'P', 'o', 'i', 'n', 't', 0,
    'U', 'p', 'p', 'e', 'r', 0,
    'a', 'b', 'o', 'r', 't', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'e', 'x', 'e', 'c', '_', 0,
    'f', 'l', 'a', 'g', 's', 0,
    'p', 'r', 'i', 'n', 't', 0,
    's', 't', 'a', 't', 'e', 0,
    'I', 'd', 'l', 'e', 0,
    'I', 'n', 'c', 'h', 0,
    'P', 'i', 'c', 'a', 0,
    'd', 'o', 'n', 'e', 0,
    'e', 'x', 'e', 'c', 0,
    'm', 'o', 'd', 'e', 0,
    'o', 'p', 'e', 'n', 0,
};
#line 166 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qabstractprintdialog.sip"
// Imports from QtCore.
pyqt5_qtprintsupport_get_connection_parts_t pyqt5_qtprintsupport_get_connection_parts;
#line 471 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"

void sipVH_QtPrintSupport_43(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPagedPaintDevice::PageSize a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_QPagedPaintDevice_PageSize);
}

void sipVH_QtPrintSupport_42(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QSizeF& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QSizeF(a0), sipType_QSizeF, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_41(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPagedPaintDevice::Margins& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QPagedPaintDevice::Margins(a0), sipType_QPagedPaintDevice_Margins, SIP_NULLPTR);
}

::QPrinter::PrinterState sipVH_QtPrintSupport_40(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPrinter::PrinterState sipRes = ::QPrinter::Idle;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QPrinter_PrinterState, &sipRes);

    return sipRes;
}

::QVariant sipVH_QtPrintSupport_39(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPrintEngine::PrintEnginePropertyKey a0)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QPrintEngine_PrintEnginePropertyKey);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

void sipVH_QtPrintSupport_38(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPrintEngine::PrintEnginePropertyKey a0, const ::QVariant& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "FN", a0, sipType_QPrintEngine_PrintEnginePropertyKey, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_37(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QPainter, SIP_NULLPTR);
}

::QPainter* sipVH_QtPrintSupport_36(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPainter* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPainter, &sipRes);

    return sipRes;
}

bool sipVH_QtPrintSupport_35(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QByteArray& a0, void*a1, long*a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NV", new ::QByteArray(a0), sipType_QByteArray, SIP_NULLPTR, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(bl)", &sipRes, a2);

    return sipRes;
}

bool sipVH_QtPrintSupport_34(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtPrintSupport_33(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "b", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QVariant sipVH_QtPrintSupport_32(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::Qt::InputMethodQuery a0)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_Qt_InputMethodQuery);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

void sipVH_QtPrintSupport_31(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QInputMethodEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QInputMethodEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_30(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QHideEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QHideEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_29(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QShowEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QShowEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_28(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDropEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDropEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_27(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDragLeaveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragLeaveEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_26(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDragMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragMoveEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_25(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDragEnterEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragEnterEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_24(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QActionEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QActionEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_23(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTabletEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTabletEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_22(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QContextMenuEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QContextMenuEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCloseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QCloseEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QResizeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QResizeEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMoveEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPaintEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QPaintEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QFocusEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QFocusEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QKeyEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QKeyEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWheelEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QWheelEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMouseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMouseEvent, SIP_NULLPTR);
}

int sipVH_QtPrintSupport_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

::QSize sipVH_QtPrintSupport_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

void sipVH_QtPrintSupport_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "b", a0);
}

::QPaintEngine* sipVH_QtPrintSupport_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPaintEngine* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPaintEngine, &sipRes);

    return sipRes;
}

int sipVH_QtPrintSupport_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPaintDevice::PaintDeviceMetric a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QPaintDevice_PaintDeviceMetric);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

bool sipVH_QtPrintSupport_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtPrintSupport_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtPrintSupport_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtPrintSupport_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}

int sipVH_QtPrintSupport_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

void sipVH_QtPrintSupport_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "i", a0);
}

void sipVH_QtPrintSupport_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QAbstractPrintDialog(void **);}
static const sipTypeDef *sipSubClass_QAbstractPrintDialog(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 32 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qabstractprintdialog.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
    #if defined(SIP_FEATURE_PyQt_PrintDialog)
        {sipName_QPageSetupDialog, &sipType_QPageSetupDialog, -1, 1},
    #else
        {0, 0, -1, 1},
    #endif
    #if defined(SIP_FEATURE_PyQt_PrintPreviewWidget)
        {sipName_QPrintPreviewWidget, &sipType_QPrintPreviewWidget, -1, 2},
    #else
        {0, 0, -1, 2},
    #endif
    #if defined(SIP_FEATURE_PyQt_PrintPreviewDialog)
        {sipName_QPrintPreviewDialog, &sipType_QPrintPreviewDialog, -1, 3},
    #else
        {0, 0, -1, 3},
    #endif
    #if defined(SIP_FEATURE_PyQt_Printer)
        {sipName_QAbstractPrintDialog, &sipType_QAbstractPrintDialog, 4, -1},
    #else
        {0, 0, 4, -1},
    #endif
    #if defined(SIP_FEATURE_PyQt_PrintDialog)
        {sipName_QPrintDialog, &sipType_QPrintDialog, -1, -1},
    #else
        {0, 0, -1, -1},
    #endif
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 821 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"

    return sipType;
}


extern "C" {static PyObject *slot_QAbstractPrintDialog_PrintDialogOption___or__(PyObject *, PyObject *);}
static PyObject *slot_QAbstractPrintDialog_PrintDialogOption___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractPrintDialog::PrintDialogOption a0;
        ::QAbstractPrintDialog::PrintDialogOptions* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QAbstractPrintDialog_PrintDialogOption, &a0, sipType_QAbstractPrintDialog_PrintDialogOptions, &a1, &a1State))
        {
            ::QAbstractPrintDialog::PrintDialogOptions*sipRes;

            sipRes = new ::QAbstractPrintDialog::PrintDialogOptions((a0 | *a1));
            sipReleaseType(a1, sipType_QAbstractPrintDialog_PrintDialogOptions, a1State);

            return sipConvertFromNewType(sipRes, sipType_QAbstractPrintDialog_PrintDialogOptions, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QAbstractPrintDialog_PrintDialogOption[] = {
    {(void *)slot_QAbstractPrintDialog_PrintDialogOption___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};

static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAbstractPrintDialog__PrintDialogOption, SIP_NULLPTR, 0}, sipNameNr_PrintDialogOption, 0, slots_QAbstractPrintDialog_PrintDialogOption},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAbstractPrintDialog__PrintRange, SIP_NULLPTR, 0}, sipNameNr_PrintRange, 0, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPrintEngine__PrintEnginePropertyKey, SIP_NULLPTR, 0}, sipNameNr_PrintEnginePropertyKey, 12, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPrintPreviewWidget__ViewMode, SIP_NULLPTR, 0}, sipNameNr_ViewMode, 15, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPrintPreviewWidget__ZoomMode, SIP_NULLPTR, 0}, sipNameNr_ZoomMode, 15, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPrinter__ColorMode, SIP_NULLPTR, 0}, sipNameNr_ColorMode, 18, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPrinter__DuplexMode, SIP_NULLPTR, 0}, sipNameNr_DuplexMode, 18, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPrinter__Orientation, SIP_NULLPTR, 0}, sipNameNr_Orientation, 18, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPrinter__OutputFormat, SIP_NULLPTR, 0}, sipNameNr_OutputFormat, 18, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPrinter__PageOrder, SIP_NULLPTR, 0}, sipNameNr_PageOrder, 18, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPrinter__PaperSource, SIP_NULLPTR, 0}, sipNameNr_PaperSource, 18, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPrinter__PrintRange, SIP_NULLPTR, 0}, sipNameNr_PrintRange, 18, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPrinter__PrinterMode, SIP_NULLPTR, 0}, sipNameNr_PrinterMode, 18, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPrinter__PrinterState, SIP_NULLPTR, 0}, sipNameNr_PrinterState, 18, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QPrinter__Unit, SIP_NULLPTR, 0}, sipNameNr_Unit, 18, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtPrintSupport[] = {
    &sipTypeDef_QtPrintSupport_QAbstractPrintDialog.ctd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_QtPrintSupport_QAbstractPrintDialog_PrintDialogOptions.ctd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_QtPrintSupport_QList_0100QPageSize.mtd_base,
    &sipTypeDef_QtPrintSupport_QList_0100QPagedPaintDevice_PageSize.mtd_base,
    &sipTypeDef_QtPrintSupport_QList_0600QPair_0100QString_0100QSizeF.mtd_base,
    &sipTypeDef_QtPrintSupport_QList_0100QPrinter_ColorMode.mtd_base,
    &sipTypeDef_QtPrintSupport_QList_0100QPrinter_DuplexMode.mtd_base,
    &sipTypeDef_QtPrintSupport_QList_0100QPrinterInfo.mtd_base,
    &sipTypeDef_QtPrintSupport_QPageSetupDialog.ctd_base,
    &sipTypeDef_QtPrintSupport_QPrintDialog.ctd_base,
    &sipTypeDef_QtPrintSupport_QPrintEngine.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_QtPrintSupport_QPrintPreviewDialog.ctd_base,
    &sipTypeDef_QtPrintSupport_QPrintPreviewWidget.ctd_base,
    &enumTypes[3].etd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_QtPrintSupport_QPrinter.ctd_base,
    &enumTypes[5].etd_base,
    &enumTypes[6].etd_base,
    &enumTypes[7].etd_base,
    &enumTypes[8].etd_base,
    &enumTypes[9].etd_base,
    &enumTypes[10].etd_base,
    &enumTypes[11].etd_base,
    &enumTypes[12].etd_base,
    &enumTypes[13].etd_base,
    &enumTypes[14].etd_base,
    &sipTypeDef_QtPrintSupport_QPrinterInfo.ctd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"QPrinter::PaperSize", "QPagedPaintDevice::PageSize"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtPrintSupport_QtCore[] = {
    {"QByteArray"},
    {"QChildEvent"},
    {"QEvent"},
    {"QList<int>"},
    {"QMetaMethod"},
    {"QObject"},
    {"QRect"},
    {"QRectF"},
    {"QSize"},
    {"QSizeF"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QVariant"},
    {"Qt::InputMethodQuery"},
    {"Qt::WindowFlags"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_QtPrintSupport_QtGui[] = {
    {"QActionEvent"},
    {"QCloseEvent"},
    {"QContextMenuEvent"},
    {"QDragEnterEvent"},
    {"QDragLeaveEvent"},
    {"QDragMoveEvent"},
    {"QDropEvent"},
    {"QFocusEvent"},
    {"QHideEvent"},
    {"QInputMethodEvent"},
    {"QKeyEvent"},
    {"QMouseEvent"},
    {"QMoveEvent"},
    {"QPageSize"},
    {"QPagedPaintDevice"},
    {"QPagedPaintDevice::Margins"},
    {"QPagedPaintDevice::PageSize"},
    {"QPagedPaintDevice::PdfVersion"},
    {"QPaintDevice"},
    {"QPaintDevice::PaintDeviceMetric"},
    {"QPaintEngine"},
    {"QPaintEvent"},
    {"QPainter"},
    {"QResizeEvent"},
    {"QShowEvent"},
    {"QTabletEvent"},
    {"QWheelEvent"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtWidgets. */
sipImportedTypeDef sipImportedTypes_QtPrintSupport_QtWidgets[] = {
    {"QDialog"},
    {"QList<QWidget*>"},
    {"QWidget"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_QtPrintSupport_QtCore, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore, SIP_NULLPTR},
    {"PyQt5.QtGui", sipImportedTypes_QtPrintSupport_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.QtWidgets", sipImportedTypes_QtPrintSupport_QtWidgets, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QAbstractPrintDialog, {5, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtPrintSupport = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_QtPrintSupport,
    0,
    sipStrings_QtPrintSupport,
    importsTable,
    SIP_NULLPTR,
    30,
    sipExportedTypes_QtPrintSupport,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    1,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtPrintSupport;

sip_qt_metaobject_func sip_QtPrintSupport_qt_metaobject;
sip_qt_metacall_func sip_QtPrintSupport_qt_metacall;
sip_qt_metacast_func sip_QtPrintSupport_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtPrintSupport()
#else
PyMODINIT_FUNC PyInit_QtPrintSupport()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.QtPrintSupport",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtPrintSupport = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_QtPrintSupport == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtPrintSupport, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtPrintSupport_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtPrintSupport_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtPrintSupport_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtPrintSupport_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtPrintSupport, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }
#line 171 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qabstractprintdialog.sip"
// Imports from QtCore.
pyqt5_qtprintsupport_get_connection_parts = (pyqt5_qtprintsupport_get_connection_parts_t)sipImportSymbol("pyqt5_get_connection_parts");
Q_ASSERT(pyqt5_qtprintsupport_get_connection_parts);
#line 1138 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportcmodule.cpp"

    return sipModule;
}
