/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 243 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qxmlstream.sip"
#include <qxmlstream.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQXmlStreamNotationDeclaration.cpp"

#line 59 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQXmlStreamNotationDeclaration.cpp"


PyDoc_STRVAR(doc_QXmlStreamNotationDeclaration_name, "name(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamNotationDeclaration_name(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamNotationDeclaration_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamNotationDeclaration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamNotationDeclaration, &sipCpp))
        {
            ::QStringRef*sipRes;

            sipRes = new ::QStringRef(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QStringRef, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamNotationDeclaration, sipName_name, doc_QXmlStreamNotationDeclaration_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamNotationDeclaration_systemId, "systemId(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamNotationDeclaration_systemId(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamNotationDeclaration_systemId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamNotationDeclaration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamNotationDeclaration, &sipCpp))
        {
            ::QStringRef*sipRes;

            sipRes = new ::QStringRef(sipCpp->systemId());

            return sipConvertFromNewType(sipRes, sipType_QStringRef, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamNotationDeclaration, sipName_systemId, doc_QXmlStreamNotationDeclaration_systemId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlStreamNotationDeclaration_publicId, "publicId(self) -> str");

extern "C" {static PyObject *meth_QXmlStreamNotationDeclaration_publicId(PyObject *, PyObject *);}
static PyObject *meth_QXmlStreamNotationDeclaration_publicId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamNotationDeclaration *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlStreamNotationDeclaration, &sipCpp))
        {
            ::QStringRef*sipRes;

            sipRes = new ::QStringRef(sipCpp->publicId());

            return sipConvertFromNewType(sipRes, sipType_QStringRef, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlStreamNotationDeclaration, sipName_publicId, doc_QXmlStreamNotationDeclaration_publicId);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QXmlStreamNotationDeclaration___ne__(PyObject *, PyObject *);}
static PyObject *slot_QXmlStreamNotationDeclaration___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QXmlStreamNotationDeclaration *sipCpp = reinterpret_cast< ::QXmlStreamNotationDeclaration *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QXmlStreamNotationDeclaration));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamNotationDeclaration* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QXmlStreamNotationDeclaration, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QXmlStreamNotationDeclaration::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, ne_slot, sipType_QXmlStreamNotationDeclaration, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QXmlStreamNotationDeclaration___eq__(PyObject *, PyObject *);}
static PyObject *slot_QXmlStreamNotationDeclaration___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QXmlStreamNotationDeclaration *sipCpp = reinterpret_cast< ::QXmlStreamNotationDeclaration *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QXmlStreamNotationDeclaration));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlStreamNotationDeclaration* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QXmlStreamNotationDeclaration, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QXmlStreamNotationDeclaration::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, eq_slot, sipType_QXmlStreamNotationDeclaration, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QXmlStreamNotationDeclaration(void *, int);}
static void release_QXmlStreamNotationDeclaration(void *sipCppV, int)
{
    delete reinterpret_cast< ::QXmlStreamNotationDeclaration *>(sipCppV);
}


extern "C" {static void *array_QXmlStreamNotationDeclaration(Py_ssize_t);}
static void *array_QXmlStreamNotationDeclaration(Py_ssize_t sipNrElem)
{
    return new ::QXmlStreamNotationDeclaration[sipNrElem];
}


extern "C" {static void array_delete_QXmlStreamNotationDeclaration(void *);}
static void array_delete_QXmlStreamNotationDeclaration(void *sipCpp)
{
    delete[] reinterpret_cast< ::QXmlStreamNotationDeclaration *>(sipCpp);
}


extern "C" {static void assign_QXmlStreamNotationDeclaration(void *, Py_ssize_t, void *);}
static void assign_QXmlStreamNotationDeclaration(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QXmlStreamNotationDeclaration *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QXmlStreamNotationDeclaration *>(sipSrc);
}


extern "C" {static void *copy_QXmlStreamNotationDeclaration(const void *, Py_ssize_t);}
static void *copy_QXmlStreamNotationDeclaration(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QXmlStreamNotationDeclaration(reinterpret_cast<const ::QXmlStreamNotationDeclaration *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QXmlStreamNotationDeclaration(sipSimpleWrapper *);}
static void dealloc_QXmlStreamNotationDeclaration(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QXmlStreamNotationDeclaration(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QXmlStreamNotationDeclaration(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QXmlStreamNotationDeclaration(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QXmlStreamNotationDeclaration *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QXmlStreamNotationDeclaration();

            return sipCpp;
        }
    }

    {
        const ::QXmlStreamNotationDeclaration* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QXmlStreamNotationDeclaration, &a0))
        {
            sipCpp = new ::QXmlStreamNotationDeclaration(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QXmlStreamNotationDeclaration[] = {
    {(void *)slot_QXmlStreamNotationDeclaration___ne__, ne_slot},
    {(void *)slot_QXmlStreamNotationDeclaration___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QXmlStreamNotationDeclaration[] = {
    {sipName_name, meth_QXmlStreamNotationDeclaration_name, METH_VARARGS, doc_QXmlStreamNotationDeclaration_name},
    {sipName_publicId, meth_QXmlStreamNotationDeclaration_publicId, METH_VARARGS, doc_QXmlStreamNotationDeclaration_publicId},
    {sipName_systemId, meth_QXmlStreamNotationDeclaration_systemId, METH_VARARGS, doc_QXmlStreamNotationDeclaration_systemId}
};

PyDoc_STRVAR(doc_QXmlStreamNotationDeclaration, "\1QXmlStreamNotationDeclaration()\n"
"QXmlStreamNotationDeclaration(a0: QXmlStreamNotationDeclaration)");


static pyqt5ClassPluginDef plugin_QXmlStreamNotationDeclaration = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QXmlStreamNotationDeclaration = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QXmlStreamNotationDeclaration,
        SIP_NULLPTR,
        &plugin_QXmlStreamNotationDeclaration,
    },
    {
        sipNameNr_QXmlStreamNotationDeclaration,
        {0, 0, 1},
        3, methods_QXmlStreamNotationDeclaration,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QXmlStreamNotationDeclaration,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QXmlStreamNotationDeclaration,
    init_type_QXmlStreamNotationDeclaration,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QXmlStreamNotationDeclaration,
    assign_QXmlStreamNotationDeclaration,
    array_QXmlStreamNotationDeclaration,
    copy_QXmlStreamNotationDeclaration,
    release_QXmlStreamNotationDeclaration,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QXmlStreamNotationDeclaration,
    sizeof (::QXmlStreamNotationDeclaration),
};
