/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerafocus.sip"
#include <qcamerafocus.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerafocus.sip"
#include <qcamerafocus.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerafocus.sip"
#include <qcamerafocus.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocus.cpp"


PyDoc_STRVAR(doc_QCameraFocus_isAvailable, "isAvailable(self) -> bool");

extern "C" {static PyObject *meth_QCameraFocus_isAvailable(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocus_isAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraFocus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocus, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocus, sipName_isAvailable, doc_QCameraFocus_isAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocus_focusMode, "focusMode(self) -> QCameraFocus.FocusModes");

extern "C" {static PyObject *meth_QCameraFocus_focusMode(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocus_focusMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraFocus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocus, &sipCpp))
        {
            ::QCameraFocus::FocusModes*sipRes;

            sipRes = new ::QCameraFocus::FocusModes(sipCpp->focusMode());

            return sipConvertFromNewType(sipRes, sipType_QCameraFocus_FocusModes, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocus, sipName_focusMode, doc_QCameraFocus_focusMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocus_setFocusMode, "setFocusMode(self, mode: Union[QCameraFocus.FocusModes, QCameraFocus.FocusMode])");

extern "C" {static PyObject *meth_QCameraFocus_setFocusMode(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocus_setFocusMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCameraFocus::FocusModes* a0;
        int a0State = 0;
        ::QCameraFocus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCameraFocus, &sipCpp, sipType_QCameraFocus_FocusModes, &a0, &a0State))
        {
            sipCpp->setFocusMode(*a0);
            sipReleaseType(a0, sipType_QCameraFocus_FocusModes, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocus, sipName_setFocusMode, doc_QCameraFocus_setFocusMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocus_isFocusModeSupported, "isFocusModeSupported(self, mode: Union[QCameraFocus.FocusModes, QCameraFocus.FocusMode]) -> bool");

extern "C" {static PyObject *meth_QCameraFocus_isFocusModeSupported(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocus_isFocusModeSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCameraFocus::FocusModes* a0;
        int a0State = 0;
        const ::QCameraFocus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCameraFocus, &sipCpp, sipType_QCameraFocus_FocusModes, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->isFocusModeSupported(*a0);
            sipReleaseType(a0, sipType_QCameraFocus_FocusModes, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocus, sipName_isFocusModeSupported, doc_QCameraFocus_isFocusModeSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocus_focusPointMode, "focusPointMode(self) -> QCameraFocus.FocusPointMode");

extern "C" {static PyObject *meth_QCameraFocus_focusPointMode(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocus_focusPointMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraFocus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocus, &sipCpp))
        {
            ::QCameraFocus::FocusPointMode sipRes;

            sipRes = sipCpp->focusPointMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCameraFocus_FocusPointMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocus, sipName_focusPointMode, doc_QCameraFocus_focusPointMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocus_setFocusPointMode, "setFocusPointMode(self, mode: QCameraFocus.FocusPointMode)");

extern "C" {static PyObject *meth_QCameraFocus_setFocusPointMode(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocus_setFocusPointMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCameraFocus::FocusPointMode a0;
        ::QCameraFocus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraFocus, &sipCpp, sipType_QCameraFocus_FocusPointMode, &a0))
        {
            sipCpp->setFocusPointMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocus, sipName_setFocusPointMode, doc_QCameraFocus_setFocusPointMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocus_isFocusPointModeSupported, "isFocusPointModeSupported(self, a0: QCameraFocus.FocusPointMode) -> bool");

extern "C" {static PyObject *meth_QCameraFocus_isFocusPointModeSupported(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocus_isFocusPointModeSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCameraFocus::FocusPointMode a0;
        const ::QCameraFocus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraFocus, &sipCpp, sipType_QCameraFocus_FocusPointMode, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isFocusPointModeSupported(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocus, sipName_isFocusPointModeSupported, doc_QCameraFocus_isFocusPointModeSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocus_customFocusPoint, "customFocusPoint(self) -> QPointF");

extern "C" {static PyObject *meth_QCameraFocus_customFocusPoint(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocus_customFocusPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraFocus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocus, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->customFocusPoint());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocus, sipName_customFocusPoint, doc_QCameraFocus_customFocusPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocus_setCustomFocusPoint, "setCustomFocusPoint(self, point: Union[QPointF, QPoint])");

extern "C" {static PyObject *meth_QCameraFocus_setCustomFocusPoint(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocus_setCustomFocusPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        int a0State = 0;
        ::QCameraFocus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCameraFocus, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
            sipCpp->setCustomFocusPoint(*a0);
            sipReleaseType(const_cast< ::QPointF *>(a0), sipType_QPointF, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocus, sipName_setCustomFocusPoint, doc_QCameraFocus_setCustomFocusPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocus_focusZones, "focusZones(self) -> list[QCameraFocusZone]");

extern "C" {static PyObject *meth_QCameraFocus_focusZones(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocus_focusZones(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraFocus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocus, &sipCpp))
        {
            ::QCameraFocusZoneList*sipRes;

            sipRes = new ::QCameraFocusZoneList(sipCpp->focusZones());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QCameraFocusZone, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocus, sipName_focusZones, doc_QCameraFocus_focusZones);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocus_maximumOpticalZoom, "maximumOpticalZoom(self) -> float");

extern "C" {static PyObject *meth_QCameraFocus_maximumOpticalZoom(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocus_maximumOpticalZoom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraFocus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocus, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->maximumOpticalZoom();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocus, sipName_maximumOpticalZoom, doc_QCameraFocus_maximumOpticalZoom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocus_maximumDigitalZoom, "maximumDigitalZoom(self) -> float");

extern "C" {static PyObject *meth_QCameraFocus_maximumDigitalZoom(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocus_maximumDigitalZoom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraFocus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocus, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->maximumDigitalZoom();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocus, sipName_maximumDigitalZoom, doc_QCameraFocus_maximumDigitalZoom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocus_opticalZoom, "opticalZoom(self) -> float");

extern "C" {static PyObject *meth_QCameraFocus_opticalZoom(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocus_opticalZoom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraFocus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocus, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->opticalZoom();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocus, sipName_opticalZoom, doc_QCameraFocus_opticalZoom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocus_digitalZoom, "digitalZoom(self) -> float");

extern "C" {static PyObject *meth_QCameraFocus_digitalZoom(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocus_digitalZoom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraFocus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocus, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->digitalZoom();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocus, sipName_digitalZoom, doc_QCameraFocus_digitalZoom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocus_zoomTo, "zoomTo(self, opticalZoom: float, digitalZoom: float)");

extern "C" {static PyObject *meth_QCameraFocus_zoomTo(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocus_zoomTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::qreal a1;
        ::QCameraFocus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QCameraFocus, &sipCpp, &a0, &a1))
        {
            sipCpp->zoomTo(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocus, sipName_zoomTo, doc_QCameraFocus_zoomTo);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QCameraFocus(void *, const sipTypeDef *);}
static void *cast_QCameraFocus(void *sipCppV, const sipTypeDef *targetType)
{
    ::QCameraFocus *sipCpp = reinterpret_cast< ::QCameraFocus *>(sipCppV);

    if (targetType == sipType_QCameraFocus)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QCameraFocus(void *, int);}
static void release_QCameraFocus(void *, int)
{
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QCameraFocus[] = {{9, 0, 1}};


static PyMethodDef methods_QCameraFocus[] = {
    {sipName_customFocusPoint, meth_QCameraFocus_customFocusPoint, METH_VARARGS, doc_QCameraFocus_customFocusPoint},
    {sipName_digitalZoom, meth_QCameraFocus_digitalZoom, METH_VARARGS, doc_QCameraFocus_digitalZoom},
    {sipName_focusMode, meth_QCameraFocus_focusMode, METH_VARARGS, doc_QCameraFocus_focusMode},
    {sipName_focusPointMode, meth_QCameraFocus_focusPointMode, METH_VARARGS, doc_QCameraFocus_focusPointMode},
    {sipName_focusZones, meth_QCameraFocus_focusZones, METH_VARARGS, doc_QCameraFocus_focusZones},
    {sipName_isAvailable, meth_QCameraFocus_isAvailable, METH_VARARGS, doc_QCameraFocus_isAvailable},
    {sipName_isFocusModeSupported, meth_QCameraFocus_isFocusModeSupported, METH_VARARGS, doc_QCameraFocus_isFocusModeSupported},
    {sipName_isFocusPointModeSupported, meth_QCameraFocus_isFocusPointModeSupported, METH_VARARGS, doc_QCameraFocus_isFocusPointModeSupported},
    {sipName_maximumDigitalZoom, meth_QCameraFocus_maximumDigitalZoom, METH_VARARGS, doc_QCameraFocus_maximumDigitalZoom},
    {sipName_maximumOpticalZoom, meth_QCameraFocus_maximumOpticalZoom, METH_VARARGS, doc_QCameraFocus_maximumOpticalZoom},
    {sipName_opticalZoom, meth_QCameraFocus_opticalZoom, METH_VARARGS, doc_QCameraFocus_opticalZoom},
    {sipName_setCustomFocusPoint, meth_QCameraFocus_setCustomFocusPoint, METH_VARARGS, doc_QCameraFocus_setCustomFocusPoint},
    {sipName_setFocusMode, meth_QCameraFocus_setFocusMode, METH_VARARGS, doc_QCameraFocus_setFocusMode},
    {sipName_setFocusPointMode, meth_QCameraFocus_setFocusPointMode, METH_VARARGS, doc_QCameraFocus_setFocusPointMode},
    {sipName_zoomTo, meth_QCameraFocus_zoomTo, METH_VARARGS, doc_QCameraFocus_zoomTo}
};

static sipEnumMemberDef enummembers_QCameraFocus[] = {
    {sipName_AutoFocus, static_cast<int>(::QCameraFocus::AutoFocus), 57},
    {sipName_ContinuousFocus, static_cast<int>(::QCameraFocus::ContinuousFocus), 57},
    {sipName_FocusPointAuto, static_cast<int>(::QCameraFocus::FocusPointAuto), 59},
    {sipName_FocusPointCenter, static_cast<int>(::QCameraFocus::FocusPointCenter), 59},
    {sipName_FocusPointCustom, static_cast<int>(::QCameraFocus::FocusPointCustom), 59},
    {sipName_FocusPointFaceDetection, static_cast<int>(::QCameraFocus::FocusPointFaceDetection), 59},
    {sipName_HyperfocalFocus, static_cast<int>(::QCameraFocus::HyperfocalFocus), 57},
    {sipName_InfinityFocus, static_cast<int>(::QCameraFocus::InfinityFocus), 57},
    {sipName_MacroFocus, static_cast<int>(::QCameraFocus::MacroFocus), 57},
    {sipName_ManualFocus, static_cast<int>(::QCameraFocus::ManualFocus), 57},
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QCameraFocus[] = {
    {"maximumDigitalZoomChanged(qreal)", "\1maximumDigitalZoomChanged(self, a0: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"maximumOpticalZoomChanged(qreal)", "\1maximumOpticalZoomChanged(self, a0: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"focusZonesChanged()", "\1focusZonesChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"digitalZoomChanged(qreal)", "\1digitalZoomChanged(self, a0: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"opticalZoomChanged(qreal)", "\1opticalZoomChanged(self, a0: float)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QCameraFocus = {
    &::QCameraFocus::staticMetaObject,
    0,
    signals_QCameraFocus,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QCameraFocus = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCameraFocus,
        SIP_NULLPTR,
        &plugin_QCameraFocus,
    },
    {
        sipNameNr_QCameraFocus,
        {0, 0, 1},
        15, methods_QCameraFocus,
        10, enummembers_QCameraFocus,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QCameraFocus,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QCameraFocus,
    cast_QCameraFocus,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
