/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoroute.sip"
#include <qgeoroute.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoute.cpp"

#line 24 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoute.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoute.cpp"
#line 73 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoroute.sip"
#include <qgeoroute.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoute.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoute.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeocoordinate.sip"
#include <qgeocoordinate.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoute.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoute.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoroutesegment.sip"
#include <qgeoroutesegment.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoute.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeorectangle.sip"
#include <qgeorectangle.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoute.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoute.cpp"


PyDoc_STRVAR(doc_QGeoRoute_setRouteId, "setRouteId(self, id: Optional[str])");

extern "C" {static PyObject *meth_QGeoRoute_setRouteId(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_setRouteId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoRoute, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setRouteId(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_setRouteId, doc_QGeoRoute_setRouteId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_routeId, "routeId(self) -> str");

extern "C" {static PyObject *meth_QGeoRoute_routeId(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_routeId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoute, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->routeId());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_routeId, doc_QGeoRoute_routeId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_setRequest, "setRequest(self, request: QGeoRouteRequest)");

extern "C" {static PyObject *meth_QGeoRoute_setRequest(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_setRequest(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteRequest* a0;
        ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRoute, &sipCpp, sipType_QGeoRouteRequest, &a0))
        {
            sipCpp->setRequest(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_setRequest, doc_QGeoRoute_setRequest);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_request, "request(self) -> QGeoRouteRequest");

extern "C" {static PyObject *meth_QGeoRoute_request(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_request(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoute, &sipCpp))
        {
            ::QGeoRouteRequest*sipRes;

            sipRes = new ::QGeoRouteRequest(sipCpp->request());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_request, doc_QGeoRoute_request);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_setBounds, "setBounds(self, bounds: QGeoRectangle)");

extern "C" {static PyObject *meth_QGeoRoute_setBounds(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_setBounds(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRectangle* a0;
        ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRoute, &sipCpp, sipType_QGeoRectangle, &a0))
        {
            sipCpp->setBounds(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_setBounds, doc_QGeoRoute_setBounds);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_bounds, "bounds(self) -> QGeoRectangle");

extern "C" {static PyObject *meth_QGeoRoute_bounds(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_bounds(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoute, &sipCpp))
        {
            ::QGeoRectangle*sipRes;

            sipRes = new ::QGeoRectangle(sipCpp->bounds());

            return sipConvertFromNewType(sipRes, sipType_QGeoRectangle, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_bounds, doc_QGeoRoute_bounds);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_setFirstRouteSegment, "setFirstRouteSegment(self, routeSegment: QGeoRouteSegment)");

extern "C" {static PyObject *meth_QGeoRoute_setFirstRouteSegment(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_setFirstRouteSegment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteSegment* a0;
        ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRoute, &sipCpp, sipType_QGeoRouteSegment, &a0))
        {
            sipCpp->setFirstRouteSegment(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_setFirstRouteSegment, doc_QGeoRoute_setFirstRouteSegment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_firstRouteSegment, "firstRouteSegment(self) -> QGeoRouteSegment");

extern "C" {static PyObject *meth_QGeoRoute_firstRouteSegment(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_firstRouteSegment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoute, &sipCpp))
        {
            ::QGeoRouteSegment*sipRes;

            sipRes = new ::QGeoRouteSegment(sipCpp->firstRouteSegment());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteSegment, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_firstRouteSegment, doc_QGeoRoute_firstRouteSegment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_setTravelTime, "setTravelTime(self, secs: int)");

extern "C" {static PyObject *meth_QGeoRoute_setTravelTime(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_setTravelTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QGeoRoute, &sipCpp, &a0))
        {
            sipCpp->setTravelTime(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_setTravelTime, doc_QGeoRoute_setTravelTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_travelTime, "travelTime(self) -> int");

extern "C" {static PyObject *meth_QGeoRoute_travelTime(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_travelTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoute, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->travelTime();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_travelTime, doc_QGeoRoute_travelTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_setDistance, "setDistance(self, distance: float)");

extern "C" {static PyObject *meth_QGeoRoute_setDistance(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_setDistance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QGeoRoute, &sipCpp, &a0))
        {
            sipCpp->setDistance(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_setDistance, doc_QGeoRoute_setDistance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_distance, "distance(self) -> float");

extern "C" {static PyObject *meth_QGeoRoute_distance(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_distance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoute, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->distance();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_distance, doc_QGeoRoute_distance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_setTravelMode, "setTravelMode(self, mode: QGeoRouteRequest.TravelMode)");

extern "C" {static PyObject *meth_QGeoRoute_setTravelMode(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_setTravelMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::TravelMode a0;
        ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGeoRoute, &sipCpp, sipType_QGeoRouteRequest_TravelMode, &a0))
        {
            sipCpp->setTravelMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_setTravelMode, doc_QGeoRoute_setTravelMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_travelMode, "travelMode(self) -> QGeoRouteRequest.TravelMode");

extern "C" {static PyObject *meth_QGeoRoute_travelMode(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_travelMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoute, &sipCpp))
        {
            ::QGeoRouteRequest::TravelMode sipRes;

            sipRes = sipCpp->travelMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoRouteRequest_TravelMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_travelMode, doc_QGeoRoute_travelMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_setPath, "setPath(self, path: Iterable[QGeoCoordinate])");

extern "C" {static PyObject *meth_QGeoRoute_setPath(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_setPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QGeoCoordinate>* a0;
        int a0State = 0;
        ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoRoute, &sipCpp, sipType_QList_0100QGeoCoordinate, &a0, &a0State))
        {
            sipCpp->setPath(*a0);
            sipReleaseType(const_cast<QList< ::QGeoCoordinate> *>(a0), sipType_QList_0100QGeoCoordinate, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_setPath, doc_QGeoRoute_setPath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_path, "path(self) -> list[QGeoCoordinate]");

extern "C" {static PyObject *meth_QGeoRoute_path(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_path(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoute, &sipCpp))
        {
            QList< ::QGeoCoordinate>*sipRes;

            sipRes = new QList< ::QGeoCoordinate>(sipCpp->path());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QGeoCoordinate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_path, doc_QGeoRoute_path);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_setRouteLegs, "setRouteLegs(self, legs: Iterable[QGeoRouteLeg])");

extern "C" {static PyObject *meth_QGeoRoute_setRouteLegs(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_setRouteLegs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QGeoRouteLeg>* a0;
        int a0State = 0;
        ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoRoute, &sipCpp, sipType_QList_0100QGeoRouteLeg, &a0, &a0State))
        {
            sipCpp->setRouteLegs(*a0);
            sipReleaseType(const_cast<QList< ::QGeoRouteLeg> *>(a0), sipType_QList_0100QGeoRouteLeg, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_setRouteLegs, doc_QGeoRoute_setRouteLegs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_routeLegs, "routeLegs(self) -> list[QGeoRouteLeg]");

extern "C" {static PyObject *meth_QGeoRoute_routeLegs(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_routeLegs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoute, &sipCpp))
        {
            QList< ::QGeoRouteLeg>*sipRes;

            sipRes = new QList< ::QGeoRouteLeg>(sipCpp->routeLegs());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QGeoRouteLeg, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_routeLegs, doc_QGeoRoute_routeLegs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_setExtendedAttributes, "setExtendedAttributes(self, extendedAttributes: dict[str, Any])");

extern "C" {static PyObject *meth_QGeoRoute_setExtendedAttributes(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_setExtendedAttributes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariantMap* a0;
        int a0State = 0;
        ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoRoute, &sipCpp, sipType_QVariantMap, &a0, &a0State))
        {
            sipCpp->setExtendedAttributes(*a0);
            sipReleaseType(const_cast< ::QVariantMap *>(a0), sipType_QVariantMap, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_setExtendedAttributes, doc_QGeoRoute_setExtendedAttributes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoute_extendedAttributes, "extendedAttributes(self) -> dict[str, Any]");

extern "C" {static PyObject *meth_QGeoRoute_extendedAttributes(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoute_extendedAttributes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoute *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoute, &sipCpp))
        {
            ::QVariantMap*sipRes;

            sipRes = new ::QVariantMap(sipCpp->extendedAttributes());

            return sipConvertFromNewType(sipRes, sipType_QVariantMap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoute, sipName_extendedAttributes, doc_QGeoRoute_extendedAttributes);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QGeoRoute___ne__(PyObject *, PyObject *);}
static PyObject *slot_QGeoRoute___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoRoute *sipCpp = reinterpret_cast< ::QGeoRoute *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoRoute));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoute* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGeoRoute, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QGeoRoute::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, ne_slot, sipType_QGeoRoute, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QGeoRoute___eq__(PyObject *, PyObject *);}
static PyObject *slot_QGeoRoute___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoRoute *sipCpp = reinterpret_cast< ::QGeoRoute *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoRoute));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoute* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGeoRoute, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QGeoRoute::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, eq_slot, sipType_QGeoRoute, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoRoute(void *, int);}
static void release_QGeoRoute(void *sipCppV, int)
{
    delete reinterpret_cast< ::QGeoRoute *>(sipCppV);
}


extern "C" {static void *array_QGeoRoute(Py_ssize_t);}
static void *array_QGeoRoute(Py_ssize_t sipNrElem)
{
    return new ::QGeoRoute[sipNrElem];
}


extern "C" {static void array_delete_QGeoRoute(void *);}
static void array_delete_QGeoRoute(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGeoRoute *>(sipCpp);
}


extern "C" {static void assign_QGeoRoute(void *, Py_ssize_t, void *);}
static void assign_QGeoRoute(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QGeoRoute *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QGeoRoute *>(sipSrc);
}


extern "C" {static void *copy_QGeoRoute(const void *, Py_ssize_t);}
static void *copy_QGeoRoute(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QGeoRoute(reinterpret_cast<const ::QGeoRoute *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QGeoRoute(sipSimpleWrapper *);}
static void dealloc_QGeoRoute(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoRoute(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QGeoRoute(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoRoute(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QGeoRoute *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QGeoRoute();

            return sipCpp;
        }
    }

    {
        const ::QGeoRoute* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QGeoRoute, &a0))
        {
            sipCpp = new ::QGeoRoute(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QGeoRoute[] = {
    {(void *)slot_QGeoRoute___ne__, ne_slot},
    {(void *)slot_QGeoRoute___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QGeoRoute[] = {
    {sipName_bounds, meth_QGeoRoute_bounds, METH_VARARGS, doc_QGeoRoute_bounds},
    {sipName_distance, meth_QGeoRoute_distance, METH_VARARGS, doc_QGeoRoute_distance},
    {sipName_extendedAttributes, meth_QGeoRoute_extendedAttributes, METH_VARARGS, doc_QGeoRoute_extendedAttributes},
    {sipName_firstRouteSegment, meth_QGeoRoute_firstRouteSegment, METH_VARARGS, doc_QGeoRoute_firstRouteSegment},
    {sipName_path, meth_QGeoRoute_path, METH_VARARGS, doc_QGeoRoute_path},
    {sipName_request, meth_QGeoRoute_request, METH_VARARGS, doc_QGeoRoute_request},
    {sipName_routeId, meth_QGeoRoute_routeId, METH_VARARGS, doc_QGeoRoute_routeId},
    {sipName_routeLegs, meth_QGeoRoute_routeLegs, METH_VARARGS, doc_QGeoRoute_routeLegs},
    {sipName_setBounds, meth_QGeoRoute_setBounds, METH_VARARGS, doc_QGeoRoute_setBounds},
    {sipName_setDistance, meth_QGeoRoute_setDistance, METH_VARARGS, doc_QGeoRoute_setDistance},
    {sipName_setExtendedAttributes, meth_QGeoRoute_setExtendedAttributes, METH_VARARGS, doc_QGeoRoute_setExtendedAttributes},
    {sipName_setFirstRouteSegment, meth_QGeoRoute_setFirstRouteSegment, METH_VARARGS, doc_QGeoRoute_setFirstRouteSegment},
    {sipName_setPath, meth_QGeoRoute_setPath, METH_VARARGS, doc_QGeoRoute_setPath},
    {sipName_setRequest, meth_QGeoRoute_setRequest, METH_VARARGS, doc_QGeoRoute_setRequest},
    {sipName_setRouteId, meth_QGeoRoute_setRouteId, METH_VARARGS, doc_QGeoRoute_setRouteId},
    {sipName_setRouteLegs, meth_QGeoRoute_setRouteLegs, METH_VARARGS, doc_QGeoRoute_setRouteLegs},
    {sipName_setTravelMode, meth_QGeoRoute_setTravelMode, METH_VARARGS, doc_QGeoRoute_setTravelMode},
    {sipName_setTravelTime, meth_QGeoRoute_setTravelTime, METH_VARARGS, doc_QGeoRoute_setTravelTime},
    {sipName_travelMode, meth_QGeoRoute_travelMode, METH_VARARGS, doc_QGeoRoute_travelMode},
    {sipName_travelTime, meth_QGeoRoute_travelTime, METH_VARARGS, doc_QGeoRoute_travelTime}
};

PyDoc_STRVAR(doc_QGeoRoute, "\1QGeoRoute()\n"
"QGeoRoute(other: QGeoRoute)");


static pyqt5ClassPluginDef plugin_QGeoRoute = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QGeoRoute = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoRoute,
        SIP_NULLPTR,
        &plugin_QGeoRoute,
    },
    {
        sipNameNr_QGeoRoute,
        {0, 0, 1},
        20, methods_QGeoRoute,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoRoute,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QGeoRoute,
    init_type_QGeoRoute,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoRoute,
    assign_QGeoRoute,
    array_QGeoRoute,
    copy_QGeoRoute,
    release_QGeoRoute,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGeoRoute,
    sizeof (::QGeoRoute),
};
