/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceeditorial.sip"
#include <qplaceeditorial.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceEditorial.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecontent.sip"
#include <qplacecontent.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceEditorial.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceEditorial.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceuser.sip"
#include <qplaceuser.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceEditorial.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesupplier.sip"
#include <qplacesupplier.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceEditorial.cpp"


class sipQPlaceEditorial : public ::QPlaceEditorial
{
public:
    sipQPlaceEditorial();
    sipQPlaceEditorial(const ::QPlaceContent&);
    sipQPlaceEditorial(const ::QPlaceEditorial&);
    ~sipQPlaceEditorial();

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPlaceEditorial(const sipQPlaceEditorial &);
    sipQPlaceEditorial &operator = (const sipQPlaceEditorial &);
};

sipQPlaceEditorial::sipQPlaceEditorial(): ::QPlaceEditorial(), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceEditorial::sipQPlaceEditorial(const ::QPlaceContent& a0): ::QPlaceEditorial(a0), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceEditorial::sipQPlaceEditorial(const ::QPlaceEditorial& a0): ::QPlaceEditorial(a0), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceEditorial::~sipQPlaceEditorial()
{
    sipInstanceDestroyedEx(&sipPySelf);
}


PyDoc_STRVAR(doc_QPlaceEditorial_text, "text(self) -> str");

extern "C" {static PyObject *meth_QPlaceEditorial_text(PyObject *, PyObject *);}
static PyObject *meth_QPlaceEditorial_text(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceEditorial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceEditorial, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->text());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceEditorial, sipName_text, doc_QPlaceEditorial_text);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceEditorial_setText, "setText(self, text: Optional[str])");

extern "C" {static PyObject *meth_QPlaceEditorial_setText(PyObject *, PyObject *);}
static PyObject *meth_QPlaceEditorial_setText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceEditorial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceEditorial, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceEditorial, sipName_setText, doc_QPlaceEditorial_setText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceEditorial_title, "title(self) -> str");

extern "C" {static PyObject *meth_QPlaceEditorial_title(PyObject *, PyObject *);}
static PyObject *meth_QPlaceEditorial_title(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceEditorial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceEditorial, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->title());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceEditorial, sipName_title, doc_QPlaceEditorial_title);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceEditorial_setTitle, "setTitle(self, data: Optional[str])");

extern "C" {static PyObject *meth_QPlaceEditorial_setTitle(PyObject *, PyObject *);}
static PyObject *meth_QPlaceEditorial_setTitle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceEditorial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceEditorial, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTitle(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceEditorial, sipName_setTitle, doc_QPlaceEditorial_setTitle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceEditorial_language, "language(self) -> str");

extern "C" {static PyObject *meth_QPlaceEditorial_language(PyObject *, PyObject *);}
static PyObject *meth_QPlaceEditorial_language(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceEditorial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceEditorial, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->language());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceEditorial, sipName_language, doc_QPlaceEditorial_language);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceEditorial_setLanguage, "setLanguage(self, data: Optional[str])");

extern "C" {static PyObject *meth_QPlaceEditorial_setLanguage(PyObject *, PyObject *);}
static PyObject *meth_QPlaceEditorial_setLanguage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceEditorial *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceEditorial, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setLanguage(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceEditorial, sipName_setLanguage, doc_QPlaceEditorial_setLanguage);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPlaceEditorial(void *, const sipTypeDef *);}
static void *cast_QPlaceEditorial(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPlaceEditorial *sipCpp = reinterpret_cast< ::QPlaceEditorial *>(sipCppV);

    if (targetType == sipType_QPlaceEditorial)
        return sipCppV;

    if (targetType == sipType_QPlaceContent)
        return static_cast< ::QPlaceContent *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPlaceEditorial(void *, int);}
static void release_QPlaceEditorial(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQPlaceEditorial *>(sipCppV);
    else
        delete reinterpret_cast< ::QPlaceEditorial *>(sipCppV);
}


extern "C" {static void *array_QPlaceEditorial(Py_ssize_t);}
static void *array_QPlaceEditorial(Py_ssize_t sipNrElem)
{
    return new ::QPlaceEditorial[sipNrElem];
}


extern "C" {static void array_delete_QPlaceEditorial(void *);}
static void array_delete_QPlaceEditorial(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPlaceEditorial *>(sipCpp);
}


extern "C" {static void assign_QPlaceEditorial(void *, Py_ssize_t, void *);}
static void assign_QPlaceEditorial(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPlaceEditorial *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPlaceEditorial *>(sipSrc);
}


extern "C" {static void *copy_QPlaceEditorial(const void *, Py_ssize_t);}
static void *copy_QPlaceEditorial(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPlaceEditorial(reinterpret_cast<const ::QPlaceEditorial *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPlaceEditorial(sipSimpleWrapper *);}
static void dealloc_QPlaceEditorial(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPlaceEditorial *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPlaceEditorial(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPlaceEditorial(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPlaceEditorial(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQPlaceEditorial *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQPlaceEditorial();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QPlaceContent* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPlaceContent, &a0))
        {
            sipCpp = new sipQPlaceEditorial(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QPlaceEditorial* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPlaceEditorial, &a0))
        {
            sipCpp = new sipQPlaceEditorial(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPlaceEditorial[] = {{57, 255, 1}};


static PyMethodDef methods_QPlaceEditorial[] = {
    {sipName_language, meth_QPlaceEditorial_language, METH_VARARGS, doc_QPlaceEditorial_language},
    {sipName_setLanguage, meth_QPlaceEditorial_setLanguage, METH_VARARGS, doc_QPlaceEditorial_setLanguage},
    {sipName_setText, meth_QPlaceEditorial_setText, METH_VARARGS, doc_QPlaceEditorial_setText},
    {sipName_setTitle, meth_QPlaceEditorial_setTitle, METH_VARARGS, doc_QPlaceEditorial_setTitle},
    {sipName_text, meth_QPlaceEditorial_text, METH_VARARGS, doc_QPlaceEditorial_text},
    {sipName_title, meth_QPlaceEditorial_title, METH_VARARGS, doc_QPlaceEditorial_title}
};

PyDoc_STRVAR(doc_QPlaceEditorial, "\1QPlaceEditorial()\n"
"QPlaceEditorial(other: QPlaceContent)\n"
"QPlaceEditorial(a0: QPlaceEditorial)");


static pyqt5ClassPluginDef plugin_QPlaceEditorial = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QPlaceEditorial = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPlaceEditorial,
        SIP_NULLPTR,
        &plugin_QPlaceEditorial,
    },
    {
        sipNameNr_QPlaceEditorial,
        {0, 0, 1},
        6, methods_QPlaceEditorial,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPlaceEditorial,
    -1,
    -1,
    supers_QPlaceEditorial,
    SIP_NULLPTR,
    init_type_QPlaceEditorial,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPlaceEditorial,
    assign_QPlaceEditorial,
    array_QPlaceEditorial,
    copy_QPlaceEditorial,
    release_QPlaceEditorial,
    cast_QPlaceEditorial,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPlaceEditorial,
    sizeof (::QPlaceEditorial),
};
