/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtXml.h"

#line 295 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"

#line 54 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 312 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 364 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 275 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 429 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 388 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 402 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 351 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 417 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 174 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 192 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 263 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 376 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 237 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"
#line 154 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomAttr.cpp"


PyDoc_STRVAR(doc_QDomAttr_name, "name(self) -> str");

extern "C" {static PyObject *meth_QDomAttr_name(PyObject *, PyObject *);}
static PyObject *meth_QDomAttr_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomAttr *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomAttr, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomAttr, sipName_name, doc_QDomAttr_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomAttr_specified, "specified(self) -> bool");

extern "C" {static PyObject *meth_QDomAttr_specified(PyObject *, PyObject *);}
static PyObject *meth_QDomAttr_specified(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomAttr *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomAttr, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->specified();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomAttr, sipName_specified, doc_QDomAttr_specified);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomAttr_ownerElement, "ownerElement(self) -> QDomElement");

extern "C" {static PyObject *meth_QDomAttr_ownerElement(PyObject *, PyObject *);}
static PyObject *meth_QDomAttr_ownerElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomAttr *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomAttr, &sipCpp))
        {
            ::QDomElement*sipRes;

            sipRes = new ::QDomElement(sipCpp->ownerElement());

            return sipConvertFromNewType(sipRes, sipType_QDomElement, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomAttr, sipName_ownerElement, doc_QDomAttr_ownerElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomAttr_value, "value(self) -> str");

extern "C" {static PyObject *meth_QDomAttr_value(PyObject *, PyObject *);}
static PyObject *meth_QDomAttr_value(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomAttr *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomAttr, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->value());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomAttr, sipName_value, doc_QDomAttr_value);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomAttr_setValue, "setValue(self, a0: Optional[str])");

extern "C" {static PyObject *meth_QDomAttr_setValue(PyObject *, PyObject *);}
static PyObject *meth_QDomAttr_setValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDomAttr *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDomAttr, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setValue(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomAttr, sipName_setValue, doc_QDomAttr_setValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomAttr_nodeType, "nodeType(self) -> QDomNode.NodeType");

extern "C" {static PyObject *meth_QDomAttr_nodeType(PyObject *, PyObject *);}
static PyObject *meth_QDomAttr_nodeType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomAttr *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomAttr, &sipCpp))
        {
            ::QDomNode::NodeType sipRes;

            sipRes = sipCpp->nodeType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QDomNode_NodeType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomAttr, sipName_nodeType, doc_QDomAttr_nodeType);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QDomAttr(void *, const sipTypeDef *);}
static void *cast_QDomAttr(void *sipCppV, const sipTypeDef *targetType)
{
    ::QDomAttr *sipCpp = reinterpret_cast< ::QDomAttr *>(sipCppV);

    if (targetType == sipType_QDomAttr)
        return sipCppV;

    if (targetType == sipType_QDomNode)
        return static_cast< ::QDomNode *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDomAttr(void *, int);}
static void release_QDomAttr(void *sipCppV, int)
{
    delete reinterpret_cast< ::QDomAttr *>(sipCppV);
}


extern "C" {static void *array_QDomAttr(Py_ssize_t);}
static void *array_QDomAttr(Py_ssize_t sipNrElem)
{
    return new ::QDomAttr[sipNrElem];
}


extern "C" {static void array_delete_QDomAttr(void *);}
static void array_delete_QDomAttr(void *sipCpp)
{
    delete[] reinterpret_cast< ::QDomAttr *>(sipCpp);
}


extern "C" {static void assign_QDomAttr(void *, Py_ssize_t, void *);}
static void assign_QDomAttr(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QDomAttr *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QDomAttr *>(sipSrc);
}


extern "C" {static void *copy_QDomAttr(const void *, Py_ssize_t);}
static void *copy_QDomAttr(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QDomAttr(reinterpret_cast<const ::QDomAttr *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QDomAttr(sipSimpleWrapper *);}
static void dealloc_QDomAttr(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDomAttr(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QDomAttr(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDomAttr(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QDomAttr *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QDomAttr();

            return sipCpp;
        }
    }

    {
        const ::QDomAttr* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QDomAttr, &a0))
        {
            sipCpp = new ::QDomAttr(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QDomAttr[] = {{13, 255, 1}};


static PyMethodDef methods_QDomAttr[] = {
    {sipName_name, meth_QDomAttr_name, METH_VARARGS, doc_QDomAttr_name},
    {sipName_nodeType, meth_QDomAttr_nodeType, METH_VARARGS, doc_QDomAttr_nodeType},
    {sipName_ownerElement, meth_QDomAttr_ownerElement, METH_VARARGS, doc_QDomAttr_ownerElement},
    {sipName_setValue, meth_QDomAttr_setValue, METH_VARARGS, doc_QDomAttr_setValue},
    {sipName_specified, meth_QDomAttr_specified, METH_VARARGS, doc_QDomAttr_specified},
    {sipName_value, meth_QDomAttr_value, METH_VARARGS, doc_QDomAttr_value}
};

PyDoc_STRVAR(doc_QDomAttr, "\1QDomAttr()\n"
"QDomAttr(x: QDomAttr)");


static pyqt5ClassPluginDef plugin_QDomAttr = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtXml_QDomAttr = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDomAttr,
        SIP_NULLPTR,
        &plugin_QDomAttr,
    },
    {
        sipNameNr_QDomAttr,
        {0, 0, 1},
        6, methods_QDomAttr,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDomAttr,
    -1,
    -1,
    supers_QDomAttr,
    SIP_NULLPTR,
    init_type_QDomAttr,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDomAttr,
    assign_QDomAttr,
    array_QDomAttr,
    copy_QDomAttr,
    release_QDomAttr,
    cast_QDomAttr,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QDomAttr,
    sizeof (::QDomAttr),
};
