/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPrintSupport.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qprintpreviewwidget.sip"
#include <qprintpreviewwidget.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qprinter.sip"
#include <qprinter.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 99 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 102 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 105 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 108 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 114 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 509 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 117 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 120 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 471 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 123 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 460 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 126 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 570 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 129 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 619 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 132 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 592 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 135 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 608 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 138 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 675 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 141 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 302 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 144 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 482 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 147 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 438 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 150 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 425 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 153 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 412 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 156 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 398 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 159 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 384 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 162 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 363 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 165 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 253 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 168 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 205 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 171 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 174 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 177 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 180 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 183 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 186 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 189 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 192 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 198 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 201 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 204 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 209 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 212 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 215 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 218 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 221 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 224 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 227 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 230 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 233 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 236 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 239 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 242 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQPrintPreviewWidget.cpp"


class sipQPrintPreviewWidget : public ::QPrintPreviewWidget
{
public:
    sipQPrintPreviewWidget(::QPrinter*, ::QWidget*, ::Qt::WindowFlags);
    sipQPrintPreviewWidget(::QWidget*, ::Qt::WindowFlags);
    virtual ~sipQPrintPreviewWidget();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void enterEvent(::QEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, long*) SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    void initPainter(::QPainter*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPrintPreviewWidget(const sipQPrintPreviewWidget &);
    sipQPrintPreviewWidget &operator = (const sipQPrintPreviewWidget &);

    char sipPyMethods[46];
};

sipQPrintPreviewWidget::sipQPrintPreviewWidget(::QPrinter*a0, ::QWidget*a1, ::Qt::WindowFlags a2): ::QPrintPreviewWidget(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQPrintPreviewWidget::sipQPrintPreviewWidget(::QWidget*a0, ::Qt::WindowFlags a1): ::QPrintPreviewWidget(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQPrintPreviewWidget::~sipQPrintPreviewWidget()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQPrintPreviewWidget::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtPrintSupport_qt_metaobject(sipPySelf, sipType_QPrintPreviewWidget);

    return ::QPrintPreviewWidget::metaObject();
}

int sipQPrintPreviewWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QPrintPreviewWidget::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtPrintSupport_qt_metacall(sipPySelf, sipType_QPrintPreviewWidget, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQPrintPreviewWidget::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtPrintSupport_qt_metacast(sipPySelf, sipType_QPrintPreviewWidget, _clname, &sipCpp) ? sipCpp : ::QPrintPreviewWidget::qt_metacast(_clname));
}

void sipQPrintPreviewWidget::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPrintSupport_3(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::connectNotify(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPrintSupport_3(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::customEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPrintSupport_4(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::childEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtPrintSupport_5(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::timerEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtPrintSupport_6(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPrintPreviewWidget::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QPrintPreviewWidget::eventFilter(a0, a1);

    extern bool sipVH_QtPrintSupport_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtPrintSupport_7(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQPrintPreviewWidget::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QPrintPreviewWidget::event(a0);

    extern bool sipVH_QtPrintSupport_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtPrintSupport_8(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQPrintPreviewWidget::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QPrintPreviewWidget::metric(a0);

    extern int sipVH_QtPrintSupport_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtPrintSupport_9(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPaintEngine* sipQPrintPreviewWidget::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QPrintPreviewWidget::paintEngine();

    extern ::QPaintEngine* sipVH_QtPrintSupport_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPrintSupport_10(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQPrintPreviewWidget::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QPrintPreviewWidget::devType();

    extern int sipVH_QtPrintSupport_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPrintSupport_2(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQPrintPreviewWidget::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::setVisible(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtPrintSupport_11(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQPrintPreviewWidget::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QPrintPreviewWidget::sizeHint();

    extern ::QSize sipVH_QtPrintSupport_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPrintSupport_12(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQPrintPreviewWidget::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QPrintPreviewWidget::minimumSizeHint();

    extern ::QSize sipVH_QtPrintSupport_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPrintSupport_12(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQPrintPreviewWidget::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QPrintPreviewWidget::heightForWidth(a0);

    extern int sipVH_QtPrintSupport_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtPrintSupport_13(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtPrintSupport_14(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtPrintSupport_14(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtPrintSupport_14(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtPrintSupport_14(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtPrintSupport_15(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtPrintSupport_16(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtPrintSupport_16(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtPrintSupport_17(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtPrintSupport_17(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::enterEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::enterEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPrintSupport_4(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPrintSupport_4(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::paintEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtPrintSupport_18(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::moveEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtPrintSupport_19(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtPrintSupport_20(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::closeEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtPrintSupport_21(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtPrintSupport_22(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtPrintSupport_23(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::actionEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtPrintSupport_24(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtPrintSupport_25(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtPrintSupport_26(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtPrintSupport_27(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::dropEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtPrintSupport_28(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::showEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtPrintSupport_29(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::hideEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtPrintSupport_30(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[38], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::changeEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPrintSupport_4(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPrintPreviewWidget::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtPrintSupport_31(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQPrintPreviewWidget::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[40]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QPrintPreviewWidget::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtPrintSupport_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtPrintSupport_32(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPrintPreviewWidget::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[41], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QPrintPreviewWidget::focusNextPrevChild(a0);

    extern bool sipVH_QtPrintSupport_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtPrintSupport_33(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPrintPreviewWidget::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[42]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QPrintPreviewWidget::hasHeightForWidth();

    extern bool sipVH_QtPrintSupport_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPrintSupport_34(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQPrintPreviewWidget::nativeEvent(const ::QByteArray& a0, void*a1, long*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[43], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QPrintPreviewWidget::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtPrintSupport_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, long*);

    return sipVH_QtPrintSupport_35(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPainter* sipQPrintPreviewWidget::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[44]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QPrintPreviewWidget::sharedPainter();

    extern ::QPainter* sipVH_QtPrintSupport_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPrintSupport_36(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQPrintPreviewWidget::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[45]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QPrintPreviewWidget::initPainter(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtPrintSupport_37(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_zoomFactor, "zoomFactor(self) -> float");

extern "C" {static PyObject *meth_QPrintPreviewWidget_zoomFactor(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_zoomFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->zoomFactor();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_zoomFactor, doc_QPrintPreviewWidget_zoomFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_orientation, "orientation(self) -> QPrinter.Orientation");

extern "C" {static PyObject *meth_QPrintPreviewWidget_orientation(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_orientation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            ::QPrinter::Orientation sipRes;

            sipRes = sipCpp->orientation();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPrinter_Orientation);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_orientation, doc_QPrintPreviewWidget_orientation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_viewMode, "viewMode(self) -> QPrintPreviewWidget.ViewMode");

extern "C" {static PyObject *meth_QPrintPreviewWidget_viewMode(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_viewMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            ::QPrintPreviewWidget::ViewMode sipRes;

            sipRes = sipCpp->viewMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPrintPreviewWidget_ViewMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_viewMode, doc_QPrintPreviewWidget_viewMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_zoomMode, "zoomMode(self) -> QPrintPreviewWidget.ZoomMode");

extern "C" {static PyObject *meth_QPrintPreviewWidget_zoomMode(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_zoomMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            ::QPrintPreviewWidget::ZoomMode sipRes;

            sipRes = sipCpp->zoomMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPrintPreviewWidget_ZoomMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_zoomMode, doc_QPrintPreviewWidget_zoomMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_currentPage, "currentPage(self) -> int");

extern "C" {static PyObject *meth_QPrintPreviewWidget_currentPage(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_currentPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->currentPage();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_currentPage, doc_QPrintPreviewWidget_currentPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_setVisible, "setVisible(self, visible: bool)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_setVisible(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_setVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        bool a0;
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QPrintPreviewWidget::setVisible(a0) : sipCpp->setVisible(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_setVisible, doc_QPrintPreviewWidget_setVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_print_, "print_(self)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_print_(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_print_(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            sipCpp->print();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_print_, doc_QPrintPreviewWidget_print_);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_print, "print(self)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_print(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_print(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            sipCpp->print();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_print, doc_QPrintPreviewWidget_print);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_zoomIn, "zoomIn(self, factor: float = 1.1)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_zoomIn(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_zoomIn(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0 = 1.1;
        ::QPrintPreviewWidget *sipCpp;

        static const char *sipKwdList[] = {
            sipName_factor,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|d", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp, &a0))
        {
            sipCpp->zoomIn(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_zoomIn, doc_QPrintPreviewWidget_zoomIn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_zoomOut, "zoomOut(self, factor: float = 1.1)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_zoomOut(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_zoomOut(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0 = 1.1;
        ::QPrintPreviewWidget *sipCpp;

        static const char *sipKwdList[] = {
            sipName_factor,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|d", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp, &a0))
        {
            sipCpp->zoomOut(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_zoomOut, doc_QPrintPreviewWidget_zoomOut);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_setZoomFactor, "setZoomFactor(self, zoomFactor: float)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_setZoomFactor(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_setZoomFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp, &a0))
        {
            sipCpp->setZoomFactor(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_setZoomFactor, doc_QPrintPreviewWidget_setZoomFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_setOrientation, "setOrientation(self, orientation: QPrinter.Orientation)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_setOrientation(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_setOrientation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrinter::Orientation a0;
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp, sipType_QPrinter_Orientation, &a0))
        {
            sipCpp->setOrientation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_setOrientation, doc_QPrintPreviewWidget_setOrientation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_setViewMode, "setViewMode(self, viewMode: QPrintPreviewWidget.ViewMode)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_setViewMode(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_setViewMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrintPreviewWidget::ViewMode a0;
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp, sipType_QPrintPreviewWidget_ViewMode, &a0))
        {
            sipCpp->setViewMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_setViewMode, doc_QPrintPreviewWidget_setViewMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_setZoomMode, "setZoomMode(self, zoomMode: QPrintPreviewWidget.ZoomMode)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_setZoomMode(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_setZoomMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrintPreviewWidget::ZoomMode a0;
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp, sipType_QPrintPreviewWidget_ZoomMode, &a0))
        {
            sipCpp->setZoomMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_setZoomMode, doc_QPrintPreviewWidget_setZoomMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_setCurrentPage, "setCurrentPage(self, pageNumber: int)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_setCurrentPage(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_setCurrentPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp, &a0))
        {
            sipCpp->setCurrentPage(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_setCurrentPage, doc_QPrintPreviewWidget_setCurrentPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_fitToWidth, "fitToWidth(self)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_fitToWidth(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_fitToWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            sipCpp->fitToWidth();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_fitToWidth, doc_QPrintPreviewWidget_fitToWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_fitInView, "fitInView(self)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_fitInView(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_fitInView(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            sipCpp->fitInView();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_fitInView, doc_QPrintPreviewWidget_fitInView);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_setLandscapeOrientation, "setLandscapeOrientation(self)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_setLandscapeOrientation(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_setLandscapeOrientation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            sipCpp->setLandscapeOrientation();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_setLandscapeOrientation, doc_QPrintPreviewWidget_setLandscapeOrientation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_setPortraitOrientation, "setPortraitOrientation(self)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_setPortraitOrientation(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_setPortraitOrientation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            sipCpp->setPortraitOrientation();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_setPortraitOrientation, doc_QPrintPreviewWidget_setPortraitOrientation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_setSinglePageViewMode, "setSinglePageViewMode(self)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_setSinglePageViewMode(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_setSinglePageViewMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            sipCpp->setSinglePageViewMode();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_setSinglePageViewMode, doc_QPrintPreviewWidget_setSinglePageViewMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_setFacingPagesViewMode, "setFacingPagesViewMode(self)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_setFacingPagesViewMode(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_setFacingPagesViewMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            sipCpp->setFacingPagesViewMode();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_setFacingPagesViewMode, doc_QPrintPreviewWidget_setFacingPagesViewMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_setAllPagesViewMode, "setAllPagesViewMode(self)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_setAllPagesViewMode(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_setAllPagesViewMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            sipCpp->setAllPagesViewMode();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_setAllPagesViewMode, doc_QPrintPreviewWidget_setAllPagesViewMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_updatePreview, "updatePreview(self)");

extern "C" {static PyObject *meth_QPrintPreviewWidget_updatePreview(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_updatePreview(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            sipCpp->updatePreview();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_updatePreview, doc_QPrintPreviewWidget_updatePreview);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPrintPreviewWidget_pageCount, "pageCount(self) -> int");

extern "C" {static PyObject *meth_QPrintPreviewWidget_pageCount(PyObject *, PyObject *);}
static PyObject *meth_QPrintPreviewWidget_pageCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPrintPreviewWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPrintPreviewWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->pageCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPrintPreviewWidget, sipName_pageCount, doc_QPrintPreviewWidget_pageCount);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPrintPreviewWidget(void *, const sipTypeDef *);}
static void *cast_QPrintPreviewWidget(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPrintPreviewWidget *sipCpp = reinterpret_cast< ::QPrintPreviewWidget *>(sipCppV);

    if (targetType == sipType_QPrintPreviewWidget)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QWidget)->ctd_cast(static_cast< ::QWidget *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPrintPreviewWidget(void *, int);}
static void release_QPrintPreviewWidget(void *sipCppV, int)
{
    ::QPrintPreviewWidget *sipCpp = reinterpret_cast< ::QPrintPreviewWidget *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QPrintPreviewWidget(Py_ssize_t);}
static void *array_QPrintPreviewWidget(Py_ssize_t sipNrElem)
{
    return new ::QPrintPreviewWidget[sipNrElem];
}


extern "C" {static void array_delete_QPrintPreviewWidget(void *);}
static void array_delete_QPrintPreviewWidget(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPrintPreviewWidget *>(sipCpp);
}


extern "C" {static void dealloc_QPrintPreviewWidget(sipSimpleWrapper *);}
static void dealloc_QPrintPreviewWidget(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPrintPreviewWidget *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPrintPreviewWidget(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPrintPreviewWidget(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPrintPreviewWidget(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQPrintPreviewWidget *sipCpp = SIP_NULLPTR;

    {
        ::QPrinter* a0;
        ::QWidget* a1 = 0;
        ::Qt::WindowFlags a2def = Qt::WindowFlags();
        ::Qt::WindowFlags* a2 = &a2def;
        int a2State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
            sipName_flags,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|JHJ1", sipType_QPrinter, &a0, sipType_QWidget, &a1, sipOwner, sipType_Qt_WindowFlags, &a2, &a2State))
        {
            sipCpp = new sipQPrintPreviewWidget(a0, a1, *a2);
            sipReleaseType(a2, sipType_Qt_WindowFlags, a2State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QWidget* a0 = 0;
        ::Qt::WindowFlags a1def = Qt::WindowFlags();
        ::Qt::WindowFlags* a1 = &a1def;
        int a1State = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
            sipName_flags,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JHJ1", sipType_QWidget, &a0, sipOwner, sipType_Qt_WindowFlags, &a1, &a1State))
        {
            sipCpp = new sipQPrintPreviewWidget(a0, *a1);
            sipReleaseType(a1, sipType_Qt_WindowFlags, a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPrintPreviewWidget[] = {{2, 2, 1}};


static PyMethodDef methods_QPrintPreviewWidget[] = {
    {sipName_currentPage, meth_QPrintPreviewWidget_currentPage, METH_VARARGS, doc_QPrintPreviewWidget_currentPage},
    {sipName_fitInView, meth_QPrintPreviewWidget_fitInView, METH_VARARGS, doc_QPrintPreviewWidget_fitInView},
    {sipName_fitToWidth, meth_QPrintPreviewWidget_fitToWidth, METH_VARARGS, doc_QPrintPreviewWidget_fitToWidth},
    {sipName_orientation, meth_QPrintPreviewWidget_orientation, METH_VARARGS, doc_QPrintPreviewWidget_orientation},
    {sipName_pageCount, meth_QPrintPreviewWidget_pageCount, METH_VARARGS, doc_QPrintPreviewWidget_pageCount},
    {sipName_print, meth_QPrintPreviewWidget_print, METH_VARARGS, doc_QPrintPreviewWidget_print},
    {sipName_print_, meth_QPrintPreviewWidget_print_, METH_VARARGS, doc_QPrintPreviewWidget_print_},
    {sipName_setAllPagesViewMode, meth_QPrintPreviewWidget_setAllPagesViewMode, METH_VARARGS, doc_QPrintPreviewWidget_setAllPagesViewMode},
    {sipName_setCurrentPage, meth_QPrintPreviewWidget_setCurrentPage, METH_VARARGS, doc_QPrintPreviewWidget_setCurrentPage},
    {sipName_setFacingPagesViewMode, meth_QPrintPreviewWidget_setFacingPagesViewMode, METH_VARARGS, doc_QPrintPreviewWidget_setFacingPagesViewMode},
    {sipName_setLandscapeOrientation, meth_QPrintPreviewWidget_setLandscapeOrientation, METH_VARARGS, doc_QPrintPreviewWidget_setLandscapeOrientation},
    {sipName_setOrientation, meth_QPrintPreviewWidget_setOrientation, METH_VARARGS, doc_QPrintPreviewWidget_setOrientation},
    {sipName_setPortraitOrientation, meth_QPrintPreviewWidget_setPortraitOrientation, METH_VARARGS, doc_QPrintPreviewWidget_setPortraitOrientation},
    {sipName_setSinglePageViewMode, meth_QPrintPreviewWidget_setSinglePageViewMode, METH_VARARGS, doc_QPrintPreviewWidget_setSinglePageViewMode},
    {sipName_setViewMode, meth_QPrintPreviewWidget_setViewMode, METH_VARARGS, doc_QPrintPreviewWidget_setViewMode},
    {sipName_setVisible, meth_QPrintPreviewWidget_setVisible, METH_VARARGS, doc_QPrintPreviewWidget_setVisible},
    {sipName_setZoomFactor, meth_QPrintPreviewWidget_setZoomFactor, METH_VARARGS, doc_QPrintPreviewWidget_setZoomFactor},
    {sipName_setZoomMode, meth_QPrintPreviewWidget_setZoomMode, METH_VARARGS, doc_QPrintPreviewWidget_setZoomMode},
    {sipName_updatePreview, meth_QPrintPreviewWidget_updatePreview, METH_VARARGS, doc_QPrintPreviewWidget_updatePreview},
    {sipName_viewMode, meth_QPrintPreviewWidget_viewMode, METH_VARARGS, doc_QPrintPreviewWidget_viewMode},
    {sipName_zoomFactor, meth_QPrintPreviewWidget_zoomFactor, METH_VARARGS, doc_QPrintPreviewWidget_zoomFactor},
    {sipName_zoomIn, SIP_MLMETH_CAST(meth_QPrintPreviewWidget_zoomIn), METH_VARARGS|METH_KEYWORDS, doc_QPrintPreviewWidget_zoomIn},
    {sipName_zoomMode, meth_QPrintPreviewWidget_zoomMode, METH_VARARGS, doc_QPrintPreviewWidget_zoomMode},
    {sipName_zoomOut, SIP_MLMETH_CAST(meth_QPrintPreviewWidget_zoomOut), METH_VARARGS|METH_KEYWORDS, doc_QPrintPreviewWidget_zoomOut}
};

static sipEnumMemberDef enummembers_QPrintPreviewWidget[] = {
    {sipName_AllPagesView, static_cast<int>(::QPrintPreviewWidget::AllPagesView), 16},
    {sipName_CustomZoom, static_cast<int>(::QPrintPreviewWidget::CustomZoom), 17},
    {sipName_FacingPagesView, static_cast<int>(::QPrintPreviewWidget::FacingPagesView), 16},
    {sipName_FitInView, static_cast<int>(::QPrintPreviewWidget::FitInView), 17},
    {sipName_FitToWidth, static_cast<int>(::QPrintPreviewWidget::FitToWidth), 17},
    {sipName_SinglePageView, static_cast<int>(::QPrintPreviewWidget::SinglePageView), 16},
};

PyDoc_STRVAR(doc_QPrintPreviewWidget, "\1QPrintPreviewWidget(printer: Optional[QPrinter], parent: Optional[QWidget] = None, flags: Union[Qt.WindowFlags, Qt.WindowType] = Qt.WindowFlags())\n"
"QPrintPreviewWidget(parent: Optional[QWidget] = None, flags: Union[Qt.WindowFlags, Qt.WindowType] = Qt.WindowFlags())");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QPrintPreviewWidget[] = {
    {"previewChanged()", "\1previewChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"paintRequested(QPrinter*)", "\1paintRequested(self, printer: Optional[QPrinter])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QPrintPreviewWidget = {
    &::QPrintPreviewWidget::staticMetaObject,
    0,
    signals_QPrintPreviewWidget,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtPrintSupport_QPrintPreviewWidget = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPrintPreviewWidget,
        SIP_NULLPTR,
        &plugin_QPrintPreviewWidget,
    },
    {
        sipNameNr_QPrintPreviewWidget,
        {0, 0, 1},
        24, methods_QPrintPreviewWidget,
        6, enummembers_QPrintPreviewWidget,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPrintPreviewWidget,
    -1,
    -1,
    supers_QPrintPreviewWidget,
    SIP_NULLPTR,
    init_type_QPrintPreviewWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPrintPreviewWidget,
    SIP_NULLPTR,
    array_QPrintPreviewWidget,
    SIP_NULLPTR,
    release_QPrintPreviewWidget,
    cast_QPrintPreviewWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPrintPreviewWidget,
    sizeof (::QPrintPreviewWidget),
};
