/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef __QOpenGLFunctions_2_0API_H
#define __QOpenGLFunctions_2_0API_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_PyQt5__QOpenGLFunctions_2_0 0
#define sipName_PyQt5__QOpenGLFunctions_2_0 &sipStrings__QOpenGLFunctions_2_0[0]
#define sipNameNr_glGetConvolutionParameterfv 28
#define sipName_glGetConvolutionParameterfv &sipStrings__QOpenGLFunctions_2_0[28]
#define sipNameNr_glGetConvolutionParameteriv 56
#define sipName_glGetConvolutionParameteriv &sipStrings__QOpenGLFunctions_2_0[56]
#define sipNameNr_glDisableVertexAttribArray 84
#define sipName_glDisableVertexAttribArray &sipStrings__QOpenGLFunctions_2_0[84]
#define sipNameNr_glGetColorTableParameterfv 111
#define sipName_glGetColorTableParameterfv &sipStrings__QOpenGLFunctions_2_0[111]
#define sipNameNr_glGetColorTableParameteriv 138
#define sipName_glGetColorTableParameteriv &sipStrings__QOpenGLFunctions_2_0[138]
#define sipNameNr_glCompressedTexSubImage1D 165
#define sipName_glCompressedTexSubImage1D &sipStrings__QOpenGLFunctions_2_0[165]
#define sipNameNr_glCompressedTexSubImage2D 191
#define sipName_glCompressedTexSubImage2D &sipStrings__QOpenGLFunctions_2_0[191]
#define sipNameNr_glCompressedTexSubImage3D 217
#define sipName_glCompressedTexSubImage3D &sipStrings__QOpenGLFunctions_2_0[217]
#define sipNameNr_glCopyConvolutionFilter1D 243
#define sipName_glCopyConvolutionFilter1D &sipStrings__QOpenGLFunctions_2_0[243]
#define sipNameNr_glCopyConvolutionFilter2D 269
#define sipName_glCopyConvolutionFilter2D &sipStrings__QOpenGLFunctions_2_0[269]
#define sipNameNr_glEnableVertexAttribArray 295
#define sipName_glEnableVertexAttribArray &sipStrings__QOpenGLFunctions_2_0[295]
#define sipNameNr_initializeOpenGLFunctions 321
#define sipName_initializeOpenGLFunctions &sipStrings__QOpenGLFunctions_2_0[321]
#define sipNameNr_glConvolutionParameterfv 347
#define sipName_glConvolutionParameterfv &sipStrings__QOpenGLFunctions_2_0[347]
#define sipNameNr_glConvolutionParameteriv 372
#define sipName_glConvolutionParameteriv &sipStrings__QOpenGLFunctions_2_0[372]
#define sipNameNr_glGetTexLevelParameterfv 397
#define sipName_glGetTexLevelParameterfv &sipStrings__QOpenGLFunctions_2_0[397]
#define sipNameNr_glGetTexLevelParameteriv 422
#define sipName_glGetTexLevelParameteriv &sipStrings__QOpenGLFunctions_2_0[422]
#define sipNameNr_glBlendEquationSeparate 447
#define sipName_glBlendEquationSeparate &sipStrings__QOpenGLFunctions_2_0[447]
#define sipNameNr_glColorTableParameterfv 471
#define sipName_glColorTableParameterfv &sipStrings__QOpenGLFunctions_2_0[471]
#define sipNameNr_glColorTableParameteriv 495
#define sipName_glColorTableParameteriv &sipStrings__QOpenGLFunctions_2_0[495]
#define sipNameNr_glConvolutionParameterf 519
#define sipName_glConvolutionParameterf &sipStrings__QOpenGLFunctions_2_0[519]
#define sipNameNr_glConvolutionParameteri 543
#define sipName_glConvolutionParameteri &sipStrings__QOpenGLFunctions_2_0[543]
#define sipNameNr_glSecondaryColorPointer 567
#define sipName_glSecondaryColorPointer &sipStrings__QOpenGLFunctions_2_0[567]
#define sipNameNr_glCompressedTexImage1D 591
#define sipName_glCompressedTexImage1D &sipStrings__QOpenGLFunctions_2_0[591]
#define sipNameNr_glCompressedTexImage2D 614
#define sipName_glCompressedTexImage2D &sipStrings__QOpenGLFunctions_2_0[614]
#define sipNameNr_glCompressedTexImage3D 637
#define sipName_glCompressedTexImage3D &sipStrings__QOpenGLFunctions_2_0[637]
#define sipNameNr_glGetBufferParameteriv 660
#define sipName_glGetBufferParameteriv &sipStrings__QOpenGLFunctions_2_0[660]
#define sipNameNr_glLoadTransposeMatrixd 683
#define sipName_glLoadTransposeMatrixd &sipStrings__QOpenGLFunctions_2_0[683]
#define sipNameNr_glLoadTransposeMatrixf 706
#define sipName_glLoadTransposeMatrixf &sipStrings__QOpenGLFunctions_2_0[706]
#define sipNameNr_glMultTransposeMatrixd 729
#define sipName_glMultTransposeMatrixd &sipStrings__QOpenGLFunctions_2_0[729]
#define sipNameNr_glMultTransposeMatrixf 752
#define sipName_glMultTransposeMatrixf &sipStrings__QOpenGLFunctions_2_0[752]
#define sipNameNr_glClientActiveTexture 775
#define sipName_glClientActiveTexture &sipStrings__QOpenGLFunctions_2_0[775]
#define sipNameNr_glConvolutionFilter1D 797
#define sipName_glConvolutionFilter1D &sipStrings__QOpenGLFunctions_2_0[797]
#define sipNameNr_glConvolutionFilter2D 819
#define sipName_glConvolutionFilter2D &sipStrings__QOpenGLFunctions_2_0[819]
#define sipNameNr_glStencilFuncSeparate 841
#define sipName_glStencilFuncSeparate &sipStrings__QOpenGLFunctions_2_0[841]
#define sipNameNr_glStencilMaskSeparate 863
#define sipName_glStencilMaskSeparate &sipStrings__QOpenGLFunctions_2_0[863]
#define sipNameNr_glVertexAttribPointer 885
#define sipName_glVertexAttribPointer &sipStrings__QOpenGLFunctions_2_0[885]
#define sipNameNr_QOpenGLFunctions_2_0 7
#define sipName_QOpenGLFunctions_2_0 &sipStrings__QOpenGLFunctions_2_0[7]
#define sipNameNr_glBindAttribLocation 907
#define sipName_glBindAttribLocation &sipStrings__QOpenGLFunctions_2_0[907]
#define sipNameNr_glDisableClientState 928
#define sipName_glDisableClientState &sipStrings__QOpenGLFunctions_2_0[928]
#define sipNameNr_glGetAttachedShaders 949
#define sipName_glGetAttachedShaders &sipStrings__QOpenGLFunctions_2_0[949]
#define sipNameNr_glGetUniformLocation 970
#define sipName_glGetUniformLocation &sipStrings__QOpenGLFunctions_2_0[970]
#define sipNameNr_glSecondaryColor3ubv 991
#define sipName_glSecondaryColor3ubv &sipStrings__QOpenGLFunctions_2_0[991]
#define sipNameNr_glSecondaryColor3uiv 1012
#define sipName_glSecondaryColor3uiv &sipStrings__QOpenGLFunctions_2_0[1012]
#define sipNameNr_glSecondaryColor3usv 1033
#define sipName_glSecondaryColor3usv &sipStrings__QOpenGLFunctions_2_0[1033]
#define sipNameNr_glBlendFuncSeparate 1054
#define sipName_glBlendFuncSeparate &sipStrings__QOpenGLFunctions_2_0[1054]
#define sipNameNr_glCopyColorSubTable 1074
#define sipName_glCopyColorSubTable &sipStrings__QOpenGLFunctions_2_0[1074]
#define sipNameNr_glCopyTexSubImage1D 1094
#define sipName_glCopyTexSubImage1D &sipStrings__QOpenGLFunctions_2_0[1094]
#define sipNameNr_glCopyTexSubImage2D 1114
#define sipName_glCopyTexSubImage2D &sipStrings__QOpenGLFunctions_2_0[1114]
#define sipNameNr_glCopyTexSubImage3D 1134
#define sipName_glCopyTexSubImage3D &sipStrings__QOpenGLFunctions_2_0[1134]
#define sipNameNr_glDrawRangeElements 1154
#define sipName_glDrawRangeElements &sipStrings__QOpenGLFunctions_2_0[1154]
#define sipNameNr_glEnableClientState 1174
#define sipName_glEnableClientState &sipStrings__QOpenGLFunctions_2_0[1174]
#define sipNameNr_glGetAttribLocation 1194
#define sipName_glGetAttribLocation &sipStrings__QOpenGLFunctions_2_0[1194]
#define sipNameNr_glGetProgramInfoLog 1214
#define sipName_glGetProgramInfoLog &sipStrings__QOpenGLFunctions_2_0[1214]
#define sipNameNr_glGetTexParameterfv 1234
#define sipName_glGetTexParameterfv &sipStrings__QOpenGLFunctions_2_0[1234]
#define sipNameNr_glGetTexParameteriv 1254
#define sipName_glGetTexParameteriv &sipStrings__QOpenGLFunctions_2_0[1254]
#define sipNameNr_glGetVertexAttribdv 1274
#define sipName_glGetVertexAttribdv &sipStrings__QOpenGLFunctions_2_0[1274]
#define sipNameNr_glGetVertexAttribfv 1294
#define sipName_glGetVertexAttribfv &sipStrings__QOpenGLFunctions_2_0[1294]
#define sipNameNr_glGetVertexAttribiv 1314
#define sipName_glGetVertexAttribiv &sipStrings__QOpenGLFunctions_2_0[1314]
#define sipNameNr_glSecondaryColor3bv 1334
#define sipName_glSecondaryColor3bv &sipStrings__QOpenGLFunctions_2_0[1334]
#define sipNameNr_glSecondaryColor3dv 1354
#define sipName_glSecondaryColor3dv &sipStrings__QOpenGLFunctions_2_0[1354]
#define sipNameNr_glSecondaryColor3fv 1374
#define sipName_glSecondaryColor3fv &sipStrings__QOpenGLFunctions_2_0[1374]
#define sipNameNr_glSecondaryColor3iv 1394
#define sipName_glSecondaryColor3iv &sipStrings__QOpenGLFunctions_2_0[1394]
#define sipNameNr_glSecondaryColor3sv 1414
#define sipName_glSecondaryColor3sv &sipStrings__QOpenGLFunctions_2_0[1414]
#define sipNameNr_glSecondaryColor3ub 1434
#define sipName_glSecondaryColor3ub &sipStrings__QOpenGLFunctions_2_0[1434]
#define sipNameNr_glSecondaryColor3ui 1454
#define sipName_glSecondaryColor3ui &sipStrings__QOpenGLFunctions_2_0[1454]
#define sipNameNr_glSecondaryColor3us 1474
#define sipName_glSecondaryColor3us &sipStrings__QOpenGLFunctions_2_0[1474]
#define sipNameNr_glStencilOpSeparate 1494
#define sipName_glStencilOpSeparate &sipStrings__QOpenGLFunctions_2_0[1494]
#define sipNameNr_glVertexAttrib4Nubv 1514
#define sipName_glVertexAttrib4Nubv &sipStrings__QOpenGLFunctions_2_0[1514]
#define sipNameNr_glVertexAttrib4Nuiv 1534
#define sipName_glVertexAttrib4Nuiv &sipStrings__QOpenGLFunctions_2_0[1534]
#define sipNameNr_glVertexAttrib4Nusv 1554
#define sipName_glVertexAttrib4Nusv &sipStrings__QOpenGLFunctions_2_0[1554]
#define sipNameNr_glGetActiveUniform 1574
#define sipName_glGetActiveUniform &sipStrings__QOpenGLFunctions_2_0[1574]
#define sipNameNr_glGetShaderInfoLog 1593
#define sipName_glGetShaderInfoLog &sipStrings__QOpenGLFunctions_2_0[1593]
#define sipNameNr_glMultiTexCoord1dv 1612
#define sipName_glMultiTexCoord1dv &sipStrings__QOpenGLFunctions_2_0[1612]
#define sipNameNr_glMultiTexCoord1fv 1631
#define sipName_glMultiTexCoord1fv &sipStrings__QOpenGLFunctions_2_0[1631]
#define sipNameNr_glMultiTexCoord1iv 1650
#define sipName_glMultiTexCoord1iv &sipStrings__QOpenGLFunctions_2_0[1650]
#define sipNameNr_glMultiTexCoord1sv 1669
#define sipName_glMultiTexCoord1sv &sipStrings__QOpenGLFunctions_2_0[1669]
#define sipNameNr_glMultiTexCoord2dv 1688
#define sipName_glMultiTexCoord2dv &sipStrings__QOpenGLFunctions_2_0[1688]
#define sipNameNr_glMultiTexCoord2fv 1707
#define sipName_glMultiTexCoord2fv &sipStrings__QOpenGLFunctions_2_0[1707]
#define sipNameNr_glMultiTexCoord2iv 1726
#define sipName_glMultiTexCoord2iv &sipStrings__QOpenGLFunctions_2_0[1726]
#define sipNameNr_glMultiTexCoord2sv 1745
#define sipName_glMultiTexCoord2sv &sipStrings__QOpenGLFunctions_2_0[1745]
#define sipNameNr_glMultiTexCoord3dv 1764
#define sipName_glMultiTexCoord3dv &sipStrings__QOpenGLFunctions_2_0[1764]
#define sipNameNr_glMultiTexCoord3fv 1783
#define sipName_glMultiTexCoord3fv &sipStrings__QOpenGLFunctions_2_0[1783]
#define sipNameNr_glMultiTexCoord3iv 1802
#define sipName_glMultiTexCoord3iv &sipStrings__QOpenGLFunctions_2_0[1802]
#define sipNameNr_glMultiTexCoord3sv 1821
#define sipName_glMultiTexCoord3sv &sipStrings__QOpenGLFunctions_2_0[1821]
#define sipNameNr_glMultiTexCoord4dv 1840
#define sipName_glMultiTexCoord4dv &sipStrings__QOpenGLFunctions_2_0[1840]
#define sipNameNr_glMultiTexCoord4fv 1859
#define sipName_glMultiTexCoord4fv &sipStrings__QOpenGLFunctions_2_0[1859]
#define sipNameNr_glMultiTexCoord4iv 1878
#define sipName_glMultiTexCoord4iv &sipStrings__QOpenGLFunctions_2_0[1878]
#define sipNameNr_glMultiTexCoord4sv 1897
#define sipName_glMultiTexCoord4sv &sipStrings__QOpenGLFunctions_2_0[1897]
#define sipNameNr_glPointParameterfv 1916
#define sipName_glPointParameterfv &sipStrings__QOpenGLFunctions_2_0[1916]
#define sipNameNr_glPointParameteriv 1935
#define sipName_glPointParameteriv &sipStrings__QOpenGLFunctions_2_0[1935]
#define sipNameNr_glPushClientAttrib 1954
#define sipName_glPushClientAttrib &sipStrings__QOpenGLFunctions_2_0[1954]
#define sipNameNr_glSecondaryColor3b 1973
#define sipName_glSecondaryColor3b &sipStrings__QOpenGLFunctions_2_0[1973]
#define sipNameNr_glSecondaryColor3d 1992
#define sipName_glSecondaryColor3d &sipStrings__QOpenGLFunctions_2_0[1992]
#define sipNameNr_glSecondaryColor3f 2011
#define sipName_glSecondaryColor3f &sipStrings__QOpenGLFunctions_2_0[2011]
#define sipNameNr_glSecondaryColor3i 2030
#define sipName_glSecondaryColor3i &sipStrings__QOpenGLFunctions_2_0[2030]
#define sipNameNr_glSecondaryColor3s 2049
#define sipName_glSecondaryColor3s &sipStrings__QOpenGLFunctions_2_0[2049]
#define sipNameNr_glUniformMatrix2fv 2068
#define sipName_glUniformMatrix2fv &sipStrings__QOpenGLFunctions_2_0[2068]
#define sipNameNr_glUniformMatrix3fv 2087
#define sipName_glUniformMatrix3fv &sipStrings__QOpenGLFunctions_2_0[2087]
#define sipNameNr_glUniformMatrix4fv 2106
#define sipName_glUniformMatrix4fv &sipStrings__QOpenGLFunctions_2_0[2106]
#define sipNameNr_glVertexAttrib4Nbv 2125
#define sipName_glVertexAttrib4Nbv &sipStrings__QOpenGLFunctions_2_0[2125]
#define sipNameNr_glVertexAttrib4Niv 2144
#define sipName_glVertexAttrib4Niv &sipStrings__QOpenGLFunctions_2_0[2144]
#define sipNameNr_glVertexAttrib4Nsv 2163
#define sipName_glVertexAttrib4Nsv &sipStrings__QOpenGLFunctions_2_0[2163]
#define sipNameNr_glVertexAttrib4Nub 2182
#define sipName_glVertexAttrib4Nub &sipStrings__QOpenGLFunctions_2_0[2182]
#define sipNameNr_glVertexAttrib4ubv 2201
#define sipName_glVertexAttrib4ubv &sipStrings__QOpenGLFunctions_2_0[2201]
#define sipNameNr_glVertexAttrib4uiv 2220
#define sipName_glVertexAttrib4uiv &sipStrings__QOpenGLFunctions_2_0[2220]
#define sipNameNr_glVertexAttrib4usv 2239
#define sipName_glVertexAttrib4usv &sipStrings__QOpenGLFunctions_2_0[2239]
#define sipNameNr_glEdgeFlagPointer 2258
#define sipName_glEdgeFlagPointer &sipStrings__QOpenGLFunctions_2_0[2258]
#define sipNameNr_glFogCoordPointer 2276
#define sipName_glFogCoordPointer &sipStrings__QOpenGLFunctions_2_0[2276]
#define sipNameNr_glGetActiveAttrib 2294
#define sipName_glGetActiveAttrib &sipStrings__QOpenGLFunctions_2_0[2294]
#define sipNameNr_glGetShaderSource 2312
#define sipName_glGetShaderSource &sipStrings__QOpenGLFunctions_2_0[2312]
#define sipNameNr_glMultiTexCoord1d 2330
#define sipName_glMultiTexCoord1d &sipStrings__QOpenGLFunctions_2_0[2330]
#define sipNameNr_glMultiTexCoord1f 2348
#define sipName_glMultiTexCoord1f &sipStrings__QOpenGLFunctions_2_0[2348]
#define sipNameNr_glMultiTexCoord1i 2366
#define sipName_glMultiTexCoord1i &sipStrings__QOpenGLFunctions_2_0[2366]
#define sipNameNr_glMultiTexCoord1s 2384
#define sipName_glMultiTexCoord1s &sipStrings__QOpenGLFunctions_2_0[2384]
#define sipNameNr_glMultiTexCoord2d 2402
#define sipName_glMultiTexCoord2d &sipStrings__QOpenGLFunctions_2_0[2402]
#define sipNameNr_glMultiTexCoord2f 2420
#define sipName_glMultiTexCoord2f &sipStrings__QOpenGLFunctions_2_0[2420]
#define sipNameNr_glMultiTexCoord2i 2438
#define sipName_glMultiTexCoord2i &sipStrings__QOpenGLFunctions_2_0[2438]
#define sipNameNr_glMultiTexCoord2s 2456
#define sipName_glMultiTexCoord2s &sipStrings__QOpenGLFunctions_2_0[2456]
#define sipNameNr_glMultiTexCoord3d 2474
#define sipName_glMultiTexCoord3d &sipStrings__QOpenGLFunctions_2_0[2474]
#define sipNameNr_glMultiTexCoord3f 2492
#define sipName_glMultiTexCoord3f &sipStrings__QOpenGLFunctions_2_0[2492]
#define sipNameNr_glMultiTexCoord3i 2510
#define sipName_glMultiTexCoord3i &sipStrings__QOpenGLFunctions_2_0[2510]
#define sipNameNr_glMultiTexCoord3s 2528
#define sipName_glMultiTexCoord3s &sipStrings__QOpenGLFunctions_2_0[2528]
#define sipNameNr_glMultiTexCoord4d 2546
#define sipName_glMultiTexCoord4d &sipStrings__QOpenGLFunctions_2_0[2546]
#define sipNameNr_glMultiTexCoord4f 2564
#define sipName_glMultiTexCoord4f &sipStrings__QOpenGLFunctions_2_0[2564]
#define sipNameNr_glMultiTexCoord4i 2582
#define sipName_glMultiTexCoord4i &sipStrings__QOpenGLFunctions_2_0[2582]
#define sipNameNr_glMultiTexCoord4s 2600
#define sipName_glMultiTexCoord4s &sipStrings__QOpenGLFunctions_2_0[2600]
#define sipNameNr_glPointParameterf 2618
#define sipName_glPointParameterf &sipStrings__QOpenGLFunctions_2_0[2618]
#define sipNameNr_glPointParameteri 2636
#define sipName_glPointParameteri &sipStrings__QOpenGLFunctions_2_0[2636]
#define sipNameNr_glPopClientAttrib 2654
#define sipName_glPopClientAttrib &sipStrings__QOpenGLFunctions_2_0[2654]
#define sipNameNr_glTexCoordPointer 2672
#define sipName_glTexCoordPointer &sipStrings__QOpenGLFunctions_2_0[2672]
#define sipNameNr_glValidateProgram 2690
#define sipName_glValidateProgram &sipStrings__QOpenGLFunctions_2_0[2690]
#define sipNameNr_glVertexAttrib1dv 2708
#define sipName_glVertexAttrib1dv &sipStrings__QOpenGLFunctions_2_0[2708]
#define sipNameNr_glVertexAttrib1fv 2726
#define sipName_glVertexAttrib1fv &sipStrings__QOpenGLFunctions_2_0[2726]
#define sipNameNr_glVertexAttrib1sv 2744
#define sipName_glVertexAttrib1sv &sipStrings__QOpenGLFunctions_2_0[2744]
#define sipNameNr_glVertexAttrib2dv 2762
#define sipName_glVertexAttrib2dv &sipStrings__QOpenGLFunctions_2_0[2762]
#define sipNameNr_glVertexAttrib2fv 2780
#define sipName_glVertexAttrib2fv &sipStrings__QOpenGLFunctions_2_0[2780]
#define sipNameNr_glVertexAttrib2sv 2798
#define sipName_glVertexAttrib2sv &sipStrings__QOpenGLFunctions_2_0[2798]
#define sipNameNr_glVertexAttrib3dv 2816
#define sipName_glVertexAttrib3dv &sipStrings__QOpenGLFunctions_2_0[2816]
#define sipNameNr_glVertexAttrib3fv 2834
#define sipName_glVertexAttrib3fv &sipStrings__QOpenGLFunctions_2_0[2834]
#define sipNameNr_glVertexAttrib3sv 2852
#define sipName_glVertexAttrib3sv &sipStrings__QOpenGLFunctions_2_0[2852]
#define sipNameNr_glVertexAttrib4bv 2870
#define sipName_glVertexAttrib4bv &sipStrings__QOpenGLFunctions_2_0[2870]
#define sipNameNr_glVertexAttrib4dv 2888
#define sipName_glVertexAttrib4dv &sipStrings__QOpenGLFunctions_2_0[2888]
#define sipNameNr_glVertexAttrib4fv 2906
#define sipName_glVertexAttrib4fv &sipStrings__QOpenGLFunctions_2_0[2906]
#define sipNameNr_glVertexAttrib4iv 2924
#define sipName_glVertexAttrib4iv &sipStrings__QOpenGLFunctions_2_0[2924]
#define sipNameNr_glVertexAttrib4sv 2942
#define sipName_glVertexAttrib4sv &sipStrings__QOpenGLFunctions_2_0[2942]
#define sipNameNr_glCopyColorTable 2960
#define sipName_glCopyColorTable &sipStrings__QOpenGLFunctions_2_0[2960]
#define sipNameNr_glCopyTexImage1D 2977
#define sipName_glCopyTexImage1D &sipStrings__QOpenGLFunctions_2_0[2977]
#define sipNameNr_glCopyTexImage2D 2994
#define sipName_glCopyTexImage2D &sipStrings__QOpenGLFunctions_2_0[2994]
#define sipNameNr_glDeleteTextures 3011
#define sipName_glDeleteTextures &sipStrings__QOpenGLFunctions_2_0[3011]
#define sipNameNr_glPixelTransferf 3028
#define sipName_glPixelTransferf &sipStrings__QOpenGLFunctions_2_0[3028]
#define sipNameNr_glPixelTransferi 3045
#define sipName_glPixelTransferi &sipStrings__QOpenGLFunctions_2_0[3045]
#define sipNameNr_glPolygonStipple 3062
#define sipName_glPolygonStipple &sipStrings__QOpenGLFunctions_2_0[3062]
#define sipNameNr_glResetHistogram 3079
#define sipName_glResetHistogram &sipStrings__QOpenGLFunctions_2_0[3079]
#define sipNameNr_glSampleCoverage 3096
#define sipName_glSampleCoverage &sipStrings__QOpenGLFunctions_2_0[3096]
#define sipNameNr_glTexParameterfv 3113
#define sipName_glTexParameterfv &sipStrings__QOpenGLFunctions_2_0[3113]
#define sipNameNr_glTexParameteriv 3130
#define sipName_glTexParameteriv &sipStrings__QOpenGLFunctions_2_0[3130]
#define sipNameNr_glVertexAttrib1d 3147
#define sipName_glVertexAttrib1d &sipStrings__QOpenGLFunctions_2_0[3147]
#define sipNameNr_glVertexAttrib1f 3164
#define sipName_glVertexAttrib1f &sipStrings__QOpenGLFunctions_2_0[3164]
#define sipNameNr_glVertexAttrib1s 3181
#define sipName_glVertexAttrib1s &sipStrings__QOpenGLFunctions_2_0[3181]
#define sipNameNr_glVertexAttrib2d 3198
#define sipName_glVertexAttrib2d &sipStrings__QOpenGLFunctions_2_0[3198]
#define sipNameNr_glVertexAttrib2f 3215
#define sipName_glVertexAttrib2f &sipStrings__QOpenGLFunctions_2_0[3215]
#define sipNameNr_glVertexAttrib2s 3232
#define sipName_glVertexAttrib2s &sipStrings__QOpenGLFunctions_2_0[3232]
#define sipNameNr_glVertexAttrib3d 3249
#define sipName_glVertexAttrib3d &sipStrings__QOpenGLFunctions_2_0[3249]
#define sipNameNr_glVertexAttrib3f 3266
#define sipName_glVertexAttrib3f &sipStrings__QOpenGLFunctions_2_0[3266]
#define sipNameNr_glVertexAttrib3s 3283
#define sipName_glVertexAttrib3s &sipStrings__QOpenGLFunctions_2_0[3283]
#define sipNameNr_glVertexAttrib4d 3300
#define sipName_glVertexAttrib4d &sipStrings__QOpenGLFunctions_2_0[3300]
#define sipNameNr_glVertexAttrib4f 3317
#define sipName_glVertexAttrib4f &sipStrings__QOpenGLFunctions_2_0[3317]
#define sipNameNr_glVertexAttrib4s 3334
#define sipName_glVertexAttrib4s &sipStrings__QOpenGLFunctions_2_0[3334]
#define sipNameNr_glActiveTexture 3351
#define sipName_glActiveTexture &sipStrings__QOpenGLFunctions_2_0[3351]
#define sipNameNr_glBlendEquation 3367
#define sipName_glBlendEquation &sipStrings__QOpenGLFunctions_2_0[3367]
#define sipNameNr_glBufferSubData 3383
#define sipName_glBufferSubData &sipStrings__QOpenGLFunctions_2_0[3383]
#define sipNameNr_glColorMaterial 3399
#define sipName_glColorMaterial &sipStrings__QOpenGLFunctions_2_0[3399]
#define sipNameNr_glColorSubTable 3415
#define sipName_glColorSubTable &sipStrings__QOpenGLFunctions_2_0[3415]
#define sipNameNr_glCompileShader 3431
#define sipName_glCompileShader &sipStrings__QOpenGLFunctions_2_0[3431]
#define sipNameNr_glCreateProgram 3447
#define sipName_glCreateProgram &sipStrings__QOpenGLFunctions_2_0[3447]
#define sipNameNr_glDeleteBuffers 3463
#define sipName_glDeleteBuffers &sipStrings__QOpenGLFunctions_2_0[3463]
#define sipNameNr_glDeleteProgram 3479
#define sipName_glDeleteProgram &sipStrings__QOpenGLFunctions_2_0[3479]
#define sipNameNr_glDeleteQueries 3495
#define sipName_glDeleteQueries &sipStrings__QOpenGLFunctions_2_0[3495]
#define sipNameNr_glGetMaterialfv 3511
#define sipName_glGetMaterialfv &sipStrings__QOpenGLFunctions_2_0[3511]
#define sipNameNr_glGetMaterialiv 3527
#define sipName_glGetMaterialiv &sipStrings__QOpenGLFunctions_2_0[3527]
#define sipNameNr_glNormalPointer 3543
#define sipName_glNormalPointer &sipStrings__QOpenGLFunctions_2_0[3543]
#define sipNameNr_glPolygonOffset 3559
#define sipName_glPolygonOffset &sipStrings__QOpenGLFunctions_2_0[3559]
#define sipNameNr_glTexParameterf 3575
#define sipName_glTexParameterf &sipStrings__QOpenGLFunctions_2_0[3575]
#define sipNameNr_glTexParameteri 3591
#define sipName_glTexParameteri &sipStrings__QOpenGLFunctions_2_0[3591]
#define sipNameNr_glTexSubImage1D 3607
#define sipName_glTexSubImage1D &sipStrings__QOpenGLFunctions_2_0[3607]
#define sipNameNr_glTexSubImage2D 3623
#define sipName_glTexSubImage2D &sipStrings__QOpenGLFunctions_2_0[3623]
#define sipNameNr_glTexSubImage3D 3639
#define sipName_glTexSubImage3D &sipStrings__QOpenGLFunctions_2_0[3639]
#define sipNameNr_glVertexPointer 3655
#define sipName_glVertexPointer &sipStrings__QOpenGLFunctions_2_0[3655]
#define sipNameNr_glArrayElement 3671
#define sipName_glArrayElement &sipStrings__QOpenGLFunctions_2_0[3671]
#define sipNameNr_glAttachShader 3686
#define sipName_glAttachShader &sipStrings__QOpenGLFunctions_2_0[3686]
#define sipNameNr_glClearStencil 3701
#define sipName_glClearStencil &sipStrings__QOpenGLFunctions_2_0[3701]
#define sipNameNr_glColorPointer 3716
#define sipName_glColorPointer &sipStrings__QOpenGLFunctions_2_0[3716]
#define sipNameNr_glCreateShader 3731
#define sipName_glCreateShader &sipStrings__QOpenGLFunctions_2_0[3731]
#define sipNameNr_glDeleteShader 3746
#define sipName_glDeleteShader &sipStrings__QOpenGLFunctions_2_0[3746]
#define sipNameNr_glDetachShader 3761
#define sipName_glDetachShader &sipStrings__QOpenGLFunctions_2_0[3761]
#define sipNameNr_glDrawElements 3776
#define sipName_glDrawElements &sipStrings__QOpenGLFunctions_2_0[3776]
#define sipNameNr_glEvalCoord1dv 3791
#define sipName_glEvalCoord1dv &sipStrings__QOpenGLFunctions_2_0[3791]
#define sipNameNr_glEvalCoord1fv 3806
#define sipName_glEvalCoord1fv &sipStrings__QOpenGLFunctions_2_0[3806]
#define sipNameNr_glEvalCoord2dv 3821
#define sipName_glEvalCoord2dv &sipStrings__QOpenGLFunctions_2_0[3821]
#define sipNameNr_glEvalCoord2fv 3836
#define sipName_glEvalCoord2fv &sipStrings__QOpenGLFunctions_2_0[3836]
#define sipNameNr_glGetClipPlane 3851
#define sipName_glGetClipPlane &sipStrings__QOpenGLFunctions_2_0[3851]
#define sipNameNr_glGetProgramiv 3866
#define sipName_glGetProgramiv &sipStrings__QOpenGLFunctions_2_0[3866]
#define sipNameNr_glIndexPointer 3881
#define sipName_glIndexPointer &sipStrings__QOpenGLFunctions_2_0[3881]
#define sipNameNr_glLightModelfv 3896
#define sipName_glLightModelfv &sipStrings__QOpenGLFunctions_2_0[3896]
#define sipNameNr_glLightModeliv 3911
#define sipName_glLightModeliv &sipStrings__QOpenGLFunctions_2_0[3911]
#define sipNameNr_glLoadIdentity 3926
#define sipName_glLoadIdentity &sipStrings__QOpenGLFunctions_2_0[3926]
#define sipNameNr_glRasterPos2dv 3941
#define sipName_glRasterPos2dv &sipStrings__QOpenGLFunctions_2_0[3941]
#define sipNameNr_glRasterPos2fv 3956
#define sipName_glRasterPos2fv &sipStrings__QOpenGLFunctions_2_0[3956]
#define sipNameNr_glRasterPos2iv 3971
#define sipName_glRasterPos2iv &sipStrings__QOpenGLFunctions_2_0[3971]
#define sipNameNr_glRasterPos2sv 3986
#define sipName_glRasterPos2sv &sipStrings__QOpenGLFunctions_2_0[3986]
#define sipNameNr_glRasterPos3dv 4001
#define sipName_glRasterPos3dv &sipStrings__QOpenGLFunctions_2_0[4001]
#define sipNameNr_glRasterPos3fv 4016
#define sipName_glRasterPos3fv &sipStrings__QOpenGLFunctions_2_0[4016]
#define sipNameNr_glRasterPos3iv 4031
#define sipName_glRasterPos3iv &sipStrings__QOpenGLFunctions_2_0[4031]
#define sipNameNr_glRasterPos3sv 4046
#define sipName_glRasterPos3sv &sipStrings__QOpenGLFunctions_2_0[4046]
#define sipNameNr_glRasterPos4dv 4061
#define sipName_glRasterPos4dv &sipStrings__QOpenGLFunctions_2_0[4061]
#define sipNameNr_glRasterPos4fv 4076
#define sipName_glRasterPos4fv &sipStrings__QOpenGLFunctions_2_0[4076]
#define sipNameNr_glRasterPos4iv 4091
#define sipName_glRasterPos4iv &sipStrings__QOpenGLFunctions_2_0[4091]
#define sipNameNr_glRasterPos4sv 4106
#define sipName_glRasterPos4sv &sipStrings__QOpenGLFunctions_2_0[4106]
#define sipNameNr_glWindowPos2dv 4121
#define sipName_glWindowPos2dv &sipStrings__QOpenGLFunctions_2_0[4121]
#define sipNameNr_glWindowPos2fv 4136
#define sipName_glWindowPos2fv &sipStrings__QOpenGLFunctions_2_0[4136]
#define sipNameNr_glWindowPos2iv 4151
#define sipName_glWindowPos2iv &sipStrings__QOpenGLFunctions_2_0[4151]
#define sipNameNr_glWindowPos2sv 4166
#define sipName_glWindowPos2sv &sipStrings__QOpenGLFunctions_2_0[4166]
#define sipNameNr_glWindowPos3dv 4181
#define sipName_glWindowPos3dv &sipStrings__QOpenGLFunctions_2_0[4181]
#define sipNameNr_glWindowPos3fv 4196
#define sipName_glWindowPos3fv &sipStrings__QOpenGLFunctions_2_0[4196]
#define sipNameNr_glWindowPos3iv 4211
#define sipName_glWindowPos3iv &sipStrings__QOpenGLFunctions_2_0[4211]
#define sipNameNr_glWindowPos3sv 4226
#define sipName_glWindowPos3sv &sipStrings__QOpenGLFunctions_2_0[4226]
#define sipNameNr_glBindTexture 4241
#define sipName_glBindTexture &sipStrings__QOpenGLFunctions_2_0[4241]
#define sipNameNr_glDeleteLists 4255
#define sipName_glDeleteLists &sipStrings__QOpenGLFunctions_2_0[4255]
#define sipNameNr_glDrawBuffers 4269
#define sipName_glDrawBuffers &sipStrings__QOpenGLFunctions_2_0[4269]
#define sipNameNr_glEvalCoord1d 4283
#define sipName_glEvalCoord1d &sipStrings__QOpenGLFunctions_2_0[4283]
#define sipNameNr_glEvalCoord1f 4297
#define sipName_glEvalCoord1f &sipStrings__QOpenGLFunctions_2_0[4297]
#define sipNameNr_glEvalCoord2d 4311
#define sipName_glEvalCoord2d &sipStrings__QOpenGLFunctions_2_0[4311]
#define sipNameNr_glEvalCoord2f 4325
#define sipName_glEvalCoord2f &sipStrings__QOpenGLFunctions_2_0[4325]
#define sipNameNr_glGenTextures 4339
#define sipName_glGenTextures &sipStrings__QOpenGLFunctions_2_0[4339]
#define sipNameNr_glGetBooleanv 4353
#define sipName_glGetBooleanv &sipStrings__QOpenGLFunctions_2_0[4353]
#define sipNameNr_glGetIntegerv 4367
#define sipName_glGetIntegerv &sipStrings__QOpenGLFunctions_2_0[4367]
#define sipNameNr_glGetShaderiv 4381
#define sipName_glGetShaderiv &sipStrings__QOpenGLFunctions_2_0[4381]
#define sipNameNr_glGetTexEnvfv 4395
#define sipName_glGetTexEnvfv &sipStrings__QOpenGLFunctions_2_0[4395]
#define sipNameNr_glGetTexEnviv 4409
#define sipName_glGetTexEnviv &sipStrings__QOpenGLFunctions_2_0[4409]
#define sipNameNr_glGetTexGendv 4423
#define sipName_glGetTexGendv &sipStrings__QOpenGLFunctions_2_0[4423]
#define sipNameNr_glGetTexGenfv 4437
#define sipName_glGetTexGenfv &sipStrings__QOpenGLFunctions_2_0[4437]
#define sipNameNr_glGetTexGeniv 4451
#define sipName_glGetTexGeniv &sipStrings__QOpenGLFunctions_2_0[4451]
#define sipNameNr_glLightModelf 4465
#define sipName_glLightModelf &sipStrings__QOpenGLFunctions_2_0[4465]
#define sipNameNr_glLightModeli 4479
#define sipName_glLightModeli &sipStrings__QOpenGLFunctions_2_0[4479]
#define sipNameNr_glLineStipple 4493
#define sipName_glLineStipple &sipStrings__QOpenGLFunctions_2_0[4493]
#define sipNameNr_glLinkProgram 4507
#define sipName_glLinkProgram &sipStrings__QOpenGLFunctions_2_0[4507]
#define sipNameNr_glLoadMatrixd 4521
#define sipName_glLoadMatrixd &sipStrings__QOpenGLFunctions_2_0[4521]
#define sipNameNr_glLoadMatrixf 4535
#define sipName_glLoadMatrixf &sipStrings__QOpenGLFunctions_2_0[4535]
#define sipNameNr_glMultMatrixd 4549
#define sipName_glMultMatrixd &sipStrings__QOpenGLFunctions_2_0[4549]
#define sipNameNr_glMultMatrixf 4563
#define sipName_glMultMatrixf &sipStrings__QOpenGLFunctions_2_0[4563]
#define sipNameNr_glPassThrough 4577
#define sipName_glPassThrough &sipStrings__QOpenGLFunctions_2_0[4577]
#define sipNameNr_glPixelMapuiv 4591
#define sipName_glPixelMapuiv &sipStrings__QOpenGLFunctions_2_0[4591]
#define sipNameNr_glPixelMapusv 4605
#define sipName_glPixelMapusv &sipStrings__QOpenGLFunctions_2_0[4605]
#define sipNameNr_glPixelStoref 4619
#define sipName_glPixelStoref &sipStrings__QOpenGLFunctions_2_0[4619]
#define sipNameNr_glPixelStorei 4633
#define sipName_glPixelStorei &sipStrings__QOpenGLFunctions_2_0[4633]
#define sipNameNr_glPolygonMode 4647
#define sipName_glPolygonMode &sipStrings__QOpenGLFunctions_2_0[4647]
#define sipNameNr_glRasterPos2d 4661
#define sipName_glRasterPos2d &sipStrings__QOpenGLFunctions_2_0[4661]
#define sipNameNr_glRasterPos2f 4675
#define sipName_glRasterPos2f &sipStrings__QOpenGLFunctions_2_0[4675]
#define sipNameNr_glRasterPos2i 4689
#define sipName_glRasterPos2i &sipStrings__QOpenGLFunctions_2_0[4689]
#define sipNameNr_glRasterPos2s 4703
#define sipName_glRasterPos2s &sipStrings__QOpenGLFunctions_2_0[4703]
#define sipNameNr_glRasterPos3d 4717
#define sipName_glRasterPos3d &sipStrings__QOpenGLFunctions_2_0[4717]
#define sipNameNr_glRasterPos3f 4731
#define sipName_glRasterPos3f &sipStrings__QOpenGLFunctions_2_0[4731]
#define sipNameNr_glRasterPos3i 4745
#define sipName_glRasterPos3i &sipStrings__QOpenGLFunctions_2_0[4745]
#define sipNameNr_glRasterPos3s 4759
#define sipName_glRasterPos3s &sipStrings__QOpenGLFunctions_2_0[4759]
#define sipNameNr_glRasterPos4d 4773
#define sipName_glRasterPos4d &sipStrings__QOpenGLFunctions_2_0[4773]
#define sipNameNr_glRasterPos4f 4787
#define sipName_glRasterPos4f &sipStrings__QOpenGLFunctions_2_0[4787]
#define sipNameNr_glRasterPos4i 4801
#define sipName_glRasterPos4i &sipStrings__QOpenGLFunctions_2_0[4801]
#define sipNameNr_glRasterPos4s 4815
#define sipName_glRasterPos4s &sipStrings__QOpenGLFunctions_2_0[4815]
#define sipNameNr_glResetMinmax 4829
#define sipName_glResetMinmax &sipStrings__QOpenGLFunctions_2_0[4829]
#define sipNameNr_glStencilFunc 4843
#define sipName_glStencilFunc &sipStrings__QOpenGLFunctions_2_0[4843]
#define sipNameNr_glStencilMask 4857
#define sipName_glStencilMask &sipStrings__QOpenGLFunctions_2_0[4857]
#define sipNameNr_glTexCoord1dv 4871
#define sipName_glTexCoord1dv &sipStrings__QOpenGLFunctions_2_0[4871]
#define sipNameNr_glTexCoord1fv 4885
#define sipName_glTexCoord1fv &sipStrings__QOpenGLFunctions_2_0[4885]
#define sipNameNr_glTexCoord1iv 4899
#define sipName_glTexCoord1iv &sipStrings__QOpenGLFunctions_2_0[4899]
#define sipNameNr_glTexCoord1sv 4913
#define sipName_glTexCoord1sv &sipStrings__QOpenGLFunctions_2_0[4913]
#define sipNameNr_glTexCoord2dv 4927
#define sipName_glTexCoord2dv &sipStrings__QOpenGLFunctions_2_0[4927]
#define sipNameNr_glTexCoord2fv 4941
#define sipName_glTexCoord2fv &sipStrings__QOpenGLFunctions_2_0[4941]
#define sipNameNr_glTexCoord2iv 4955
#define sipName_glTexCoord2iv &sipStrings__QOpenGLFunctions_2_0[4955]
#define sipNameNr_glTexCoord2sv 4969
#define sipName_glTexCoord2sv &sipStrings__QOpenGLFunctions_2_0[4969]
#define sipNameNr_glTexCoord3dv 4983
#define sipName_glTexCoord3dv &sipStrings__QOpenGLFunctions_2_0[4983]
#define sipNameNr_glTexCoord3fv 4997
#define sipName_glTexCoord3fv &sipStrings__QOpenGLFunctions_2_0[4997]
#define sipNameNr_glTexCoord3iv 5011
#define sipName_glTexCoord3iv &sipStrings__QOpenGLFunctions_2_0[5011]
#define sipNameNr_glTexCoord3sv 5025
#define sipName_glTexCoord3sv &sipStrings__QOpenGLFunctions_2_0[5025]
#define sipNameNr_glTexCoord4dv 5039
#define sipName_glTexCoord4dv &sipStrings__QOpenGLFunctions_2_0[5039]
#define sipNameNr_glTexCoord4fv 5053
#define sipName_glTexCoord4fv &sipStrings__QOpenGLFunctions_2_0[5053]
#define sipNameNr_glTexCoord4iv 5067
#define sipName_glTexCoord4iv &sipStrings__QOpenGLFunctions_2_0[5067]
#define sipNameNr_glTexCoord4sv 5081
#define sipName_glTexCoord4sv &sipStrings__QOpenGLFunctions_2_0[5081]
#define sipNameNr_glUnmapBuffer 5095
#define sipName_glUnmapBuffer &sipStrings__QOpenGLFunctions_2_0[5095]
#define sipNameNr_glWindowPos2d 5109
#define sipName_glWindowPos2d &sipStrings__QOpenGLFunctions_2_0[5109]
#define sipNameNr_glWindowPos2f 5123
#define sipName_glWindowPos2f &sipStrings__QOpenGLFunctions_2_0[5123]
#define sipNameNr_glWindowPos2i 5137
#define sipName_glWindowPos2i &sipStrings__QOpenGLFunctions_2_0[5137]
#define sipNameNr_glWindowPos2s 5151
#define sipName_glWindowPos2s &sipStrings__QOpenGLFunctions_2_0[5151]
#define sipNameNr_glWindowPos3d 5165
#define sipName_glWindowPos3d &sipStrings__QOpenGLFunctions_2_0[5165]
#define sipNameNr_glWindowPos3f 5179
#define sipName_glWindowPos3f &sipStrings__QOpenGLFunctions_2_0[5179]
#define sipNameNr_glWindowPos3i 5193
#define sipName_glWindowPos3i &sipStrings__QOpenGLFunctions_2_0[5193]
#define sipNameNr_glWindowPos3s 5207
#define sipName_glWindowPos3s &sipStrings__QOpenGLFunctions_2_0[5207]
#define sipNameNr_glBeginQuery 5221
#define sipName_glBeginQuery &sipStrings__QOpenGLFunctions_2_0[5221]
#define sipNameNr_glBindBuffer 5234
#define sipName_glBindBuffer &sipStrings__QOpenGLFunctions_2_0[5234]
#define sipNameNr_glBlendColor 5247
#define sipName_glBlendColor &sipStrings__QOpenGLFunctions_2_0[5247]
#define sipNameNr_glBufferData 5260
#define sipName_glBufferData &sipStrings__QOpenGLFunctions_2_0[5260]
#define sipNameNr_glClearAccum 5273
#define sipName_glClearAccum &sipStrings__QOpenGLFunctions_2_0[5273]
#define sipNameNr_glClearColor 5286
#define sipName_glClearColor &sipStrings__QOpenGLFunctions_2_0[5286]
#define sipNameNr_glClearDepth 5299
#define sipName_glClearDepth &sipStrings__QOpenGLFunctions_2_0[5299]
#define sipNameNr_glClearIndex 5312
#define sipName_glClearIndex &sipStrings__QOpenGLFunctions_2_0[5312]
#define sipNameNr_glColorTable 5325
#define sipName_glColorTable &sipStrings__QOpenGLFunctions_2_0[5325]
#define sipNameNr_glCopyPixels 5338
#define sipName_glCopyPixels &sipStrings__QOpenGLFunctions_2_0[5338]
#define sipNameNr_glDepthRange 5351
#define sipName_glDepthRange &sipStrings__QOpenGLFunctions_2_0[5351]
#define sipNameNr_glDrawArrays 5364
#define sipName_glDrawArrays &sipStrings__QOpenGLFunctions_2_0[5364]
#define sipNameNr_glDrawBuffer 5377
#define sipName_glDrawBuffer &sipStrings__QOpenGLFunctions_2_0[5377]
#define sipNameNr_glDrawPixels 5390
#define sipName_glDrawPixels &sipStrings__QOpenGLFunctions_2_0[5390]
#define sipNameNr_glEvalPoint1 5403
#define sipName_glEvalPoint1 &sipStrings__QOpenGLFunctions_2_0[5403]
#define sipNameNr_glEvalPoint2 5416
#define sipName_glEvalPoint2 &sipStrings__QOpenGLFunctions_2_0[5416]
#define sipNameNr_glFogCoorddv 5429
#define sipName_glFogCoorddv &sipStrings__QOpenGLFunctions_2_0[5429]
#define sipNameNr_glFogCoordfv 5442
#define sipName_glFogCoordfv &sipStrings__QOpenGLFunctions_2_0[5442]
#define sipNameNr_glGenBuffers 5455
#define sipName_glGenBuffers &sipStrings__QOpenGLFunctions_2_0[5455]
#define sipNameNr_glGenQueries 5468
#define sipName_glGenQueries &sipStrings__QOpenGLFunctions_2_0[5468]
#define sipNameNr_glGetDoublev 5481
#define sipName_glGetDoublev &sipStrings__QOpenGLFunctions_2_0[5481]
#define sipNameNr_glGetLightfv 5494
#define sipName_glGetLightfv &sipStrings__QOpenGLFunctions_2_0[5494]
#define sipNameNr_glGetLightiv 5507
#define sipName_glGetLightiv &sipStrings__QOpenGLFunctions_2_0[5507]
#define sipNameNr_glGetQueryiv 5520
#define sipName_glGetQueryiv &sipStrings__QOpenGLFunctions_2_0[5520]
#define sipNameNr_glMaterialfv 5533
#define sipName_glMaterialfv &sipStrings__QOpenGLFunctions_2_0[5533]
#define sipNameNr_glMaterialiv 5546
#define sipName_glMaterialiv &sipStrings__QOpenGLFunctions_2_0[5546]
#define sipNameNr_glMatrixMode 5559
#define sipName_glMatrixMode &sipStrings__QOpenGLFunctions_2_0[5559]
#define sipNameNr_glPixelMapfv 5572
#define sipName_glPixelMapfv &sipStrings__QOpenGLFunctions_2_0[5572]
#define sipNameNr_glPushAttrib 5585
#define sipName_glPushAttrib &sipStrings__QOpenGLFunctions_2_0[5585]
#define sipNameNr_glPushMatrix 5598
#define sipName_glPushMatrix &sipStrings__QOpenGLFunctions_2_0[5598]
#define sipNameNr_glReadBuffer 5611
#define sipName_glReadBuffer &sipStrings__QOpenGLFunctions_2_0[5611]
#define sipNameNr_glReadPixels 5624
#define sipName_glReadPixels &sipStrings__QOpenGLFunctions_2_0[5624]
#define sipNameNr_glRenderMode 5637
#define sipName_glRenderMode &sipStrings__QOpenGLFunctions_2_0[5637]
#define sipNameNr_glShadeModel 5650
#define sipName_glShadeModel &sipStrings__QOpenGLFunctions_2_0[5650]
#define sipNameNr_glTexCoord1d 5663
#define sipName_glTexCoord1d &sipStrings__QOpenGLFunctions_2_0[5663]
#define sipNameNr_glTexCoord1f 5676
#define sipName_glTexCoord1f &sipStrings__QOpenGLFunctions_2_0[5676]
#define sipNameNr_glTexCoord1i 5689
#define sipName_glTexCoord1i &sipStrings__QOpenGLFunctions_2_0[5689]
#define sipNameNr_glTexCoord1s 5702
#define sipName_glTexCoord1s &sipStrings__QOpenGLFunctions_2_0[5702]
#define sipNameNr_glTexCoord2d 5715
#define sipName_glTexCoord2d &sipStrings__QOpenGLFunctions_2_0[5715]
#define sipNameNr_glTexCoord2f 5728
#define sipName_glTexCoord2f &sipStrings__QOpenGLFunctions_2_0[5728]
#define sipNameNr_glTexCoord2i 5741
#define sipName_glTexCoord2i &sipStrings__QOpenGLFunctions_2_0[5741]
#define sipNameNr_glTexCoord2s 5754
#define sipName_glTexCoord2s &sipStrings__QOpenGLFunctions_2_0[5754]
#define sipNameNr_glTexCoord3d 5767
#define sipName_glTexCoord3d &sipStrings__QOpenGLFunctions_2_0[5767]
#define sipNameNr_glTexCoord3f 5780
#define sipName_glTexCoord3f &sipStrings__QOpenGLFunctions_2_0[5780]
#define sipNameNr_glTexCoord3i 5793
#define sipName_glTexCoord3i &sipStrings__QOpenGLFunctions_2_0[5793]
#define sipNameNr_glTexCoord3s 5806
#define sipName_glTexCoord3s &sipStrings__QOpenGLFunctions_2_0[5806]
#define sipNameNr_glTexCoord4d 5819
#define sipName_glTexCoord4d &sipStrings__QOpenGLFunctions_2_0[5819]
#define sipNameNr_glTexCoord4f 5832
#define sipName_glTexCoord4f &sipStrings__QOpenGLFunctions_2_0[5832]
#define sipNameNr_glTexCoord4i 5845
#define sipName_glTexCoord4i &sipStrings__QOpenGLFunctions_2_0[5845]
#define sipNameNr_glTexCoord4s 5858
#define sipName_glTexCoord4s &sipStrings__QOpenGLFunctions_2_0[5858]
#define sipNameNr_glTexImage1D 5871
#define sipName_glTexImage1D &sipStrings__QOpenGLFunctions_2_0[5871]
#define sipNameNr_glTexImage2D 5884
#define sipName_glTexImage2D &sipStrings__QOpenGLFunctions_2_0[5884]
#define sipNameNr_glTexImage3D 5897
#define sipName_glTexImage3D &sipStrings__QOpenGLFunctions_2_0[5897]
#define sipNameNr_glTranslated 5910
#define sipName_glTranslated &sipStrings__QOpenGLFunctions_2_0[5910]
#define sipNameNr_glTranslatef 5923
#define sipName_glTranslatef &sipStrings__QOpenGLFunctions_2_0[5923]
#define sipNameNr_glUniform1fv 5936
#define sipName_glUniform1fv &sipStrings__QOpenGLFunctions_2_0[5936]
#define sipNameNr_glUniform1iv 5949
#define sipName_glUniform1iv &sipStrings__QOpenGLFunctions_2_0[5949]
#define sipNameNr_glUniform2fv 5962
#define sipName_glUniform2fv &sipStrings__QOpenGLFunctions_2_0[5962]
#define sipNameNr_glUniform2iv 5975
#define sipName_glUniform2iv &sipStrings__QOpenGLFunctions_2_0[5975]
#define sipNameNr_glUniform3fv 5988
#define sipName_glUniform3fv &sipStrings__QOpenGLFunctions_2_0[5988]
#define sipNameNr_glUniform3iv 6001
#define sipName_glUniform3iv &sipStrings__QOpenGLFunctions_2_0[6001]
#define sipNameNr_glUniform4fv 6014
#define sipName_glUniform4fv &sipStrings__QOpenGLFunctions_2_0[6014]
#define sipNameNr_glUniform4iv 6027
#define sipName_glUniform4iv &sipStrings__QOpenGLFunctions_2_0[6027]
#define sipNameNr_glUseProgram 6040
#define sipName_glUseProgram &sipStrings__QOpenGLFunctions_2_0[6040]
#define sipNameNr_glAlphaFunc 6053
#define sipName_glAlphaFunc &sipStrings__QOpenGLFunctions_2_0[6053]
#define sipNameNr_glBlendFunc 6065
#define sipName_glBlendFunc &sipStrings__QOpenGLFunctions_2_0[6065]
#define sipNameNr_glClipPlane 6077
#define sipName_glClipPlane &sipStrings__QOpenGLFunctions_2_0[6077]
#define sipNameNr_glColor3ubv 6089
#define sipName_glColor3ubv &sipStrings__QOpenGLFunctions_2_0[6089]
#define sipNameNr_glColor3uiv 6101
#define sipName_glColor3uiv &sipStrings__QOpenGLFunctions_2_0[6101]
#define sipNameNr_glColor3usv 6113
#define sipName_glColor3usv &sipStrings__QOpenGLFunctions_2_0[6113]
#define sipNameNr_glColor4ubv 6125
#define sipName_glColor4ubv &sipStrings__QOpenGLFunctions_2_0[6125]
#define sipNameNr_glColor4uiv 6137
#define sipName_glColor4uiv &sipStrings__QOpenGLFunctions_2_0[6137]
#define sipNameNr_glColor4usv 6149
#define sipName_glColor4usv &sipStrings__QOpenGLFunctions_2_0[6149]
#define sipNameNr_glColorMask 6161
#define sipName_glColorMask &sipStrings__QOpenGLFunctions_2_0[6161]
#define sipNameNr_glDepthFunc 6173
#define sipName_glDepthFunc &sipStrings__QOpenGLFunctions_2_0[6173]
#define sipNameNr_glDepthMask 6185
#define sipName_glDepthMask &sipStrings__QOpenGLFunctions_2_0[6185]
#define sipNameNr_glEdgeFlagv 6197
#define sipName_glEdgeFlagv &sipStrings__QOpenGLFunctions_2_0[6197]
#define sipNameNr_glEvalMesh1 6209
#define sipName_glEvalMesh1 &sipStrings__QOpenGLFunctions_2_0[6209]
#define sipNameNr_glEvalMesh2 6221
#define sipName_glEvalMesh2 &sipStrings__QOpenGLFunctions_2_0[6221]
#define sipNameNr_glFogCoordd 6233
#define sipName_glFogCoordd &sipStrings__QOpenGLFunctions_2_0[6233]
#define sipNameNr_glFogCoordf 6245
#define sipName_glFogCoordf &sipStrings__QOpenGLFunctions_2_0[6245]
#define sipNameNr_glFrontFace 6257
#define sipName_glFrontFace &sipStrings__QOpenGLFunctions_2_0[6257]
#define sipNameNr_glGetFloatv 6269
#define sipName_glGetFloatv &sipStrings__QOpenGLFunctions_2_0[6269]
#define sipNameNr_glGetString 6281
#define sipName_glGetString &sipStrings__QOpenGLFunctions_2_0[6281]
#define sipNameNr_glHistogram 6293
#define sipName_glHistogram &sipStrings__QOpenGLFunctions_2_0[6293]
#define sipNameNr_glIndexMask 6305
#define sipName_glIndexMask &sipStrings__QOpenGLFunctions_2_0[6305]
#define sipNameNr_glInitNames 6317
#define sipName_glInitNames &sipStrings__QOpenGLFunctions_2_0[6317]
#define sipNameNr_glIsEnabled 6329
#define sipName_glIsEnabled &sipStrings__QOpenGLFunctions_2_0[6329]
#define sipNameNr_glIsProgram 6341
#define sipName_glIsProgram &sipStrings__QOpenGLFunctions_2_0[6341]
#define sipNameNr_glIsTexture 6353
#define sipName_glIsTexture &sipStrings__QOpenGLFunctions_2_0[6353]
#define sipNameNr_glLineWidth 6365
#define sipName_glLineWidth &sipStrings__QOpenGLFunctions_2_0[6365]
#define sipNameNr_glMapGrid1d 6377
#define sipName_glMapGrid1d &sipStrings__QOpenGLFunctions_2_0[6377]
#define sipNameNr_glMapGrid1f 6389
#define sipName_glMapGrid1f &sipStrings__QOpenGLFunctions_2_0[6389]
#define sipNameNr_glMapGrid2d 6401
#define sipName_glMapGrid2d &sipStrings__QOpenGLFunctions_2_0[6401]
#define sipNameNr_glMapGrid2f 6413
#define sipName_glMapGrid2f &sipStrings__QOpenGLFunctions_2_0[6413]
#define sipNameNr_glMaterialf 6425
#define sipName_glMaterialf &sipStrings__QOpenGLFunctions_2_0[6425]
#define sipNameNr_glMateriali 6437
#define sipName_glMateriali &sipStrings__QOpenGLFunctions_2_0[6437]
#define sipNameNr_glNormal3bv 6449
#define sipName_glNormal3bv &sipStrings__QOpenGLFunctions_2_0[6449]
#define sipNameNr_glNormal3dv 6461
#define sipName_glNormal3dv &sipStrings__QOpenGLFunctions_2_0[6461]
#define sipNameNr_glNormal3fv 6473
#define sipName_glNormal3fv &sipStrings__QOpenGLFunctions_2_0[6473]
#define sipNameNr_glNormal3iv 6485
#define sipName_glNormal3iv &sipStrings__QOpenGLFunctions_2_0[6485]
#define sipNameNr_glNormal3sv 6497
#define sipName_glNormal3sv &sipStrings__QOpenGLFunctions_2_0[6497]
#define sipNameNr_glPixelZoom 6509
#define sipName_glPixelZoom &sipStrings__QOpenGLFunctions_2_0[6509]
#define sipNameNr_glPointSize 6521
#define sipName_glPointSize &sipStrings__QOpenGLFunctions_2_0[6521]
#define sipNameNr_glPopAttrib 6533
#define sipName_glPopAttrib &sipStrings__QOpenGLFunctions_2_0[6533]
#define sipNameNr_glPopMatrix 6545
#define sipName_glPopMatrix &sipStrings__QOpenGLFunctions_2_0[6545]
#define sipNameNr_glStencilOp 6557
#define sipName_glStencilOp &sipStrings__QOpenGLFunctions_2_0[6557]
#define sipNameNr_glUniform1f 6569
#define sipName_glUniform1f &sipStrings__QOpenGLFunctions_2_0[6569]
#define sipNameNr_glUniform1i 6581
#define sipName_glUniform1i &sipStrings__QOpenGLFunctions_2_0[6581]
#define sipNameNr_glUniform2f 6593
#define sipName_glUniform2f &sipStrings__QOpenGLFunctions_2_0[6593]
#define sipNameNr_glUniform2i 6605
#define sipName_glUniform2i &sipStrings__QOpenGLFunctions_2_0[6605]
#define sipNameNr_glUniform3f 6617
#define sipName_glUniform3f &sipStrings__QOpenGLFunctions_2_0[6617]
#define sipNameNr_glUniform3i 6629
#define sipName_glUniform3i &sipStrings__QOpenGLFunctions_2_0[6629]
#define sipNameNr_glUniform4f 6641
#define sipName_glUniform4f &sipStrings__QOpenGLFunctions_2_0[6641]
#define sipNameNr_glUniform4i 6653
#define sipName_glUniform4i &sipStrings__QOpenGLFunctions_2_0[6653]
#define sipNameNr_glVertex2dv 6665
#define sipName_glVertex2dv &sipStrings__QOpenGLFunctions_2_0[6665]
#define sipNameNr_glVertex2fv 6677
#define sipName_glVertex2fv &sipStrings__QOpenGLFunctions_2_0[6677]
#define sipNameNr_glVertex2iv 6689
#define sipName_glVertex2iv &sipStrings__QOpenGLFunctions_2_0[6689]
#define sipNameNr_glVertex2sv 6701
#define sipName_glVertex2sv &sipStrings__QOpenGLFunctions_2_0[6701]
#define sipNameNr_glVertex3dv 6713
#define sipName_glVertex3dv &sipStrings__QOpenGLFunctions_2_0[6713]
#define sipNameNr_glVertex3fv 6725
#define sipName_glVertex3fv &sipStrings__QOpenGLFunctions_2_0[6725]
#define sipNameNr_glVertex3iv 6737
#define sipName_glVertex3iv &sipStrings__QOpenGLFunctions_2_0[6737]
#define sipNameNr_glVertex3sv 6749
#define sipName_glVertex3sv &sipStrings__QOpenGLFunctions_2_0[6749]
#define sipNameNr_glVertex4dv 6761
#define sipName_glVertex4dv &sipStrings__QOpenGLFunctions_2_0[6761]
#define sipNameNr_glVertex4fv 6773
#define sipName_glVertex4fv &sipStrings__QOpenGLFunctions_2_0[6773]
#define sipNameNr_glVertex4iv 6785
#define sipName_glVertex4iv &sipStrings__QOpenGLFunctions_2_0[6785]
#define sipNameNr_glVertex4sv 6797
#define sipName_glVertex4sv &sipStrings__QOpenGLFunctions_2_0[6797]
#define sipNameNr_glCallList 6809
#define sipName_glCallList &sipStrings__QOpenGLFunctions_2_0[6809]
#define sipNameNr_glColor3bv 6820
#define sipName_glColor3bv &sipStrings__QOpenGLFunctions_2_0[6820]
#define sipNameNr_glColor3dv 6831
#define sipName_glColor3dv &sipStrings__QOpenGLFunctions_2_0[6831]
#define sipNameNr_glColor3fv 6842
#define sipName_glColor3fv &sipStrings__QOpenGLFunctions_2_0[6842]
#define sipNameNr_glColor3iv 6853
#define sipName_glColor3iv &sipStrings__QOpenGLFunctions_2_0[6853]
#define sipNameNr_glColor3sv 6864
#define sipName_glColor3sv &sipStrings__QOpenGLFunctions_2_0[6864]
#define sipNameNr_glColor3ub 6875
#define sipName_glColor3ub &sipStrings__QOpenGLFunctions_2_0[6875]
#define sipNameNr_glColor3ui 6886
#define sipName_glColor3ui &sipStrings__QOpenGLFunctions_2_0[6886]
#define sipNameNr_glColor3us 6897
#define sipName_glColor3us &sipStrings__QOpenGLFunctions_2_0[6897]
#define sipNameNr_glColor4bv 6908
#define sipName_glColor4bv &sipStrings__QOpenGLFunctions_2_0[6908]
#define sipNameNr_glColor4dv 6919
#define sipName_glColor4dv &sipStrings__QOpenGLFunctions_2_0[6919]
#define sipNameNr_glColor4fv 6930
#define sipName_glColor4fv &sipStrings__QOpenGLFunctions_2_0[6930]
#define sipNameNr_glColor4iv 6941
#define sipName_glColor4iv &sipStrings__QOpenGLFunctions_2_0[6941]
#define sipNameNr_glColor4sv 6952
#define sipName_glColor4sv &sipStrings__QOpenGLFunctions_2_0[6952]
#define sipNameNr_glColor4ub 6963
#define sipName_glColor4ub &sipStrings__QOpenGLFunctions_2_0[6963]
#define sipNameNr_glColor4ui 6974
#define sipName_glColor4ui &sipStrings__QOpenGLFunctions_2_0[6974]
#define sipNameNr_glColor4us 6985
#define sipName_glColor4us &sipStrings__QOpenGLFunctions_2_0[6985]
#define sipNameNr_glCullFace 6996
#define sipName_glCullFace &sipStrings__QOpenGLFunctions_2_0[6996]
#define sipNameNr_glEdgeFlag 7007
#define sipName_glEdgeFlag &sipStrings__QOpenGLFunctions_2_0[7007]
#define sipNameNr_glEndQuery 7018
#define sipName_glEndQuery &sipStrings__QOpenGLFunctions_2_0[7018]
#define sipNameNr_glGenLists 7029
#define sipName_glGenLists &sipStrings__QOpenGLFunctions_2_0[7029]
#define sipNameNr_glGetError 7040
#define sipName_glGetError &sipStrings__QOpenGLFunctions_2_0[7040]
#define sipNameNr_glIndexubv 7051
#define sipName_glIndexubv &sipStrings__QOpenGLFunctions_2_0[7051]
#define sipNameNr_glIsBuffer 7062
#define sipName_glIsBuffer &sipStrings__QOpenGLFunctions_2_0[7062]
#define sipNameNr_glIsShader 7073
#define sipName_glIsShader &sipStrings__QOpenGLFunctions_2_0[7073]
#define sipNameNr_glListBase 7084
#define sipName_glListBase &sipStrings__QOpenGLFunctions_2_0[7084]
#define sipNameNr_glLoadName 7095
#define sipName_glLoadName &sipStrings__QOpenGLFunctions_2_0[7095]
#define sipNameNr_glNormal3b 7106
#define sipName_glNormal3b &sipStrings__QOpenGLFunctions_2_0[7106]
#define sipNameNr_glNormal3d 7117
#define sipName_glNormal3d &sipStrings__QOpenGLFunctions_2_0[7117]
#define sipNameNr_glNormal3f 7128
#define sipName_glNormal3f &sipStrings__QOpenGLFunctions_2_0[7128]
#define sipNameNr_glNormal3i 7139
#define sipName_glNormal3i &sipStrings__QOpenGLFunctions_2_0[7139]
#define sipNameNr_glNormal3s 7150
#define sipName_glNormal3s &sipStrings__QOpenGLFunctions_2_0[7150]
#define sipNameNr_glPushName 7161
#define sipName_glPushName &sipStrings__QOpenGLFunctions_2_0[7161]
#define sipNameNr_glTexEnvfv 7172
#define sipName_glTexEnvfv &sipStrings__QOpenGLFunctions_2_0[7172]
#define sipNameNr_glTexEnviv 7183
#define sipName_glTexEnviv &sipStrings__QOpenGLFunctions_2_0[7183]
#define sipNameNr_glTexGendv 7194
#define sipName_glTexGendv &sipStrings__QOpenGLFunctions_2_0[7194]
#define sipNameNr_glTexGenfv 7205
#define sipName_glTexGenfv &sipStrings__QOpenGLFunctions_2_0[7205]
#define sipNameNr_glTexGeniv 7216
#define sipName_glTexGeniv &sipStrings__QOpenGLFunctions_2_0[7216]
#define sipNameNr_glVertex2d 7227
#define sipName_glVertex2d &sipStrings__QOpenGLFunctions_2_0[7227]
#define sipNameNr_glVertex2f 7238
#define sipName_glVertex2f &sipStrings__QOpenGLFunctions_2_0[7238]
#define sipNameNr_glVertex2i 7249
#define sipName_glVertex2i &sipStrings__QOpenGLFunctions_2_0[7249]
#define sipNameNr_glVertex2s 7260
#define sipName_glVertex2s &sipStrings__QOpenGLFunctions_2_0[7260]
#define sipNameNr_glVertex3d 7271
#define sipName_glVertex3d &sipStrings__QOpenGLFunctions_2_0[7271]
#define sipNameNr_glVertex3f 7282
#define sipName_glVertex3f &sipStrings__QOpenGLFunctions_2_0[7282]
#define sipNameNr_glVertex3i 7293
#define sipName_glVertex3i &sipStrings__QOpenGLFunctions_2_0[7293]
#define sipNameNr_glVertex3s 7304
#define sipName_glVertex3s &sipStrings__QOpenGLFunctions_2_0[7304]
#define sipNameNr_glVertex4d 7315
#define sipName_glVertex4d &sipStrings__QOpenGLFunctions_2_0[7315]
#define sipNameNr_glVertex4f 7326
#define sipName_glVertex4f &sipStrings__QOpenGLFunctions_2_0[7326]
#define sipNameNr_glVertex4i 7337
#define sipName_glVertex4i &sipStrings__QOpenGLFunctions_2_0[7337]
#define sipNameNr_glVertex4s 7348
#define sipName_glVertex4s &sipStrings__QOpenGLFunctions_2_0[7348]
#define sipNameNr_glViewport 7359
#define sipName_glViewport &sipStrings__QOpenGLFunctions_2_0[7359]
#define sipNameNr_glColor3b 7370
#define sipName_glColor3b &sipStrings__QOpenGLFunctions_2_0[7370]
#define sipNameNr_glColor3d 7380
#define sipName_glColor3d &sipStrings__QOpenGLFunctions_2_0[7380]
#define sipNameNr_glColor3f 7390
#define sipName_glColor3f &sipStrings__QOpenGLFunctions_2_0[7390]
#define sipNameNr_glColor3i 7400
#define sipName_glColor3i &sipStrings__QOpenGLFunctions_2_0[7400]
#define sipNameNr_glColor3s 7410
#define sipName_glColor3s &sipStrings__QOpenGLFunctions_2_0[7410]
#define sipNameNr_glColor4b 7420
#define sipName_glColor4b &sipStrings__QOpenGLFunctions_2_0[7420]
#define sipNameNr_glColor4d 7430
#define sipName_glColor4d &sipStrings__QOpenGLFunctions_2_0[7430]
#define sipNameNr_glColor4f 7440
#define sipName_glColor4f &sipStrings__QOpenGLFunctions_2_0[7440]
#define sipNameNr_glColor4i 7450
#define sipName_glColor4i &sipStrings__QOpenGLFunctions_2_0[7450]
#define sipNameNr_glColor4s 7460
#define sipName_glColor4s &sipStrings__QOpenGLFunctions_2_0[7460]
#define sipNameNr_glDisable 7470
#define sipName_glDisable &sipStrings__QOpenGLFunctions_2_0[7470]
#define sipNameNr_glEndList 7480
#define sipName_glEndList &sipStrings__QOpenGLFunctions_2_0[7480]
#define sipNameNr_glFrustum 7490
#define sipName_glFrustum &sipStrings__QOpenGLFunctions_2_0[7490]
#define sipNameNr_glIndexdv 7500
#define sipName_glIndexdv &sipStrings__QOpenGLFunctions_2_0[7500]
#define sipNameNr_glIndexfv 7510
#define sipName_glIndexfv &sipStrings__QOpenGLFunctions_2_0[7510]
#define sipNameNr_glIndexiv 7520
#define sipName_glIndexiv &sipStrings__QOpenGLFunctions_2_0[7520]
#define sipNameNr_glIndexsv 7530
#define sipName_glIndexsv &sipStrings__QOpenGLFunctions_2_0[7530]
#define sipNameNr_glIndexub 7540
#define sipName_glIndexub &sipStrings__QOpenGLFunctions_2_0[7540]
#define sipNameNr_glIsQuery 7550
#define sipName_glIsQuery &sipStrings__QOpenGLFunctions_2_0[7550]
#define sipNameNr_glLightfv 7560
#define sipName_glLightfv &sipStrings__QOpenGLFunctions_2_0[7560]
#define sipNameNr_glLightiv 7570
#define sipName_glLightiv &sipStrings__QOpenGLFunctions_2_0[7570]
#define sipNameNr_glLogicOp 7580
#define sipName_glLogicOp &sipStrings__QOpenGLFunctions_2_0[7580]
#define sipNameNr_glNewList 7590
#define sipName_glNewList &sipStrings__QOpenGLFunctions_2_0[7590]
#define sipNameNr_glPopName 7600
#define sipName_glPopName &sipStrings__QOpenGLFunctions_2_0[7600]
#define sipNameNr_glRotated 7610
#define sipName_glRotated &sipStrings__QOpenGLFunctions_2_0[7610]
#define sipNameNr_glRotatef 7620
#define sipName_glRotatef &sipStrings__QOpenGLFunctions_2_0[7620]
#define sipNameNr_glScissor 7630
#define sipName_glScissor &sipStrings__QOpenGLFunctions_2_0[7630]
#define sipNameNr_glTexEnvf 7640
#define sipName_glTexEnvf &sipStrings__QOpenGLFunctions_2_0[7640]
#define sipNameNr_glTexEnvi 7650
#define sipName_glTexEnvi &sipStrings__QOpenGLFunctions_2_0[7650]
#define sipNameNr_glTexGend 7660
#define sipName_glTexGend &sipStrings__QOpenGLFunctions_2_0[7660]
#define sipNameNr_glTexGenf 7670
#define sipName_glTexGenf &sipStrings__QOpenGLFunctions_2_0[7670]
#define sipNameNr_glTexGeni 7680
#define sipName_glTexGeni &sipStrings__QOpenGLFunctions_2_0[7680]
#define sipNameNr_glBitmap 7690
#define sipName_glBitmap &sipStrings__QOpenGLFunctions_2_0[7690]
#define sipNameNr_glEnable 7699
#define sipName_glEnable &sipStrings__QOpenGLFunctions_2_0[7699]
#define sipNameNr_glFinish 7708
#define sipName_glFinish &sipStrings__QOpenGLFunctions_2_0[7708]
#define sipNameNr_glIndexd 7717
#define sipName_glIndexd &sipStrings__QOpenGLFunctions_2_0[7717]
#define sipNameNr_glIndexf 7726
#define sipName_glIndexf &sipStrings__QOpenGLFunctions_2_0[7726]
#define sipNameNr_glIndexi 7735
#define sipName_glIndexi &sipStrings__QOpenGLFunctions_2_0[7735]
#define sipNameNr_glIndexs 7744
#define sipName_glIndexs &sipStrings__QOpenGLFunctions_2_0[7744]
#define sipNameNr_glIsList 7753
#define sipName_glIsList &sipStrings__QOpenGLFunctions_2_0[7753]
#define sipNameNr_glLightf 7762
#define sipName_glLightf &sipStrings__QOpenGLFunctions_2_0[7762]
#define sipNameNr_glLighti 7771
#define sipName_glLighti &sipStrings__QOpenGLFunctions_2_0[7771]
#define sipNameNr_glMinmax 7780
#define sipName_glMinmax &sipStrings__QOpenGLFunctions_2_0[7780]
#define sipNameNr_glScaled 7789
#define sipName_glScaled &sipStrings__QOpenGLFunctions_2_0[7789]
#define sipNameNr_glScalef 7798
#define sipName_glScalef &sipStrings__QOpenGLFunctions_2_0[7798]
#define sipNameNr_glAccum 7807
#define sipName_glAccum &sipStrings__QOpenGLFunctions_2_0[7807]
#define sipNameNr_glBegin 7815
#define sipName_glBegin &sipStrings__QOpenGLFunctions_2_0[7815]
#define sipNameNr_glClear 7823
#define sipName_glClear &sipStrings__QOpenGLFunctions_2_0[7823]
#define sipNameNr_glFlush 7831
#define sipName_glFlush &sipStrings__QOpenGLFunctions_2_0[7831]
#define sipNameNr_glFogfv 7839
#define sipName_glFogfv &sipStrings__QOpenGLFunctions_2_0[7839]
#define sipNameNr_glFogiv 7847
#define sipName_glFogiv &sipStrings__QOpenGLFunctions_2_0[7847]
#define sipNameNr_glMap1d 7855
#define sipName_glMap1d &sipStrings__QOpenGLFunctions_2_0[7855]
#define sipNameNr_glMap1f 7863
#define sipName_glMap1f &sipStrings__QOpenGLFunctions_2_0[7863]
#define sipNameNr_glMap2d 7871
#define sipName_glMap2d &sipStrings__QOpenGLFunctions_2_0[7871]
#define sipNameNr_glMap2f 7879
#define sipName_glMap2f &sipStrings__QOpenGLFunctions_2_0[7879]
#define sipNameNr_glOrtho 7887
#define sipName_glOrtho &sipStrings__QOpenGLFunctions_2_0[7887]
#define sipNameNr_glRectd 7895
#define sipName_glRectd &sipStrings__QOpenGLFunctions_2_0[7895]
#define sipNameNr_glRectf 7903
#define sipName_glRectf &sipStrings__QOpenGLFunctions_2_0[7903]
#define sipNameNr_glRecti 7911
#define sipName_glRecti &sipStrings__QOpenGLFunctions_2_0[7911]
#define sipNameNr_glRects 7919
#define sipName_glRects &sipStrings__QOpenGLFunctions_2_0[7919]
#define sipNameNr_glFogf 7927
#define sipName_glFogf &sipStrings__QOpenGLFunctions_2_0[7927]
#define sipNameNr_glFogi 7934
#define sipName_glFogi &sipStrings__QOpenGLFunctions_2_0[7934]
#define sipNameNr_glHint 7941
#define sipName_glHint &sipStrings__QOpenGLFunctions_2_0[7941]
#define sipNameNr_glEnd 7948
#define sipName_glEnd &sipStrings__QOpenGLFunctions_2_0[7948]

#define sipMalloc                   sipAPI__QOpenGLFunctions_2_0->api_malloc
#define sipFree                     sipAPI__QOpenGLFunctions_2_0->api_free
#define sipBuildResult              sipAPI__QOpenGLFunctions_2_0->api_build_result
#define sipCallMethod               sipAPI__QOpenGLFunctions_2_0->api_call_method
#define sipCallProcedureMethod      sipAPI__QOpenGLFunctions_2_0->api_call_procedure_method
#define sipCallErrorHandler         sipAPI__QOpenGLFunctions_2_0->api_call_error_handler
#define sipParseResultEx            sipAPI__QOpenGLFunctions_2_0->api_parse_result_ex
#define sipParseResult              sipAPI__QOpenGLFunctions_2_0->api_parse_result
#define sipParseArgs                sipAPI__QOpenGLFunctions_2_0->api_parse_args
#define sipParseKwdArgs             sipAPI__QOpenGLFunctions_2_0->api_parse_kwd_args
#define sipParsePair                sipAPI__QOpenGLFunctions_2_0->api_parse_pair
#define sipInstanceDestroyed        sipAPI__QOpenGLFunctions_2_0->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI__QOpenGLFunctions_2_0->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI__QOpenGLFunctions_2_0->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI__QOpenGLFunctions_2_0->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI__QOpenGLFunctions_2_0->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI__QOpenGLFunctions_2_0->api_convert_to_void_ptr
#define sipAddException             sipAPI__QOpenGLFunctions_2_0->api_add_exception
#define sipNoFunction               sipAPI__QOpenGLFunctions_2_0->api_no_function
#define sipNoMethod                 sipAPI__QOpenGLFunctions_2_0->api_no_method
#define sipAbstractMethod           sipAPI__QOpenGLFunctions_2_0->api_abstract_method
#define sipBadClass                 sipAPI__QOpenGLFunctions_2_0->api_bad_class
#define sipBadCatcherResult         sipAPI__QOpenGLFunctions_2_0->api_bad_catcher_result
#define sipBadCallableArg           sipAPI__QOpenGLFunctions_2_0->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI__QOpenGLFunctions_2_0->api_bad_operator_arg
#define sipTrace                    sipAPI__QOpenGLFunctions_2_0->api_trace
#define sipTransferBack             sipAPI__QOpenGLFunctions_2_0->api_transfer_back
#define sipTransferTo               sipAPI__QOpenGLFunctions_2_0->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI__QOpenGLFunctions_2_0->api_simplewrapper_type
#define sipWrapper_Type             sipAPI__QOpenGLFunctions_2_0->api_wrapper_type
#define sipWrapperType_Type         sipAPI__QOpenGLFunctions_2_0->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI__QOpenGLFunctions_2_0->api_voidptr_type
#define sipGetPyObject              sipAPI__QOpenGLFunctions_2_0->api_get_pyobject
#define sipGetAddress               sipAPI__QOpenGLFunctions_2_0->api_get_address
#define sipGetMixinAddress          sipAPI__QOpenGLFunctions_2_0->api_get_mixin_address
#define sipGetCppPtr                sipAPI__QOpenGLFunctions_2_0->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI__QOpenGLFunctions_2_0->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI__QOpenGLFunctions_2_0->api_call_hook
#define sipEndThread                sipAPI__QOpenGLFunctions_2_0->api_end_thread
#define sipRaiseUnknownException    sipAPI__QOpenGLFunctions_2_0->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI__QOpenGLFunctions_2_0->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI__QOpenGLFunctions_2_0->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI__QOpenGLFunctions_2_0->api_add_type_instance
#define sipPySlotExtend             sipAPI__QOpenGLFunctions_2_0->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI__QOpenGLFunctions_2_0->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI__QOpenGLFunctions_2_0->api_can_convert_to_type
#define sipConvertToType            sipAPI__QOpenGLFunctions_2_0->api_convert_to_type
#define sipForceConvertToType       sipAPI__QOpenGLFunctions_2_0->api_force_convert_to_type
#define sipConvertToEnum            sipAPI__QOpenGLFunctions_2_0->api_convert_to_enum
#define sipConvertToBool            sipAPI__QOpenGLFunctions_2_0->api_convert_to_bool
#define sipReleaseType              sipAPI__QOpenGLFunctions_2_0->api_release_type
#define sipConvertFromType          sipAPI__QOpenGLFunctions_2_0->api_convert_from_type
#define sipConvertFromNewType       sipAPI__QOpenGLFunctions_2_0->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI__QOpenGLFunctions_2_0->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI__QOpenGLFunctions_2_0->api_convert_from_enum
#define sipGetState                 sipAPI__QOpenGLFunctions_2_0->api_get_state
#define sipExportSymbol             sipAPI__QOpenGLFunctions_2_0->api_export_symbol
#define sipImportSymbol             sipAPI__QOpenGLFunctions_2_0->api_import_symbol
#define sipFindType                 sipAPI__QOpenGLFunctions_2_0->api_find_type
#define sipBytes_AsChar             sipAPI__QOpenGLFunctions_2_0->api_bytes_as_char
#define sipBytes_AsString           sipAPI__QOpenGLFunctions_2_0->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI__QOpenGLFunctions_2_0->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI__QOpenGLFunctions_2_0->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI__QOpenGLFunctions_2_0->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI__QOpenGLFunctions_2_0->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI__QOpenGLFunctions_2_0->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI__QOpenGLFunctions_2_0->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI__QOpenGLFunctions_2_0->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI__QOpenGLFunctions_2_0->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI__QOpenGLFunctions_2_0->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI__QOpenGLFunctions_2_0->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI__QOpenGLFunctions_2_0->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI__QOpenGLFunctions_2_0->api_get_reference
#define sipKeepReference            sipAPI__QOpenGLFunctions_2_0->api_keep_reference
#define sipRegisterProxyResolver    sipAPI__QOpenGLFunctions_2_0->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI__QOpenGLFunctions_2_0->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI__QOpenGLFunctions_2_0->api_type_from_py_type_object
#define sipTypeScope                sipAPI__QOpenGLFunctions_2_0->api_type_scope
#define sipResolveTypedef           sipAPI__QOpenGLFunctions_2_0->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI__QOpenGLFunctions_2_0->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI__QOpenGLFunctions_2_0->api_enable_autoconversion
#define sipInitMixin                sipAPI__QOpenGLFunctions_2_0->api_init_mixin
#define sipExportModule             sipAPI__QOpenGLFunctions_2_0->api_export_module
#define sipInitModule               sipAPI__QOpenGLFunctions_2_0->api_init_module
#define sipGetInterpreter           sipAPI__QOpenGLFunctions_2_0->api_get_interpreter
#define sipSetTypeUserData          sipAPI__QOpenGLFunctions_2_0->api_set_type_user_data
#define sipGetTypeUserData          sipAPI__QOpenGLFunctions_2_0->api_get_type_user_data
#define sipPyTypeDict               sipAPI__QOpenGLFunctions_2_0->api_py_type_dict
#define sipPyTypeName               sipAPI__QOpenGLFunctions_2_0->api_py_type_name
#define sipGetCFunction             sipAPI__QOpenGLFunctions_2_0->api_get_c_function
#define sipGetMethod                sipAPI__QOpenGLFunctions_2_0->api_get_method
#define sipFromMethod               sipAPI__QOpenGLFunctions_2_0->api_from_method
#define sipGetDate                  sipAPI__QOpenGLFunctions_2_0->api_get_date
#define sipFromDate                 sipAPI__QOpenGLFunctions_2_0->api_from_date
#define sipGetDateTime              sipAPI__QOpenGLFunctions_2_0->api_get_datetime
#define sipFromDateTime             sipAPI__QOpenGLFunctions_2_0->api_from_datetime
#define sipGetTime                  sipAPI__QOpenGLFunctions_2_0->api_get_time
#define sipFromTime                 sipAPI__QOpenGLFunctions_2_0->api_from_time
#define sipIsUserType               sipAPI__QOpenGLFunctions_2_0->api_is_user_type
#define sipCheckPluginForType       sipAPI__QOpenGLFunctions_2_0->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI__QOpenGLFunctions_2_0->api_unicode_new
#define sipUnicodeWrite             sipAPI__QOpenGLFunctions_2_0->api_unicode_write
#define sipUnicodeData              sipAPI__QOpenGLFunctions_2_0->api_unicode_data
#define sipGetBufferInfo            sipAPI__QOpenGLFunctions_2_0->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI__QOpenGLFunctions_2_0->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI__QOpenGLFunctions_2_0->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI__QOpenGLFunctions_2_0->api_is_derived_class
#define sipGetUserObject            sipAPI__QOpenGLFunctions_2_0->api_get_user_object
#define sipSetUserObject            sipAPI__QOpenGLFunctions_2_0->api_set_user_object
#define sipRegisterEventHandler     sipAPI__QOpenGLFunctions_2_0->api_register_event_handler
#define sipConvertToArray           sipAPI__QOpenGLFunctions_2_0->api_convert_to_array
#define sipConvertToTypedArray      sipAPI__QOpenGLFunctions_2_0->api_convert_to_typed_array
#define sipEnableGC                 sipAPI__QOpenGLFunctions_2_0->api_enable_gc
#define sipPrintObject              sipAPI__QOpenGLFunctions_2_0->api_print_object
#define sipLong_AsChar              sipAPI__QOpenGLFunctions_2_0->api_long_as_char
#define sipLong_AsSignedChar        sipAPI__QOpenGLFunctions_2_0->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI__QOpenGLFunctions_2_0->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI__QOpenGLFunctions_2_0->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI__QOpenGLFunctions_2_0->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI__QOpenGLFunctions_2_0->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI__QOpenGLFunctions_2_0->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI__QOpenGLFunctions_2_0->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI__QOpenGLFunctions_2_0->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI__QOpenGLFunctions_2_0->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI__QOpenGLFunctions_2_0->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI__QOpenGLFunctions_2_0->api_long_as_size_t
#define sipVisitWrappers            sipAPI__QOpenGLFunctions_2_0->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI__QOpenGLFunctions_2_0->api_register_exit_notifier
#define sipDeprecated               sipAPI__QOpenGLFunctions_2_0->api_deprecated
#define sipPyTypeDictRef            sipAPI__QOpenGLFunctions_2_0->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI__QOpenGLFunctions_2_0->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI__QOpenGLFunctions_2_0->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI__QOpenGLFunctions_2_0->api_get_frame
#define sipSetDestroyOnExit         sipAPI__QOpenGLFunctions_2_0->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI__QOpenGLFunctions_2_0->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI__QOpenGLFunctions_2_0->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI__QOpenGLFunctions_2_0->api_clear_any_slot_reference
#define sipConnectRx                sipAPI__QOpenGLFunctions_2_0->api_connect_rx
#define sipConvertRx                sipAPI__QOpenGLFunctions_2_0->api_convert_rx
#define sipDisconnectRx             sipAPI__QOpenGLFunctions_2_0->api_disconnect_rx
#define sipFreeSipslot              sipAPI__QOpenGLFunctions_2_0->api_free_sipslot
#define sipInvokeSlot               sipAPI__QOpenGLFunctions_2_0->api_invoke_slot
#define sipInvokeSlotEx             sipAPI__QOpenGLFunctions_2_0->api_invoke_slot_ex
#define sipSameSlot                 sipAPI__QOpenGLFunctions_2_0->api_same_slot
#define sipSaveSlot                 sipAPI__QOpenGLFunctions_2_0->api_save_slot
#define sipVisitSlot                sipAPI__QOpenGLFunctions_2_0->api_visit_slot
#define sipIsPyMethod               sipAPI__QOpenGLFunctions_2_0->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings__QOpenGLFunctions_2_0[];

#define sipType_QOpenGLFunctions_2_0 sipExportedTypes__QOpenGLFunctions_2_0[0]

extern sipClassTypeDef sipTypeDef__QOpenGLFunctions_2_0_QOpenGLFunctions_2_0;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI__QOpenGLFunctions_2_0;
extern sipExportedModuleDef sipModuleAPI__QOpenGLFunctions_2_0;
extern sipTypeDef *sipExportedTypes__QOpenGLFunctions_2_0[];

#define sipType_QAbstractOpenGLFunctions sipImportedTypes__QOpenGLFunctions_2_0_QtGui[0].it_td
extern sipImportedTypeDef sipImportedTypes__QOpenGLFunctions_2_0_QtGui[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip__QOpenGLFunctions_2_0_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip__QOpenGLFunctions_2_0_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip__QOpenGLFunctions_2_0_qt_metacast;
#line 2922 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_0/qopenglfunctions_2_0.sip"
#include <qopengl.h>

// Imports from QtGui.
typedef const GLvoid *(*qpyopengl_value_array_t)(sipErrorState *, PyObject *, GLenum, PyObject *);
extern qpyopengl_value_array_t qpyopengl_value_array;

typedef const GLvoid *(*qpyopengl_value_array_cached_t)(sipErrorState *, PyObject *, GLenum, PyObject *, const char *, GLuint);
extern qpyopengl_value_array_cached_t qpyopengl_value_array_cached;

typedef GLint (*qpyopengl_get_t)(GLenum, GLenum *);
extern qpyopengl_get_t qpyopengl_get;

typedef PyObject *(*qpyopengl_from_GLint_t)(int *, const GLint *, Py_ssize_t);
extern qpyopengl_from_GLint_t qpyopengl_from_GLint;

typedef PyObject *(*qpyopengl_from_GLuint_t)(int *, const GLuint *, Py_ssize_t);
extern qpyopengl_from_GLuint_t qpyopengl_from_GLuint;

typedef PyObject *(*qpyopengl_from_GLboolean_t)(int *, const GLboolean *, Py_ssize_t);
extern qpyopengl_from_GLboolean_t qpyopengl_from_GLboolean;

typedef PyObject *(*qpyopengl_from_GLfloat_t)(int *, const GLfloat *, Py_ssize_t);
extern qpyopengl_from_GLfloat_t qpyopengl_from_GLfloat;

typedef PyObject *(*qpyopengl_from_GLdouble_t)(int *, const GLdouble *, Py_ssize_t);
extern qpyopengl_from_GLdouble_t qpyopengl_from_GLdouble;
#line 1340 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_0/sipAPI_QOpenGLFunctions_2_0.h"

#endif
