/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameracontrol.sip"
#include <qcameracontrol.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraControl.cpp"


class sipQCameraControl : public ::QCameraControl
{
public:
    sipQCameraControl(::QObject*);
    virtual ~sipQCameraControl();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool canChangeProperty(::QCameraControl::PropertyChangeType, ::QCamera::Status) const SIP_OVERRIDE;
    bool isCaptureModeSupported(::QCamera::CaptureModes) const SIP_OVERRIDE;
    void setCaptureMode(::QCamera::CaptureModes) SIP_OVERRIDE;
    ::QCamera::CaptureModes captureMode() const SIP_OVERRIDE;
    ::QCamera::Status status() const SIP_OVERRIDE;
    void setState(::QCamera::State) SIP_OVERRIDE;
    ::QCamera::State state() const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQCameraControl(const sipQCameraControl &);
    sipQCameraControl &operator = (const sipQCameraControl &);

    char sipPyMethods[14];
};

sipQCameraControl::sipQCameraControl(::QObject*a0): ::QCameraControl(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCameraControl::~sipQCameraControl()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQCameraControl::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QCameraControl);

    return ::QCameraControl::metaObject();
}

int sipQCameraControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QCameraControl::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QCameraControl, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQCameraControl::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QCameraControl, _clname, &sipCpp) ? sipCpp : ::QCameraControl::qt_metacast(_clname));
}

bool sipQCameraControl::canChangeProperty(::QCameraControl::PropertyChangeType a0, ::QCamera::Status a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraControl, sipName_canChangeProperty);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_53(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCameraControl::PropertyChangeType, ::QCamera::Status);

    return sipVH_QtMultimedia_53(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQCameraControl::isCaptureModeSupported(::QCamera::CaptureModes a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraControl, sipName_isCaptureModeSupported);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_52(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCamera::CaptureModes);

    return sipVH_QtMultimedia_52(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraControl::setCaptureMode(::QCamera::CaptureModes a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, sipName_QCameraControl, sipName_setCaptureMode);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_51(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCamera::CaptureModes);

    sipVH_QtMultimedia_51(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QCamera::CaptureModes sipQCameraControl::captureMode() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraControl, sipName_captureMode);

    if (!sipMeth)
        return ::QCamera::CaptureModes();

    extern ::QCamera::CaptureModes sipVH_QtMultimedia_50(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_50(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QCamera::Status sipQCameraControl::status() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraControl, sipName_status);

    if (!sipMeth)
        return ::QCamera::UnavailableStatus;

    extern ::QCamera::Status sipVH_QtMultimedia_49(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_49(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQCameraControl::setState(::QCamera::State a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, sipName_QCameraControl, sipName_setState);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCamera::State);

    sipVH_QtMultimedia_48(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QCamera::State sipQCameraControl::state() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraControl, sipName_state);

    if (!sipMeth)
        return ::QCamera::UnloadedState;

    extern ::QCamera::State sipVH_QtMultimedia_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_47(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQCameraControl::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QCameraControl::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraControl::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QCameraControl::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraControl::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QCameraControl::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraControl::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QCameraControl::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraControl::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QCameraControl::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCameraControl::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QCameraControl::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQCameraControl::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QCameraControl::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QCameraControl_state, "state(self) -> QCamera.State");

extern "C" {static PyObject *meth_QCameraControl_state(PyObject *, PyObject *);}
static PyObject *meth_QCameraControl_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QCameraControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraControl, &sipCpp))
        {
            ::QCamera::State sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraControl, sipName_state);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCamera_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraControl, sipName_state, doc_QCameraControl_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraControl_setState, "setState(self, state: QCamera.State)");

extern "C" {static PyObject *meth_QCameraControl_setState(PyObject *, PyObject *);}
static PyObject *meth_QCameraControl_setState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCamera::State a0;
        ::QCameraControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraControl, &sipCpp, sipType_QCamera_State, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraControl, sipName_setState);
                return SIP_NULLPTR;
            }

            sipCpp->setState(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraControl, sipName_setState, doc_QCameraControl_setState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraControl_status, "status(self) -> QCamera.Status");

extern "C" {static PyObject *meth_QCameraControl_status(PyObject *, PyObject *);}
static PyObject *meth_QCameraControl_status(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QCameraControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraControl, &sipCpp))
        {
            ::QCamera::Status sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraControl, sipName_status);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->status();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCamera_Status);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraControl, sipName_status, doc_QCameraControl_status);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraControl_captureMode, "captureMode(self) -> QCamera.CaptureModes");

extern "C" {static PyObject *meth_QCameraControl_captureMode(PyObject *, PyObject *);}
static PyObject *meth_QCameraControl_captureMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QCameraControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraControl, &sipCpp))
        {
            ::QCamera::CaptureModes*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraControl, sipName_captureMode);
                return SIP_NULLPTR;
            }

            sipRes = new ::QCamera::CaptureModes(sipCpp->captureMode());

            return sipConvertFromNewType(sipRes, sipType_QCamera_CaptureModes, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraControl, sipName_captureMode, doc_QCameraControl_captureMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraControl_setCaptureMode, "setCaptureMode(self, a0: Union[QCamera.CaptureModes, QCamera.CaptureMode])");

extern "C" {static PyObject *meth_QCameraControl_setCaptureMode(PyObject *, PyObject *);}
static PyObject *meth_QCameraControl_setCaptureMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCamera::CaptureModes* a0;
        int a0State = 0;
        ::QCameraControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCameraControl, &sipCpp, sipType_QCamera_CaptureModes, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraControl, sipName_setCaptureMode);
                return SIP_NULLPTR;
            }

            sipCpp->setCaptureMode(*a0);
            sipReleaseType(a0, sipType_QCamera_CaptureModes, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraControl, sipName_setCaptureMode, doc_QCameraControl_setCaptureMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraControl_isCaptureModeSupported, "isCaptureModeSupported(self, mode: Union[QCamera.CaptureModes, QCamera.CaptureMode]) -> bool");

extern "C" {static PyObject *meth_QCameraControl_isCaptureModeSupported(PyObject *, PyObject *);}
static PyObject *meth_QCameraControl_isCaptureModeSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCamera::CaptureModes* a0;
        int a0State = 0;
        const ::QCameraControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCameraControl, &sipCpp, sipType_QCamera_CaptureModes, &a0, &a0State))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraControl, sipName_isCaptureModeSupported);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isCaptureModeSupported(*a0);
            sipReleaseType(a0, sipType_QCamera_CaptureModes, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraControl, sipName_isCaptureModeSupported, doc_QCameraControl_isCaptureModeSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraControl_canChangeProperty, "canChangeProperty(self, changeType: QCameraControl.PropertyChangeType, status: QCamera.Status) -> bool");

extern "C" {static PyObject *meth_QCameraControl_canChangeProperty(PyObject *, PyObject *);}
static PyObject *meth_QCameraControl_canChangeProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCameraControl::PropertyChangeType a0;
        ::QCamera::Status a1;
        const ::QCameraControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEE", &sipSelf, sipType_QCameraControl, &sipCpp, sipType_QCameraControl_PropertyChangeType, &a0, sipType_QCamera_Status, &a1))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraControl, sipName_canChangeProperty);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->canChangeProperty(a0, a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraControl, sipName_canChangeProperty, doc_QCameraControl_canChangeProperty);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QCameraControl(void *, const sipTypeDef *);}
static void *cast_QCameraControl(void *sipCppV, const sipTypeDef *targetType)
{
    ::QCameraControl *sipCpp = reinterpret_cast< ::QCameraControl *>(sipCppV);

    if (targetType == sipType_QCameraControl)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaControl)->ctd_cast(static_cast< ::QMediaControl *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QCameraControl(void *, int);}
static void release_QCameraControl(void *sipCppV, int)
{
    ::QCameraControl *sipCpp = reinterpret_cast< ::QCameraControl *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QCameraControl(sipSimpleWrapper *);}
static void dealloc_QCameraControl(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQCameraControl *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QCameraControl(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QCameraControl(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QCameraControl(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQCameraControl *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQCameraControl(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QCameraControl[] = {{104, 255, 1}};


static PyMethodDef methods_QCameraControl[] = {
    {sipName_canChangeProperty, meth_QCameraControl_canChangeProperty, METH_VARARGS, doc_QCameraControl_canChangeProperty},
    {sipName_captureMode, meth_QCameraControl_captureMode, METH_VARARGS, doc_QCameraControl_captureMode},
    {sipName_isCaptureModeSupported, meth_QCameraControl_isCaptureModeSupported, METH_VARARGS, doc_QCameraControl_isCaptureModeSupported},
    {sipName_setCaptureMode, meth_QCameraControl_setCaptureMode, METH_VARARGS, doc_QCameraControl_setCaptureMode},
    {sipName_setState, meth_QCameraControl_setState, METH_VARARGS, doc_QCameraControl_setState},
    {sipName_state, meth_QCameraControl_state, METH_VARARGS, doc_QCameraControl_state},
    {sipName_status, meth_QCameraControl_status, METH_VARARGS, doc_QCameraControl_status}
};

static sipEnumMemberDef enummembers_QCameraControl[] = {
    {sipName_CaptureMode, static_cast<int>(::QCameraControl::CaptureMode), 45},
    {sipName_ImageEncodingSettings, static_cast<int>(::QCameraControl::ImageEncodingSettings), 45},
    {sipName_VideoEncodingSettings, static_cast<int>(::QCameraControl::VideoEncodingSettings), 45},
    {sipName_Viewfinder, static_cast<int>(::QCameraControl::Viewfinder), 45},
    {sipName_ViewfinderSettings, static_cast<int>(::QCameraControl::ViewfinderSettings), 45},
};

PyDoc_STRVAR(doc_QCameraControl, "\1QCameraControl(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QCameraControl[] = {
    {"captureModeChanged(QCamera::CaptureModes)", "\1captureModeChanged(self, mode: Union[QCamera.CaptureModes, QCamera.CaptureMode])", SIP_NULLPTR, SIP_NULLPTR},
    {"error(int,QString)", "\1error(self, error: int, errorString: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"statusChanged(QCamera::Status)", "\1statusChanged(self, a0: QCamera.Status)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QCamera::State)", "\1stateChanged(self, a0: QCamera.State)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QCameraControl = {
    &::QCameraControl::staticMetaObject,
    0,
    signals_QCameraControl,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QCameraControl = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCameraControl,
        SIP_NULLPTR,
        &plugin_QCameraControl,
    },
    {
        sipNameNr_QCameraControl,
        {0, 0, 1},
        7, methods_QCameraControl,
        5, enummembers_QCameraControl,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QCameraControl,
    -1,
    -1,
    supers_QCameraControl,
    SIP_NULLPTR,
    init_type_QCameraControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QCameraControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QCameraControl,
    cast_QCameraControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QCameraControl),
};
