/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtX11ExtrasAPI_H
#define _QtX11ExtrasAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_PyQt5_QtX11Extras 0
#define sipName_PyQt5_QtX11Extras &sipStrings_QtX11Extras[0]
#define sipNameNr_sip_simplewrapper 18
#define sipName_sip_simplewrapper &sipStrings_QtX11Extras[18]
#define sipNameNr_setNextStartupId 36
#define sipName_setNextStartupId &sipStrings_QtX11Extras[36]
#define sipNameNr_xcb_connection_t 53
#define sipName_xcb_connection_t &sipStrings_QtX11Extras[53]
#define sipNameNr_setAppUserTime 70
#define sipName_setAppUserTime &sipStrings_QtX11Extras[70]
#define sipNameNr_appRootWindow 85
#define sipName_appRootWindow &sipStrings_QtX11Extras[85]
#define sipNameNr_isPlatformX11 99
#define sipName_isPlatformX11 &sipStrings_QtX11Extras[99]
#define sipNameNr_nextStartupId 113
#define sipName_nextStartupId &sipStrings_QtX11Extras[113]
#define sipNameNr_getTimestamp 127
#define sipName_getTimestamp &sipStrings_QtX11Extras[127]
#define sipNameNr_appUserTime 140
#define sipName_appUserTime &sipStrings_QtX11Extras[140]
#define sipNameNr_connection 152
#define sipName_connection &sipStrings_QtX11Extras[152]
#define sipNameNr_setAppTime 163
#define sipName_setAppTime &sipStrings_QtX11Extras[163]
#define sipNameNr_appScreen 174
#define sipName_appScreen &sipStrings_QtX11Extras[174]
#define sipNameNr_QX11Info 184
#define sipName_QX11Info &sipStrings_QtX11Extras[184]
#define sipNameNr_Display 193
#define sipName_Display &sipStrings_QtX11Extras[193]
#define sipNameNr_appDpiX 201
#define sipName_appDpiX &sipStrings_QtX11Extras[201]
#define sipNameNr_appDpiY 209
#define sipName_appDpiY &sipStrings_QtX11Extras[209]
#define sipNameNr_appTime 217
#define sipName_appTime &sipStrings_QtX11Extras[217]
#define sipNameNr_display 225
#define sipName_display &sipStrings_QtX11Extras[225]
#define sipNameNr_screen 233
#define sipName_screen &sipStrings_QtX11Extras[233]

#define sipMalloc                   sipAPI_QtX11Extras->api_malloc
#define sipFree                     sipAPI_QtX11Extras->api_free
#define sipBuildResult              sipAPI_QtX11Extras->api_build_result
#define sipCallMethod               sipAPI_QtX11Extras->api_call_method
#define sipCallProcedureMethod      sipAPI_QtX11Extras->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtX11Extras->api_call_error_handler
#define sipParseResultEx            sipAPI_QtX11Extras->api_parse_result_ex
#define sipParseResult              sipAPI_QtX11Extras->api_parse_result
#define sipParseArgs                sipAPI_QtX11Extras->api_parse_args
#define sipParseKwdArgs             sipAPI_QtX11Extras->api_parse_kwd_args
#define sipParsePair                sipAPI_QtX11Extras->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtX11Extras->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtX11Extras->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtX11Extras->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtX11Extras->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtX11Extras->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtX11Extras->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtX11Extras->api_add_exception
#define sipNoFunction               sipAPI_QtX11Extras->api_no_function
#define sipNoMethod                 sipAPI_QtX11Extras->api_no_method
#define sipAbstractMethod           sipAPI_QtX11Extras->api_abstract_method
#define sipBadClass                 sipAPI_QtX11Extras->api_bad_class
#define sipBadCatcherResult         sipAPI_QtX11Extras->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtX11Extras->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtX11Extras->api_bad_operator_arg
#define sipTrace                    sipAPI_QtX11Extras->api_trace
#define sipTransferBack             sipAPI_QtX11Extras->api_transfer_back
#define sipTransferTo               sipAPI_QtX11Extras->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtX11Extras->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtX11Extras->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtX11Extras->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtX11Extras->api_voidptr_type
#define sipGetPyObject              sipAPI_QtX11Extras->api_get_pyobject
#define sipGetAddress               sipAPI_QtX11Extras->api_get_address
#define sipGetMixinAddress          sipAPI_QtX11Extras->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtX11Extras->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtX11Extras->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtX11Extras->api_call_hook
#define sipEndThread                sipAPI_QtX11Extras->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtX11Extras->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtX11Extras->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtX11Extras->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtX11Extras->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtX11Extras->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtX11Extras->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtX11Extras->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtX11Extras->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtX11Extras->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtX11Extras->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtX11Extras->api_convert_to_bool
#define sipReleaseType              sipAPI_QtX11Extras->api_release_type
#define sipConvertFromType          sipAPI_QtX11Extras->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtX11Extras->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtX11Extras->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtX11Extras->api_convert_from_enum
#define sipGetState                 sipAPI_QtX11Extras->api_get_state
#define sipExportSymbol             sipAPI_QtX11Extras->api_export_symbol
#define sipImportSymbol             sipAPI_QtX11Extras->api_import_symbol
#define sipFindType                 sipAPI_QtX11Extras->api_find_type
#define sipBytes_AsChar             sipAPI_QtX11Extras->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtX11Extras->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtX11Extras->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtX11Extras->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtX11Extras->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtX11Extras->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtX11Extras->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtX11Extras->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtX11Extras->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtX11Extras->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtX11Extras->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtX11Extras->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtX11Extras->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtX11Extras->api_get_reference
#define sipKeepReference            sipAPI_QtX11Extras->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtX11Extras->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtX11Extras->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtX11Extras->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtX11Extras->api_type_scope
#define sipResolveTypedef           sipAPI_QtX11Extras->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtX11Extras->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtX11Extras->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtX11Extras->api_init_mixin
#define sipExportModule             sipAPI_QtX11Extras->api_export_module
#define sipInitModule               sipAPI_QtX11Extras->api_init_module
#define sipGetInterpreter           sipAPI_QtX11Extras->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtX11Extras->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtX11Extras->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtX11Extras->api_py_type_dict
#define sipPyTypeName               sipAPI_QtX11Extras->api_py_type_name
#define sipGetCFunction             sipAPI_QtX11Extras->api_get_c_function
#define sipGetMethod                sipAPI_QtX11Extras->api_get_method
#define sipFromMethod               sipAPI_QtX11Extras->api_from_method
#define sipGetDate                  sipAPI_QtX11Extras->api_get_date
#define sipFromDate                 sipAPI_QtX11Extras->api_from_date
#define sipGetDateTime              sipAPI_QtX11Extras->api_get_datetime
#define sipFromDateTime             sipAPI_QtX11Extras->api_from_datetime
#define sipGetTime                  sipAPI_QtX11Extras->api_get_time
#define sipFromTime                 sipAPI_QtX11Extras->api_from_time
#define sipIsUserType               sipAPI_QtX11Extras->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtX11Extras->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtX11Extras->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtX11Extras->api_unicode_write
#define sipUnicodeData              sipAPI_QtX11Extras->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtX11Extras->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtX11Extras->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtX11Extras->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtX11Extras->api_is_derived_class
#define sipGetUserObject            sipAPI_QtX11Extras->api_get_user_object
#define sipSetUserObject            sipAPI_QtX11Extras->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtX11Extras->api_register_event_handler
#define sipConvertToArray           sipAPI_QtX11Extras->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtX11Extras->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtX11Extras->api_enable_gc
#define sipPrintObject              sipAPI_QtX11Extras->api_print_object
#define sipLong_AsChar              sipAPI_QtX11Extras->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtX11Extras->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtX11Extras->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtX11Extras->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtX11Extras->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtX11Extras->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtX11Extras->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtX11Extras->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtX11Extras->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtX11Extras->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtX11Extras->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtX11Extras->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtX11Extras->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtX11Extras->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtX11Extras->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtX11Extras->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtX11Extras->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtX11Extras->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtX11Extras->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtX11Extras->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtX11Extras->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtX11Extras->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtX11Extras->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtX11Extras->api_connect_rx
#define sipConvertRx                sipAPI_QtX11Extras->api_convert_rx
#define sipDisconnectRx             sipAPI_QtX11Extras->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtX11Extras->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtX11Extras->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtX11Extras->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtX11Extras->api_same_slot
#define sipSaveSlot                 sipAPI_QtX11Extras->api_save_slot
#define sipVisitSlot                sipAPI_QtX11Extras->api_visit_slot
#define sipIsPyMethod               sipAPI_QtX11Extras->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtX11Extras[];

#define sipType_Display sipExportedTypes_QtX11Extras[0]

extern sipClassTypeDef sipTypeDef_QtX11Extras_Display;

#define sipType_xcb_connection_t sipExportedTypes_QtX11Extras[2]

extern sipClassTypeDef sipTypeDef_QtX11Extras_xcb_connection_t;

#define sipType_QX11Info sipExportedTypes_QtX11Extras[1]

extern sipClassTypeDef sipTypeDef_QtX11Extras_QX11Info;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtX11Extras;
extern sipExportedModuleDef sipModuleAPI_QtX11Extras;
extern sipTypeDef *sipExportedTypes_QtX11Extras[];

#define sipType_QByteArray sipImportedTypes_QtX11Extras_QtCore[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtX11Extras_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtX11Extras_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtX11Extras_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtX11Extras_qt_metacast;

#endif
