/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qradiotuner.sip"
#include <qradiotuner.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qradiodata.sip"
#include <qradiodata.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 250 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qpair.sip"
#include <qpair.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmultimedia.sip"
#include <qmultimedia.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaservice.sip"
#include <qmediaservice.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTuner.cpp"


class sipQRadioTuner : public ::QRadioTuner
{
public:
    sipQRadioTuner(::QObject*);
    virtual ~sipQRadioTuner();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool isAvailable() const SIP_OVERRIDE;
    ::QMultimedia::AvailabilityStatus availability() const SIP_OVERRIDE;
    ::QMediaService* service() const SIP_OVERRIDE;
    bool bind(::QObject*) SIP_OVERRIDE;
    void unbind(::QObject*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQRadioTuner(const sipQRadioTuner &);
    sipQRadioTuner &operator = (const sipQRadioTuner &);

    char sipPyMethods[12];
};

sipQRadioTuner::sipQRadioTuner(::QObject*a0): ::QRadioTuner(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQRadioTuner::~sipQRadioTuner()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQRadioTuner::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QRadioTuner);

    return ::QRadioTuner::metaObject();
}

int sipQRadioTuner::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QRadioTuner::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QRadioTuner, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQRadioTuner::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QRadioTuner, _clname, &sipCpp) ? sipCpp : ::QRadioTuner::qt_metacast(_clname));
}

void sipQRadioTuner::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QRadioTuner::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioTuner::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QRadioTuner::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioTuner::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QRadioTuner::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioTuner::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QRadioTuner::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioTuner::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QRadioTuner::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQRadioTuner::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QRadioTuner::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQRadioTuner::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QRadioTuner::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQRadioTuner::isAvailable() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isAvailable);

    if (!sipMeth)
        return ::QRadioTuner::isAvailable();

    extern bool sipVH_QtMultimedia_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_16(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QMultimedia::AvailabilityStatus sipQRadioTuner::availability() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_availability);

    if (!sipMeth)
        return ::QRadioTuner::availability();

    extern ::QMultimedia::AvailabilityStatus sipVH_QtMultimedia_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_17(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QMediaService* sipQRadioTuner::service() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_service);

    if (!sipMeth)
        return ::QRadioTuner::service();

    extern ::QMediaService* sipVH_QtMultimedia_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_18(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQRadioTuner::bind(::QObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_bind);

    if (!sipMeth)
        return ::QRadioTuner::bind(a0);

    extern bool sipVH_QtMultimedia_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*);

    return sipVH_QtMultimedia_19(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioTuner::unbind(::QObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_unbind);

    if (!sipMeth)
    {
        ::QRadioTuner::unbind(a0);
        return;
    }

    extern void sipVH_QtMultimedia_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*);

    sipVH_QtMultimedia_20(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QRadioTuner_availability, "availability(self) -> QMultimedia.AvailabilityStatus");

extern "C" {static PyObject *meth_QRadioTuner_availability(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_availability(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            ::QMultimedia::AvailabilityStatus sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRadioTuner::availability() : sipCpp->availability());

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMultimedia_AvailabilityStatus);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_availability, doc_QRadioTuner_availability);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_state, "state(self) -> QRadioTuner.State");

extern "C" {static PyObject *meth_QRadioTuner_state(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            ::QRadioTuner::State sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QRadioTuner_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_state, doc_QRadioTuner_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_band, "band(self) -> QRadioTuner.Band");

extern "C" {static PyObject *meth_QRadioTuner_band(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_band(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            ::QRadioTuner::Band sipRes;

            sipRes = sipCpp->band();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QRadioTuner_Band);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_band, doc_QRadioTuner_band);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_isBandSupported, "isBandSupported(self, b: QRadioTuner.Band) -> bool");

extern "C" {static PyObject *meth_QRadioTuner_isBandSupported(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_isBandSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRadioTuner::Band a0;
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QRadioTuner, &sipCpp, sipType_QRadioTuner_Band, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isBandSupported(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_isBandSupported, doc_QRadioTuner_isBandSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_frequency, "frequency(self) -> int");

extern "C" {static PyObject *meth_QRadioTuner_frequency(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_frequency(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->frequency();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_frequency, doc_QRadioTuner_frequency);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_frequencyStep, "frequencyStep(self, band: QRadioTuner.Band) -> int");

extern "C" {static PyObject *meth_QRadioTuner_frequencyStep(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_frequencyStep(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRadioTuner::Band a0;
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QRadioTuner, &sipCpp, sipType_QRadioTuner_Band, &a0))
        {
            int sipRes;

            sipRes = sipCpp->frequencyStep(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_frequencyStep, doc_QRadioTuner_frequencyStep);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_frequencyRange, "frequencyRange(self, band: QRadioTuner.Band) -> tuple[int, int]");

extern "C" {static PyObject *meth_QRadioTuner_frequencyRange(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_frequencyRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRadioTuner::Band a0;
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QRadioTuner, &sipCpp, sipType_QRadioTuner_Band, &a0))
        {
            ::QPair<int, int>*sipRes;

            sipRes = new ::QPair<int, int>(sipCpp->frequencyRange(a0));

            return sipConvertFromNewType(sipRes, sipType_QPair_1800_1800, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_frequencyRange, doc_QRadioTuner_frequencyRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_isStereo, "isStereo(self) -> bool");

extern "C" {static PyObject *meth_QRadioTuner_isStereo(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_isStereo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isStereo();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_isStereo, doc_QRadioTuner_isStereo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_setStereoMode, "setStereoMode(self, mode: QRadioTuner.StereoMode)");

extern "C" {static PyObject *meth_QRadioTuner_setStereoMode(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_setStereoMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRadioTuner::StereoMode a0;
        ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QRadioTuner, &sipCpp, sipType_QRadioTuner_StereoMode, &a0))
        {
            sipCpp->setStereoMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_setStereoMode, doc_QRadioTuner_setStereoMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_stereoMode, "stereoMode(self) -> QRadioTuner.StereoMode");

extern "C" {static PyObject *meth_QRadioTuner_stereoMode(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_stereoMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            ::QRadioTuner::StereoMode sipRes;

            sipRes = sipCpp->stereoMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QRadioTuner_StereoMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_stereoMode, doc_QRadioTuner_stereoMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_signalStrength, "signalStrength(self) -> int");

extern "C" {static PyObject *meth_QRadioTuner_signalStrength(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_signalStrength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->signalStrength();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_signalStrength, doc_QRadioTuner_signalStrength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_volume, "volume(self) -> int");

extern "C" {static PyObject *meth_QRadioTuner_volume(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_volume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->volume();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_volume, doc_QRadioTuner_volume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_isMuted, "isMuted(self) -> bool");

extern "C" {static PyObject *meth_QRadioTuner_isMuted(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_isMuted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isMuted();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_isMuted, doc_QRadioTuner_isMuted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_isSearching, "isSearching(self) -> bool");

extern "C" {static PyObject *meth_QRadioTuner_isSearching(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_isSearching(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isSearching();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_isSearching, doc_QRadioTuner_isSearching);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_isAntennaConnected, "isAntennaConnected(self) -> bool");

extern "C" {static PyObject *meth_QRadioTuner_isAntennaConnected(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_isAntennaConnected(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAntennaConnected();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_isAntennaConnected, doc_QRadioTuner_isAntennaConnected);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_error, "error(self) -> QRadioTuner.Error");

extern "C" {static PyObject *meth_QRadioTuner_error(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            ::QRadioTuner::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QRadioTuner_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_error, doc_QRadioTuner_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QRadioTuner_errorString(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_errorString, doc_QRadioTuner_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_radioData, "radioData(self) -> Optional[QRadioData]");

extern "C" {static PyObject *meth_QRadioTuner_radioData(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_radioData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            ::QRadioData*sipRes;

            sipRes = sipCpp->radioData();

            return sipConvertFromType(sipRes, sipType_QRadioData, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_radioData, doc_QRadioTuner_radioData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_searchForward, "searchForward(self)");

extern "C" {static PyObject *meth_QRadioTuner_searchForward(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_searchForward(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            sipCpp->searchForward();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_searchForward, doc_QRadioTuner_searchForward);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_searchBackward, "searchBackward(self)");

extern "C" {static PyObject *meth_QRadioTuner_searchBackward(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_searchBackward(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            sipCpp->searchBackward();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_searchBackward, doc_QRadioTuner_searchBackward);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_searchAllStations, "searchAllStations(self, searchMode: QRadioTuner.SearchMode = QRadioTuner.SearchFast)");

extern "C" {static PyObject *meth_QRadioTuner_searchAllStations(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_searchAllStations(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRadioTuner::SearchMode a0 = QRadioTuner::SearchFast;
        ::QRadioTuner *sipCpp;

        static const char *sipKwdList[] = {
            sipName_searchMode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QRadioTuner, &sipCpp, sipType_QRadioTuner_SearchMode, &a0))
        {
            sipCpp->searchAllStations(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_searchAllStations, doc_QRadioTuner_searchAllStations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_cancelSearch, "cancelSearch(self)");

extern "C" {static PyObject *meth_QRadioTuner_cancelSearch(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_cancelSearch(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            sipCpp->cancelSearch();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_cancelSearch, doc_QRadioTuner_cancelSearch);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_setBand, "setBand(self, band: QRadioTuner.Band)");

extern "C" {static PyObject *meth_QRadioTuner_setBand(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_setBand(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRadioTuner::Band a0;
        ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QRadioTuner, &sipCpp, sipType_QRadioTuner_Band, &a0))
        {
            sipCpp->setBand(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_setBand, doc_QRadioTuner_setBand);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_setFrequency, "setFrequency(self, frequency: int)");

extern "C" {static PyObject *meth_QRadioTuner_setFrequency(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_setFrequency(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QRadioTuner, &sipCpp, &a0))
        {
            sipCpp->setFrequency(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_setFrequency, doc_QRadioTuner_setFrequency);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_setVolume, "setVolume(self, volume: int)");

extern "C" {static PyObject *meth_QRadioTuner_setVolume(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_setVolume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QRadioTuner, &sipCpp, &a0))
        {
            sipCpp->setVolume(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_setVolume, doc_QRadioTuner_setVolume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_setMuted, "setMuted(self, muted: bool)");

extern "C" {static PyObject *meth_QRadioTuner_setMuted(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_setMuted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QRadioTuner, &sipCpp, &a0))
        {
            sipCpp->setMuted(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_setMuted, doc_QRadioTuner_setMuted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_start, "start(self)");

extern "C" {static PyObject *meth_QRadioTuner_start(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_start(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            sipCpp->start();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_start, doc_QRadioTuner_start);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTuner_stop, "stop(self)");

extern "C" {static PyObject *meth_QRadioTuner_stop(PyObject *, PyObject *);}
static PyObject *meth_QRadioTuner_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QRadioTuner *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTuner, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTuner, sipName_stop, doc_QRadioTuner_stop);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QRadioTuner(void *, const sipTypeDef *);}
static void *cast_QRadioTuner(void *sipCppV, const sipTypeDef *targetType)
{
    ::QRadioTuner *sipCpp = reinterpret_cast< ::QRadioTuner *>(sipCppV);

    if (targetType == sipType_QRadioTuner)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaObject)->ctd_cast(static_cast< ::QMediaObject *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QRadioTuner(void *, int);}
static void release_QRadioTuner(void *sipCppV, int)
{
    ::QRadioTuner *sipCpp = reinterpret_cast< ::QRadioTuner *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QRadioTuner(Py_ssize_t);}
static void *array_QRadioTuner(Py_ssize_t sipNrElem)
{
    return new ::QRadioTuner[sipNrElem];
}


extern "C" {static void array_delete_QRadioTuner(void *);}
static void array_delete_QRadioTuner(void *sipCpp)
{
    delete[] reinterpret_cast< ::QRadioTuner *>(sipCpp);
}


extern "C" {static void dealloc_QRadioTuner(sipSimpleWrapper *);}
static void dealloc_QRadioTuner(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQRadioTuner *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QRadioTuner(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QRadioTuner(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QRadioTuner(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQRadioTuner *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQRadioTuner(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QRadioTuner[] = {{108, 255, 1}};


static PyMethodDef methods_QRadioTuner[] = {
    {sipName_availability, meth_QRadioTuner_availability, METH_VARARGS, doc_QRadioTuner_availability},
    {sipName_band, meth_QRadioTuner_band, METH_VARARGS, doc_QRadioTuner_band},
    {sipName_cancelSearch, meth_QRadioTuner_cancelSearch, METH_VARARGS, doc_QRadioTuner_cancelSearch},
    {sipName_error, meth_QRadioTuner_error, METH_VARARGS, doc_QRadioTuner_error},
    {sipName_errorString, meth_QRadioTuner_errorString, METH_VARARGS, doc_QRadioTuner_errorString},
    {sipName_frequency, meth_QRadioTuner_frequency, METH_VARARGS, doc_QRadioTuner_frequency},
    {sipName_frequencyRange, meth_QRadioTuner_frequencyRange, METH_VARARGS, doc_QRadioTuner_frequencyRange},
    {sipName_frequencyStep, meth_QRadioTuner_frequencyStep, METH_VARARGS, doc_QRadioTuner_frequencyStep},
    {sipName_isAntennaConnected, meth_QRadioTuner_isAntennaConnected, METH_VARARGS, doc_QRadioTuner_isAntennaConnected},
    {sipName_isBandSupported, meth_QRadioTuner_isBandSupported, METH_VARARGS, doc_QRadioTuner_isBandSupported},
    {sipName_isMuted, meth_QRadioTuner_isMuted, METH_VARARGS, doc_QRadioTuner_isMuted},
    {sipName_isSearching, meth_QRadioTuner_isSearching, METH_VARARGS, doc_QRadioTuner_isSearching},
    {sipName_isStereo, meth_QRadioTuner_isStereo, METH_VARARGS, doc_QRadioTuner_isStereo},
    {sipName_radioData, meth_QRadioTuner_radioData, METH_VARARGS, doc_QRadioTuner_radioData},
    {sipName_searchAllStations, SIP_MLMETH_CAST(meth_QRadioTuner_searchAllStations), METH_VARARGS|METH_KEYWORDS, doc_QRadioTuner_searchAllStations},
    {sipName_searchBackward, meth_QRadioTuner_searchBackward, METH_VARARGS, doc_QRadioTuner_searchBackward},
    {sipName_searchForward, meth_QRadioTuner_searchForward, METH_VARARGS, doc_QRadioTuner_searchForward},
    {sipName_setBand, meth_QRadioTuner_setBand, METH_VARARGS, doc_QRadioTuner_setBand},
    {sipName_setFrequency, meth_QRadioTuner_setFrequency, METH_VARARGS, doc_QRadioTuner_setFrequency},
    {sipName_setMuted, meth_QRadioTuner_setMuted, METH_VARARGS, doc_QRadioTuner_setMuted},
    {sipName_setStereoMode, meth_QRadioTuner_setStereoMode, METH_VARARGS, doc_QRadioTuner_setStereoMode},
    {sipName_setVolume, meth_QRadioTuner_setVolume, METH_VARARGS, doc_QRadioTuner_setVolume},
    {sipName_signalStrength, meth_QRadioTuner_signalStrength, METH_VARARGS, doc_QRadioTuner_signalStrength},
    {sipName_start, meth_QRadioTuner_start, METH_VARARGS, doc_QRadioTuner_start},
    {sipName_state, meth_QRadioTuner_state, METH_VARARGS, doc_QRadioTuner_state},
    {sipName_stereoMode, meth_QRadioTuner_stereoMode, METH_VARARGS, doc_QRadioTuner_stereoMode},
    {sipName_stop, meth_QRadioTuner_stop, METH_VARARGS, doc_QRadioTuner_stop},
    {sipName_volume, meth_QRadioTuner_volume, METH_VARARGS, doc_QRadioTuner_volume}
};

static sipEnumMemberDef enummembers_QRadioTuner[] = {
    {sipName_AM, static_cast<int>(::QRadioTuner::AM), 143},
    {sipName_ActiveState, static_cast<int>(::QRadioTuner::ActiveState), 146},
    {sipName_Auto, static_cast<int>(::QRadioTuner::Auto), 147},
    {sipName_FM, static_cast<int>(::QRadioTuner::FM), 143},
    {sipName_FM2, static_cast<int>(::QRadioTuner::FM2), 143},
    {sipName_ForceMono, static_cast<int>(::QRadioTuner::ForceMono), 147},
    {sipName_ForceStereo, static_cast<int>(::QRadioTuner::ForceStereo), 147},
    {sipName_LW, static_cast<int>(::QRadioTuner::LW), 143},
    {sipName_NoError, static_cast<int>(::QRadioTuner::NoError), 144},
    {sipName_OpenError, static_cast<int>(::QRadioTuner::OpenError), 144},
    {sipName_OutOfRangeError, static_cast<int>(::QRadioTuner::OutOfRangeError), 144},
    {sipName_ResourceError, static_cast<int>(::QRadioTuner::ResourceError), 144},
    {sipName_SW, static_cast<int>(::QRadioTuner::SW), 143},
    {sipName_SearchFast, static_cast<int>(::QRadioTuner::SearchFast), 145},
    {sipName_SearchGetStationId, static_cast<int>(::QRadioTuner::SearchGetStationId), 145},
    {sipName_StoppedState, static_cast<int>(::QRadioTuner::StoppedState), 146},
};

PyDoc_STRVAR(doc_QRadioTuner, "\1QRadioTuner(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QRadioTuner[] = {
    {"antennaConnectedChanged(bool)", "\1antennaConnectedChanged(self, connectionStatus: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"stationFound(int,QString)", "\1stationFound(self, frequency: int, stationId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"mutedChanged(bool)", "\1mutedChanged(self, muted: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"volumeChanged(int)", "\1volumeChanged(self, volume: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"signalStrengthChanged(int)", "\1signalStrengthChanged(self, signalStrength: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"searchingChanged(bool)", "\1searchingChanged(self, searching: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"stereoStatusChanged(bool)", "\1stereoStatusChanged(self, stereo: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"frequencyChanged(int)", "\1frequencyChanged(self, frequency: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"bandChanged(QRadioTuner::Band)", "\1bandChanged(self, band: QRadioTuner.Band)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QRadioTuner::State)", "\1stateChanged(self, state: QRadioTuner.State)", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QRadioTuner::Error)", "\1error(self, error: QRadioTuner.Error)", &methods_QRadioTuner[3], SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QRadioTuner = {
    &::QRadioTuner::staticMetaObject,
    0,
    signals_QRadioTuner,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QRadioTuner = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QRadioTuner,
        SIP_NULLPTR,
        &plugin_QRadioTuner,
    },
    {
        sipNameNr_QRadioTuner,
        {0, 0, 1},
        28, methods_QRadioTuner,
        16, enummembers_QRadioTuner,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QRadioTuner,
    -1,
    -1,
    supers_QRadioTuner,
    SIP_NULLPTR,
    init_type_QRadioTuner,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QRadioTuner,
    SIP_NULLPTR,
    array_QRadioTuner,
    SIP_NULLPTR,
    release_QRadioTuner,
    cast_QRadioTuner,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QRadioTuner,
    sizeof (::QRadioTuner),
};
