/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qradiotunercontrol.sip"
#include <qradiotunercontrol.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qradiotuner.sip"
#include <qradiotuner.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 250 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qpair.sip"
#include <qpair.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioTunerControl.cpp"


class sipQRadioTunerControl : public ::QRadioTunerControl
{
public:
    sipQRadioTunerControl(::QObject*);
    virtual ~sipQRadioTunerControl();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QString errorString() const SIP_OVERRIDE;
    ::QRadioTuner::Error error() const SIP_OVERRIDE;
    void stop() SIP_OVERRIDE;
    void start() SIP_OVERRIDE;
    void cancelSearch() SIP_OVERRIDE;
    void searchAllStations(::QRadioTuner::SearchMode) SIP_OVERRIDE;
    void searchBackward() SIP_OVERRIDE;
    void searchForward() SIP_OVERRIDE;
    bool isAntennaConnected() const SIP_OVERRIDE;
    bool isSearching() const SIP_OVERRIDE;
    void setMuted(bool) SIP_OVERRIDE;
    bool isMuted() const SIP_OVERRIDE;
    void setVolume(int) SIP_OVERRIDE;
    int volume() const SIP_OVERRIDE;
    int signalStrength() const SIP_OVERRIDE;
    void setStereoMode(::QRadioTuner::StereoMode) SIP_OVERRIDE;
    ::QRadioTuner::StereoMode stereoMode() const SIP_OVERRIDE;
    bool isStereo() const SIP_OVERRIDE;
    void setFrequency(int) SIP_OVERRIDE;
    ::QPair<int, int> frequencyRange(::QRadioTuner::Band) const SIP_OVERRIDE;
    int frequencyStep(::QRadioTuner::Band) const SIP_OVERRIDE;
    int frequency() const SIP_OVERRIDE;
    bool isBandSupported(::QRadioTuner::Band) const SIP_OVERRIDE;
    void setBand(::QRadioTuner::Band) SIP_OVERRIDE;
    ::QRadioTuner::Band band() const SIP_OVERRIDE;
    ::QRadioTuner::State state() const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQRadioTunerControl(const sipQRadioTunerControl &);
    sipQRadioTunerControl &operator = (const sipQRadioTunerControl &);

    char sipPyMethods[33];
};

sipQRadioTunerControl::sipQRadioTunerControl(::QObject*a0): ::QRadioTunerControl(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQRadioTunerControl::~sipQRadioTunerControl()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQRadioTunerControl::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QRadioTunerControl);

    return ::QRadioTunerControl::metaObject();
}

int sipQRadioTunerControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QRadioTunerControl::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QRadioTunerControl, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQRadioTunerControl::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QRadioTunerControl, _clname, &sipCpp) ? sipCpp : ::QRadioTunerControl::qt_metacast(_clname));
}

::QString sipQRadioTunerControl::errorString() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioTunerControl, sipName_errorString);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtMultimedia_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_22(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QRadioTuner::Error sipQRadioTunerControl::error() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioTunerControl, sipName_error);

    if (!sipMeth)
        return ::QRadioTuner::NoError;

    extern ::QRadioTuner::Error sipVH_QtMultimedia_134(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_134(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQRadioTunerControl::stop()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, sipName_QRadioTunerControl, sipName_stop);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQRadioTunerControl::start()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, sipName_QRadioTunerControl, sipName_start);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQRadioTunerControl::cancelSearch()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, sipName_QRadioTunerControl, sipName_cancelSearch);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQRadioTunerControl::searchAllStations(::QRadioTuner::SearchMode a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, sipName_QRadioTunerControl, sipName_searchAllStations);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_133(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QRadioTuner::SearchMode);

    sipVH_QtMultimedia_133(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioTunerControl::searchBackward()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, sipName_QRadioTunerControl, sipName_searchBackward);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQRadioTunerControl::searchForward()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, sipName_QRadioTunerControl, sipName_searchForward);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQRadioTunerControl::isAntennaConnected() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isAntennaConnected);

    if (!sipMeth)
        return ::QRadioTunerControl::isAntennaConnected();

    extern bool sipVH_QtMultimedia_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_16(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQRadioTunerControl::isSearching() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioTunerControl, sipName_isSearching);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_16(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQRadioTunerControl::setMuted(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, sipName_QRadioTunerControl, sipName_setMuted);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_106(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtMultimedia_106(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQRadioTunerControl::isMuted() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioTunerControl, sipName_isMuted);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_16(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQRadioTunerControl::setVolume(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, sipName_QRadioTunerControl, sipName_setVolume);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_105(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtMultimedia_105(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQRadioTunerControl::volume() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioTunerControl, sipName_volume);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtMultimedia_104(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_104(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQRadioTunerControl::signalStrength() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[14]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioTunerControl, sipName_signalStrength);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtMultimedia_104(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_104(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQRadioTunerControl::setStereoMode(::QRadioTuner::StereoMode a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, sipName_QRadioTunerControl, sipName_setStereoMode);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_132(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QRadioTuner::StereoMode);

    sipVH_QtMultimedia_132(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QRadioTuner::StereoMode sipQRadioTunerControl::stereoMode() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[16]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioTunerControl, sipName_stereoMode);

    if (!sipMeth)
        return ::QRadioTuner::ForceStereo;

    extern ::QRadioTuner::StereoMode sipVH_QtMultimedia_131(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_131(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQRadioTunerControl::isStereo() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[17]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioTunerControl, sipName_isStereo);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_16(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQRadioTunerControl::setFrequency(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, sipName_QRadioTunerControl, sipName_setFrequency);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_105(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtMultimedia_105(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPair<int, int> sipQRadioTunerControl::frequencyRange(::QRadioTuner::Band a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[19]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioTunerControl, sipName_frequencyRange);

    if (!sipMeth)
        return ::QPair<int, int>();

    extern ::QPair<int, int> sipVH_QtMultimedia_130(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QRadioTuner::Band);

    return sipVH_QtMultimedia_130(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQRadioTunerControl::frequencyStep(::QRadioTuner::Band a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[20]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioTunerControl, sipName_frequencyStep);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtMultimedia_129(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QRadioTuner::Band);

    return sipVH_QtMultimedia_129(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQRadioTunerControl::frequency() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[21]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioTunerControl, sipName_frequency);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtMultimedia_104(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_104(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQRadioTunerControl::isBandSupported(::QRadioTuner::Band a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[22]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioTunerControl, sipName_isBandSupported);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_128(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QRadioTuner::Band);

    return sipVH_QtMultimedia_128(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioTunerControl::setBand(::QRadioTuner::Band a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, sipName_QRadioTunerControl, sipName_setBand);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_127(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QRadioTuner::Band);

    sipVH_QtMultimedia_127(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QRadioTuner::Band sipQRadioTunerControl::band() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[24]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioTunerControl, sipName_band);

    if (!sipMeth)
        return ::QRadioTuner::AM;

    extern ::QRadioTuner::Band sipVH_QtMultimedia_126(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_126(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QRadioTuner::State sipQRadioTunerControl::state() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[25]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QRadioTunerControl, sipName_state);

    if (!sipMeth)
        return ::QRadioTuner::ActiveState;

    extern ::QRadioTuner::State sipVH_QtMultimedia_125(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_125(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQRadioTunerControl::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QRadioTunerControl::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioTunerControl::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QRadioTunerControl::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioTunerControl::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QRadioTunerControl::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioTunerControl::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QRadioTunerControl::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioTunerControl::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QRadioTunerControl::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQRadioTunerControl::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QRadioTunerControl::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQRadioTunerControl::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QRadioTunerControl::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QRadioTunerControl_state, "state(self) -> QRadioTuner.State");

extern "C" {static PyObject *meth_QRadioTunerControl_state(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            ::QRadioTuner::State sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_state);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QRadioTuner_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_state, doc_QRadioTunerControl_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_band, "band(self) -> QRadioTuner.Band");

extern "C" {static PyObject *meth_QRadioTunerControl_band(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_band(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            ::QRadioTuner::Band sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_band);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->band();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QRadioTuner_Band);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_band, doc_QRadioTunerControl_band);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_setBand, "setBand(self, b: QRadioTuner.Band)");

extern "C" {static PyObject *meth_QRadioTunerControl_setBand(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_setBand(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QRadioTuner::Band a0;
        ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QRadioTunerControl, &sipCpp, sipType_QRadioTuner_Band, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_setBand);
                return SIP_NULLPTR;
            }

            sipCpp->setBand(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_setBand, doc_QRadioTunerControl_setBand);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_isBandSupported, "isBandSupported(self, b: QRadioTuner.Band) -> bool");

extern "C" {static PyObject *meth_QRadioTunerControl_isBandSupported(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_isBandSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QRadioTuner::Band a0;
        const ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QRadioTunerControl, &sipCpp, sipType_QRadioTuner_Band, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_isBandSupported);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isBandSupported(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_isBandSupported, doc_QRadioTunerControl_isBandSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_frequency, "frequency(self) -> int");

extern "C" {static PyObject *meth_QRadioTunerControl_frequency(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_frequency(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_frequency);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->frequency();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_frequency, doc_QRadioTunerControl_frequency);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_frequencyStep, "frequencyStep(self, b: QRadioTuner.Band) -> int");

extern "C" {static PyObject *meth_QRadioTunerControl_frequencyStep(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_frequencyStep(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QRadioTuner::Band a0;
        const ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QRadioTunerControl, &sipCpp, sipType_QRadioTuner_Band, &a0))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_frequencyStep);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->frequencyStep(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_frequencyStep, doc_QRadioTunerControl_frequencyStep);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_frequencyRange, "frequencyRange(self, b: QRadioTuner.Band) -> tuple[int, int]");

extern "C" {static PyObject *meth_QRadioTunerControl_frequencyRange(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_frequencyRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QRadioTuner::Band a0;
        const ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QRadioTunerControl, &sipCpp, sipType_QRadioTuner_Band, &a0))
        {
            ::QPair<int, int>*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_frequencyRange);
                return SIP_NULLPTR;
            }

            sipRes = new ::QPair<int, int>(sipCpp->frequencyRange(a0));

            return sipConvertFromNewType(sipRes, sipType_QPair_1800_1800, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_frequencyRange, doc_QRadioTunerControl_frequencyRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_setFrequency, "setFrequency(self, frequency: int)");

extern "C" {static PyObject *meth_QRadioTunerControl_setFrequency(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_setFrequency(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QRadioTunerControl, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_setFrequency);
                return SIP_NULLPTR;
            }

            sipCpp->setFrequency(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_setFrequency, doc_QRadioTunerControl_setFrequency);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_isStereo, "isStereo(self) -> bool");

extern "C" {static PyObject *meth_QRadioTunerControl_isStereo(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_isStereo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_isStereo);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isStereo();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_isStereo, doc_QRadioTunerControl_isStereo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_stereoMode, "stereoMode(self) -> QRadioTuner.StereoMode");

extern "C" {static PyObject *meth_QRadioTunerControl_stereoMode(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_stereoMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            ::QRadioTuner::StereoMode sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_stereoMode);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->stereoMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QRadioTuner_StereoMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_stereoMode, doc_QRadioTunerControl_stereoMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_setStereoMode, "setStereoMode(self, mode: QRadioTuner.StereoMode)");

extern "C" {static PyObject *meth_QRadioTunerControl_setStereoMode(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_setStereoMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QRadioTuner::StereoMode a0;
        ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QRadioTunerControl, &sipCpp, sipType_QRadioTuner_StereoMode, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_setStereoMode);
                return SIP_NULLPTR;
            }

            sipCpp->setStereoMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_setStereoMode, doc_QRadioTunerControl_setStereoMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_signalStrength, "signalStrength(self) -> int");

extern "C" {static PyObject *meth_QRadioTunerControl_signalStrength(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_signalStrength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_signalStrength);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->signalStrength();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_signalStrength, doc_QRadioTunerControl_signalStrength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_volume, "volume(self) -> int");

extern "C" {static PyObject *meth_QRadioTunerControl_volume(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_volume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_volume);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->volume();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_volume, doc_QRadioTunerControl_volume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_setVolume, "setVolume(self, volume: int)");

extern "C" {static PyObject *meth_QRadioTunerControl_setVolume(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_setVolume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QRadioTunerControl, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_setVolume);
                return SIP_NULLPTR;
            }

            sipCpp->setVolume(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_setVolume, doc_QRadioTunerControl_setVolume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_isMuted, "isMuted(self) -> bool");

extern "C" {static PyObject *meth_QRadioTunerControl_isMuted(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_isMuted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_isMuted);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isMuted();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_isMuted, doc_QRadioTunerControl_isMuted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_setMuted, "setMuted(self, muted: bool)");

extern "C" {static PyObject *meth_QRadioTunerControl_setMuted(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_setMuted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        bool a0;
        ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QRadioTunerControl, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_setMuted);
                return SIP_NULLPTR;
            }

            sipCpp->setMuted(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_setMuted, doc_QRadioTunerControl_setMuted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_isSearching, "isSearching(self) -> bool");

extern "C" {static PyObject *meth_QRadioTunerControl_isSearching(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_isSearching(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_isSearching);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isSearching();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_isSearching, doc_QRadioTunerControl_isSearching);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_isAntennaConnected, "isAntennaConnected(self) -> bool");

extern "C" {static PyObject *meth_QRadioTunerControl_isAntennaConnected(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_isAntennaConnected(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRadioTunerControl::isAntennaConnected() : sipCpp->isAntennaConnected());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_isAntennaConnected, doc_QRadioTunerControl_isAntennaConnected);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_searchForward, "searchForward(self)");

extern "C" {static PyObject *meth_QRadioTunerControl_searchForward(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_searchForward(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_searchForward);
                return SIP_NULLPTR;
            }

            sipCpp->searchForward();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_searchForward, doc_QRadioTunerControl_searchForward);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_searchBackward, "searchBackward(self)");

extern "C" {static PyObject *meth_QRadioTunerControl_searchBackward(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_searchBackward(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_searchBackward);
                return SIP_NULLPTR;
            }

            sipCpp->searchBackward();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_searchBackward, doc_QRadioTunerControl_searchBackward);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_searchAllStations, "searchAllStations(self, searchMode: QRadioTuner.SearchMode = QRadioTuner.SearchFast)");

extern "C" {static PyObject *meth_QRadioTunerControl_searchAllStations(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_searchAllStations(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QRadioTuner::SearchMode a0 = QRadioTuner::SearchFast;
        ::QRadioTunerControl *sipCpp;

        static const char *sipKwdList[] = {
            sipName_searchMode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QRadioTunerControl, &sipCpp, sipType_QRadioTuner_SearchMode, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_searchAllStations);
                return SIP_NULLPTR;
            }

            sipCpp->searchAllStations(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_searchAllStations, doc_QRadioTunerControl_searchAllStations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_cancelSearch, "cancelSearch(self)");

extern "C" {static PyObject *meth_QRadioTunerControl_cancelSearch(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_cancelSearch(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_cancelSearch);
                return SIP_NULLPTR;
            }

            sipCpp->cancelSearch();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_cancelSearch, doc_QRadioTunerControl_cancelSearch);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_start, "start(self)");

extern "C" {static PyObject *meth_QRadioTunerControl_start(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_start(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_start);
                return SIP_NULLPTR;
            }

            sipCpp->start();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_start, doc_QRadioTunerControl_start);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_stop, "stop(self)");

extern "C" {static PyObject *meth_QRadioTunerControl_stop(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_stop);
                return SIP_NULLPTR;
            }

            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_stop, doc_QRadioTunerControl_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_error, "error(self) -> QRadioTuner.Error");

extern "C" {static PyObject *meth_QRadioTunerControl_error(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            ::QRadioTuner::Error sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_error);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QRadioTuner_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_error, doc_QRadioTunerControl_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioTunerControl_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QRadioTunerControl_errorString(PyObject *, PyObject *);}
static PyObject *meth_QRadioTunerControl_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRadioTunerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioTunerControl, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QRadioTunerControl, sipName_errorString);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioTunerControl, sipName_errorString, doc_QRadioTunerControl_errorString);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QRadioTunerControl(void *, const sipTypeDef *);}
static void *cast_QRadioTunerControl(void *sipCppV, const sipTypeDef *targetType)
{
    ::QRadioTunerControl *sipCpp = reinterpret_cast< ::QRadioTunerControl *>(sipCppV);

    if (targetType == sipType_QRadioTunerControl)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaControl)->ctd_cast(static_cast< ::QMediaControl *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QRadioTunerControl(void *, int);}
static void release_QRadioTunerControl(void *sipCppV, int)
{
    ::QRadioTunerControl *sipCpp = reinterpret_cast< ::QRadioTunerControl *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QRadioTunerControl(sipSimpleWrapper *);}
static void dealloc_QRadioTunerControl(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQRadioTunerControl *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QRadioTunerControl(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QRadioTunerControl(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QRadioTunerControl(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQRadioTunerControl *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQRadioTunerControl(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QRadioTunerControl[] = {{104, 255, 1}};


static PyMethodDef methods_QRadioTunerControl[] = {
    {sipName_band, meth_QRadioTunerControl_band, METH_VARARGS, doc_QRadioTunerControl_band},
    {sipName_cancelSearch, meth_QRadioTunerControl_cancelSearch, METH_VARARGS, doc_QRadioTunerControl_cancelSearch},
    {sipName_error, meth_QRadioTunerControl_error, METH_VARARGS, doc_QRadioTunerControl_error},
    {sipName_errorString, meth_QRadioTunerControl_errorString, METH_VARARGS, doc_QRadioTunerControl_errorString},
    {sipName_frequency, meth_QRadioTunerControl_frequency, METH_VARARGS, doc_QRadioTunerControl_frequency},
    {sipName_frequencyRange, meth_QRadioTunerControl_frequencyRange, METH_VARARGS, doc_QRadioTunerControl_frequencyRange},
    {sipName_frequencyStep, meth_QRadioTunerControl_frequencyStep, METH_VARARGS, doc_QRadioTunerControl_frequencyStep},
    {sipName_isAntennaConnected, meth_QRadioTunerControl_isAntennaConnected, METH_VARARGS, doc_QRadioTunerControl_isAntennaConnected},
    {sipName_isBandSupported, meth_QRadioTunerControl_isBandSupported, METH_VARARGS, doc_QRadioTunerControl_isBandSupported},
    {sipName_isMuted, meth_QRadioTunerControl_isMuted, METH_VARARGS, doc_QRadioTunerControl_isMuted},
    {sipName_isSearching, meth_QRadioTunerControl_isSearching, METH_VARARGS, doc_QRadioTunerControl_isSearching},
    {sipName_isStereo, meth_QRadioTunerControl_isStereo, METH_VARARGS, doc_QRadioTunerControl_isStereo},
    {sipName_searchAllStations, SIP_MLMETH_CAST(meth_QRadioTunerControl_searchAllStations), METH_VARARGS|METH_KEYWORDS, doc_QRadioTunerControl_searchAllStations},
    {sipName_searchBackward, meth_QRadioTunerControl_searchBackward, METH_VARARGS, doc_QRadioTunerControl_searchBackward},
    {sipName_searchForward, meth_QRadioTunerControl_searchForward, METH_VARARGS, doc_QRadioTunerControl_searchForward},
    {sipName_setBand, meth_QRadioTunerControl_setBand, METH_VARARGS, doc_QRadioTunerControl_setBand},
    {sipName_setFrequency, meth_QRadioTunerControl_setFrequency, METH_VARARGS, doc_QRadioTunerControl_setFrequency},
    {sipName_setMuted, meth_QRadioTunerControl_setMuted, METH_VARARGS, doc_QRadioTunerControl_setMuted},
    {sipName_setStereoMode, meth_QRadioTunerControl_setStereoMode, METH_VARARGS, doc_QRadioTunerControl_setStereoMode},
    {sipName_setVolume, meth_QRadioTunerControl_setVolume, METH_VARARGS, doc_QRadioTunerControl_setVolume},
    {sipName_signalStrength, meth_QRadioTunerControl_signalStrength, METH_VARARGS, doc_QRadioTunerControl_signalStrength},
    {sipName_start, meth_QRadioTunerControl_start, METH_VARARGS, doc_QRadioTunerControl_start},
    {sipName_state, meth_QRadioTunerControl_state, METH_VARARGS, doc_QRadioTunerControl_state},
    {sipName_stereoMode, meth_QRadioTunerControl_stereoMode, METH_VARARGS, doc_QRadioTunerControl_stereoMode},
    {sipName_stop, meth_QRadioTunerControl_stop, METH_VARARGS, doc_QRadioTunerControl_stop},
    {sipName_volume, meth_QRadioTunerControl_volume, METH_VARARGS, doc_QRadioTunerControl_volume}
};

PyDoc_STRVAR(doc_QRadioTunerControl, "\1QRadioTunerControl(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QRadioTunerControl[] = {
    {"antennaConnectedChanged(bool)", "\1antennaConnectedChanged(self, connectionStatus: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"stationFound(int,QString)", "\1stationFound(self, frequency: int, stationId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"mutedChanged(bool)", "\1mutedChanged(self, muted: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"volumeChanged(int)", "\1volumeChanged(self, volume: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"signalStrengthChanged(int)", "\1signalStrengthChanged(self, signalStrength: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"searchingChanged(bool)", "\1searchingChanged(self, searching: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"stereoStatusChanged(bool)", "\1stereoStatusChanged(self, stereo: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"frequencyChanged(int)", "\1frequencyChanged(self, frequency: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"bandChanged(QRadioTuner::Band)", "\1bandChanged(self, band: QRadioTuner.Band)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QRadioTuner::State)", "\1stateChanged(self, state: QRadioTuner.State)", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QRadioTuner::Error)", "\1error(self, err: QRadioTuner.Error)", &methods_QRadioTunerControl[2], SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QRadioTunerControl = {
    &::QRadioTunerControl::staticMetaObject,
    0,
    signals_QRadioTunerControl,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QRadioTunerControl = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QRadioTunerControl,
        SIP_NULLPTR,
        &plugin_QRadioTunerControl,
    },
    {
        sipNameNr_QRadioTunerControl,
        {0, 0, 1},
        26, methods_QRadioTunerControl,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QRadioTunerControl,
    -1,
    -1,
    supers_QRadioTunerControl,
    SIP_NULLPTR,
    init_type_QRadioTunerControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QRadioTunerControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QRadioTunerControl,
    cast_QRadioTunerControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QRadioTunerControl),
};
