/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaplayercontrol.sip"
#include <qmediaplayercontrol.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediatimerange.sip"
#include <qmediatimerange.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaplayer.sip"
#include <qmediaplayer.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediacontent.sip"
#include <qmediacontent.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlayerControl.cpp"


class sipQMediaPlayerControl : public ::QMediaPlayerControl
{
public:
    sipQMediaPlayerControl(::QObject*);
    virtual ~sipQMediaPlayerControl();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void stop() SIP_OVERRIDE;
    void pause() SIP_OVERRIDE;
    void play() SIP_OVERRIDE;
    void setMedia(const ::QMediaContent&, ::QIODevice*) SIP_OVERRIDE;
    const ::QIODevice* mediaStream() const SIP_OVERRIDE;
    ::QMediaContent media() const SIP_OVERRIDE;
    void setPlaybackRate(::qreal) SIP_OVERRIDE;
    ::qreal playbackRate() const SIP_OVERRIDE;
    ::QMediaTimeRange availablePlaybackRanges() const SIP_OVERRIDE;
    bool isSeekable() const SIP_OVERRIDE;
    bool isVideoAvailable() const SIP_OVERRIDE;
    bool isAudioAvailable() const SIP_OVERRIDE;
    int bufferStatus() const SIP_OVERRIDE;
    void setMuted(bool) SIP_OVERRIDE;
    bool isMuted() const SIP_OVERRIDE;
    void setVolume(int) SIP_OVERRIDE;
    int volume() const SIP_OVERRIDE;
    void setPosition(::qint64) SIP_OVERRIDE;
    ::qint64 position() const SIP_OVERRIDE;
    ::qint64 duration() const SIP_OVERRIDE;
    ::QMediaPlayer::MediaStatus mediaStatus() const SIP_OVERRIDE;
    ::QMediaPlayer::State state() const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQMediaPlayerControl(const sipQMediaPlayerControl &);
    sipQMediaPlayerControl &operator = (const sipQMediaPlayerControl &);

    char sipPyMethods[29];
};

sipQMediaPlayerControl::sipQMediaPlayerControl(::QObject*a0): ::QMediaPlayerControl(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQMediaPlayerControl::~sipQMediaPlayerControl()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQMediaPlayerControl::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QMediaPlayerControl);

    return ::QMediaPlayerControl::metaObject();
}

int sipQMediaPlayerControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QMediaPlayerControl::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QMediaPlayerControl, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQMediaPlayerControl::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QMediaPlayerControl, _clname, &sipCpp) ? sipCpp : ::QMediaPlayerControl::qt_metacast(_clname));
}

void sipQMediaPlayerControl::stop()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, sipName_QMediaPlayerControl, sipName_stop);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQMediaPlayerControl::pause()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, sipName_QMediaPlayerControl, sipName_pause);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQMediaPlayerControl::play()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, sipName_QMediaPlayerControl, sipName_play);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQMediaPlayerControl::setMedia(const ::QMediaContent& a0, ::QIODevice*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, sipName_QMediaPlayerControl, sipName_setMedia);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_109(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMediaContent&, ::QIODevice*);

    sipVH_QtMultimedia_109(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

const ::QIODevice* sipQMediaPlayerControl::mediaStream() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaPlayerControl, sipName_mediaStream);

    if (!sipMeth)
        return 0;

    extern const ::QIODevice* sipVH_QtMultimedia_108(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_108(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QMediaContent sipQMediaPlayerControl::media() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaPlayerControl, sipName_media);

    if (!sipMeth)
        return ::QMediaContent();

    extern ::QMediaContent sipVH_QtMultimedia_96(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_96(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQMediaPlayerControl::setPlaybackRate(::qreal a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, sipName_QMediaPlayerControl, sipName_setPlaybackRate);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_98(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::qreal);

    sipVH_QtMultimedia_98(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::qreal sipQMediaPlayerControl::playbackRate() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaPlayerControl, sipName_playbackRate);

    if (!sipMeth)
        return 0;

    extern ::qreal sipVH_QtMultimedia_91(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_91(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QMediaTimeRange sipQMediaPlayerControl::availablePlaybackRanges() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaPlayerControl, sipName_availablePlaybackRanges);

    if (!sipMeth)
        return ::QMediaTimeRange();

    extern ::QMediaTimeRange sipVH_QtMultimedia_107(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_107(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQMediaPlayerControl::isSeekable() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaPlayerControl, sipName_isSeekable);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_16(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQMediaPlayerControl::isVideoAvailable() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaPlayerControl, sipName_isVideoAvailable);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_16(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQMediaPlayerControl::isAudioAvailable() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaPlayerControl, sipName_isAudioAvailable);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_16(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQMediaPlayerControl::bufferStatus() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaPlayerControl, sipName_bufferStatus);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtMultimedia_104(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_104(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQMediaPlayerControl::setMuted(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, sipName_QMediaPlayerControl, sipName_setMuted);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_106(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtMultimedia_106(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQMediaPlayerControl::isMuted() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[14]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaPlayerControl, sipName_isMuted);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_16(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQMediaPlayerControl::setVolume(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, sipName_QMediaPlayerControl, sipName_setVolume);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_105(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtMultimedia_105(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQMediaPlayerControl::volume() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[16]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaPlayerControl, sipName_volume);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtMultimedia_104(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_104(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQMediaPlayerControl::setPosition(::qint64 a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, sipName_QMediaPlayerControl, sipName_setPosition);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_103(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::qint64);

    sipVH_QtMultimedia_103(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::qint64 sipQMediaPlayerControl::position() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[18]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaPlayerControl, sipName_position);

    if (!sipMeth)
        return 0;

    extern ::qint64 sipVH_QtMultimedia_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_29(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::qint64 sipQMediaPlayerControl::duration() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[19]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaPlayerControl, sipName_duration);

    if (!sipMeth)
        return 0;

    extern ::qint64 sipVH_QtMultimedia_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_29(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QMediaPlayer::MediaStatus sipQMediaPlayerControl::mediaStatus() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[20]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaPlayerControl, sipName_mediaStatus);

    if (!sipMeth)
        return ::QMediaPlayer::UnknownMediaStatus;

    extern ::QMediaPlayer::MediaStatus sipVH_QtMultimedia_102(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_102(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QMediaPlayer::State sipQMediaPlayerControl::state() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[21]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QMediaPlayerControl, sipName_state);

    if (!sipMeth)
        return ::QMediaPlayer::StoppedState;

    extern ::QMediaPlayer::State sipVH_QtMultimedia_101(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_101(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQMediaPlayerControl::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QMediaPlayerControl::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlayerControl::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QMediaPlayerControl::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlayerControl::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QMediaPlayerControl::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlayerControl::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QMediaPlayerControl::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlayerControl::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QMediaPlayerControl::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQMediaPlayerControl::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QMediaPlayerControl::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQMediaPlayerControl::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QMediaPlayerControl::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QMediaPlayerControl_state, "state(self) -> QMediaPlayer.State");

extern "C" {static PyObject *meth_QMediaPlayerControl_state(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            ::QMediaPlayer::State sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_state);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaPlayer_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_state, doc_QMediaPlayerControl_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_mediaStatus, "mediaStatus(self) -> QMediaPlayer.MediaStatus");

extern "C" {static PyObject *meth_QMediaPlayerControl_mediaStatus(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_mediaStatus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            ::QMediaPlayer::MediaStatus sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_mediaStatus);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->mediaStatus();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaPlayer_MediaStatus);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_mediaStatus, doc_QMediaPlayerControl_mediaStatus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_duration, "duration(self) -> int");

extern "C" {static PyObject *meth_QMediaPlayerControl_duration(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_duration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            ::qint64 sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_duration);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->duration();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_duration, doc_QMediaPlayerControl_duration);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_position, "position(self) -> int");

extern "C" {static PyObject *meth_QMediaPlayerControl_position(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            ::qint64 sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_position);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->position();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_position, doc_QMediaPlayerControl_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_setPosition, "setPosition(self, position: int)");

extern "C" {static PyObject *meth_QMediaPlayerControl_setPosition(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_setPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::qint64 a0;
        ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QMediaPlayerControl, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_setPosition);
                return SIP_NULLPTR;
            }

            sipCpp->setPosition(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_setPosition, doc_QMediaPlayerControl_setPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_volume, "volume(self) -> int");

extern "C" {static PyObject *meth_QMediaPlayerControl_volume(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_volume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_volume);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->volume();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_volume, doc_QMediaPlayerControl_volume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_setVolume, "setVolume(self, volume: int)");

extern "C" {static PyObject *meth_QMediaPlayerControl_setVolume(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_setVolume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaPlayerControl, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_setVolume);
                return SIP_NULLPTR;
            }

            sipCpp->setVolume(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_setVolume, doc_QMediaPlayerControl_setVolume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_isMuted, "isMuted(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlayerControl_isMuted(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_isMuted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_isMuted);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isMuted();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_isMuted, doc_QMediaPlayerControl_isMuted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_setMuted, "setMuted(self, mute: bool)");

extern "C" {static PyObject *meth_QMediaPlayerControl_setMuted(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_setMuted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        bool a0;
        ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QMediaPlayerControl, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_setMuted);
                return SIP_NULLPTR;
            }

            sipCpp->setMuted(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_setMuted, doc_QMediaPlayerControl_setMuted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_bufferStatus, "bufferStatus(self) -> int");

extern "C" {static PyObject *meth_QMediaPlayerControl_bufferStatus(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_bufferStatus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_bufferStatus);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->bufferStatus();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_bufferStatus, doc_QMediaPlayerControl_bufferStatus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_isAudioAvailable, "isAudioAvailable(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlayerControl_isAudioAvailable(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_isAudioAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_isAudioAvailable);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isAudioAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_isAudioAvailable, doc_QMediaPlayerControl_isAudioAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_isVideoAvailable, "isVideoAvailable(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlayerControl_isVideoAvailable(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_isVideoAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_isVideoAvailable);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isVideoAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_isVideoAvailable, doc_QMediaPlayerControl_isVideoAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_isSeekable, "isSeekable(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlayerControl_isSeekable(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_isSeekable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_isSeekable);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isSeekable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_isSeekable, doc_QMediaPlayerControl_isSeekable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_availablePlaybackRanges, "availablePlaybackRanges(self) -> QMediaTimeRange");

extern "C" {static PyObject *meth_QMediaPlayerControl_availablePlaybackRanges(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_availablePlaybackRanges(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            ::QMediaTimeRange*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_availablePlaybackRanges);
                return SIP_NULLPTR;
            }

            sipRes = new ::QMediaTimeRange(sipCpp->availablePlaybackRanges());

            return sipConvertFromNewType(sipRes, sipType_QMediaTimeRange, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_availablePlaybackRanges, doc_QMediaPlayerControl_availablePlaybackRanges);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_playbackRate, "playbackRate(self) -> float");

extern "C" {static PyObject *meth_QMediaPlayerControl_playbackRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_playbackRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            ::qreal sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_playbackRate);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->playbackRate();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_playbackRate, doc_QMediaPlayerControl_playbackRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_setPlaybackRate, "setPlaybackRate(self, rate: float)");

extern "C" {static PyObject *meth_QMediaPlayerControl_setPlaybackRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_setPlaybackRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::qreal a0;
        ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QMediaPlayerControl, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_setPlaybackRate);
                return SIP_NULLPTR;
            }

            sipCpp->setPlaybackRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_setPlaybackRate, doc_QMediaPlayerControl_setPlaybackRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_media, "media(self) -> QMediaContent");

extern "C" {static PyObject *meth_QMediaPlayerControl_media(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_media(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            ::QMediaContent*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_media);
                return SIP_NULLPTR;
            }

            sipRes = new ::QMediaContent(sipCpp->media());

            return sipConvertFromNewType(sipRes, sipType_QMediaContent, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_media, doc_QMediaPlayerControl_media);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_mediaStream, "mediaStream(self) -> Optional[QIODevice]");

extern "C" {static PyObject *meth_QMediaPlayerControl_mediaStream(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_mediaStream(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            const ::QIODevice*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_mediaStream);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->mediaStream();

            return sipConvertFromType(const_cast< ::QIODevice *>(sipRes), sipType_QIODevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_mediaStream, doc_QMediaPlayerControl_mediaStream);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_setMedia, "setMedia(self, media: QMediaContent, stream: Optional[QIODevice])");

extern "C" {static PyObject *meth_QMediaPlayerControl_setMedia(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_setMedia(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QMediaContent* a0;
        ::QIODevice* a1;
        ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J8", &sipSelf, sipType_QMediaPlayerControl, &sipCpp, sipType_QMediaContent, &a0, sipType_QIODevice, &a1))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_setMedia);
                return SIP_NULLPTR;
            }

            sipCpp->setMedia(*a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_setMedia, doc_QMediaPlayerControl_setMedia);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_play, "play(self)");

extern "C" {static PyObject *meth_QMediaPlayerControl_play(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_play(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_play);
                return SIP_NULLPTR;
            }

            sipCpp->play();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_play, doc_QMediaPlayerControl_play);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_pause, "pause(self)");

extern "C" {static PyObject *meth_QMediaPlayerControl_pause(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_pause(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_pause);
                return SIP_NULLPTR;
            }

            sipCpp->pause();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_pause, doc_QMediaPlayerControl_pause);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlayerControl_stop, "stop(self)");

extern "C" {static PyObject *meth_QMediaPlayerControl_stop(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlayerControl_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QMediaPlayerControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlayerControl, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QMediaPlayerControl, sipName_stop);
                return SIP_NULLPTR;
            }

            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlayerControl, sipName_stop, doc_QMediaPlayerControl_stop);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QMediaPlayerControl(void *, const sipTypeDef *);}
static void *cast_QMediaPlayerControl(void *sipCppV, const sipTypeDef *targetType)
{
    ::QMediaPlayerControl *sipCpp = reinterpret_cast< ::QMediaPlayerControl *>(sipCppV);

    if (targetType == sipType_QMediaPlayerControl)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaControl)->ctd_cast(static_cast< ::QMediaControl *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QMediaPlayerControl(void *, int);}
static void release_QMediaPlayerControl(void *sipCppV, int)
{
    ::QMediaPlayerControl *sipCpp = reinterpret_cast< ::QMediaPlayerControl *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QMediaPlayerControl(sipSimpleWrapper *);}
static void dealloc_QMediaPlayerControl(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQMediaPlayerControl *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QMediaPlayerControl(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QMediaPlayerControl(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QMediaPlayerControl(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQMediaPlayerControl *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQMediaPlayerControl(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QMediaPlayerControl[] = {{104, 255, 1}};


static PyMethodDef methods_QMediaPlayerControl[] = {
    {sipName_availablePlaybackRanges, meth_QMediaPlayerControl_availablePlaybackRanges, METH_VARARGS, doc_QMediaPlayerControl_availablePlaybackRanges},
    {sipName_bufferStatus, meth_QMediaPlayerControl_bufferStatus, METH_VARARGS, doc_QMediaPlayerControl_bufferStatus},
    {sipName_duration, meth_QMediaPlayerControl_duration, METH_VARARGS, doc_QMediaPlayerControl_duration},
    {sipName_isAudioAvailable, meth_QMediaPlayerControl_isAudioAvailable, METH_VARARGS, doc_QMediaPlayerControl_isAudioAvailable},
    {sipName_isMuted, meth_QMediaPlayerControl_isMuted, METH_VARARGS, doc_QMediaPlayerControl_isMuted},
    {sipName_isSeekable, meth_QMediaPlayerControl_isSeekable, METH_VARARGS, doc_QMediaPlayerControl_isSeekable},
    {sipName_isVideoAvailable, meth_QMediaPlayerControl_isVideoAvailable, METH_VARARGS, doc_QMediaPlayerControl_isVideoAvailable},
    {sipName_media, meth_QMediaPlayerControl_media, METH_VARARGS, doc_QMediaPlayerControl_media},
    {sipName_mediaStatus, meth_QMediaPlayerControl_mediaStatus, METH_VARARGS, doc_QMediaPlayerControl_mediaStatus},
    {sipName_mediaStream, meth_QMediaPlayerControl_mediaStream, METH_VARARGS, doc_QMediaPlayerControl_mediaStream},
    {sipName_pause, meth_QMediaPlayerControl_pause, METH_VARARGS, doc_QMediaPlayerControl_pause},
    {sipName_play, meth_QMediaPlayerControl_play, METH_VARARGS, doc_QMediaPlayerControl_play},
    {sipName_playbackRate, meth_QMediaPlayerControl_playbackRate, METH_VARARGS, doc_QMediaPlayerControl_playbackRate},
    {sipName_position, meth_QMediaPlayerControl_position, METH_VARARGS, doc_QMediaPlayerControl_position},
    {sipName_setMedia, meth_QMediaPlayerControl_setMedia, METH_VARARGS, doc_QMediaPlayerControl_setMedia},
    {sipName_setMuted, meth_QMediaPlayerControl_setMuted, METH_VARARGS, doc_QMediaPlayerControl_setMuted},
    {sipName_setPlaybackRate, meth_QMediaPlayerControl_setPlaybackRate, METH_VARARGS, doc_QMediaPlayerControl_setPlaybackRate},
    {sipName_setPosition, meth_QMediaPlayerControl_setPosition, METH_VARARGS, doc_QMediaPlayerControl_setPosition},
    {sipName_setVolume, meth_QMediaPlayerControl_setVolume, METH_VARARGS, doc_QMediaPlayerControl_setVolume},
    {sipName_state, meth_QMediaPlayerControl_state, METH_VARARGS, doc_QMediaPlayerControl_state},
    {sipName_stop, meth_QMediaPlayerControl_stop, METH_VARARGS, doc_QMediaPlayerControl_stop},
    {sipName_volume, meth_QMediaPlayerControl_volume, METH_VARARGS, doc_QMediaPlayerControl_volume}
};

PyDoc_STRVAR(doc_QMediaPlayerControl, "\1QMediaPlayerControl(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QMediaPlayerControl[] = {
    {"error(int,QString)", "\1error(self, error: int, errorString: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"playbackRateChanged(qreal)", "\1playbackRateChanged(self, rate: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"availablePlaybackRangesChanged(QMediaTimeRange)", "\1availablePlaybackRangesChanged(self, ranges: QMediaTimeRange)", SIP_NULLPTR, SIP_NULLPTR},
    {"seekableChanged(bool)", "\1seekableChanged(self, seekable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"bufferStatusChanged(int)", "\1bufferStatusChanged(self, percentFilled: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"videoAvailableChanged(bool)", "\1videoAvailableChanged(self, videoAvailable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"audioAvailableChanged(bool)", "\1audioAvailableChanged(self, audioAvailable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"mutedChanged(bool)", "\1mutedChanged(self, mute: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"volumeChanged(int)", "\1volumeChanged(self, volume: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"mediaStatusChanged(QMediaPlayer::MediaStatus)", "\1mediaStatusChanged(self, status: QMediaPlayer.MediaStatus)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QMediaPlayer::State)", "\1stateChanged(self, newState: QMediaPlayer.State)", SIP_NULLPTR, SIP_NULLPTR},
    {"positionChanged(qint64)", "\1positionChanged(self, position: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"durationChanged(qint64)", "\1durationChanged(self, duration: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"mediaChanged(QMediaContent)", "\1mediaChanged(self, content: QMediaContent)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QMediaPlayerControl = {
    &::QMediaPlayerControl::staticMetaObject,
    0,
    signals_QMediaPlayerControl,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QMediaPlayerControl = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QMediaPlayerControl,
        SIP_NULLPTR,
        &plugin_QMediaPlayerControl,
    },
    {
        sipNameNr_QMediaPlayerControl,
        {0, 0, 1},
        22, methods_QMediaPlayerControl,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QMediaPlayerControl,
    -1,
    -1,
    supers_QMediaPlayerControl,
    SIP_NULLPTR,
    init_type_QMediaPlayerControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QMediaPlayerControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QMediaPlayerControl,
    cast_QMediaPlayerControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QMediaPlayerControl),
};
