/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKit.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebdatabase.sip"
#include <qwebdatabase.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebDatabase.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebsecurityorigin.sip"
#include <qwebsecurityorigin.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebDatabase.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebDatabase.cpp"


PyDoc_STRVAR(doc_QWebDatabase_name, "name(self) -> str");

extern "C" {static PyObject *meth_QWebDatabase_name(PyObject *, PyObject *);}
static PyObject *meth_QWebDatabase_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebDatabase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebDatabase, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebDatabase, sipName_name, doc_QWebDatabase_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebDatabase_displayName, "displayName(self) -> str");

extern "C" {static PyObject *meth_QWebDatabase_displayName(PyObject *, PyObject *);}
static PyObject *meth_QWebDatabase_displayName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebDatabase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebDatabase, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->displayName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebDatabase, sipName_displayName, doc_QWebDatabase_displayName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebDatabase_expectedSize, "expectedSize(self) -> int");

extern "C" {static PyObject *meth_QWebDatabase_expectedSize(PyObject *, PyObject *);}
static PyObject *meth_QWebDatabase_expectedSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebDatabase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebDatabase, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->expectedSize();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebDatabase, sipName_expectedSize, doc_QWebDatabase_expectedSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebDatabase_size, "size(self) -> int");

extern "C" {static PyObject *meth_QWebDatabase_size(PyObject *, PyObject *);}
static PyObject *meth_QWebDatabase_size(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebDatabase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebDatabase, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->size();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebDatabase, sipName_size, doc_QWebDatabase_size);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebDatabase_fileName, "fileName(self) -> str");

extern "C" {static PyObject *meth_QWebDatabase_fileName(PyObject *, PyObject *);}
static PyObject *meth_QWebDatabase_fileName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebDatabase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebDatabase, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->fileName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebDatabase, sipName_fileName, doc_QWebDatabase_fileName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebDatabase_origin, "origin(self) -> QWebSecurityOrigin");

extern "C" {static PyObject *meth_QWebDatabase_origin(PyObject *, PyObject *);}
static PyObject *meth_QWebDatabase_origin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebDatabase *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebDatabase, &sipCpp))
        {
            ::QWebSecurityOrigin*sipRes;

            sipRes = new ::QWebSecurityOrigin(sipCpp->origin());

            return sipConvertFromNewType(sipRes, sipType_QWebSecurityOrigin, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebDatabase, sipName_origin, doc_QWebDatabase_origin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebDatabase_removeDatabase, "removeDatabase(db: QWebDatabase)");

extern "C" {static PyObject *meth_QWebDatabase_removeDatabase(PyObject *, PyObject *);}
static PyObject *meth_QWebDatabase_removeDatabase(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebDatabase* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QWebDatabase, &a0))
        {
            ::QWebDatabase::removeDatabase(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebDatabase, sipName_removeDatabase, doc_QWebDatabase_removeDatabase);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebDatabase_removeAllDatabases, "removeAllDatabases()");

extern "C" {static PyObject *meth_QWebDatabase_removeAllDatabases(PyObject *, PyObject *);}
static PyObject *meth_QWebDatabase_removeAllDatabases(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QWebDatabase::removeAllDatabases();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebDatabase, sipName_removeAllDatabases, doc_QWebDatabase_removeAllDatabases);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebDatabase(void *, int);}
static void release_QWebDatabase(void *sipCppV, int)
{
    delete reinterpret_cast< ::QWebDatabase *>(sipCppV);
}


extern "C" {static void assign_QWebDatabase(void *, Py_ssize_t, void *);}
static void assign_QWebDatabase(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QWebDatabase *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QWebDatabase *>(sipSrc);
}


extern "C" {static void *copy_QWebDatabase(const void *, Py_ssize_t);}
static void *copy_QWebDatabase(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QWebDatabase(reinterpret_cast<const ::QWebDatabase *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QWebDatabase(sipSimpleWrapper *);}
static void dealloc_QWebDatabase(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWebDatabase(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QWebDatabase(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWebDatabase(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QWebDatabase *sipCpp = SIP_NULLPTR;

    {
        const ::QWebDatabase* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QWebDatabase, &a0))
        {
            sipCpp = new ::QWebDatabase(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QWebDatabase[] = {
    {sipName_displayName, meth_QWebDatabase_displayName, METH_VARARGS, doc_QWebDatabase_displayName},
    {sipName_expectedSize, meth_QWebDatabase_expectedSize, METH_VARARGS, doc_QWebDatabase_expectedSize},
    {sipName_fileName, meth_QWebDatabase_fileName, METH_VARARGS, doc_QWebDatabase_fileName},
    {sipName_name, meth_QWebDatabase_name, METH_VARARGS, doc_QWebDatabase_name},
    {sipName_origin, meth_QWebDatabase_origin, METH_VARARGS, doc_QWebDatabase_origin},
    {sipName_removeAllDatabases, meth_QWebDatabase_removeAllDatabases, METH_VARARGS, doc_QWebDatabase_removeAllDatabases},
    {sipName_removeDatabase, meth_QWebDatabase_removeDatabase, METH_VARARGS, doc_QWebDatabase_removeDatabase},
    {sipName_size, meth_QWebDatabase_size, METH_VARARGS, doc_QWebDatabase_size}
};

PyDoc_STRVAR(doc_QWebDatabase, "\1QWebDatabase(other: QWebDatabase)");


static pyqt5ClassPluginDef plugin_QWebDatabase = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKit_QWebDatabase = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebDatabase,
        SIP_NULLPTR,
        &plugin_QWebDatabase,
    },
    {
        sipNameNr_QWebDatabase,
        {0, 0, 1},
        8, methods_QWebDatabase,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWebDatabase,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QWebDatabase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWebDatabase,
    assign_QWebDatabase,
    SIP_NULLPTR,
    copy_QWebDatabase,
    release_QWebDatabase,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QWebDatabase),
};
