/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPrintSupport.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qabstractprintdialog.sip"
#include <qabstractprintdialog.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qprinter.sip"
#include <qprinter.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qabstractprintdialog.sip"
#include <qabstractprintdialog.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 482 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 425 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 460 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 438 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 363 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 99 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 102 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 105 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 108 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 114 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 117 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 120 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 123 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 126 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 129 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 132 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 135 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 138 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 141 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 509 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 144 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 471 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 147 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 570 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 150 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 619 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 153 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 592 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 156 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 608 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 159 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 675 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 162 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 302 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 165 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 412 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 168 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 398 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 171 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 384 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 174 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 253 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 177 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 205 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 180 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 183 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 186 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 189 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 192 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 198 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 201 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 204 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 207 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 210 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 213 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 218 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 221 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 224 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 227 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 230 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 233 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 236 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 239 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 242 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 245 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 248 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipQtPrintSupportQAbstractPrintDialog.cpp"


class sipQAbstractPrintDialog : public ::QAbstractPrintDialog
{
public:
    sipQAbstractPrintDialog(::QPrinter*, ::QWidget*);
    virtual ~sipQAbstractPrintDialog();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void initPainter(::QPainter*) const SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, long*) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void enterEvent(::QEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    int exec() SIP_OVERRIDE;
    void done(int) SIP_OVERRIDE;
    void accept() SIP_OVERRIDE;
    void reject() SIP_OVERRIDE;
    void open() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAbstractPrintDialog(const sipQAbstractPrintDialog &);
    sipQAbstractPrintDialog &operator = (const sipQAbstractPrintDialog &);

    char sipPyMethods[51];
};

sipQAbstractPrintDialog::sipQAbstractPrintDialog(::QPrinter*a0, ::QWidget*a1): ::QAbstractPrintDialog(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAbstractPrintDialog::~sipQAbstractPrintDialog()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQAbstractPrintDialog::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtPrintSupport_qt_metaobject(sipPySelf, sipType_QAbstractPrintDialog);

    return ::QAbstractPrintDialog::metaObject();
}

int sipQAbstractPrintDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QAbstractPrintDialog::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtPrintSupport_qt_metacall(sipPySelf, sipType_QAbstractPrintDialog, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQAbstractPrintDialog::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtPrintSupport_qt_metacast(sipPySelf, sipType_QAbstractPrintDialog, _clname, &sipCpp) ? sipCpp : ::QAbstractPrintDialog::qt_metacast(_clname));
}

void sipQAbstractPrintDialog::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::initPainter(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtPrintSupport_37(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPainter* sipQAbstractPrintDialog::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QAbstractPrintDialog::sharedPainter();

    extern ::QPainter* sipVH_QtPrintSupport_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPrintSupport_36(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQAbstractPrintDialog::nativeEvent(const ::QByteArray& a0, void*a1, long*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QAbstractPrintDialog::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtPrintSupport_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, long*);

    return sipVH_QtPrintSupport_35(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQAbstractPrintDialog::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QAbstractPrintDialog::hasHeightForWidth();

    extern bool sipVH_QtPrintSupport_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPrintSupport_34(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQAbstractPrintDialog::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QAbstractPrintDialog::focusNextPrevChild(a0);

    extern bool sipVH_QtPrintSupport_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtPrintSupport_33(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQAbstractPrintDialog::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QAbstractPrintDialog::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtPrintSupport_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtPrintSupport_32(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtPrintSupport_31(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::changeEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPrintSupport_4(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::hideEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtPrintSupport_30(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::showEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtPrintSupport_29(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::dropEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtPrintSupport_28(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtPrintSupport_27(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtPrintSupport_26(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtPrintSupport_25(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::actionEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtPrintSupport_24(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtPrintSupport_23(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtPrintSupport_22(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::closeEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtPrintSupport_21(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtPrintSupport_20(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::moveEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtPrintSupport_19(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::paintEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtPrintSupport_18(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPrintSupport_4(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::enterEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::enterEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPrintSupport_4(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtPrintSupport_17(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtPrintSupport_17(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtPrintSupport_16(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtPrintSupport_16(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtPrintSupport_15(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtPrintSupport_14(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtPrintSupport_14(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtPrintSupport_14(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtPrintSupport_14(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQAbstractPrintDialog::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[32]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QAbstractPrintDialog::heightForWidth(a0);

    extern int sipVH_QtPrintSupport_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtPrintSupport_13(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQAbstractPrintDialog::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[33]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QAbstractPrintDialog::minimumSizeHint();

    extern ::QSize sipVH_QtPrintSupport_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPrintSupport_12(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQAbstractPrintDialog::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[34]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QAbstractPrintDialog::sizeHint();

    extern ::QSize sipVH_QtPrintSupport_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPrintSupport_12(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAbstractPrintDialog::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::setVisible(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtPrintSupport_11(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQAbstractPrintDialog::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[36]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QAbstractPrintDialog::devType();

    extern int sipVH_QtPrintSupport_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPrintSupport_2(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QPaintEngine* sipQAbstractPrintDialog::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[37]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QAbstractPrintDialog::paintEngine();

    extern ::QPaintEngine* sipVH_QtPrintSupport_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPrintSupport_10(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQAbstractPrintDialog::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[38]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QAbstractPrintDialog::metric(a0);

    extern int sipVH_QtPrintSupport_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtPrintSupport_9(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstractPrintDialog::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QAbstractPrintDialog::event(a0);

    extern bool sipVH_QtPrintSupport_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtPrintSupport_8(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstractPrintDialog::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QAbstractPrintDialog::eventFilter(a0, a1);

    extern bool sipVH_QtPrintSupport_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtPrintSupport_7(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQAbstractPrintDialog::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[41], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::timerEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtPrintSupport_6(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[42], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::childEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtPrintSupport_5(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[43], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::customEvent(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtPrintSupport_4(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[44], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::connectNotify(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPrintSupport_3(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[45], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtPrintSupport_3(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQAbstractPrintDialog::exec()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[46], &sipPySelf, sipName_QAbstractPrintDialog, sipName_exec);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtPrintSupport_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtPrintSupport_2(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAbstractPrintDialog::done(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[47], &sipPySelf, SIP_NULLPTR, sipName_done);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::done(a0);
        return;
    }

    extern void sipVH_QtPrintSupport_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtPrintSupport_1(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractPrintDialog::accept()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[48], &sipPySelf, SIP_NULLPTR, sipName_accept);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::accept();
        return;
    }

    extern void sipVH_QtPrintSupport_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtPrintSupport_0(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAbstractPrintDialog::reject()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[49], &sipPySelf, SIP_NULLPTR, sipName_reject);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::reject();
        return;
    }

    extern void sipVH_QtPrintSupport_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtPrintSupport_0(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAbstractPrintDialog::open()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[50], &sipPySelf, SIP_NULLPTR, sipName_open);

    if (!sipMeth)
    {
        ::QAbstractPrintDialog::open();
        return;
    }

    extern void sipVH_QtPrintSupport_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtPrintSupport_0(sipGILState, sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QAbstractPrintDialog_exec_, "exec_(self) -> int");

extern "C" {static PyObject *meth_QAbstractPrintDialog_exec_(PyObject *, PyObject *);}
static PyObject *meth_QAbstractPrintDialog_exec_(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QAbstractPrintDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractPrintDialog, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractPrintDialog, sipName_exec_);
                return SIP_NULLPTR;
            }

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->exec();
            Py_END_ALLOW_THREADS

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractPrintDialog, sipName_exec_, doc_QAbstractPrintDialog_exec_);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractPrintDialog_exec, "exec(self) -> int");

extern "C" {static PyObject *meth_QAbstractPrintDialog_exec(PyObject *, PyObject *);}
static PyObject *meth_QAbstractPrintDialog_exec(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QAbstractPrintDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractPrintDialog, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractPrintDialog, sipName_exec);
                return SIP_NULLPTR;
            }

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->exec();
            Py_END_ALLOW_THREADS

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractPrintDialog, sipName_exec, doc_QAbstractPrintDialog_exec);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractPrintDialog_setPrintRange, "setPrintRange(self, range: QAbstractPrintDialog.PrintRange)");

extern "C" {static PyObject *meth_QAbstractPrintDialog_setPrintRange(PyObject *, PyObject *);}
static PyObject *meth_QAbstractPrintDialog_setPrintRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractPrintDialog::PrintRange a0;
        ::QAbstractPrintDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAbstractPrintDialog, &sipCpp, sipType_QAbstractPrintDialog_PrintRange, &a0))
        {
            sipCpp->setPrintRange(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractPrintDialog, sipName_setPrintRange, doc_QAbstractPrintDialog_setPrintRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractPrintDialog_printRange, "printRange(self) -> QAbstractPrintDialog.PrintRange");

extern "C" {static PyObject *meth_QAbstractPrintDialog_printRange(PyObject *, PyObject *);}
static PyObject *meth_QAbstractPrintDialog_printRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractPrintDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractPrintDialog, &sipCpp))
        {
            ::QAbstractPrintDialog::PrintRange sipRes;

            sipRes = sipCpp->printRange();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAbstractPrintDialog_PrintRange);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractPrintDialog, sipName_printRange, doc_QAbstractPrintDialog_printRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractPrintDialog_setMinMax, "setMinMax(self, min: int, max: int)");

extern "C" {static PyObject *meth_QAbstractPrintDialog_setMinMax(PyObject *, PyObject *);}
static PyObject *meth_QAbstractPrintDialog_setMinMax(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QAbstractPrintDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QAbstractPrintDialog, &sipCpp, &a0, &a1))
        {
            sipCpp->setMinMax(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractPrintDialog, sipName_setMinMax, doc_QAbstractPrintDialog_setMinMax);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractPrintDialog_minPage, "minPage(self) -> int");

extern "C" {static PyObject *meth_QAbstractPrintDialog_minPage(PyObject *, PyObject *);}
static PyObject *meth_QAbstractPrintDialog_minPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractPrintDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractPrintDialog, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->minPage();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractPrintDialog, sipName_minPage, doc_QAbstractPrintDialog_minPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractPrintDialog_maxPage, "maxPage(self) -> int");

extern "C" {static PyObject *meth_QAbstractPrintDialog_maxPage(PyObject *, PyObject *);}
static PyObject *meth_QAbstractPrintDialog_maxPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractPrintDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractPrintDialog, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxPage();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractPrintDialog, sipName_maxPage, doc_QAbstractPrintDialog_maxPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractPrintDialog_setFromTo, "setFromTo(self, fromPage: int, toPage: int)");

extern "C" {static PyObject *meth_QAbstractPrintDialog_setFromTo(PyObject *, PyObject *);}
static PyObject *meth_QAbstractPrintDialog_setFromTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QAbstractPrintDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QAbstractPrintDialog, &sipCpp, &a0, &a1))
        {
            sipCpp->setFromTo(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractPrintDialog, sipName_setFromTo, doc_QAbstractPrintDialog_setFromTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractPrintDialog_fromPage, "fromPage(self) -> int");

extern "C" {static PyObject *meth_QAbstractPrintDialog_fromPage(PyObject *, PyObject *);}
static PyObject *meth_QAbstractPrintDialog_fromPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractPrintDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractPrintDialog, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->fromPage();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractPrintDialog, sipName_fromPage, doc_QAbstractPrintDialog_fromPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractPrintDialog_toPage, "toPage(self) -> int");

extern "C" {static PyObject *meth_QAbstractPrintDialog_toPage(PyObject *, PyObject *);}
static PyObject *meth_QAbstractPrintDialog_toPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractPrintDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractPrintDialog, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->toPage();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractPrintDialog, sipName_toPage, doc_QAbstractPrintDialog_toPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractPrintDialog_printer, "printer(self) -> Optional[QPrinter]");

extern "C" {static PyObject *meth_QAbstractPrintDialog_printer(PyObject *, PyObject *);}
static PyObject *meth_QAbstractPrintDialog_printer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractPrintDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractPrintDialog, &sipCpp))
        {
            ::QPrinter*sipRes;

            sipRes = sipCpp->printer();

            return sipConvertFromType(sipRes, sipType_QPrinter, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractPrintDialog, sipName_printer, doc_QAbstractPrintDialog_printer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractPrintDialog_setOptionTabs, "setOptionTabs(self, tabs: Iterable[QWidget])");

extern "C" {static PyObject *meth_QAbstractPrintDialog_setOptionTabs(PyObject *, PyObject *);}
static PyObject *meth_QAbstractPrintDialog_setOptionTabs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QWidget*>* a0;
        int a0State = 0;
        ::QAbstractPrintDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAbstractPrintDialog, &sipCpp, sipType_QList_0101QWidget, &a0, &a0State))
        {
            sipCpp->setOptionTabs(*a0);
            sipReleaseType(const_cast<QList< ::QWidget*> *>(a0), sipType_QList_0101QWidget, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractPrintDialog, sipName_setOptionTabs, doc_QAbstractPrintDialog_setOptionTabs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractPrintDialog_setEnabledOptions, "setEnabledOptions(self, options: Union[QAbstractPrintDialog.PrintDialogOptions, QAbstractPrintDialog.PrintDialogOption])");

extern "C" {static PyObject *meth_QAbstractPrintDialog_setEnabledOptions(PyObject *, PyObject *);}
static PyObject *meth_QAbstractPrintDialog_setEnabledOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractPrintDialog::PrintDialogOptions* a0;
        int a0State = 0;
        ::QAbstractPrintDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAbstractPrintDialog, &sipCpp, sipType_QAbstractPrintDialog_PrintDialogOptions, &a0, &a0State))
        {
            sipCpp->setEnabledOptions(*a0);
            sipReleaseType(a0, sipType_QAbstractPrintDialog_PrintDialogOptions, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractPrintDialog, sipName_setEnabledOptions, doc_QAbstractPrintDialog_setEnabledOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractPrintDialog_enabledOptions, "enabledOptions(self) -> QAbstractPrintDialog.PrintDialogOptions");

extern "C" {static PyObject *meth_QAbstractPrintDialog_enabledOptions(PyObject *, PyObject *);}
static PyObject *meth_QAbstractPrintDialog_enabledOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractPrintDialog *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractPrintDialog, &sipCpp))
        {
            ::QAbstractPrintDialog::PrintDialogOptions*sipRes;

            sipRes = new ::QAbstractPrintDialog::PrintDialogOptions(sipCpp->enabledOptions());

            return sipConvertFromNewType(sipRes, sipType_QAbstractPrintDialog_PrintDialogOptions, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractPrintDialog, sipName_enabledOptions, doc_QAbstractPrintDialog_enabledOptions);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAbstractPrintDialog(void *, const sipTypeDef *);}
static void *cast_QAbstractPrintDialog(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAbstractPrintDialog *sipCpp = reinterpret_cast< ::QAbstractPrintDialog *>(sipCppV);

    if (targetType == sipType_QAbstractPrintDialog)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QDialog)->ctd_cast(static_cast< ::QDialog *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAbstractPrintDialog(void *, int);}
static void release_QAbstractPrintDialog(void *sipCppV, int)
{
    ::QAbstractPrintDialog *sipCpp = reinterpret_cast< ::QAbstractPrintDialog *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QAbstractPrintDialog(sipSimpleWrapper *);}
static void dealloc_QAbstractPrintDialog(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAbstractPrintDialog *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAbstractPrintDialog(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAbstractPrintDialog(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAbstractPrintDialog(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQAbstractPrintDialog *sipCpp = SIP_NULLPTR;

    {
        ::QPrinter* a0;
        ::QWidget* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|JH", sipType_QPrinter, &a0, sipType_QWidget, &a1, sipOwner))
        {
            sipCpp = new sipQAbstractPrintDialog(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAbstractPrintDialog[] = {{0, 2, 1}};


static PyMethodDef methods_QAbstractPrintDialog[] = {
    {sipName_enabledOptions, meth_QAbstractPrintDialog_enabledOptions, METH_VARARGS, doc_QAbstractPrintDialog_enabledOptions},
    {sipName_exec, meth_QAbstractPrintDialog_exec, METH_VARARGS, doc_QAbstractPrintDialog_exec},
    {sipName_exec_, meth_QAbstractPrintDialog_exec_, METH_VARARGS, doc_QAbstractPrintDialog_exec_},
    {sipName_fromPage, meth_QAbstractPrintDialog_fromPage, METH_VARARGS, doc_QAbstractPrintDialog_fromPage},
    {sipName_maxPage, meth_QAbstractPrintDialog_maxPage, METH_VARARGS, doc_QAbstractPrintDialog_maxPage},
    {sipName_minPage, meth_QAbstractPrintDialog_minPage, METH_VARARGS, doc_QAbstractPrintDialog_minPage},
    {sipName_printRange, meth_QAbstractPrintDialog_printRange, METH_VARARGS, doc_QAbstractPrintDialog_printRange},
    {sipName_printer, meth_QAbstractPrintDialog_printer, METH_VARARGS, doc_QAbstractPrintDialog_printer},
    {sipName_setEnabledOptions, meth_QAbstractPrintDialog_setEnabledOptions, METH_VARARGS, doc_QAbstractPrintDialog_setEnabledOptions},
    {sipName_setFromTo, meth_QAbstractPrintDialog_setFromTo, METH_VARARGS, doc_QAbstractPrintDialog_setFromTo},
    {sipName_setMinMax, meth_QAbstractPrintDialog_setMinMax, METH_VARARGS, doc_QAbstractPrintDialog_setMinMax},
    {sipName_setOptionTabs, meth_QAbstractPrintDialog_setOptionTabs, METH_VARARGS, doc_QAbstractPrintDialog_setOptionTabs},
    {sipName_setPrintRange, meth_QAbstractPrintDialog_setPrintRange, METH_VARARGS, doc_QAbstractPrintDialog_setPrintRange},
    {sipName_toPage, meth_QAbstractPrintDialog_toPage, METH_VARARGS, doc_QAbstractPrintDialog_toPage}
};

static sipEnumMemberDef enummembers_QAbstractPrintDialog[] = {
    {sipName_AllPages, static_cast<int>(::QAbstractPrintDialog::AllPages), 3},
    {sipName_CurrentPage, static_cast<int>(::QAbstractPrintDialog::CurrentPage), 3},
    {sipName_None_, static_cast<int>(::QAbstractPrintDialog::None), 1},
    {sipName_PageRange, static_cast<int>(::QAbstractPrintDialog::PageRange), 3},
    {sipName_PrintCollateCopies, static_cast<int>(::QAbstractPrintDialog::PrintCollateCopies), 1},
    {sipName_PrintCurrentPage, static_cast<int>(::QAbstractPrintDialog::PrintCurrentPage), 1},
    {sipName_PrintPageRange, static_cast<int>(::QAbstractPrintDialog::PrintPageRange), 1},
    {sipName_PrintSelection, static_cast<int>(::QAbstractPrintDialog::PrintSelection), 1},
    {sipName_PrintShowPageSize, static_cast<int>(::QAbstractPrintDialog::PrintShowPageSize), 1},
    {sipName_PrintToFile, static_cast<int>(::QAbstractPrintDialog::PrintToFile), 1},
    {sipName_Selection, static_cast<int>(::QAbstractPrintDialog::Selection), 3},
};

PyDoc_STRVAR(doc_QAbstractPrintDialog, "\1QAbstractPrintDialog(printer: Optional[QPrinter], parent: Optional[QWidget] = None)");


static pyqt5ClassPluginDef plugin_QAbstractPrintDialog = {
    &::QAbstractPrintDialog::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtPrintSupport_QAbstractPrintDialog = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAbstractPrintDialog,
        SIP_NULLPTR,
        &plugin_QAbstractPrintDialog,
    },
    {
        sipNameNr_QAbstractPrintDialog,
        {0, 0, 1},
        14, methods_QAbstractPrintDialog,
        11, enummembers_QAbstractPrintDialog,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAbstractPrintDialog,
    -1,
    -1,
    supers_QAbstractPrintDialog,
    SIP_NULLPTR,
    init_type_QAbstractPrintDialog,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAbstractPrintDialog,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QAbstractPrintDialog,
    cast_QAbstractPrintDialog,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QAbstractPrintDialog),
};
