/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 57 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaencodersettings.sip"
#include <qmediaencodersettings.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoEncoderSettings.cpp"

#line 24 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoEncoderSettings.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoEncoderSettings.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoEncoderSettings.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmultimedia.sip"
#include <qmultimedia.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoEncoderSettings.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoEncoderSettings.cpp"


PyDoc_STRVAR(doc_QVideoEncoderSettings_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QVideoEncoderSettings_isNull(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_isNull, doc_QVideoEncoderSettings_isNull);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_encodingMode, "encodingMode(self) -> QMultimedia.EncodingMode");

extern "C" {static PyObject *meth_QVideoEncoderSettings_encodingMode(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_encodingMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp))
        {
            ::QMultimedia::EncodingMode sipRes;

            sipRes = sipCpp->encodingMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMultimedia_EncodingMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_encodingMode, doc_QVideoEncoderSettings_encodingMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_setEncodingMode, "setEncodingMode(self, a0: QMultimedia.EncodingMode)");

extern "C" {static PyObject *meth_QVideoEncoderSettings_setEncodingMode(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_setEncodingMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMultimedia::EncodingMode a0;
        ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp, sipType_QMultimedia_EncodingMode, &a0))
        {
            sipCpp->setEncodingMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_setEncodingMode, doc_QVideoEncoderSettings_setEncodingMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_codec, "codec(self) -> str");

extern "C" {static PyObject *meth_QVideoEncoderSettings_codec(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_codec(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->codec());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_codec, doc_QVideoEncoderSettings_codec);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_setCodec, "setCodec(self, a0: Optional[str])");

extern "C" {static PyObject *meth_QVideoEncoderSettings_setCodec(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_setCodec(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCodec(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_setCodec, doc_QVideoEncoderSettings_setCodec);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_resolution, "resolution(self) -> QSize");

extern "C" {static PyObject *meth_QVideoEncoderSettings_resolution(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_resolution(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->resolution());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_resolution, doc_QVideoEncoderSettings_resolution);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_setResolution, "setResolution(self, a0: QSize)\n"
"setResolution(self, width: int, height: int)");

extern "C" {static PyObject *meth_QVideoEncoderSettings_setResolution(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_setResolution(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setResolution(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        int a1;
        ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp, &a0, &a1))
        {
            sipCpp->setResolution(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_setResolution, doc_QVideoEncoderSettings_setResolution);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_frameRate, "frameRate(self) -> float");

extern "C" {static PyObject *meth_QVideoEncoderSettings_frameRate(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_frameRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->frameRate();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_frameRate, doc_QVideoEncoderSettings_frameRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_setFrameRate, "setFrameRate(self, rate: float)");

extern "C" {static PyObject *meth_QVideoEncoderSettings_setFrameRate(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_setFrameRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp, &a0))
        {
            sipCpp->setFrameRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_setFrameRate, doc_QVideoEncoderSettings_setFrameRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_bitRate, "bitRate(self) -> int");

extern "C" {static PyObject *meth_QVideoEncoderSettings_bitRate(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_bitRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->bitRate();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_bitRate, doc_QVideoEncoderSettings_bitRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_setBitRate, "setBitRate(self, bitrate: int)");

extern "C" {static PyObject *meth_QVideoEncoderSettings_setBitRate(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_setBitRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp, &a0))
        {
            sipCpp->setBitRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_setBitRate, doc_QVideoEncoderSettings_setBitRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_quality, "quality(self) -> QMultimedia.EncodingQuality");

extern "C" {static PyObject *meth_QVideoEncoderSettings_quality(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_quality(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp))
        {
            ::QMultimedia::EncodingQuality sipRes;

            sipRes = sipCpp->quality();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMultimedia_EncodingQuality);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_quality, doc_QVideoEncoderSettings_quality);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_setQuality, "setQuality(self, quality: QMultimedia.EncodingQuality)");

extern "C" {static PyObject *meth_QVideoEncoderSettings_setQuality(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_setQuality(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMultimedia::EncodingQuality a0;
        ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp, sipType_QMultimedia_EncodingQuality, &a0))
        {
            sipCpp->setQuality(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_setQuality, doc_QVideoEncoderSettings_setQuality);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_encodingOption, "encodingOption(self, option: Optional[str]) -> Any");

extern "C" {static PyObject *meth_QVideoEncoderSettings_encodingOption(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_encodingOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->encodingOption(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_encodingOption, doc_QVideoEncoderSettings_encodingOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_encodingOptions, "encodingOptions(self) -> dict[str, Any]");

extern "C" {static PyObject *meth_QVideoEncoderSettings_encodingOptions(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_encodingOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp))
        {
            ::QVariantMap*sipRes;

            sipRes = new ::QVariantMap(sipCpp->encodingOptions());

            return sipConvertFromNewType(sipRes, sipType_QVariantMap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_encodingOptions, doc_QVideoEncoderSettings_encodingOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_setEncodingOption, "setEncodingOption(self, option: Optional[str], value: Any)");

extern "C" {static PyObject *meth_QVideoEncoderSettings_setEncodingOption(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_setEncodingOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp, sipType_QString, &a0, &a0State, sipType_QVariant, &a1, &a1State))
        {
            sipCpp->setEncodingOption(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_setEncodingOption, doc_QVideoEncoderSettings_setEncodingOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoEncoderSettings_setEncodingOptions, "setEncodingOptions(self, options: dict[str, Any])");

extern "C" {static PyObject *meth_QVideoEncoderSettings_setEncodingOptions(PyObject *, PyObject *);}
static PyObject *meth_QVideoEncoderSettings_setEncodingOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariantMap* a0;
        int a0State = 0;
        ::QVideoEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QVideoEncoderSettings, &sipCpp, sipType_QVariantMap, &a0, &a0State))
        {
            sipCpp->setEncodingOptions(*a0);
            sipReleaseType(const_cast< ::QVariantMap *>(a0), sipType_QVariantMap, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoEncoderSettings, sipName_setEncodingOptions, doc_QVideoEncoderSettings_setEncodingOptions);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QVideoEncoderSettings___ne__(PyObject *, PyObject *);}
static PyObject *slot_QVideoEncoderSettings___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QVideoEncoderSettings *sipCpp = reinterpret_cast< ::QVideoEncoderSettings *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QVideoEncoderSettings));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVideoEncoderSettings* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QVideoEncoderSettings, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QVideoEncoderSettings::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, ne_slot, sipType_QVideoEncoderSettings, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QVideoEncoderSettings___eq__(PyObject *, PyObject *);}
static PyObject *slot_QVideoEncoderSettings___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QVideoEncoderSettings *sipCpp = reinterpret_cast< ::QVideoEncoderSettings *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QVideoEncoderSettings));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVideoEncoderSettings* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QVideoEncoderSettings, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QVideoEncoderSettings::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, eq_slot, sipType_QVideoEncoderSettings, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QVideoEncoderSettings(void *, int);}
static void release_QVideoEncoderSettings(void *sipCppV, int)
{
    delete reinterpret_cast< ::QVideoEncoderSettings *>(sipCppV);
}


extern "C" {static void *array_QVideoEncoderSettings(Py_ssize_t);}
static void *array_QVideoEncoderSettings(Py_ssize_t sipNrElem)
{
    return new ::QVideoEncoderSettings[sipNrElem];
}


extern "C" {static void array_delete_QVideoEncoderSettings(void *);}
static void array_delete_QVideoEncoderSettings(void *sipCpp)
{
    delete[] reinterpret_cast< ::QVideoEncoderSettings *>(sipCpp);
}


extern "C" {static void assign_QVideoEncoderSettings(void *, Py_ssize_t, void *);}
static void assign_QVideoEncoderSettings(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QVideoEncoderSettings *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QVideoEncoderSettings *>(sipSrc);
}


extern "C" {static void *copy_QVideoEncoderSettings(const void *, Py_ssize_t);}
static void *copy_QVideoEncoderSettings(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QVideoEncoderSettings(reinterpret_cast<const ::QVideoEncoderSettings *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QVideoEncoderSettings(sipSimpleWrapper *);}
static void dealloc_QVideoEncoderSettings(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QVideoEncoderSettings(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QVideoEncoderSettings(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QVideoEncoderSettings(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QVideoEncoderSettings *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QVideoEncoderSettings();

            return sipCpp;
        }
    }

    {
        const ::QVideoEncoderSettings* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QVideoEncoderSettings, &a0))
        {
            sipCpp = new ::QVideoEncoderSettings(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QVideoEncoderSettings[] = {
    {(void *)slot_QVideoEncoderSettings___ne__, ne_slot},
    {(void *)slot_QVideoEncoderSettings___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QVideoEncoderSettings[] = {
    {sipName_bitRate, meth_QVideoEncoderSettings_bitRate, METH_VARARGS, doc_QVideoEncoderSettings_bitRate},
    {sipName_codec, meth_QVideoEncoderSettings_codec, METH_VARARGS, doc_QVideoEncoderSettings_codec},
    {sipName_encodingMode, meth_QVideoEncoderSettings_encodingMode, METH_VARARGS, doc_QVideoEncoderSettings_encodingMode},
    {sipName_encodingOption, meth_QVideoEncoderSettings_encodingOption, METH_VARARGS, doc_QVideoEncoderSettings_encodingOption},
    {sipName_encodingOptions, meth_QVideoEncoderSettings_encodingOptions, METH_VARARGS, doc_QVideoEncoderSettings_encodingOptions},
    {sipName_frameRate, meth_QVideoEncoderSettings_frameRate, METH_VARARGS, doc_QVideoEncoderSettings_frameRate},
    {sipName_isNull, meth_QVideoEncoderSettings_isNull, METH_VARARGS, doc_QVideoEncoderSettings_isNull},
    {sipName_quality, meth_QVideoEncoderSettings_quality, METH_VARARGS, doc_QVideoEncoderSettings_quality},
    {sipName_resolution, meth_QVideoEncoderSettings_resolution, METH_VARARGS, doc_QVideoEncoderSettings_resolution},
    {sipName_setBitRate, meth_QVideoEncoderSettings_setBitRate, METH_VARARGS, doc_QVideoEncoderSettings_setBitRate},
    {sipName_setCodec, meth_QVideoEncoderSettings_setCodec, METH_VARARGS, doc_QVideoEncoderSettings_setCodec},
    {sipName_setEncodingMode, meth_QVideoEncoderSettings_setEncodingMode, METH_VARARGS, doc_QVideoEncoderSettings_setEncodingMode},
    {sipName_setEncodingOption, meth_QVideoEncoderSettings_setEncodingOption, METH_VARARGS, doc_QVideoEncoderSettings_setEncodingOption},
    {sipName_setEncodingOptions, meth_QVideoEncoderSettings_setEncodingOptions, METH_VARARGS, doc_QVideoEncoderSettings_setEncodingOptions},
    {sipName_setFrameRate, meth_QVideoEncoderSettings_setFrameRate, METH_VARARGS, doc_QVideoEncoderSettings_setFrameRate},
    {sipName_setQuality, meth_QVideoEncoderSettings_setQuality, METH_VARARGS, doc_QVideoEncoderSettings_setQuality},
    {sipName_setResolution, meth_QVideoEncoderSettings_setResolution, METH_VARARGS, doc_QVideoEncoderSettings_setResolution}
};

PyDoc_STRVAR(doc_QVideoEncoderSettings, "\1QVideoEncoderSettings()\n"
"QVideoEncoderSettings(other: QVideoEncoderSettings)");


static pyqt5ClassPluginDef plugin_QVideoEncoderSettings = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QVideoEncoderSettings = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QVideoEncoderSettings,
        SIP_NULLPTR,
        &plugin_QVideoEncoderSettings,
    },
    {
        sipNameNr_QVideoEncoderSettings,
        {0, 0, 1},
        17, methods_QVideoEncoderSettings,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QVideoEncoderSettings,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QVideoEncoderSettings,
    init_type_QVideoEncoderSettings,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QVideoEncoderSettings,
    assign_QVideoEncoderSettings,
    array_QVideoEncoderSettings,
    copy_QVideoEncoderSettings,
    release_QVideoEncoderSettings,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QVideoEncoderSettings,
    sizeof (::QVideoEncoderSettings),
};
