/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKitWidgets.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 335 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPageErrorPageExtensionOption.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 35 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPageErrorPageExtensionOption.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPageErrorPageExtensionOption.cpp"
#line 61 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebframe.sip"
#include <qwebframe.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPageErrorPageExtensionOption.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPageErrorPageExtensionOption.cpp"


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QWebPage_ErrorPageExtensionOption(void *, const sipTypeDef *);}
static void *cast_QWebPage_ErrorPageExtensionOption(void *sipCppV, const sipTypeDef *targetType)
{
    ::QWebPage::ErrorPageExtensionOption *sipCpp = reinterpret_cast< ::QWebPage::ErrorPageExtensionOption *>(sipCppV);

    if (targetType == sipType_QWebPage_ErrorPageExtensionOption)
        return sipCppV;

    if (targetType == sipType_QWebPage_ExtensionOption)
        return static_cast< ::QWebPage::ExtensionOption *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebPage_ErrorPageExtensionOption(void *, int);}
static void release_QWebPage_ErrorPageExtensionOption(void *sipCppV, int)
{
    delete reinterpret_cast< ::QWebPage::ErrorPageExtensionOption *>(sipCppV);
}


extern "C" {static void *array_QWebPage_ErrorPageExtensionOption(Py_ssize_t);}
static void *array_QWebPage_ErrorPageExtensionOption(Py_ssize_t sipNrElem)
{
    return new ::QWebPage::ErrorPageExtensionOption[sipNrElem];
}


extern "C" {static void array_delete_QWebPage_ErrorPageExtensionOption(void *);}
static void array_delete_QWebPage_ErrorPageExtensionOption(void *sipCpp)
{
    delete[] reinterpret_cast< ::QWebPage::ErrorPageExtensionOption *>(sipCpp);
}


extern "C" {static void assign_QWebPage_ErrorPageExtensionOption(void *, Py_ssize_t, void *);}
static void assign_QWebPage_ErrorPageExtensionOption(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QWebPage::ErrorPageExtensionOption *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QWebPage::ErrorPageExtensionOption *>(sipSrc);
}


extern "C" {static void *copy_QWebPage_ErrorPageExtensionOption(const void *, Py_ssize_t);}
static void *copy_QWebPage_ErrorPageExtensionOption(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QWebPage::ErrorPageExtensionOption(reinterpret_cast<const ::QWebPage::ErrorPageExtensionOption *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QWebPage_ErrorPageExtensionOption(sipSimpleWrapper *);}
static void dealloc_QWebPage_ErrorPageExtensionOption(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWebPage_ErrorPageExtensionOption(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QWebPage_ErrorPageExtensionOption(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWebPage_ErrorPageExtensionOption(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QWebPage::ErrorPageExtensionOption *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QWebPage::ErrorPageExtensionOption();

            return sipCpp;
        }
    }

    {
        const ::QWebPage::ErrorPageExtensionOption* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QWebPage_ErrorPageExtensionOption, &a0))
        {
            sipCpp = new ::QWebPage::ErrorPageExtensionOption(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QWebPage_ErrorPageExtensionOption[] = {{16, 255, 1}};


extern "C" {static PyObject *varget_QWebPage_ErrorPageExtensionOption_domain(void *, PyObject *, PyObject *);}
static PyObject *varget_QWebPage_ErrorPageExtensionOption_domain(void *sipSelf, PyObject *, PyObject *)
{
    ::QWebPage::ErrorDomain sipVal;
    ::QWebPage::ErrorPageExtensionOption *sipCpp = reinterpret_cast< ::QWebPage::ErrorPageExtensionOption *>(sipSelf);

    sipVal = sipCpp->domain;

    return sipConvertFromEnum(static_cast<int>(sipVal), sipType_QWebPage_ErrorDomain);
}


extern "C" {static int varset_QWebPage_ErrorPageExtensionOption_domain(void *, PyObject *, PyObject *);}
static int varset_QWebPage_ErrorPageExtensionOption_domain(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QWebPage::ErrorDomain sipVal;
    ::QWebPage::ErrorPageExtensionOption *sipCpp = reinterpret_cast< ::QWebPage::ErrorPageExtensionOption *>(sipSelf);

    sipVal = (::QWebPage::ErrorDomain)sipConvertToEnum(sipPy, sipType_QWebPage_ErrorDomain);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->domain = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QWebPage_ErrorPageExtensionOption_error(void *, PyObject *, PyObject *);}
static PyObject *varget_QWebPage_ErrorPageExtensionOption_error(void *sipSelf, PyObject *, PyObject *)
{
    int sipVal;
    ::QWebPage::ErrorPageExtensionOption *sipCpp = reinterpret_cast< ::QWebPage::ErrorPageExtensionOption *>(sipSelf);

    sipVal = sipCpp->error;

    return PyLong_FromLong(sipVal);
}


extern "C" {static int varset_QWebPage_ErrorPageExtensionOption_error(void *, PyObject *, PyObject *);}
static int varset_QWebPage_ErrorPageExtensionOption_error(void *sipSelf, PyObject *sipPy, PyObject *)
{
    int sipVal;
    ::QWebPage::ErrorPageExtensionOption *sipCpp = reinterpret_cast< ::QWebPage::ErrorPageExtensionOption *>(sipSelf);

    sipVal = sipLong_AsInt(sipPy);

    if (PyErr_Occurred() != SIP_NULLPTR)
        return -1;

    sipCpp->error = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QWebPage_ErrorPageExtensionOption_errorString(void *, PyObject *, PyObject *);}
static PyObject *varget_QWebPage_ErrorPageExtensionOption_errorString(void *sipSelf, PyObject *, PyObject *)
{
    ::QString*sipVal;
    ::QWebPage::ErrorPageExtensionOption *sipCpp = reinterpret_cast< ::QWebPage::ErrorPageExtensionOption *>(sipSelf);

    sipVal = &sipCpp->errorString;

    return sipConvertFromType(sipVal, sipType_QString, SIP_NULLPTR);
}


extern "C" {static int varset_QWebPage_ErrorPageExtensionOption_errorString(void *, PyObject *, PyObject *);}
static int varset_QWebPage_ErrorPageExtensionOption_errorString(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QString*sipVal;
    ::QWebPage::ErrorPageExtensionOption *sipCpp = reinterpret_cast< ::QWebPage::ErrorPageExtensionOption *>(sipSelf);

    int sipIsErr = 0;
    int sipValState;
    sipVal = reinterpret_cast< ::QString *>(sipForceConvertToType(sipPy, sipType_QString, SIP_NULLPTR, SIP_NOT_NONE, &sipValState, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->errorString = *sipVal;

    sipReleaseType(sipVal, sipType_QString, sipValState);

    return 0;
}


extern "C" {static PyObject *varget_QWebPage_ErrorPageExtensionOption_frame(void *, PyObject *, PyObject *);}
static PyObject *varget_QWebPage_ErrorPageExtensionOption_frame(void *sipSelf, PyObject *, PyObject *)
{
    ::QWebFrame*sipVal;
    ::QWebPage::ErrorPageExtensionOption *sipCpp = reinterpret_cast< ::QWebPage::ErrorPageExtensionOption *>(sipSelf);

    sipVal = sipCpp->frame;

    return sipConvertFromType(sipVal, sipType_QWebFrame, SIP_NULLPTR);
}


extern "C" {static int varset_QWebPage_ErrorPageExtensionOption_frame(void *, PyObject *, PyObject *);}
static int varset_QWebPage_ErrorPageExtensionOption_frame(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QWebFrame*sipVal;
    ::QWebPage::ErrorPageExtensionOption *sipCpp = reinterpret_cast< ::QWebPage::ErrorPageExtensionOption *>(sipSelf);

    int sipIsErr = 0;
    sipVal = reinterpret_cast< ::QWebFrame *>(sipForceConvertToType(sipPy, sipType_QWebFrame, SIP_NULLPTR, 0, SIP_NULLPTR, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->frame = sipVal;

    return 0;
}


extern "C" {static PyObject *varget_QWebPage_ErrorPageExtensionOption_url(void *, PyObject *, PyObject *);}
static PyObject *varget_QWebPage_ErrorPageExtensionOption_url(void *sipSelf, PyObject *sipPySelf, PyObject *)
{
    PyObject *sipPy;
    ::QUrl*sipVal;
    ::QWebPage::ErrorPageExtensionOption *sipCpp = reinterpret_cast< ::QWebPage::ErrorPageExtensionOption *>(sipSelf);

    sipPy = sipGetReference(sipPySelf, -9);

    if (sipPy)
        return sipPy;

    sipVal = &sipCpp->url;

    sipPy = sipConvertFromType(sipVal, sipType_QUrl, SIP_NULLPTR);

    if (sipPy)
    {
        sipKeepReference(sipPy, -16, sipPySelf);
        sipKeepReference(sipPySelf, -9, sipPy);
    }

    return sipPy;
}


extern "C" {static int varset_QWebPage_ErrorPageExtensionOption_url(void *, PyObject *, PyObject *);}
static int varset_QWebPage_ErrorPageExtensionOption_url(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QUrl*sipVal;
    ::QWebPage::ErrorPageExtensionOption *sipCpp = reinterpret_cast< ::QWebPage::ErrorPageExtensionOption *>(sipSelf);

    int sipIsErr = 0;
    sipVal = reinterpret_cast< ::QUrl *>(sipForceConvertToType(sipPy, sipType_QUrl, SIP_NULLPTR, SIP_NOT_NONE, SIP_NULLPTR, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->url = *sipVal;

    return 0;
}

sipVariableDef variables_QWebPage_ErrorPageExtensionOption[] = {
    {InstanceVariable, sipName_domain, (PyMethodDef *)varget_QWebPage_ErrorPageExtensionOption_domain, (PyMethodDef *)varset_QWebPage_ErrorPageExtensionOption_domain, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_error, (PyMethodDef *)varget_QWebPage_ErrorPageExtensionOption_error, (PyMethodDef *)varset_QWebPage_ErrorPageExtensionOption_error, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_errorString, (PyMethodDef *)varget_QWebPage_ErrorPageExtensionOption_errorString, (PyMethodDef *)varset_QWebPage_ErrorPageExtensionOption_errorString, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_frame, (PyMethodDef *)varget_QWebPage_ErrorPageExtensionOption_frame, (PyMethodDef *)varset_QWebPage_ErrorPageExtensionOption_frame, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_url, (PyMethodDef *)varget_QWebPage_ErrorPageExtensionOption_url, (PyMethodDef *)varset_QWebPage_ErrorPageExtensionOption_url, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QWebPage_ErrorPageExtensionOption, "\1QWebPage.ErrorPageExtensionOption()\n"
"QWebPage.ErrorPageExtensionOption(a0: QWebPage.ErrorPageExtensionOption)");


static pyqt5ClassPluginDef plugin_QWebPage_ErrorPageExtensionOption = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebPage_ErrorPageExtensionOption = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebPage__ErrorPageExtensionOption,
        SIP_NULLPTR,
        &plugin_QWebPage_ErrorPageExtensionOption,
    },
    {
        sipNameNr_ErrorPageExtensionOption,
        {9, 255, 0},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        5, variables_QWebPage_ErrorPageExtensionOption,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWebPage_ErrorPageExtensionOption,
    -1,
    -1,
    supers_QWebPage_ErrorPageExtensionOption,
    SIP_NULLPTR,
    init_type_QWebPage_ErrorPageExtensionOption,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWebPage_ErrorPageExtensionOption,
    assign_QWebPage_ErrorPageExtensionOption,
    array_QWebPage_ErrorPageExtensionOption,
    copy_QWebPage_ErrorPageExtensionOption,
    release_QWebPage_ErrorPageExtensionOption,
    cast_QWebPage_ErrorPageExtensionOption,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QWebPage_ErrorPageExtensionOption,
    sizeof (::QWebPage::ErrorPageExtensionOption),
};
