/*
 * Module code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtSensors.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 32 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 35 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qsensor.sip"
#include <qsensor.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qaccelerometer.sip"
#include <qaccelerometer.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qaltimeter.sip"
#include <qaltimeter.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qambientlightsensor.sip"
#include <qambientlightsensor.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qambienttemperaturesensor.sip"
#include <qambienttemperaturesensor.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qcompass.sip"
#include <qcompass.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qdistancesensor.sip"
#include <qdistancesensor.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qgyroscope.sip"
#include <qgyroscope.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qholstersensor.sip"
#include <qholstersensor.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qhumiditysensor.sip"
#include <qhumiditysensor.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qirproximitysensor.sip"
#include <qirproximitysensor.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qlidsensor.sip"
#include <qlidsensor.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qlightsensor.sip"
#include <qlightsensor.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qmagnetometer.sip"
#include <qmagnetometer.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qorientationsensor.sip"
#include <qorientationsensor.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qpressuresensor.sip"
#include <qpressuresensor.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qproximitysensor.sip"
#include <qproximitysensor.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qtapsensor.sip"
#include <qtapsensor.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qtiltsensor.sip"
#include <qtiltsensor.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qrotationsensor.sip"
#include <qrotationsensor.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qaccelerometer.sip"
#include <qaccelerometer.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 55 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qaltimeter.sip"
#include <qaltimeter.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qambientlightsensor.sip"
#include <qambientlightsensor.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 55 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qambienttemperaturesensor.sip"
#include <qambienttemperaturesensor.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qcompass.sip"
#include <qcompass.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 55 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qdistancesensor.sip"
#include <qdistancesensor.h>
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qgyroscope.sip"
#include <qgyroscope.h>
#line 122 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 55 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qholstersensor.sip"
#include <qholstersensor.h>
#line 125 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qhumiditysensor.sip"
#include <qhumiditysensor.h>
#line 128 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 55 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qirproximitysensor.sip"
#include <qirproximitysensor.h>
#line 131 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 61 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qlidsensor.sip"
#include <qlidsensor.h>
#line 134 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 55 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qlightsensor.sip"
#include <qlightsensor.h>
#line 137 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 61 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qmagnetometer.sip"
#include <qmagnetometer.h>
#line 140 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qorientationsensor.sip"
#include <qorientationsensor.h>
#line 143 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 61 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qpressuresensor.sip"
#include <qpressuresensor.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 55 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qproximitysensor.sip"
#include <qproximitysensor.h>
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 34 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qsensor.sip"
#include <qsensor.h>
#line 152 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qtapsensor.sip"
#include <qtapsensor.h>
#line 155 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qtiltsensor.sip"
#include <qtiltsensor.h>
#line 158 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qrotationsensor.sip"
#include <qrotationsensor.h>
#line 161 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtSensors[] = {
    'Q', 'A', 'c', 'c', 'e', 'l', 'e', 'r', 'o', 'm', 'e', 't', 'e', 'r', ':', ':', 'A', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'Q', 'A', 'm', 'b', 'i', 'e', 'n', 't', 'L', 'i', 'g', 'h', 't', 'R', 'e', 'a', 'd', 'i', 'n', 'g', ':', ':', 'L', 'i', 'g', 'h', 't', 'L', 'e', 'v', 'e', 'l', 0,
    'Q', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'a', 'd', 'i', 'n', 'g', ':', ':', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'S', 'e', 'n', 's', 'o', 'r', ':', ':', 'A', 'x', 'e', 's', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'r', 'e', 't', 'u', 'r', 'n', 'D', 'o', 'u', 'b', 'l', 'e', 'T', 'a', 'p', 'E', 'v', 'e', 'n', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'A', 'm', 'b', 'i', 'e', 'n', 't', 'T', 'e', 'm', 'p', 'e', 'r', 'a', 't', 'u', 'r', 'e', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'a', 'x', 'e', 's', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'P', 'r', 'e', 's', 's', 'u', 'r', 'e', 'S', 'e', 'n', 's', 'o', 'r', 'T', 'e', 'm', 'p', 'e', 'r', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'A', 'm', 'b', 'i', 'e', 'n', 't', 'T', 'e', 'm', 'p', 'e', 'r', 'a', 't', 'u', 'r', 'e', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'A', 'm', 'b', 'i', 'e', 'n', 't', 'T', 'e', 'm', 'p', 'e', 'r', 'a', 't', 'u', 'r', 'e', 'S', 'e', 'n', 's', 'o', 'r', 0,
    'Q', 'T', 'a', 'p', 'R', 'e', 'a', 'd', 'i', 'n', 'g', ':', ':', 'T', 'a', 'p', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'R', 'e', 't', 'u', 'r', 'n', 'D', 'o', 'u', 'b', 'l', 'e', 'T', 'a', 'p', 'E', 'v', 'e', 'n', 't', 's', 0,
    'a', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'S', 'e', 'n', 's', 'o', 'r', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 't', 'u', 'r', 'n', 'G', 'e', 'o', 'V', 'a', 'l', 'u', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'x', 'e', 's', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'E', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'u', 's', 'e', 'r', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'A', 'c', 'c', 'e', 'l', 'e', 'r', 'o', 'm', 'e', 't', 'e', 'r', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'S', 'e', 'n', 's', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', '*', '>', 0,
    'r', 'e', 't', 'u', 'r', 'n', 'D', 'o', 'u', 'b', 'l', 'e', 'T', 'a', 'p', 'E', 'v', 'e', 'n', 't', 's', 0,
    's', 'e', 't', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'k', 'i', 'p', 'D', 'u', 'p', 'l', 'i', 'c', 'a', 't', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'A', 'u', 't', 'o', 'm', 'a', 't', 'i', 'c', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'A', 'c', 'c', 'e', 'l', 'e', 'r', 'o', 'm', 'e', 't', 'e', 'r', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'A', 'm', 'b', 'i', 'e', 'n', 't', 'L', 'i', 'g', 'h', 't', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'Q', 'M', 'a', 'g', 'n', 'e', 't', 'o', 'm', 'e', 't', 'e', 'r', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'S', 'e', 'n', 's', 'o', 'r', 'F', 'o', 'r', 'T', 'y', 'p', 'e', 0,
    'i', 's', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', 'T', 'o', 'B', 'a', 'c', 'k', 'e', 'n', 'd', 0,
    'm', 'a', 'x', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'A', 'm', 'b', 'i', 'e', 'n', 't', 'L', 'i', 'g', 'h', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'A', 'm', 'b', 'i', 'e', 'n', 't', 'L', 'i', 'g', 'h', 't', 'S', 'e', 'n', 's', 'o', 'r', 0,
    'Q', 'I', 'R', 'P', 'r', 'o', 'x', 'i', 'm', 'i', 't', 'y', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'Q', 'L', 'i', 's', 't', '<', 'q', 'o', 'u', 't', 'p', 'u', 't', 'r', 'a', 'n', 'g', 'e', '>', 0,
    'Q', 'M', 'a', 'g', 'n', 'e', 't', 'o', 'm', 'e', 't', 'e', 'r', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'a', 'x', 'e', 's', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'e', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'A', 'b', 's', 'o', 'l', 'u', 't', 'e', 'H', 'u', 'm', 'i', 'd', 'i', 't', 'y', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'C', 'a', 'l', 'i', 'b', 'r', 'a', 't', 'i', 'o', 'n', 'L', 'e', 'v', 'e', 'l', 0,
    's', 'e', 't', 'R', 'e', 'l', 'a', 't', 'i', 'v', 'e', 'H', 'u', 'm', 'i', 'd', 'i', 't', 'y', 0,
    'Q', 'I', 'R', 'P', 'r', 'o', 'x', 'i', 'm', 'i', 't', 'y', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'I', 'R', 'P', 'r', 'o', 'x', 'i', 'm', 'i', 't', 'y', 'S', 'e', 'n', 's', 'o', 'r', 0,
    'Q', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'S', 'e', 'n', 's', 'o', 'r', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'D', 'a', 't', 'a', 'R', 'a', 't', 'e', 's', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'f', 'i', 'e', 'l', 'd', 'O', 'f', 'V', 'i', 'e', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    's', 'e', 't', 'R', 'e', 't', 'u', 'r', 'n', 'G', 'e', 'o', 'V', 'a', 'l', 'u', 'e', 's', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'A', 'l', 't', 'i', 'm', 'e', 't', 'e', 'r', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'Q', 'G', 'y', 'r', 'o', 's', 'c', 'o', 'p', 'e', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'Q', 'P', 'r', 'o', 'x', 'i', 'm', 'i', 't', 'y', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'F', 'r', 'o', 'n', 't', 'L', 'i', 'd', 'C', 'l', 'o', 's', 'e', 'd', 0,
    's', 'e', 't', 'S', 'k', 'i', 'p', 'D', 'u', 'p', 'l', 'i', 'c', 'a', 't', 'e', 's', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    'F', 'i', 'x', 'e', 'd', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'A', 'l', 't', 'i', 'm', 'e', 't', 'e', 'r', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'Q', 'G', 'y', 'r', 'o', 's', 'c', 'o', 'p', 'e', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'H', 'u', 'm', 'i', 'd', 'i', 't', 'y', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'Q', 'P', 'r', 'e', 's', 's', 'u', 'r', 'e', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'Q', 'P', 'r', 'o', 'x', 'i', 'm', 'i', 't', 'y', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'P', 'r', 'o', 'x', 'i', 'm', 'i', 't', 'y', 'S', 'e', 'n', 's', 'o', 'r', 0,
    'Q', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'Q', 'S', 'e', 'n', 's', 'o', 'r', ':', ':', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'a', 'b', 's', 'o', 'l', 'u', 't', 'e', 'H', 'u', 'm', 'i', 'd', 'i', 't', 'y', 0,
    'a', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'c', 'a', 'l', 'i', 'b', 'r', 'a', 't', 'i', 'o', 'n', 'L', 'e', 'v', 'e', 'l', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'T', 'o', 'B', 'a', 'c', 'k', 'e', 'n', 'd', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'r', 'e', 'l', 'a', 't', 'i', 'v', 'e', 'H', 'u', 'm', 'i', 'd', 'i', 't', 'y', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'L', 'i', 'd', 'C', 'l', 'o', 's', 'e', 'd', 0,
    's', 'e', 't', 'M', 'a', 'x', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'A', 'x', 'e', 's', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', 'S', 'e', 'n', 's', 'o', 'r', 's', 0,
    'Q', 'C', 'o', 'm', 'p', 'a', 's', 's', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'Q', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 'S', 'e', 'n', 's', 'o', 'r', 0,
    'Q', 'H', 'o', 'l', 's', 't', 'e', 'r', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'Q', 'H', 'u', 'm', 'i', 'd', 'i', 't', 'y', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'H', 'u', 'm', 'i', 'd', 'i', 't', 'y', 'S', 'e', 'n', 's', 'o', 'r', 0,
    'Q', 'P', 'r', 'e', 's', 's', 'u', 'r', 'e', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'P', 'r', 'e', 's', 's', 'u', 'r', 'e', 'S', 'e', 'n', 's', 'o', 'r', 0,
    'Q', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'S', 'e', 'n', 's', 'o', 'r', 0,
    'a', 'l', 'w', 'a', 'y', 's', 'O', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'a', 't', 'a', 'R', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'r', 'o', 'n', 't', 'L', 'i', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 't', 'u', 'r', 'n', 'G', 'e', 'o', 'V', 'a', 'l', 'u', 'e', 's', 0,
    's', 'e', 't', 'T', 'a', 'p', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'u', 's', 'e', 'r', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'A', 'c', 'c', 'e', 'l', 'e', 'r', 'o', 'm', 'e', 't', 'e', 'r', 0,
    'Q', 'C', 'o', 'm', 'p', 'a', 's', 's', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'H', 'o', 'l', 's', 't', 'e', 'r', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'H', 'o', 'l', 's', 't', 'e', 'r', 'S', 'e', 'n', 's', 'o', 'r', 0,
    'Q', 'S', 'e', 'n', 's', 'o', 'r', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'b', 'a', 'c', 'k', 'L', 'i', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'r', 'o', 'n', 't', 'L', 'i', 'd', 'C', 'l', 'o', 's', 'e', 'd', 0,
    'r', 'e', 'a', 'd', 'i', 'n', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'n', 's', 'o', 'r', 's', 'F', 'o', 'r', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'F', 'i', 'e', 'l', 'd', 'O', 'f', 'V', 'i', 'e', 'w', 0,
    's', 'e', 't', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'O', 'u', 't', 'p', 'u', 't', 'R', 'a', 'n', 'g', 'e', 0,
    's', 'e', 't', 'R', 'e', 'f', 'l', 'e', 'c', 't', 'a', 'n', 'c', 'e', 0,
    's', 'e', 't', 'T', 'e', 'm', 'p', 'e', 'r', 'a', 't', 'u', 'r', 'e', 0,
    's', 'k', 'i', 'p', 'D', 'u', 'p', 'l', 'i', 'c', 'a', 't', 'e', 's', 0,
    'Q', 'L', 'i', 'g', 'h', 't', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'Q', 'M', 'a', 'g', 'n', 'e', 't', 'o', 'm', 'e', 't', 'e', 'r', 0,
    'Q', 'S', 'e', 'n', 's', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'a', 'c', 'k', 'L', 'i', 'd', 'C', 'l', 'o', 's', 'e', 'd', 0,
    'm', 'a', 'x', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    's', 'e', 't', 'L', 'i', 'g', 'h', 't', 'L', 'e', 'v', 'e', 'l', 0,
    'Q', 'L', 'i', 'g', 'h', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'L', 'i', 'g', 'h', 't', 'S', 'e', 'n', 's', 'o', 'r', 0,
    'Q', 'T', 'i', 'l', 't', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'o', 'u', 't', 'p', 'u', 't', 'R', 'a', 'n', 'g', 'e', 's', 0,
    'q', 'o', 'u', 't', 'p', 'u', 't', 'r', 'a', 'n', 'g', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'F', 'i', 'l', 't', 'e', 'r', 0,
    's', 'e', 't', 'D', 'o', 'u', 'b', 'l', 'e', 'T', 'a', 'p', 0,
    's', 'e', 't', 'F', 'r', 'o', 'm', 'E', 'u', 'l', 'e', 'r', 0,
    's', 'e', 't', 'H', 'o', 'l', 's', 't', 'e', 'r', 'e', 'd', 0,
    's', 'e', 't', 'T', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 0,
    's', 'e', 't', 'X', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'Y', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    't', 'a', 'p', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'L', 'i', 'd', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'Q', 'T', 'a', 'p', 'R', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    'Q', 'T', 'i', 'l', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'T', 'i', 'l', 't', 'S', 'e', 'n', 's', 'o', 'r', 0,
    'b', 'u', 's', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'f', 'i', 'e', 'l', 'd', 'O', 'f', 'V', 'i', 'e', 'w', 0,
    'h', 'a', 's', 'Z', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'D', 'o', 'u', 'b', 'l', 'e', 'T', 'a', 'p', 0,
    'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'o', 'u', 't', 'p', 'u', 't', 'R', 'a', 'n', 'g', 'e', 0,
    'r', 'e', 'f', 'l', 'e', 'c', 't', 'a', 'n', 'c', 'e', 0,
    's', 'e', 'n', 's', 'o', 'r', 'E', 'r', 'r', 'o', 'r', 0,
    's', 'e', 'n', 's', 'o', 'r', 'T', 'y', 'p', 'e', 's', 0,
    's', 'e', 't', 'A', 'l', 't', 'i', 't', 'u', 'd', 'e', 0,
    's', 'e', 't', 'A', 'l', 'w', 'a', 'y', 's', 'O', 'n', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 'R', 'a', 't', 'e', 0,
    's', 'e', 't', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    's', 'e', 't', 'P', 'r', 'e', 's', 's', 'u', 'r', 'e', 0,
    't', 'e', 'm', 'p', 'e', 'r', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'A', 'l', 't', 'i', 'm', 'e', 't', 'e', 'r', 0,
    'Q', 'G', 'y', 'r', 'o', 's', 'c', 'o', 'p', 'e', 0,
    'Q', 'L', 'i', 'd', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'L', 'i', 'd', 'S', 'e', 'n', 's', 'o', 'r', 0,
    'Q', 'T', 'a', 'p', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'T', 'a', 'p', 'S', 'e', 'n', 's', 'o', 'r', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'i', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    'i', 's', 'A', 'l', 'w', 'a', 'y', 's', 'O', 'n', 0,
    'l', 'i', 'g', 'h', 't', 'L', 'e', 'v', 'e', 'l', 0,
    's', 'e', 't', 'A', 'z', 'i', 'm', 'u', 't', 'h', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'v', 'a', 'l', 'u', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'B', 'u', 'f', 'f', 'e', 'r', 'i', 'n', 'g', 0,
    'U', 'n', 'd', 'e', 'f', 'i', 'n', 'e', 'd', 0,
    'a', 'd', 'd', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'c', 'a', 'l', 'i', 'b', 'r', 'a', 't', 'e', 0,
    'h', 'o', 'l', 's', 't', 'e', 'r', 'e', 'd', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 0,
    't', 'i', 'm', 'e', 's', 't', 'a', 'm', 'p', 0,
    'x', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'y', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'C', 'o', 'm', 'b', 'i', 'n', 'e', 'd', 0,
    'F', 'a', 'c', 'e', 'D', 'o', 'w', 'n', 0,
    'Q', 'C', 'o', 'm', 'p', 'a', 's', 's', 0,
    'T', 'w', 'i', 'l', 'i', 'g', 'h', 't', 0,
    'a', 'c', 'c', 'u', 'r', 'a', 'c', 'y', 0,
    'a', 'l', 't', 'i', 't', 'u', 'd', 'e', 0,
    'd', 'a', 't', 'a', 'R', 'a', 't', 'e', 0,
    'd', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    'i', 's', 'A', 'c', 't', 'i', 'v', 'e', 0,
    'p', 'r', 'e', 's', 's', 'u', 'r', 'e', 0,
    's', 'e', 't', 'C', 'l', 'o', 's', 'e', 0,
    'G', 'r', 'a', 'v', 'i', 't', 'y', 0,
    'Q', 'S', 'e', 'n', 's', 'o', 'r', 0,
    'R', 'i', 'g', 'h', 't', 'U', 'p', 0,
    'T', 'o', 'p', 'D', 'o', 'w', 'n', 0,
    'a', 'z', 'i', 'm', 'u', 't', 'h', 0,
    'f', 'i', 'l', 't', 'e', 'r', 's', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 0,
    'r', 'e', 'a', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'H', 'a', 's', 'Z', 0,
    'B', 'r', 'i', 'g', 'h', 't', 0,
    'F', 'a', 'c', 'e', 'U', 'p', 0,
    'L', 'e', 'f', 't', 'U', 'p', 0,
    'X', '_', 'B', 'o', 't', 'h', 0,
    'Y', '_', 'B', 'o', 't', 'h', 0,
    'Z', '_', 'B', 'o', 't', 'h', 0,
    'f', 'i', 'l', 't', 'e', 'r', 0,
    'i', 's', 'B', 'u', 's', 'y', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    's', 'e', 't', 'L', 'u', 'x', 0,
    'L', 'i', 'g', 'h', 't', 0,
    'S', 'u', 'n', 'n', 'y', 0,
    'T', 'o', 'p', 'U', 'p', 0,
    'X', '_', 'N', 'e', 'g', 0,
    'X', '_', 'P', 'o', 's', 0,
    'Y', '_', 'N', 'e', 'g', 0,
    'Y', '_', 'P', 'o', 's', 0,
    'Z', '_', 'N', 'e', 'g', 0,
    'Z', '_', 'P', 'o', 's', 0,
    'c', 'l', 'o', 's', 'e', 0,
    'e', 'r', 'r', 'o', 'r', 0,
    'e', 'v', 'e', 'n', 't', 0,
    's', 't', 'a', 'r', 't', 0,
    'v', 'a', 'l', 'u', 'e', 0,
    'D', 'a', 'r', 'k', 0,
    'U', 's', 'e', 'r', 0,
    'h', 'a', 's', 'Z', 0,
    's', 'e', 't', 'X', 0,
    's', 'e', 't', 'Y', 0,
    's', 'e', 't', 'Z', 0,
    's', 't', 'o', 'p', 0,
    't', 'y', 'p', 'e', 0,
    'l', 'u', 'x', 0,
    'z', 0,
};

bool sipVH_QtSensors_25(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QRotationReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QRotationReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_24(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTiltReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QTiltReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_23(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTapReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QTapReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_22(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QProximityReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QProximityReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPressureReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QPressureReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QOrientationReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QOrientationReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMagnetometerReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QMagnetometerReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QLightReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QLightReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QLidReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QLidReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QIRProximityReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QIRProximityReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QHumidityReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QHumidityReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QHolsterReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QHolsterReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QGyroscopeReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QGyroscopeReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDistanceReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QDistanceReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCompassReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QCompassReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QAmbientTemperatureReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QAmbientTemperatureReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QAmbientLightReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QAmbientLightReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QAltimeterReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QAltimeterReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QAccelerometerReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QAccelerometerReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QSensorReading*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QSensorReading, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSensors_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtSensors_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtSensors_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtSensors_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtSensors_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QSensor(void **);}
static const sipTypeDef *sipSubClass_QSensor(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 89 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qsensor.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
        {sipName_QSensor, &sipType_QSensor, 2, 1},
        {sipName_QSensorReading, &sipType_QSensorReading, 21, -1},
        {sipName_QAccelerometer, &sipType_QAccelerometer, -1, 3},
        {sipName_QAltimeter, &sipType_QAltimeter, -1, 4},
        {sipName_QAmbientLightSensor, &sipType_QAmbientLightSensor, -1, 5},
        {sipName_QAmbientTemperatureSensor, &sipType_QAmbientTemperatureSensor, -1, 6},
        {sipName_QCompass, &sipType_QCompass, -1, 7},
    #if QT_VERSION >= 0x050400
        {sipName_QDistanceSensor, &sipType_QDistanceSensor, -1, 8},
    #else
        {0, 0, -1, 8},
    #endif
        {sipName_QGyroscope, &sipType_QGyroscope, -1, 9},
        {sipName_QHolsterSensor, &sipType_QHolsterSensor, -1, 10},
    #if QT_VERSION >= 0x050900
        {sipName_QHumiditySensor, &sipType_QHumiditySensor, -1, 11},
    #else
        {0, 0, -1, 11},
    #endif
        {sipName_QIRProximitySensor, &sipType_QIRProximitySensor, -1, 12},
    #if QT_VERSION >= 0x050900
        {sipName_QLidSensor, &sipType_QLidSensor, -1, 13},
    #else
        {0, 0, -1, 13},
    #endif
        {sipName_QLightSensor, &sipType_QLightSensor, -1, 14},
        {sipName_QMagnetometer, &sipType_QMagnetometer, -1, 15},
        {sipName_QOrientationSensor, &sipType_QOrientationSensor, -1, 16},
        {sipName_QPressureSensor, &sipType_QPressureSensor, -1, 17},
        {sipName_QProximitySensor, &sipType_QProximitySensor, -1, 18},
        {sipName_QRotationSensor, &sipType_QRotationSensor, -1, 19},
        {sipName_QTapSensor, &sipType_QTapSensor, -1, 20},
        {sipName_QTiltSensor, &sipType_QTiltSensor, -1, -1},
        {sipName_QAccelerometerReading, &sipType_QAccelerometerReading, -1, 22},
        {sipName_QAltimeterReading, &sipType_QAltimeterReading, -1, 23},
        {sipName_QAmbientLightReading, &sipType_QAmbientLightReading, -1, 24},
        {sipName_QAmbientTemperatureReading, &sipType_QAmbientTemperatureReading, -1, 25},
        {sipName_QCompassReading, &sipType_QCompassReading, -1, 26},
    #if QT_VERSION >= 0x050400
        {sipName_QDistanceReading, &sipType_QDistanceReading, -1, 27},
    #else
        {0, 0, -1, 27},
    #endif
        {sipName_QGyroscopeReading, &sipType_QGyroscopeReading, -1, 28},
        {sipName_QHolsterReading, &sipType_QHolsterReading, -1, 29},
    #if QT_VERSION >= 0x050900
        {sipName_QHumidityReading, &sipType_QHumidityReading, -1, 30},
    #else
        {0, 0, -1, 30},
    #endif
        {sipName_QIRProximityReading, &sipType_QIRProximityReading, -1, 31},
    #if QT_VERSION >= 0x050900
        {sipName_QLidReading, &sipType_QLidReading, -1, 32},
    #else
        {0, 0, -1, 32},
    #endif
        {sipName_QLightReading, &sipType_QLightReading, -1, 33},
        {sipName_QMagnetometerReading, &sipType_QMagnetometerReading, -1, 34},
        {sipName_QOrientationReading, &sipType_QOrientationReading, -1, 35},
        {sipName_QPressureReading, &sipType_QPressureReading, -1, 36},
        {sipName_QProximityReading, &sipType_QProximityReading, -1, 37},
        {sipName_QRotationReading, &sipType_QRotationReading, -1, 38},
        {sipName_QTapReading, &sipType_QTapReading, -1, 39},
        {sipName_QTiltReading, &sipType_QTiltReading, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 738 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorscmodule.cpp"

    return sipType;
}
static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAccelerometer__AccelerationMode, SIP_NULLPTR, 0}, sipNameNr_AccelerationMode, 0, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAmbientLightReading__LightLevel, SIP_NULLPTR, 0}, sipNameNr_LightLevel, 8, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QOrientationReading__Orientation, SIP_NULLPTR, 0}, sipNameNr_Orientation, 44, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSensor__AxesOrientationMode, SIP_NULLPTR, 0}, sipNameNr_AxesOrientationMode, 56, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSensor__Feature, SIP_NULLPTR, 0}, sipNameNr_Feature, 56, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QTapReading__TapDirection, SIP_NULLPTR, 0}, sipNameNr_TapDirection, 62, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtSensors[] = {
    &sipTypeDef_QtSensors_QAccelerometer.ctd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_QtSensors_QAccelerometerFilter.ctd_base,
    &sipTypeDef_QtSensors_QAccelerometerReading.ctd_base,
    &sipTypeDef_QtSensors_QAltimeter.ctd_base,
    &sipTypeDef_QtSensors_QAltimeterFilter.ctd_base,
    &sipTypeDef_QtSensors_QAltimeterReading.ctd_base,
    &sipTypeDef_QtSensors_QAmbientLightFilter.ctd_base,
    &sipTypeDef_QtSensors_QAmbientLightReading.ctd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_QtSensors_QAmbientLightSensor.ctd_base,
    &sipTypeDef_QtSensors_QAmbientTemperatureFilter.ctd_base,
    &sipTypeDef_QtSensors_QAmbientTemperatureReading.ctd_base,
    &sipTypeDef_QtSensors_QAmbientTemperatureSensor.ctd_base,
    &sipTypeDef_QtSensors_QCompass.ctd_base,
    &sipTypeDef_QtSensors_QCompassFilter.ctd_base,
    &sipTypeDef_QtSensors_QCompassReading.ctd_base,
    &sipTypeDef_QtSensors_QDistanceFilter.ctd_base,
    &sipTypeDef_QtSensors_QDistanceReading.ctd_base,
    &sipTypeDef_QtSensors_QDistanceSensor.ctd_base,
    &sipTypeDef_QtSensors_QGyroscope.ctd_base,
    &sipTypeDef_QtSensors_QGyroscopeFilter.ctd_base,
    &sipTypeDef_QtSensors_QGyroscopeReading.ctd_base,
    &sipTypeDef_QtSensors_QHolsterFilter.ctd_base,
    &sipTypeDef_QtSensors_QHolsterReading.ctd_base,
    &sipTypeDef_QtSensors_QHolsterSensor.ctd_base,
    &sipTypeDef_QtSensors_QHumidityFilter.ctd_base,
    &sipTypeDef_QtSensors_QHumidityReading.ctd_base,
    &sipTypeDef_QtSensors_QHumiditySensor.ctd_base,
    &sipTypeDef_QtSensors_QIRProximityFilter.ctd_base,
    &sipTypeDef_QtSensors_QIRProximityReading.ctd_base,
    &sipTypeDef_QtSensors_QIRProximitySensor.ctd_base,
    &sipTypeDef_QtSensors_QLidFilter.ctd_base,
    &sipTypeDef_QtSensors_QLidReading.ctd_base,
    &sipTypeDef_QtSensors_QLidSensor.ctd_base,
    &sipTypeDef_QtSensors_QLightFilter.ctd_base,
    &sipTypeDef_QtSensors_QLightReading.ctd_base,
    &sipTypeDef_QtSensors_QLightSensor.ctd_base,
    &sipTypeDef_QtSensors_QList_0101QSensorFilter.mtd_base,
    &sipTypeDef_QtSensors_QList_0100qoutputrange.mtd_base,
    &sipTypeDef_QtSensors_QMagnetometer.ctd_base,
    &sipTypeDef_QtSensors_QMagnetometerFilter.ctd_base,
    &sipTypeDef_QtSensors_QMagnetometerReading.ctd_base,
    &sipTypeDef_QtSensors_QOrientationFilter.ctd_base,
    &sipTypeDef_QtSensors_QOrientationReading.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_QtSensors_QOrientationSensor.ctd_base,
    &sipTypeDef_QtSensors_QPressureFilter.ctd_base,
    &sipTypeDef_QtSensors_QPressureReading.ctd_base,
    &sipTypeDef_QtSensors_QPressureSensor.ctd_base,
    &sipTypeDef_QtSensors_QProximityFilter.ctd_base,
    &sipTypeDef_QtSensors_QProximityReading.ctd_base,
    &sipTypeDef_QtSensors_QProximitySensor.ctd_base,
    &sipTypeDef_QtSensors_QRotationFilter.ctd_base,
    &sipTypeDef_QtSensors_QRotationReading.ctd_base,
    &sipTypeDef_QtSensors_QRotationSensor.ctd_base,
    &sipTypeDef_QtSensors_QSensor.ctd_base,
    &enumTypes[3].etd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_QtSensors_QSensorFilter.ctd_base,
    &sipTypeDef_QtSensors_QSensorReading.ctd_base,
    &sipTypeDef_QtSensors_QTapFilter.ctd_base,
    &sipTypeDef_QtSensors_QTapReading.ctd_base,
    &enumTypes[5].etd_base,
    &sipTypeDef_QtSensors_QTapSensor.ctd_base,
    &sipTypeDef_QtSensors_QTiltFilter.ctd_base,
    &sipTypeDef_QtSensors_QTiltReading.ctd_base,
    &sipTypeDef_QtSensors_QTiltSensor.ctd_base,
    &sipTypeDef_QtSensors_qoutputrange.ctd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"qoutputrangelist", "QList<qoutputrange>"},
    {"qrangelist", "QList<QPair<int, int>>"},
    {"qtimestamp", "unsigned long long"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtSensors_QtCore[] = {
    {"QByteArray"},
    {"QChildEvent"},
    {"QEvent"},
    {"QList<QByteArray>"},
    {"QList<QPair<int,int> >"},
    {"QMetaMethod"},
    {"QObject"},
    {"QString"},
    {"QTimerEvent"},
    {"QVariant"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtSensors_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_QtSensors_QtCore, sipImportedVirtErrorHandlers_QtSensors_QtCore, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QSensor, {6, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtSensors = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_QtSensors,
    0,
    sipStrings_QtSensors,
    importsTable,
    SIP_NULLPTR,
    69,
    sipExportedTypes_QtSensors,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    3,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtSensors;

sip_qt_metaobject_func sip_QtSensors_qt_metaobject;
sip_qt_metacall_func sip_QtSensors_qt_metacall;
sip_qt_metacast_func sip_QtSensors_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtSensors()
#else
PyMODINIT_FUNC PyInit_QtSensors()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.QtSensors",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtSensors = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_QtSensors == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtSensors, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtSensors_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtSensors_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtSensors_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtSensors_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtSensors, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    return sipModule;
}
