/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKitWidgets.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 307 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPageChooseMultipleFilesExtensionReturn.cpp"

#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 35 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPageChooseMultipleFilesExtensionReturn.cpp"


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QWebPage_ChooseMultipleFilesExtensionReturn(void *, const sipTypeDef *);}
static void *cast_QWebPage_ChooseMultipleFilesExtensionReturn(void *sipCppV, const sipTypeDef *targetType)
{
    ::QWebPage::ChooseMultipleFilesExtensionReturn *sipCpp = reinterpret_cast< ::QWebPage::ChooseMultipleFilesExtensionReturn *>(sipCppV);

    if (targetType == sipType_QWebPage_ChooseMultipleFilesExtensionReturn)
        return sipCppV;

    if (targetType == sipType_QWebPage_ExtensionReturn)
        return static_cast< ::QWebPage::ExtensionReturn *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebPage_ChooseMultipleFilesExtensionReturn(void *, int);}
static void release_QWebPage_ChooseMultipleFilesExtensionReturn(void *sipCppV, int)
{
    delete reinterpret_cast< ::QWebPage::ChooseMultipleFilesExtensionReturn *>(sipCppV);
}


extern "C" {static void *array_QWebPage_ChooseMultipleFilesExtensionReturn(Py_ssize_t);}
static void *array_QWebPage_ChooseMultipleFilesExtensionReturn(Py_ssize_t sipNrElem)
{
    return new ::QWebPage::ChooseMultipleFilesExtensionReturn[sipNrElem];
}


extern "C" {static void array_delete_QWebPage_ChooseMultipleFilesExtensionReturn(void *);}
static void array_delete_QWebPage_ChooseMultipleFilesExtensionReturn(void *sipCpp)
{
    delete[] reinterpret_cast< ::QWebPage::ChooseMultipleFilesExtensionReturn *>(sipCpp);
}


extern "C" {static void assign_QWebPage_ChooseMultipleFilesExtensionReturn(void *, Py_ssize_t, void *);}
static void assign_QWebPage_ChooseMultipleFilesExtensionReturn(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QWebPage::ChooseMultipleFilesExtensionReturn *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QWebPage::ChooseMultipleFilesExtensionReturn *>(sipSrc);
}


extern "C" {static void *copy_QWebPage_ChooseMultipleFilesExtensionReturn(const void *, Py_ssize_t);}
static void *copy_QWebPage_ChooseMultipleFilesExtensionReturn(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QWebPage::ChooseMultipleFilesExtensionReturn(reinterpret_cast<const ::QWebPage::ChooseMultipleFilesExtensionReturn *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QWebPage_ChooseMultipleFilesExtensionReturn(sipSimpleWrapper *);}
static void dealloc_QWebPage_ChooseMultipleFilesExtensionReturn(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWebPage_ChooseMultipleFilesExtensionReturn(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QWebPage_ChooseMultipleFilesExtensionReturn(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWebPage_ChooseMultipleFilesExtensionReturn(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QWebPage::ChooseMultipleFilesExtensionReturn *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QWebPage::ChooseMultipleFilesExtensionReturn();

            return sipCpp;
        }
    }

    {
        const ::QWebPage::ChooseMultipleFilesExtensionReturn* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QWebPage_ChooseMultipleFilesExtensionReturn, &a0))
        {
            sipCpp = new ::QWebPage::ChooseMultipleFilesExtensionReturn(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QWebPage_ChooseMultipleFilesExtensionReturn[] = {{17, 255, 1}};


extern "C" {static PyObject *varget_QWebPage_ChooseMultipleFilesExtensionReturn_fileNames(void *, PyObject *, PyObject *);}
static PyObject *varget_QWebPage_ChooseMultipleFilesExtensionReturn_fileNames(void *sipSelf, PyObject *, PyObject *)
{
    ::QStringList*sipVal;
    ::QWebPage::ChooseMultipleFilesExtensionReturn *sipCpp = reinterpret_cast< ::QWebPage::ChooseMultipleFilesExtensionReturn *>(sipSelf);

    sipVal = &sipCpp->fileNames;

    return sipConvertFromType(sipVal, sipType_QStringList, SIP_NULLPTR);
}


extern "C" {static int varset_QWebPage_ChooseMultipleFilesExtensionReturn_fileNames(void *, PyObject *, PyObject *);}
static int varset_QWebPage_ChooseMultipleFilesExtensionReturn_fileNames(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QStringList*sipVal;
    ::QWebPage::ChooseMultipleFilesExtensionReturn *sipCpp = reinterpret_cast< ::QWebPage::ChooseMultipleFilesExtensionReturn *>(sipSelf);

    int sipIsErr = 0;
    int sipValState;
    sipVal = reinterpret_cast< ::QStringList *>(sipForceConvertToType(sipPy, sipType_QStringList, SIP_NULLPTR, SIP_NOT_NONE, &sipValState, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->fileNames = *sipVal;

    sipReleaseType(sipVal, sipType_QStringList, sipValState);

    return 0;
}

sipVariableDef variables_QWebPage_ChooseMultipleFilesExtensionReturn[] = {
    {InstanceVariable, sipName_fileNames, (PyMethodDef *)varget_QWebPage_ChooseMultipleFilesExtensionReturn_fileNames, (PyMethodDef *)varset_QWebPage_ChooseMultipleFilesExtensionReturn_fileNames, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QWebPage_ChooseMultipleFilesExtensionReturn, "\1QWebPage.ChooseMultipleFilesExtensionReturn()\n"
"QWebPage.ChooseMultipleFilesExtensionReturn(a0: QWebPage.ChooseMultipleFilesExtensionReturn)");


static pyqt5ClassPluginDef plugin_QWebPage_ChooseMultipleFilesExtensionReturn = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebPage_ChooseMultipleFilesExtensionReturn = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebPage__ChooseMultipleFilesExtensionReturn,
        SIP_NULLPTR,
        &plugin_QWebPage_ChooseMultipleFilesExtensionReturn,
    },
    {
        sipNameNr_ChooseMultipleFilesExtensionReturn,
        {9, 255, 0},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        1, variables_QWebPage_ChooseMultipleFilesExtensionReturn,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWebPage_ChooseMultipleFilesExtensionReturn,
    -1,
    -1,
    supers_QWebPage_ChooseMultipleFilesExtensionReturn,
    SIP_NULLPTR,
    init_type_QWebPage_ChooseMultipleFilesExtensionReturn,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWebPage_ChooseMultipleFilesExtensionReturn,
    assign_QWebPage_ChooseMultipleFilesExtensionReturn,
    array_QWebPage_ChooseMultipleFilesExtensionReturn,
    copy_QWebPage_ChooseMultipleFilesExtensionReturn,
    release_QWebPage_ChooseMultipleFilesExtensionReturn,
    cast_QWebPage_ChooseMultipleFilesExtensionReturn,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QWebPage_ChooseMultipleFilesExtensionReturn,
    sizeof (::QWebPage::ChooseMultipleFilesExtensionReturn),
};
