/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecontentrequest.sip"
#include <qplacecontentrequest.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceContentRequest.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceContentRequest.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceContentRequest.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecontent.sip"
#include <qplacecontent.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceContentRequest.cpp"


PyDoc_STRVAR(doc_QPlaceContentRequest_contentType, "contentType(self) -> QPlaceContent.Type");

extern "C" {static PyObject *meth_QPlaceContentRequest_contentType(PyObject *, PyObject *);}
static PyObject *meth_QPlaceContentRequest_contentType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceContentRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceContentRequest, &sipCpp))
        {
            ::QPlaceContent::Type sipRes;

            sipRes = sipCpp->contentType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPlaceContent_Type);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceContentRequest, sipName_contentType, doc_QPlaceContentRequest_contentType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceContentRequest_setContentType, "setContentType(self, type: QPlaceContent.Type)");

extern "C" {static PyObject *meth_QPlaceContentRequest_setContentType(PyObject *, PyObject *);}
static PyObject *meth_QPlaceContentRequest_setContentType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPlaceContent::Type a0;
        ::QPlaceContentRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QPlaceContentRequest, &sipCpp, sipType_QPlaceContent_Type, &a0))
        {
            sipCpp->setContentType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceContentRequest, sipName_setContentType, doc_QPlaceContentRequest_setContentType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceContentRequest_placeId, "placeId(self) -> str");

extern "C" {static PyObject *meth_QPlaceContentRequest_placeId(PyObject *, PyObject *);}
static PyObject *meth_QPlaceContentRequest_placeId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceContentRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceContentRequest, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->placeId());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceContentRequest, sipName_placeId, doc_QPlaceContentRequest_placeId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceContentRequest_setPlaceId, "setPlaceId(self, identifier: Optional[str])");

extern "C" {static PyObject *meth_QPlaceContentRequest_setPlaceId(PyObject *, PyObject *);}
static PyObject *meth_QPlaceContentRequest_setPlaceId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceContentRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceContentRequest, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setPlaceId(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceContentRequest, sipName_setPlaceId, doc_QPlaceContentRequest_setPlaceId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceContentRequest_contentContext, "contentContext(self) -> Any");

extern "C" {static PyObject *meth_QPlaceContentRequest_contentContext(PyObject *, PyObject *);}
static PyObject *meth_QPlaceContentRequest_contentContext(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceContentRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceContentRequest, &sipCpp))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->contentContext());

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceContentRequest, sipName_contentContext, doc_QPlaceContentRequest_contentContext);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceContentRequest_setContentContext, "setContentContext(self, context: Any)");

extern "C" {static PyObject *meth_QPlaceContentRequest_setContentContext(PyObject *, PyObject *);}
static PyObject *meth_QPlaceContentRequest_setContentContext(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariant* a0;
        int a0State = 0;
        ::QPlaceContentRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceContentRequest, &sipCpp, sipType_QVariant, &a0, &a0State))
        {
            sipCpp->setContentContext(*a0);
            sipReleaseType(const_cast< ::QVariant *>(a0), sipType_QVariant, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceContentRequest, sipName_setContentContext, doc_QPlaceContentRequest_setContentContext);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceContentRequest_limit, "limit(self) -> int");

extern "C" {static PyObject *meth_QPlaceContentRequest_limit(PyObject *, PyObject *);}
static PyObject *meth_QPlaceContentRequest_limit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceContentRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceContentRequest, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->limit();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceContentRequest, sipName_limit, doc_QPlaceContentRequest_limit);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceContentRequest_setLimit, "setLimit(self, limit: int)");

extern "C" {static PyObject *meth_QPlaceContentRequest_setLimit(PyObject *, PyObject *);}
static PyObject *meth_QPlaceContentRequest_setLimit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QPlaceContentRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QPlaceContentRequest, &sipCpp, &a0))
        {
            sipCpp->setLimit(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceContentRequest, sipName_setLimit, doc_QPlaceContentRequest_setLimit);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceContentRequest_clear, "clear(self)");

extern "C" {static PyObject *meth_QPlaceContentRequest_clear(PyObject *, PyObject *);}
static PyObject *meth_QPlaceContentRequest_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPlaceContentRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceContentRequest, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceContentRequest, sipName_clear, doc_QPlaceContentRequest_clear);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QPlaceContentRequest___ne__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceContentRequest___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceContentRequest *sipCpp = reinterpret_cast< ::QPlaceContentRequest *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceContentRequest));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceContentRequest* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceContentRequest, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceContentRequest::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, ne_slot, sipType_QPlaceContentRequest, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QPlaceContentRequest___eq__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceContentRequest___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceContentRequest *sipCpp = reinterpret_cast< ::QPlaceContentRequest *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceContentRequest));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceContentRequest* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceContentRequest, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceContentRequest::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, eq_slot, sipType_QPlaceContentRequest, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QPlaceContentRequest(void *, int);}
static void release_QPlaceContentRequest(void *sipCppV, int)
{
    delete reinterpret_cast< ::QPlaceContentRequest *>(sipCppV);
}


extern "C" {static void *array_QPlaceContentRequest(Py_ssize_t);}
static void *array_QPlaceContentRequest(Py_ssize_t sipNrElem)
{
    return new ::QPlaceContentRequest[sipNrElem];
}


extern "C" {static void array_delete_QPlaceContentRequest(void *);}
static void array_delete_QPlaceContentRequest(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPlaceContentRequest *>(sipCpp);
}


extern "C" {static void assign_QPlaceContentRequest(void *, Py_ssize_t, void *);}
static void assign_QPlaceContentRequest(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPlaceContentRequest *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPlaceContentRequest *>(sipSrc);
}


extern "C" {static void *copy_QPlaceContentRequest(const void *, Py_ssize_t);}
static void *copy_QPlaceContentRequest(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPlaceContentRequest(reinterpret_cast<const ::QPlaceContentRequest *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPlaceContentRequest(sipSimpleWrapper *);}
static void dealloc_QPlaceContentRequest(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPlaceContentRequest(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QPlaceContentRequest(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPlaceContentRequest(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QPlaceContentRequest *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QPlaceContentRequest();

            return sipCpp;
        }
    }

    {
        const ::QPlaceContentRequest* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPlaceContentRequest, &a0))
        {
            sipCpp = new ::QPlaceContentRequest(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QPlaceContentRequest[] = {
    {(void *)slot_QPlaceContentRequest___ne__, ne_slot},
    {(void *)slot_QPlaceContentRequest___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QPlaceContentRequest[] = {
    {sipName_clear, meth_QPlaceContentRequest_clear, METH_VARARGS, doc_QPlaceContentRequest_clear},
    {sipName_contentContext, meth_QPlaceContentRequest_contentContext, METH_VARARGS, doc_QPlaceContentRequest_contentContext},
    {sipName_contentType, meth_QPlaceContentRequest_contentType, METH_VARARGS, doc_QPlaceContentRequest_contentType},
    {sipName_limit, meth_QPlaceContentRequest_limit, METH_VARARGS, doc_QPlaceContentRequest_limit},
    {sipName_placeId, meth_QPlaceContentRequest_placeId, METH_VARARGS, doc_QPlaceContentRequest_placeId},
    {sipName_setContentContext, meth_QPlaceContentRequest_setContentContext, METH_VARARGS, doc_QPlaceContentRequest_setContentContext},
    {sipName_setContentType, meth_QPlaceContentRequest_setContentType, METH_VARARGS, doc_QPlaceContentRequest_setContentType},
    {sipName_setLimit, meth_QPlaceContentRequest_setLimit, METH_VARARGS, doc_QPlaceContentRequest_setLimit},
    {sipName_setPlaceId, meth_QPlaceContentRequest_setPlaceId, METH_VARARGS, doc_QPlaceContentRequest_setPlaceId}
};

PyDoc_STRVAR(doc_QPlaceContentRequest, "\1QPlaceContentRequest()\n"
"QPlaceContentRequest(other: QPlaceContentRequest)");


static pyqt5ClassPluginDef plugin_QPlaceContentRequest = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QPlaceContentRequest = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPlaceContentRequest,
        SIP_NULLPTR,
        &plugin_QPlaceContentRequest,
    },
    {
        sipNameNr_QPlaceContentRequest,
        {0, 0, 1},
        9, methods_QPlaceContentRequest,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPlaceContentRequest,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QPlaceContentRequest,
    init_type_QPlaceContentRequest,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPlaceContentRequest,
    assign_QPlaceContentRequest,
    array_QPlaceContentRequest,
    copy_QPlaceContentRequest,
    release_QPlaceContentRequest,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPlaceContentRequest,
    sizeof (::QPlaceContentRequest),
};
