/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesearchresult.sip"
#include <qplacesearchresult.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceSearchResult.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceicon.sip"
#include <qplaceicon.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceSearchResult.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceSearchResult.cpp"


class sipQPlaceSearchResult : public ::QPlaceSearchResult
{
public:
    sipQPlaceSearchResult();
    sipQPlaceSearchResult(const ::QPlaceSearchResult&);
    ~sipQPlaceSearchResult();

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPlaceSearchResult(const sipQPlaceSearchResult &);
    sipQPlaceSearchResult &operator = (const sipQPlaceSearchResult &);
};

sipQPlaceSearchResult::sipQPlaceSearchResult(): ::QPlaceSearchResult(), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceSearchResult::sipQPlaceSearchResult(const ::QPlaceSearchResult& a0): ::QPlaceSearchResult(a0), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceSearchResult::~sipQPlaceSearchResult()
{
    sipInstanceDestroyedEx(&sipPySelf);
}


PyDoc_STRVAR(doc_QPlaceSearchResult_type, "type(self) -> QPlaceSearchResult.SearchResultType");

extern "C" {static PyObject *meth_QPlaceSearchResult_type(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchResult_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceSearchResult, &sipCpp))
        {
            ::QPlaceSearchResult::SearchResultType sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPlaceSearchResult_SearchResultType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchResult, sipName_type, doc_QPlaceSearchResult_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchResult_title, "title(self) -> str");

extern "C" {static PyObject *meth_QPlaceSearchResult_title(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchResult_title(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceSearchResult, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->title());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchResult, sipName_title, doc_QPlaceSearchResult_title);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchResult_setTitle, "setTitle(self, title: Optional[str])");

extern "C" {static PyObject *meth_QPlaceSearchResult_setTitle(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchResult_setTitle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceSearchResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceSearchResult, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTitle(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchResult, sipName_setTitle, doc_QPlaceSearchResult_setTitle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchResult_icon, "icon(self) -> QPlaceIcon");

extern "C" {static PyObject *meth_QPlaceSearchResult_icon(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchResult_icon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceSearchResult, &sipCpp))
        {
            ::QPlaceIcon*sipRes;

            sipRes = new ::QPlaceIcon(sipCpp->icon());

            return sipConvertFromNewType(sipRes, sipType_QPlaceIcon, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchResult, sipName_icon, doc_QPlaceSearchResult_icon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchResult_setIcon, "setIcon(self, icon: QPlaceIcon)");

extern "C" {static PyObject *meth_QPlaceSearchResult_setIcon(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchResult_setIcon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceIcon* a0;
        ::QPlaceSearchResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceSearchResult, &sipCpp, sipType_QPlaceIcon, &a0))
        {
            sipCpp->setIcon(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchResult, sipName_setIcon, doc_QPlaceSearchResult_setIcon);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QPlaceSearchResult___ne__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceSearchResult___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceSearchResult *sipCpp = reinterpret_cast< ::QPlaceSearchResult *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceSearchResult));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchResult* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceSearchResult, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceSearchResult::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, ne_slot, sipType_QPlaceSearchResult, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QPlaceSearchResult___eq__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceSearchResult___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceSearchResult *sipCpp = reinterpret_cast< ::QPlaceSearchResult *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceSearchResult));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchResult* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceSearchResult, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceSearchResult::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, eq_slot, sipType_QPlaceSearchResult, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QPlaceSearchResult(void *, int);}
static void release_QPlaceSearchResult(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQPlaceSearchResult *>(sipCppV);
    else
        delete reinterpret_cast< ::QPlaceSearchResult *>(sipCppV);
}


extern "C" {static void *array_QPlaceSearchResult(Py_ssize_t);}
static void *array_QPlaceSearchResult(Py_ssize_t sipNrElem)
{
    return new ::QPlaceSearchResult[sipNrElem];
}


extern "C" {static void array_delete_QPlaceSearchResult(void *);}
static void array_delete_QPlaceSearchResult(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPlaceSearchResult *>(sipCpp);
}


extern "C" {static void assign_QPlaceSearchResult(void *, Py_ssize_t, void *);}
static void assign_QPlaceSearchResult(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPlaceSearchResult *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPlaceSearchResult *>(sipSrc);
}


extern "C" {static void *copy_QPlaceSearchResult(const void *, Py_ssize_t);}
static void *copy_QPlaceSearchResult(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPlaceSearchResult(reinterpret_cast<const ::QPlaceSearchResult *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPlaceSearchResult(sipSimpleWrapper *);}
static void dealloc_QPlaceSearchResult(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPlaceSearchResult *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPlaceSearchResult(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPlaceSearchResult(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPlaceSearchResult(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQPlaceSearchResult *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQPlaceSearchResult();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QPlaceSearchResult* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPlaceSearchResult, &a0))
        {
            sipCpp = new sipQPlaceSearchResult(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QPlaceSearchResult[] = {
    {(void *)slot_QPlaceSearchResult___ne__, ne_slot},
    {(void *)slot_QPlaceSearchResult___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QPlaceSearchResult[] = {
    {sipName_icon, meth_QPlaceSearchResult_icon, METH_VARARGS, doc_QPlaceSearchResult_icon},
    {sipName_setIcon, meth_QPlaceSearchResult_setIcon, METH_VARARGS, doc_QPlaceSearchResult_setIcon},
    {sipName_setTitle, meth_QPlaceSearchResult_setTitle, METH_VARARGS, doc_QPlaceSearchResult_setTitle},
    {sipName_title, meth_QPlaceSearchResult_title, METH_VARARGS, doc_QPlaceSearchResult_title},
    {sipName_type, meth_QPlaceSearchResult_type, METH_VARARGS, doc_QPlaceSearchResult_type}
};

static sipEnumMemberDef enummembers_QPlaceSearchResult[] = {
    {sipName_PlaceResult, static_cast<int>(::QPlaceSearchResult::PlaceResult), 82},
    {sipName_ProposedSearchResult, static_cast<int>(::QPlaceSearchResult::ProposedSearchResult), 82},
    {sipName_UnknownSearchResult, static_cast<int>(::QPlaceSearchResult::UnknownSearchResult), 82},
};

PyDoc_STRVAR(doc_QPlaceSearchResult, "\1QPlaceSearchResult()\n"
"QPlaceSearchResult(other: QPlaceSearchResult)");


static pyqt5ClassPluginDef plugin_QPlaceSearchResult = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QPlaceSearchResult = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPlaceSearchResult,
        SIP_NULLPTR,
        &plugin_QPlaceSearchResult,
    },
    {
        sipNameNr_QPlaceSearchResult,
        {0, 0, 1},
        5, methods_QPlaceSearchResult,
        3, enummembers_QPlaceSearchResult,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPlaceSearchResult,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QPlaceSearchResult,
    init_type_QPlaceSearchResult,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPlaceSearchResult,
    assign_QPlaceSearchResult,
    array_QPlaceSearchResult,
    copy_QPlaceSearchResult,
    release_QPlaceSearchResult,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPlaceSearchResult,
    sizeof (::QPlaceSearchResult),
};
