/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtDesignerAPI_H
#define _QtDesignerAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QDesignerFormWindowCursorInterface__MoveOperation 0
#define sipName_QDesignerFormWindowCursorInterface__MoveOperation &sipStrings_QtDesigner[0]
#define sipNameNr_QDesignerFormWindowManagerInterface__ActionGroup 50
#define sipName_QDesignerFormWindowManagerInterface__ActionGroup &sipStrings_QtDesigner[50]
#define sipNameNr_QDesignerFormWindowCursorInterface__MoveMode 99
#define sipName_QDesignerFormWindowCursorInterface__MoveMode &sipStrings_QtDesigner[99]
#define sipNameNr_QDesignerFormWindowManagerInterface__Action 144
#define sipName_QDesignerFormWindowManagerInterface__Action &sipStrings_QtDesigner[144]
#define sipNameNr_QDesignerFormWindowInterface__FeatureFlag 188
#define sipName_QDesignerFormWindowInterface__FeatureFlag &sipStrings_QtDesigner[188]
#define sipNameNr_QDesignerCustomWidgetCollectionInterface 230
#define sipName_QDesignerCustomWidgetCollectionInterface &sipStrings_QtDesigner[230]
#define sipNameNr_QPyDesignerCustomWidgetCollectionPlugin 271
#define sipName_QPyDesignerCustomWidgetCollectionPlugin &sipStrings_QtDesigner[271]
#define sipNameNr_311 311
#define sipName_311 &sipStrings_QtDesigner[311]
#define sipNameNr_QDesignerFormWindowInterface__Feature 350
#define sipName_QDesignerFormWindowInterface__Feature &sipStrings_QtDesigner[350]
#define sipNameNr_QDesignerFormWindowManagerInterface 388
#define sipName_QDesignerFormWindowManagerInterface &sipStrings_QtDesigner[388]
#define sipNameNr_QDesignerFormWindowCursorInterface 424
#define sipName_QDesignerFormWindowCursorInterface &sipStrings_QtDesigner[424]
#define sipNameNr_QDesignerObjectInspectorInterface 459
#define sipName_QDesignerObjectInspectorInterface &sipStrings_QtDesigner[459]
#define sipNameNr_QPyDesignerPropertySheetExtension 493
#define sipName_QPyDesignerPropertySheetExtension &sipStrings_QtDesigner[493]
#define sipNameNr_QDesignerPropertyEditorInterface 527
#define sipName_QDesignerPropertyEditorInterface &sipStrings_QtDesigner[527]
#define sipNameNr_QDesignerPropertySheetExtension 560
#define sipName_QDesignerPropertySheetExtension &sipStrings_QtDesigner[560]
#define sipNameNr_QPyDesignerMemberSheetExtension 592
#define sipName_QPyDesignerMemberSheetExtension &sipStrings_QtDesigner[592]
#define sipNameNr_FormWindowSettingsDialogAction 624
#define sipName_FormWindowSettingsDialogAction &sipStrings_QtDesigner[624]
#define sipNameNr_QDesignerActionEditorInterface 655
#define sipName_QDesignerActionEditorInterface &sipStrings_QtDesigner[655]
#define sipNameNr_QDesignerCustomWidgetInterface 686
#define sipName_QDesignerCustomWidgetInterface &sipStrings_QtDesigner[686]
#define sipNameNr_QDesignerMemberSheetExtension 717
#define sipName_QDesignerMemberSheetExtension &sipStrings_QtDesigner[717]
#define sipNameNr_QPyDesignerContainerExtension 747
#define sipName_QPyDesignerContainerExtension &sipStrings_QtDesigner[747]
#define sipNameNr_QPyDesignerCustomWidgetPlugin 777
#define sipName_QPyDesignerCustomWidgetPlugin &sipStrings_QtDesigner[777]
#define sipNameNr_QDesignerFormEditorInterface 807
#define sipName_QDesignerFormEditorInterface &sipStrings_QtDesigner[807]
#define sipNameNr_QDesignerFormWindowInterface 836
#define sipName_QDesignerFormWindowInterface &sipStrings_QtDesigner[836]
#define sipNameNr_QPyDesignerTaskMenuExtension 865
#define sipName_QPyDesignerTaskMenuExtension &sipStrings_QtDesigner[865]
#define sipNameNr_QDesignerContainerExtension 894
#define sipName_QDesignerContainerExtension &sipStrings_QtDesigner[894]
#define sipNameNr_QDesignerWidgetBoxInterface 922
#define sipName_QDesignerWidgetBoxInterface &sipStrings_QtDesigner[922]
#define sipNameNr_QDesignerTaskMenuExtension 950
#define sipName_QDesignerTaskMenuExtension &sipStrings_QtDesigner[950]
#define sipNameNr_QAbstractExtensionFactory 977
#define sipName_QAbstractExtensionFactory &sipStrings_QtDesigner[977]
#define sipNameNr_QAbstractExtensionManager 1003
#define sipName_QAbstractExtensionManager &sipStrings_QtDesigner[1003]
#define sipNameNr_activateResourceFilePaths 1029
#define sipName_activateResourceFilePaths &sipStrings_QtDesigner[1029]
#define sipNameNr_formWindowSettingsChanged 1055
#define sipName_formWindowSettingsChanged &sipStrings_QtDesigner[1055]
#define sipNameNr_StyledPreviewActionGroup 1081
#define sipName_StyledPreviewActionGroup &sipStrings_QtDesigner[1081]
#define sipNameNr_activeFormWindowChanged 1106
#define sipName_activeFormWindowChanged &sipStrings_QtDesigner[1106]
#define sipNameNr_activeResourceFilePaths 1130
#define sipName_activeResourceFilePaths &sipStrings_QtDesigner[1130]
#define sipNameNr_HorizontalLayoutAction 1154
#define sipName_HorizontalLayoutAction &sipStrings_QtDesigner[1154]
#define sipNameNr_SplitHorizontalAction 1177
#define sipName_SplitHorizontalAction &sipStrings_QtDesigner[1177]
#define sipNameNr_aboutToUnmanageWidget 1199
#define sipName_aboutToUnmanageWidget &sipStrings_QtDesigner[1199]
#define sipNameNr_mouseDoubleClickEvent 1221
#define sipName_mouseDoubleClickEvent &sipStrings_QtDesigner[1221]
#define sipNameNr_DefaultPreviewAction 1243
#define sipName_DefaultPreviewAction &sipStrings_QtDesigner[1243]
#define sipNameNr_QAbstractFormBuilder 1264
#define sipName_QAbstractFormBuilder &sipStrings_QtDesigner[1264]
#define sipNameNr_SimplifyLayoutAction 1285
#define sipName_SimplifyLayoutAction &sipStrings_QtDesigner[1285]
#define sipNameNr_VerticalLayoutAction 1306
#define sipName_VerticalLayoutAction &sipStrings_QtDesigner[1306]
#define sipNameNr_actionSimplifyLayout 1327
#define sipName_actionSimplifyLayout &sipStrings_QtDesigner[1327]
#define sipNameNr_emitSelectionChanged 1348
#define sipName_emitSelectionChanged &sipStrings_QtDesigner[1348]
#define sipNameNr_mainContainerChanged 1369
#define sipName_mainContainerChanged &sipStrings_QtDesigner[1369]
#define sipNameNr_resourceFilesChanged 1390
#define sipName_resourceFilesChanged &sipStrings_QtDesigner[1390]
#define sipNameNr_unregisterExtensions 1411
#define sipName_unregisterExtensions &sipStrings_QtDesigner[1411]
#define sipNameNr_SplitVerticalAction 1432
#define sipName_SplitVerticalAction &sipStrings_QtDesigner[1432]
#define sipNameNr_currentPropertyName 1452
#define sipName_currentPropertyName &sipStrings_QtDesigner[1452]
#define sipNameNr_inheritedFromWidget 1472
#define sipName_inheritedFromWidget &sipStrings_QtDesigner[1472]
#define sipNameNr_preferredEditAction 1492
#define sipName_preferredEditAction &sipStrings_QtDesigner[1492]
#define sipNameNr_resetWidgetProperty 1512
#define sipName_resetWidgetProperty &sipStrings_QtDesigner[1512]
#define sipNameNr_selectedWidgetCount 1532
#define sipName_selectedWidgetCount &sipStrings_QtDesigner[1532]
#define sipNameNr_setActiveFormWindow 1552
#define sipName_setActiveFormWindow &sipStrings_QtDesigner[1552]
#define sipNameNr_setWorkingDirectory 1572
#define sipName_setWorkingDirectory &sipStrings_QtDesigner[1572]
#define sipNameNr_focusNextPrevChild 1592
#define sipName_focusNextPrevChild &sipStrings_QtDesigner[1592]
#define sipNameNr_registerExtensions 1413
#define sipName_registerExtensions &sipStrings_QtDesigner[1413]
#define sipNameNr_removeResourceFile 1611
#define sipName_removeResourceFile &sipStrings_QtDesigner[1611]
#define sipNameNr_setObjectInspector 1630
#define sipName_setObjectInspector &sipStrings_QtDesigner[1630]
#define sipNameNr_BreakLayoutAction 1649
#define sipName_BreakLayoutAction &sipStrings_QtDesigner[1649]
#define sipNameNr_QExtensionFactory 1667
#define sipName_QExtensionFactory &sipStrings_QtDesigner[1667]
#define sipNameNr_QExtensionManager 1685
#define sipName_QExtensionManager &sipStrings_QtDesigner[1685]
#define sipNameNr_formWindowManager 1703
#define sipName_formWindowManager &sipStrings_QtDesigner[1703]
#define sipNameNr_formWindowRemoved 1721
#define sipName_formWindowRemoved &sipStrings_QtDesigner[1721]
#define sipNameNr_hasHeightForWidth 1739
#define sipName_hasHeightForWidth &sipStrings_QtDesigner[1739]
#define sipNameNr_mouseReleaseEvent 1757
#define sipName_mouseReleaseEvent &sipStrings_QtDesigner[1757]
#define sipNameNr_setLayoutFunction 1775
#define sipName_setLayoutFunction &sipStrings_QtDesigner[1775]
#define sipNameNr_setPixmapFunction 1793
#define sipName_setPixmapFunction &sipStrings_QtDesigner[1793]
#define sipNameNr_setPropertyEditor 1811
#define sipName_setPropertyEditor &sipStrings_QtDesigner[1811]
#define sipNameNr_setWidgetProperty 1514
#define sipName_setWidgetProperty &sipStrings_QtDesigner[1514]
#define sipNameNr_sip_simplewrapper 1829
#define sipName_sip_simplewrapper &sipStrings_QtDesigner[1829]
#define sipNameNr_AdjustSizeAction 1847
#define sipName_AdjustSizeAction &sipStrings_QtDesigner[1847]
#define sipNameNr_FormLayoutAction 1864
#define sipName_FormLayoutAction &sipStrings_QtDesigner[1864]
#define sipNameNr_GridLayoutAction 1881
#define sipName_GridLayoutAction &sipStrings_QtDesigner[1881]
#define sipNameNr_PyQt5_QtDesigner 1898
#define sipName_PyQt5_QtDesigner &sipStrings_QtDesigner[1898]
#define sipNameNr_actionFormLayout 1915
#define sipName_actionFormLayout &sipStrings_QtDesigner[1915]
#define sipNameNr_activeFormWindow 1932
#define sipName_activeFormWindow &sipStrings_QtDesigner[1932]
#define sipNameNr_clearPluginPaths 1949
#define sipName_clearPluginPaths &sipStrings_QtDesigner[1949]
#define sipNameNr_closeAllPreviews 1966
#define sipName_closeAllPreviews &sipStrings_QtDesigner[1966]
#define sipNameNr_contextMenuEvent 1983
#define sipName_contextMenuEvent &sipStrings_QtDesigner[1983]
#define sipNameNr_createFormWindow 2000
#define sipName_createFormWindow &sipStrings_QtDesigner[2000]
#define sipNameNr_disconnectNotify 2017
#define sipName_disconnectNotify &sipStrings_QtDesigner[2017]
#define sipNameNr_extensionManager 2034
#define sipName_extensionManager &sipStrings_QtDesigner[2034]
#define sipNameNr_inputMethodEvent 2051
#define sipName_inputMethodEvent &sipStrings_QtDesigner[2051]
#define sipNameNr_inputMethodQuery 2068
#define sipName_inputMethodQuery &sipStrings_QtDesigner[2068]
#define sipNameNr_isWidgetSelected 2085
#define sipName_isWidgetSelected &sipStrings_QtDesigner[2085]
#define sipNameNr_removeFormWindow 2102
#define sipName_removeFormWindow &sipStrings_QtDesigner[2102]
#define sipNameNr_selectionChanged 2119
#define sipName_selectionChanged &sipStrings_QtDesigner[2119]
#define sipNameNr_setLayoutDefault 2136
#define sipName_setLayoutDefault &sipStrings_QtDesigner[2136]
#define sipNameNr_setMainContainer 2153
#define sipName_setMainContainer &sipStrings_QtDesigner[2153]
#define sipNameNr_setPropertyGroup 2170
#define sipName_setPropertyGroup &sipStrings_QtDesigner[2170]
#define sipNameNr_setPropertyValue 2187
#define sipName_setPropertyValue &sipStrings_QtDesigner[2187]
#define sipNameNr_showPluginDialog 2204
#define sipName_showPluginDialog &sipStrings_QtDesigner[2204]
#define sipNameNr_workingDirectory 2221
#define sipName_workingDirectory &sipStrings_QtDesigner[2221]
#define sipNameNr_SelectAllAction 2238
#define sipName_SelectAllAction &sipStrings_QtDesigner[2238]
#define sipNameNr_TabOrderFeature 2254
#define sipName_TabOrderFeature &sipStrings_QtDesigner[2254]
#define sipNameNr_addResourceFile 2270
#define sipName_addResourceFile &sipStrings_QtDesigner[2270]
#define sipNameNr_createExtension 2286
#define sipName_createExtension &sipStrings_QtDesigner[2286]
#define sipNameNr_declaredInClass 2302
#define sipName_declaredInClass &sipStrings_QtDesigner[2302]
#define sipNameNr_fileNameChanged 2318
#define sipName_fileNameChanged &sipStrings_QtDesigner[2318]
#define sipNameNr_formWindowAdded 2334
#define sipName_formWindowAdded &sipStrings_QtDesigner[2334]
#define sipNameNr_formWindowCount 2350
#define sipName_formWindowCount &sipStrings_QtDesigner[2350]
#define sipNameNr_geometryChanged 2366
#define sipName_geometryChanged &sipStrings_QtDesigner[2366]
#define sipNameNr_keyReleaseEvent 2382
#define sipName_keyReleaseEvent &sipStrings_QtDesigner[2382]
#define sipNameNr_minimumSizeHint 2398
#define sipName_minimumSizeHint &sipStrings_QtDesigner[2398]
#define sipNameNr_mousePressEvent 2414
#define sipName_mousePressEvent &sipStrings_QtDesigner[2414]
#define sipNameNr_objectInspector 2430
#define sipName_objectInspector &sipStrings_QtDesigner[2430]
#define sipNameNr_propertyChanged 2446
#define sipName_propertyChanged &sipStrings_QtDesigner[2446]
#define sipNameNr_setActionEditor 2462
#define sipName_setActionEditor &sipStrings_QtDesigner[2462]
#define sipNameNr_setCurrentIndex 2478
#define sipName_setCurrentIndex &sipStrings_QtDesigner[2478]
#define sipNameNr_setIncludeHints 2494
#define sipName_setIncludeHints &sipStrings_QtDesigner[2494]
#define sipNameNr_widgetUnmanaged 2510
#define sipName_widgetUnmanaged &sipStrings_QtDesigner[2510]
#define sipNameNr_DefaultFeature 2526
#define sipName_DefaultFeature &sipStrings_QtDesigner[2526]
#define sipNameNr_clearSelection 2541
#define sipName_clearSelection &sipStrings_QtDesigner[2541]
#define sipNameNr_dragEnterEvent 2556
#define sipName_dragEnterEvent &sipStrings_QtDesigner[2556]
#define sipNameNr_dragLeaveEvent 2571
#define sipName_dragLeaveEvent &sipStrings_QtDesigner[2571]
#define sipNameNr_featureChanged 2586
#define sipName_featureChanged &sipStrings_QtDesigner[2586]
#define sipNameNr_findFormWindow 2601
#define sipName_findFormWindow &sipStrings_QtDesigner[2601]
#define sipNameNr_heightForWidth 2616
#define sipName_heightForWidth &sipStrings_QtDesigner[2616]
#define sipNameNr_layoutFunction 2631
#define sipName_layoutFunction &sipStrings_QtDesigner[2631]
#define sipNameNr_mouseMoveEvent 2646
#define sipName_mouseMoveEvent &sipStrings_QtDesigner[2646]
#define sipNameNr_parameterNames 2661
#define sipName_parameterNames &sipStrings_QtDesigner[2661]
#define sipNameNr_parameterTypes 2676
#define sipName_parameterTypes &sipStrings_QtDesigner[2676]
#define sipNameNr_pixmapFunction 2691
#define sipName_pixmapFunction &sipStrings_QtDesigner[2691]
#define sipNameNr_propertyEditor 2706
#define sipName_propertyEditor &sipStrings_QtDesigner[2706]
#define sipNameNr_selectedWidget 2721
#define sipName_selectedWidget &sipStrings_QtDesigner[2721]
#define sipNameNr_setExportMacro 2736
#define sipName_setExportMacro &sipStrings_QtDesigner[2736]
#define sipNameNr_setMemberGroup 2751
#define sipName_setMemberGroup &sipStrings_QtDesigner[2751]
#define sipNameNr_unmanageAction 2766
#define sipName_unmanageAction &sipStrings_QtDesigner[2766]
#define sipNameNr_unmanageWidget 2781
#define sipName_unmanageWidget &sipStrings_QtDesigner[2781]
#define sipNameNr_MoveOperation 36
#define sipName_MoveOperation &sipStrings_QtDesigner[36]
#define sipNameNr_addFormWindow 2796
#define sipName_addFormWindow &sipStrings_QtDesigner[2796]
#define sipNameNr_addPluginPath 2810
#define sipName_addPluginPath &sipStrings_QtDesigner[2810]
#define sipNameNr_checkContents 2824
#define sipName_checkContents &sipStrings_QtDesigner[2824]
#define sipNameNr_connectNotify 2020
#define sipName_connectNotify &sipStrings_QtDesigner[2020]
#define sipNameNr_customWidgets 2838
#define sipName_customWidgets &sipStrings_QtDesigner[2838]
#define sipNameNr_dragMoveEvent 2852
#define sipName_dragMoveEvent &sipStrings_QtDesigner[2852]
#define sipNameNr_errorMessages 2866
#define sipName_errorMessages &sipStrings_QtDesigner[2866]
#define sipNameNr_focusOutEvent 2880
#define sipName_focusOutEvent &sipStrings_QtDesigner[2880]
#define sipNameNr_formContainer 2894
#define sipName_formContainer &sipStrings_QtDesigner[2894]
#define sipNameNr_isInitialized 2908
#define sipName_isInitialized &sipStrings_QtDesigner[2908]
#define sipNameNr_keyPressEvent 2922
#define sipName_keyPressEvent &sipStrings_QtDesigner[2922]
#define sipNameNr_layoutDefault 2936
#define sipName_layoutDefault &sipStrings_QtDesigner[2936]
#define sipNameNr_mainContainer 2950
#define sipName_mainContainer &sipStrings_QtDesigner[2950]
#define sipNameNr_objectRemoved 2964
#define sipName_objectRemoved &sipStrings_QtDesigner[2964]
#define sipNameNr_propertyGroup 2978
#define sipName_propertyGroup &sipStrings_QtDesigner[2978]
#define sipNameNr_resourceFiles 2992
#define sipName_resourceFiles &sipStrings_QtDesigner[2992]
#define sipNameNr_setFormWindow 3006
#define sipName_setFormWindow &sipStrings_QtDesigner[3006]
#define sipNameNr_setPluginPath 3020
#define sipName_setPluginPath &sipStrings_QtDesigner[3020]
#define sipNameNr_sharedPainter 3034
#define sipName_sharedPainter &sipStrings_QtDesigner[3034]
#define sipNameNr_widgetManaged 3048
#define sipName_widgetManaged &sipStrings_QtDesigner[3048]
#define sipNameNr_widgetRemoved 3062
#define sipName_widgetRemoved &sipStrings_QtDesigner[3062]
#define sipNameNr_DeleteAction 3076
#define sipName_DeleteAction &sipStrings_QtDesigner[3076]
#define sipNameNr_QFormBuilder 3089
#define sipName_QFormBuilder &sipStrings_QtDesigner[3089]
#define sipNameNr_actionEditor 3102
#define sipName_actionEditor &sipStrings_QtDesigner[3102]
#define sipNameNr_canAddWidget 3115
#define sipName_canAddWidget &sipStrings_QtDesigner[3115]
#define sipNameNr_codeTemplate 3128
#define sipName_codeTemplate &sipStrings_QtDesigner[3128]
#define sipNameNr_createWidget 3141
#define sipName_createWidget &sipStrings_QtDesigner[3141]
#define sipNameNr_currentIndex 3154
#define sipName_currentIndex &sipStrings_QtDesigner[3154]
#define sipNameNr_errorMessage 3167
#define sipName_errorMessage &sipStrings_QtDesigner[3167]
#define sipNameNr_focusInEvent 3180
#define sipName_focusInEvent &sipStrings_QtDesigner[3180]
#define sipNameNr_hasSelection 3193
#define sipName_hasSelection &sipStrings_QtDesigner[3193]
#define sipNameNr_includeHints 3206
#define sipName_includeHints &sipStrings_QtDesigner[3206]
#define sipNameNr_insertWidget 3219
#define sipName_insertWidget &sipStrings_QtDesigner[3219]
#define sipNameNr_manageAction 2768
#define sipName_manageAction &sipStrings_QtDesigner[2768]
#define sipNameNr_manageWidget 1208
#define sipName_manageWidget &sipStrings_QtDesigner[1208]
#define sipNameNr_movePosition 3232
#define sipName_movePosition &sipStrings_QtDesigner[3232]
#define sipNameNr_propertyName 3245
#define sipName_propertyName &sipStrings_QtDesigner[3245]
#define sipNameNr_selectWidget 3258
#define sipName_selectWidget &sipStrings_QtDesigner[3258]
#define sipNameNr_setAttribute 3271
#define sipName_setAttribute &sipStrings_QtDesigner[3271]
#define sipNameNr_setWidgetBox 3284
#define sipName_setWidgetBox &sipStrings_QtDesigner[3284]
#define sipNameNr_ActionGroup 87
#define sipName_ActionGroup &sipStrings_QtDesigner[87]
#define sipNameNr_EditFeature 3297
#define sipName_EditFeature &sipStrings_QtDesigner[3297]
#define sipNameNr_FeatureFlag 218
#define sipName_FeatureFlag &sipStrings_QtDesigner[218]
#define sipNameNr_GridFeature 3309
#define sipName_GridFeature &sipStrings_QtDesigner[3309]
#define sipNameNr_LowerAction 3321
#define sipName_LowerAction &sipStrings_QtDesigner[3321]
#define sipNameNr_PasteAction 3333
#define sipName_PasteAction &sipStrings_QtDesigner[3333]
#define sipNameNr_RaiseAction 3345
#define sipName_RaiseAction &sipStrings_QtDesigner[3345]
#define sipNameNr_absoluteDir 3357
#define sipName_absoluteDir &sipStrings_QtDesigner[3357]
#define sipNameNr_actionEvent 3369
#define sipName_actionEvent &sipStrings_QtDesigner[3369]
#define sipNameNr_actionGroup 3381
#define sipName_actionGroup &sipStrings_QtDesigner[3381]
#define sipNameNr_changeEvent 3393
#define sipName_changeEvent &sipStrings_QtDesigner[3393]
#define sipNameNr_customEvent 3405
#define sipName_customEvent &sipStrings_QtDesigner[3405]
#define sipNameNr_errorString 3417
#define sipName_errorString &sipStrings_QtDesigner[3417]
#define sipNameNr_eventFilter 3429
#define sipName_eventFilter &sipStrings_QtDesigner[3429]
#define sipNameNr_exportMacro 3441
#define sipName_exportMacro &sipStrings_QtDesigner[3441]
#define sipNameNr_includeFile 3453
#define sipName_includeFile &sipStrings_QtDesigner[3453]
#define sipNameNr_initPainter 3465
#define sipName_initPainter &sipStrings_QtDesigner[3465]
#define sipNameNr_isAttribute 3477
#define sipName_isAttribute &sipStrings_QtDesigner[3477]
#define sipNameNr_isContainer 3489
#define sipName_isContainer &sipStrings_QtDesigner[3489]
#define sipNameNr_memberGroup 3501
#define sipName_memberGroup &sipStrings_QtDesigner[3501]
#define sipNameNr_nativeEvent 3513
#define sipName_nativeEvent &sipStrings_QtDesigner[3513]
#define sipNameNr_paintEngine 3525
#define sipName_paintEngine &sipStrings_QtDesigner[3525]
#define sipNameNr_pluginPaths 3537
#define sipName_pluginPaths &sipStrings_QtDesigner[3537]
#define sipNameNr_resizeEvent 3549
#define sipName_resizeEvent &sipStrings_QtDesigner[3549]
#define sipNameNr_setContents 3561
#define sipName_setContents &sipStrings_QtDesigner[3561]
#define sipNameNr_setFeatures 3573
#define sipName_setFeatures &sipStrings_QtDesigner[3573]
#define sipNameNr_setFileName 3585
#define sipName_setFileName &sipStrings_QtDesigner[3585]
#define sipNameNr_setPosition 3597
#define sipName_setPosition &sipStrings_QtDesigner[3597]
#define sipNameNr_setProperty 3609
#define sipName_setProperty &sipStrings_QtDesigner[3609]
#define sipNameNr_setReadOnly 3621
#define sipName_setReadOnly &sipStrings_QtDesigner[3621]
#define sipNameNr_showPreview 3633
#define sipName_showPreview &sipStrings_QtDesigner[3633]
#define sipNameNr_tabletEvent 3645
#define sipName_tabletEvent &sipStrings_QtDesigner[3645]
#define sipNameNr_taskActions 3657
#define sipName_taskActions &sipStrings_QtDesigner[3657]
#define sipNameNr_widgetCount 3669
#define sipName_widgetCount &sipStrings_QtDesigner[3669]
#define sipNameNr_CopyAction 3681
#define sipName_CopyAction &sipStrings_QtDesigner[3681]
#define sipNameNr_KeepAnchor 3692
#define sipName_KeepAnchor &sipStrings_QtDesigner[3692]
#define sipNameNr_MoveAnchor 3703
#define sipName_MoveAnchor &sipStrings_QtDesigner[3703]
#define sipNameNr_RedoAction 3714
#define sipName_RedoAction &sipStrings_QtDesigner[3714]
#define sipNameNr_UndoAction 3725
#define sipName_UndoAction &sipStrings_QtDesigner[3725]
#define sipNameNr___invert__ 3736
#define sipName___invert__ &sipStrings_QtDesigner[3736]
#define sipNameNr_childEvent 3747
#define sipName_childEvent &sipStrings_QtDesigner[3747]
#define sipNameNr_closeEvent 3758
#define sipName_closeEvent &sipStrings_QtDesigner[3758]
#define sipNameNr_enterEvent 3769
#define sipName_enterEvent &sipStrings_QtDesigner[3769]
#define sipNameNr_errorCount 3780
#define sipName_errorCount &sipStrings_QtDesigner[3780]
#define sipNameNr_formWindow 3791
#define sipName_formWindow &sipStrings_QtDesigner[3791]
#define sipNameNr_hasFeature 3802
#define sipName_hasFeature &sipStrings_QtDesigner[3802]
#define sipNameNr_initialize 3813
#define sipName_initialize &sipStrings_QtDesigner[3813]
#define sipNameNr_isReadOnly 3824
#define sipName_isReadOnly &sipStrings_QtDesigner[3824]
#define sipNameNr_leaveEvent 3835
#define sipName_leaveEvent &sipStrings_QtDesigner[3835]
#define sipNameNr_memberName 3846
#define sipName_memberName &sipStrings_QtDesigner[3846]
#define sipNameNr_paintEvent 3857
#define sipName_paintEvent &sipStrings_QtDesigner[3857]
#define sipNameNr_setChanged 3868
#define sipName_setChanged &sipStrings_QtDesigner[3868]
#define sipNameNr_setComment 3879
#define sipName_setComment &sipStrings_QtDesigner[3879]
#define sipNameNr_setVisible 3890
#define sipName_setVisible &sipStrings_QtDesigner[3890]
#define sipNameNr_timerEvent 3901
#define sipName_timerEvent &sipStrings_QtDesigner[3901]
#define sipNameNr_wheelEvent 3912
#define sipName_wheelEvent &sipStrings_QtDesigner[3912]
#define sipNameNr_CutAction 3923
#define sipName_CutAction &sipStrings_QtDesigner[3923]
#define sipNameNr___index__ 3933
#define sipName___index__ &sipStrings_QtDesigner[3933]
#define sipNameNr_activated 3943
#define sipName_activated &sipStrings_QtDesigner[3943]
#define sipNameNr_addWidget 3953
#define sipName_addWidget &sipStrings_QtDesigner[3953]
#define sipNameNr_canRemove 3963
#define sipName_canRemove &sipStrings_QtDesigner[3963]
#define sipNameNr_dropEvent 3973
#define sipName_dropEvent &sipStrings_QtDesigner[3973]
#define sipNameNr_extension 3983
#define sipName_extension &sipStrings_QtDesigner[3983]
#define sipNameNr_hideEvent 3993
#define sipName_hideEvent &sipStrings_QtDesigner[3993]
#define sipNameNr_isChanged 4003
#define sipName_isChanged &sipStrings_QtDesigner[4003]
#define sipNameNr_isEnabled 4013
#define sipName_isEnabled &sipStrings_QtDesigner[4013]
#define sipNameNr_isManaged 4023
#define sipName_isManaged &sipStrings_QtDesigner[4023]
#define sipNameNr_isVisible 4033
#define sipName_isVisible &sipStrings_QtDesigner[4033]
#define sipNameNr_moveEvent 4043
#define sipName_moveEvent &sipStrings_QtDesigner[4043]
#define sipNameNr_setAuthor 4053
#define sipName_setAuthor &sipStrings_QtDesigner[4053]
#define sipNameNr_setObject 4063
#define sipName_setObject &sipStrings_QtDesigner[4063]
#define sipNameNr_showEvent 4073
#define sipName_showEvent &sipStrings_QtDesigner[4073]
#define sipNameNr_signature 4083
#define sipName_signature &sipStrings_QtDesigner[4083]
#define sipNameNr_whatsThis 4093
#define sipName_whatsThis &sipStrings_QtDesigner[4093]
#define sipNameNr_widgetBox 4103
#define sipName_widgetBox &sipStrings_QtDesigner[4103]
#define sipNameNr_MoveMode 135
#define sipName_MoveMode &sipStrings_QtDesigner[135]
#define sipNameNr___bool__ 4113
#define sipName___bool__ &sipStrings_QtDesigner[4113]
#define sipNameNr___hash__ 4122
#define sipName___hash__ &sipStrings_QtDesigner[4122]
#define sipNameNr___iand__ 4131
#define sipName___iand__ &sipStrings_QtDesigner[4131]
#define sipNameNr___ixor__ 4140
#define sipName___ixor__ &sipStrings_QtDesigner[4140]
#define sipNameNr_contents 4149
#define sipName_contents &sipStrings_QtDesigner[4149]
#define sipNameNr_features 4158
#define sipName_features &sipStrings_QtDesigner[4158]
#define sipNameNr_fileName 4167
#define sipName_fileName &sipStrings_QtDesigner[4167]
#define sipNameNr_hasReset 4176
#define sipName_hasReset &sipStrings_QtDesigner[4176]
#define sipNameNr_isSignal 4185
#define sipName_isSignal &sipStrings_QtDesigner[4185]
#define sipNameNr_position 4194
#define sipName_position &sipStrings_QtDesigner[4194]
#define sipNameNr_property 4203
#define sipName_property &sipStrings_QtDesigner[4203]
#define sipNameNr_setDirty 4212
#define sipName_setDirty &sipStrings_QtDesigner[4212]
#define sipNameNr_sizeHint 4221
#define sipName_sizeHint &sipStrings_QtDesigner[4221]
#define sipNameNr_topLevel 4230
#define sipName_topLevel &sipStrings_QtDesigner[4230]
#define sipNameNr_Feature 380
#define sipName_Feature &sipStrings_QtDesigner[380]
#define sipNameNr___and__ 4239
#define sipName___and__ &sipStrings_QtDesigner[4239]
#define sipNameNr___int__ 4247
#define sipName___int__ &sipStrings_QtDesigner[4247]
#define sipNameNr___ior__ 4255
#define sipName___ior__ &sipStrings_QtDesigner[4255]
#define sipNameNr___len__ 4263
#define sipName___len__ &sipStrings_QtDesigner[4263]
#define sipNameNr___xor__ 4271
#define sipName___xor__ &sipStrings_QtDesigner[4271]
#define sipNameNr_changed 4279
#define sipName_changed &sipStrings_QtDesigner[4279]
#define sipNameNr_comment 4287
#define sipName_comment &sipStrings_QtDesigner[4287]
#define sipNameNr_current 4295
#define sipName_current &sipStrings_QtDesigner[4295]
#define sipNameNr_devType 4303
#define sipName_devType &sipStrings_QtDesigner[4303]
#define sipNameNr_indexOf 4311
#define sipName_indexOf &sipStrings_QtDesigner[4311]
#define sipNameNr_isDirty 4319
#define sipName_isDirty &sipStrings_QtDesigner[4319]
#define sipNameNr_setGrid 4327
#define sipName_setGrid &sipStrings_QtDesigner[4327]
#define sipNameNr_toolTip 4335
#define sipName_toolTip &sipStrings_QtDesigner[4335]
#define sipNameNr_Action 181
#define sipName_Action &sipStrings_QtDesigner[181]
#define sipNameNr_NoMove 4343
#define sipName_NoMove &sipStrings_QtDesigner[4343]
#define sipNameNr___eq__ 4350
#define sipName___eq__ &sipStrings_QtDesigner[4350]
#define sipNameNr___ne__ 4357
#define sipName___ne__ &sipStrings_QtDesigner[4357]
#define sipNameNr___or__ 4364
#define sipName___or__ &sipStrings_QtDesigner[4364]
#define sipNameNr_action 4371
#define sipName_action &sipStrings_QtDesigner[4371]
#define sipNameNr_author 4378
#define sipName_author &sipStrings_QtDesigner[4378]
#define sipNameNr_cursor 4385
#define sipName_cursor &sipStrings_QtDesigner[4385]
#define sipNameNr_domXml 4392
#define sipName_domXml &sipStrings_QtDesigner[4392]
#define sipNameNr_isSlot 4399
#define sipName_isSlot &sipStrings_QtDesigner[4399]
#define sipNameNr_metric 4406
#define sipName_metric &sipStrings_QtDesigner[4406]
#define sipNameNr_object 4413
#define sipName_object &sipStrings_QtDesigner[4413]
#define sipNameNr_parent 4420
#define sipName_parent &sipStrings_QtDesigner[4420]
#define sipNameNr_remove 4427
#define sipName_remove &sipStrings_QtDesigner[4427]
#define sipNameNr_select 4434
#define sipName_select &sipStrings_QtDesigner[4434]
#define sipNameNr_update 4441
#define sipName_update &sipStrings_QtDesigner[4441]
#define sipNameNr_widget 4448
#define sipName_widget &sipStrings_QtDesigner[4448]
#define sipNameNr_Right 4455
#define sipName_Right &sipStrings_QtDesigner[4455]
#define sipNameNr_Start 4461
#define sipName_Start &sipStrings_QtDesigner[4461]
#define sipNameNr_count 4467
#define sipName_count &sipStrings_QtDesigner[4467]
#define sipNameNr_event 4473
#define sipName_event &sipStrings_QtDesigner[4473]
#define sipNameNr_flags 4479
#define sipName_flags &sipStrings_QtDesigner[4479]
#define sipNameNr_group 4485
#define sipName_group &sipStrings_QtDesigner[4485]
#define sipNameNr_reset 4491
#define sipName_reset &sipStrings_QtDesigner[4491]
#define sipNameNr_Down 4497
#define sipName_Down &sipStrings_QtDesigner[4497]
#define sipNameNr_Left 4502
#define sipName_Left &sipStrings_QtDesigner[4502]
#define sipNameNr_Next 4507
#define sipName_Next &sipStrings_QtDesigner[4507]
#define sipNameNr_Prev 4512
#define sipName_Prev &sipStrings_QtDesigner[4512]
#define sipNameNr_core 4517
#define sipName_core &sipStrings_QtDesigner[4517]
#define sipNameNr_grid 4522
#define sipName_grid &sipStrings_QtDesigner[4522]
#define sipNameNr_icon 4527
#define sipName_icon &sipStrings_QtDesigner[4527]
#define sipNameNr_load 4532
#define sipName_load &sipStrings_QtDesigner[4532]
#define sipNameNr_mode 4537
#define sipName_mode &sipStrings_QtDesigner[4537]
#define sipNameNr_name 4542
#define sipName_name &sipStrings_QtDesigner[4542]
#define sipNameNr_save 4547
#define sipName_save &sipStrings_QtDesigner[4547]
#define sipNameNr_End 4552
#define sipName_End &sipStrings_QtDesigner[4552]
#define sipNameNr_iid 4556
#define sipName_iid &sipStrings_QtDesigner[4556]
#define sipNameNr_Up 4560
#define sipName_Up &sipStrings_QtDesigner[4560]

#define sipMalloc                   sipAPI_QtDesigner->api_malloc
#define sipFree                     sipAPI_QtDesigner->api_free
#define sipBuildResult              sipAPI_QtDesigner->api_build_result
#define sipCallMethod               sipAPI_QtDesigner->api_call_method
#define sipCallProcedureMethod      sipAPI_QtDesigner->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtDesigner->api_call_error_handler
#define sipParseResultEx            sipAPI_QtDesigner->api_parse_result_ex
#define sipParseResult              sipAPI_QtDesigner->api_parse_result
#define sipParseArgs                sipAPI_QtDesigner->api_parse_args
#define sipParseKwdArgs             sipAPI_QtDesigner->api_parse_kwd_args
#define sipParsePair                sipAPI_QtDesigner->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtDesigner->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtDesigner->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtDesigner->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtDesigner->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtDesigner->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtDesigner->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtDesigner->api_add_exception
#define sipNoFunction               sipAPI_QtDesigner->api_no_function
#define sipNoMethod                 sipAPI_QtDesigner->api_no_method
#define sipAbstractMethod           sipAPI_QtDesigner->api_abstract_method
#define sipBadClass                 sipAPI_QtDesigner->api_bad_class
#define sipBadCatcherResult         sipAPI_QtDesigner->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtDesigner->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtDesigner->api_bad_operator_arg
#define sipTrace                    sipAPI_QtDesigner->api_trace
#define sipTransferBack             sipAPI_QtDesigner->api_transfer_back
#define sipTransferTo               sipAPI_QtDesigner->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtDesigner->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtDesigner->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtDesigner->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtDesigner->api_voidptr_type
#define sipGetPyObject              sipAPI_QtDesigner->api_get_pyobject
#define sipGetAddress               sipAPI_QtDesigner->api_get_address
#define sipGetMixinAddress          sipAPI_QtDesigner->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtDesigner->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtDesigner->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtDesigner->api_call_hook
#define sipEndThread                sipAPI_QtDesigner->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtDesigner->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtDesigner->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtDesigner->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtDesigner->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtDesigner->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtDesigner->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtDesigner->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtDesigner->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtDesigner->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtDesigner->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtDesigner->api_convert_to_bool
#define sipReleaseType              sipAPI_QtDesigner->api_release_type
#define sipConvertFromType          sipAPI_QtDesigner->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtDesigner->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtDesigner->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtDesigner->api_convert_from_enum
#define sipGetState                 sipAPI_QtDesigner->api_get_state
#define sipExportSymbol             sipAPI_QtDesigner->api_export_symbol
#define sipImportSymbol             sipAPI_QtDesigner->api_import_symbol
#define sipFindType                 sipAPI_QtDesigner->api_find_type
#define sipBytes_AsChar             sipAPI_QtDesigner->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtDesigner->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtDesigner->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtDesigner->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtDesigner->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtDesigner->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtDesigner->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtDesigner->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtDesigner->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtDesigner->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtDesigner->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtDesigner->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtDesigner->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtDesigner->api_get_reference
#define sipKeepReference            sipAPI_QtDesigner->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtDesigner->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtDesigner->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtDesigner->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtDesigner->api_type_scope
#define sipResolveTypedef           sipAPI_QtDesigner->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtDesigner->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtDesigner->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtDesigner->api_init_mixin
#define sipExportModule             sipAPI_QtDesigner->api_export_module
#define sipInitModule               sipAPI_QtDesigner->api_init_module
#define sipGetInterpreter           sipAPI_QtDesigner->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtDesigner->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtDesigner->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtDesigner->api_py_type_dict
#define sipPyTypeName               sipAPI_QtDesigner->api_py_type_name
#define sipGetCFunction             sipAPI_QtDesigner->api_get_c_function
#define sipGetMethod                sipAPI_QtDesigner->api_get_method
#define sipFromMethod               sipAPI_QtDesigner->api_from_method
#define sipGetDate                  sipAPI_QtDesigner->api_get_date
#define sipFromDate                 sipAPI_QtDesigner->api_from_date
#define sipGetDateTime              sipAPI_QtDesigner->api_get_datetime
#define sipFromDateTime             sipAPI_QtDesigner->api_from_datetime
#define sipGetTime                  sipAPI_QtDesigner->api_get_time
#define sipFromTime                 sipAPI_QtDesigner->api_from_time
#define sipIsUserType               sipAPI_QtDesigner->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtDesigner->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtDesigner->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtDesigner->api_unicode_write
#define sipUnicodeData              sipAPI_QtDesigner->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtDesigner->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtDesigner->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtDesigner->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtDesigner->api_is_derived_class
#define sipGetUserObject            sipAPI_QtDesigner->api_get_user_object
#define sipSetUserObject            sipAPI_QtDesigner->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtDesigner->api_register_event_handler
#define sipConvertToArray           sipAPI_QtDesigner->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtDesigner->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtDesigner->api_enable_gc
#define sipPrintObject              sipAPI_QtDesigner->api_print_object
#define sipLong_AsChar              sipAPI_QtDesigner->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtDesigner->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtDesigner->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtDesigner->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtDesigner->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtDesigner->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtDesigner->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtDesigner->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtDesigner->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtDesigner->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtDesigner->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtDesigner->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtDesigner->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtDesigner->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtDesigner->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtDesigner->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtDesigner->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtDesigner->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtDesigner->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtDesigner->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtDesigner->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtDesigner->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtDesigner->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtDesigner->api_connect_rx
#define sipConvertRx                sipAPI_QtDesigner->api_convert_rx
#define sipDisconnectRx             sipAPI_QtDesigner->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtDesigner->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtDesigner->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtDesigner->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtDesigner->api_same_slot
#define sipSaveSlot                 sipAPI_QtDesigner->api_save_slot
#define sipVisitSlot                sipAPI_QtDesigner->api_visit_slot
#define sipIsPyMethod               sipAPI_QtDesigner->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtDesigner[];

#define sipType_QDesignerActionEditorInterface sipExportedTypes_QtDesigner[3]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerActionEditorInterface;

#define sipType_QAbstractFormBuilder sipExportedTypes_QtDesigner[2]

extern sipClassTypeDef sipTypeDef_QtDesigner_QAbstractFormBuilder;

#define sipType_QDesignerFormEditorInterface sipExportedTypes_QtDesigner[7]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerFormEditorInterface;

#define sipType_QDesignerFormWindowInterface sipExportedTypes_QtDesigner[11]

#define sipType_QDesignerFormWindowInterface_FeatureFlag sipExportedTypes_QtDesigner[13]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerFormWindowInterface;

#define sipType_QDesignerFormWindowInterface_Feature sipExportedTypes_QtDesigner[12]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerFormWindowInterface_Feature;

#define sipType_QDesignerFormWindowCursorInterface sipExportedTypes_QtDesigner[8]

#define sipType_QDesignerFormWindowCursorInterface_MoveMode sipExportedTypes_QtDesigner[9]

#define sipType_QDesignerFormWindowCursorInterface_MoveOperation sipExportedTypes_QtDesigner[10]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerFormWindowCursorInterface;

#define sipType_QDesignerFormWindowManagerInterface sipExportedTypes_QtDesigner[14]

#define sipType_QDesignerFormWindowManagerInterface_ActionGroup sipExportedTypes_QtDesigner[16]

#define sipType_QDesignerFormWindowManagerInterface_Action sipExportedTypes_QtDesigner[15]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerFormWindowManagerInterface;

#define sipType_QDesignerObjectInspectorInterface sipExportedTypes_QtDesigner[18]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerObjectInspectorInterface;

#define sipType_QDesignerPropertyEditorInterface sipExportedTypes_QtDesigner[19]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerPropertyEditorInterface;

#define sipType_QDesignerWidgetBoxInterface sipExportedTypes_QtDesigner[22]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerWidgetBoxInterface;

#define sipType_QDesignerContainerExtension sipExportedTypes_QtDesigner[4]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerContainerExtension;

#define sipType_QDesignerCustomWidgetInterface sipExportedTypes_QtDesigner[6]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerCustomWidgetInterface;

#define sipType_QDesignerCustomWidgetCollectionInterface sipExportedTypes_QtDesigner[5]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerCustomWidgetCollectionInterface;

#define sipType_QAbstractExtensionFactory sipExportedTypes_QtDesigner[0]

extern sipClassTypeDef sipTypeDef_QtDesigner_QAbstractExtensionFactory;

#define sipType_QExtensionFactory sipExportedTypes_QtDesigner[23]

extern sipClassTypeDef sipTypeDef_QtDesigner_QExtensionFactory;

#define sipType_QAbstractExtensionManager sipExportedTypes_QtDesigner[1]

extern sipClassTypeDef sipTypeDef_QtDesigner_QAbstractExtensionManager;

#define sipType_QFormBuilder sipExportedTypes_QtDesigner[25]

extern sipClassTypeDef sipTypeDef_QtDesigner_QFormBuilder;

#define sipType_QDesignerMemberSheetExtension sipExportedTypes_QtDesigner[17]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerMemberSheetExtension;

#define sipType_QDesignerPropertySheetExtension sipExportedTypes_QtDesigner[20]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerPropertySheetExtension;

#define sipType_QExtensionManager sipExportedTypes_QtDesigner[24]

extern sipClassTypeDef sipTypeDef_QtDesigner_QExtensionManager;

#define sipType_QDesignerTaskMenuExtension sipExportedTypes_QtDesigner[21]

extern sipClassTypeDef sipTypeDef_QtDesigner_QDesignerTaskMenuExtension;

#define sipType_QPyDesignerContainerExtension sipExportedTypes_QtDesigner[27]

extern sipClassTypeDef sipTypeDef_QtDesigner_QPyDesignerContainerExtension;

#define sipType_QPyDesignerCustomWidgetCollectionPlugin sipExportedTypes_QtDesigner[28]

extern sipClassTypeDef sipTypeDef_QtDesigner_QPyDesignerCustomWidgetCollectionPlugin;

#define sipType_QPyDesignerCustomWidgetPlugin sipExportedTypes_QtDesigner[29]

extern sipClassTypeDef sipTypeDef_QtDesigner_QPyDesignerCustomWidgetPlugin;

#define sipType_QPyDesignerTaskMenuExtension sipExportedTypes_QtDesigner[32]

extern sipClassTypeDef sipTypeDef_QtDesigner_QPyDesignerTaskMenuExtension;

#define sipType_QPyDesignerPropertySheetExtension sipExportedTypes_QtDesigner[31]

extern sipClassTypeDef sipTypeDef_QtDesigner_QPyDesignerPropertySheetExtension;

#define sipType_QPyDesignerMemberSheetExtension sipExportedTypes_QtDesigner[30]

extern sipClassTypeDef sipTypeDef_QtDesigner_QPyDesignerMemberSheetExtension;

#define sipType_QList_0101QDesignerCustomWidgetInterface sipExportedTypes_QtDesigner[26]

extern sipMappedTypeDef sipTypeDef_QtDesigner_QList_0101QDesignerCustomWidgetInterface;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtDesigner;
extern sipExportedModuleDef sipModuleAPI_QtDesigner;
extern sipTypeDef *sipExportedTypes_QtDesigner[];

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtDesigner_QtCore[14].it_td

#define sipType_Qt_WindowFlags sipImportedTypes_QtDesigner_QtCore[15].it_td

#define sipType_QObject sipImportedTypes_QtDesigner_QtCore[7].it_td

#define sipType_QIODevice sipImportedTypes_QtDesigner_QtCore[4].it_td

#define sipType_QByteArray sipImportedTypes_QtDesigner_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtDesigner_QtCore[3].it_td

#define sipType_QTimerEvent sipImportedTypes_QtDesigner_QtCore[12].it_td

#define sipType_QChildEvent sipImportedTypes_QtDesigner_QtCore[1].it_td

#define sipType_QDir sipImportedTypes_QtDesigner_QtCore[2].it_td

#define sipType_QMetaMethod sipImportedTypes_QtDesigner_QtCore[6].it_td

#define sipType_QPoint sipImportedTypes_QtDesigner_QtCore[8].it_td

#define sipType_QSize sipImportedTypes_QtDesigner_QtCore[9].it_td

#define sipType_QVariant sipImportedTypes_QtDesigner_QtCore[13].it_td

#define sipType_QList_0100QByteArray sipImportedTypes_QtDesigner_QtCore[5].it_td

#define sipType_QStringList sipImportedTypes_QtDesigner_QtCore[11].it_td

#define sipType_QString sipImportedTypes_QtDesigner_QtCore[10].it_td
extern sipImportedTypeDef sipImportedTypes_QtDesigner_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtDesigner_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtDesigner_QtGui[14].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtDesigner_QtGui[15].it_td

#define sipType_QMouseEvent sipImportedTypes_QtDesigner_QtGui[12].it_td

#define sipType_QWheelEvent sipImportedTypes_QtDesigner_QtGui[22].it_td

#define sipType_QTabletEvent sipImportedTypes_QtDesigner_QtGui[21].it_td

#define sipType_QKeyEvent sipImportedTypes_QtDesigner_QtGui[11].it_td

#define sipType_QFocusEvent sipImportedTypes_QtDesigner_QtGui[7].it_td

#define sipType_QPaintEvent sipImportedTypes_QtDesigner_QtGui[17].it_td

#define sipType_QMoveEvent sipImportedTypes_QtDesigner_QtGui[13].it_td

#define sipType_QResizeEvent sipImportedTypes_QtDesigner_QtGui[19].it_td

#define sipType_QCloseEvent sipImportedTypes_QtDesigner_QtGui[1].it_td

#define sipType_QShowEvent sipImportedTypes_QtDesigner_QtGui[20].it_td

#define sipType_QHideEvent sipImportedTypes_QtDesigner_QtGui[8].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtDesigner_QtGui[2].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtDesigner_QtGui[10].it_td

#define sipType_QDropEvent sipImportedTypes_QtDesigner_QtGui[6].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtDesigner_QtGui[5].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtDesigner_QtGui[3].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtDesigner_QtGui[4].it_td

#define sipType_QActionEvent sipImportedTypes_QtDesigner_QtGui[0].it_td

#define sipType_QIcon sipImportedTypes_QtDesigner_QtGui[9].it_td

#define sipType_QPainter sipImportedTypes_QtDesigner_QtGui[18].it_td

#define sipType_QPaintEngine sipImportedTypes_QtDesigner_QtGui[16].it_td
extern sipImportedTypeDef sipImportedTypes_QtDesigner_QtGui[];

#define sipType_QWidget sipImportedTypes_QtDesigner_QtWidgets[3].it_td

#define sipType_QAction sipImportedTypes_QtDesigner_QtWidgets[0].it_td

#define sipType_QActionGroup sipImportedTypes_QtDesigner_QtWidgets[1].it_td

#define sipType_QList_0101QAction sipImportedTypes_QtDesigner_QtWidgets[2].it_td
extern sipImportedTypeDef sipImportedTypes_QtDesigner_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtDesigner_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtDesigner_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtDesigner_qt_metacast;

#endif
