/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesearchrequest.sip"
#include <qplacesearchrequest.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceSearchRequest.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qlocation.sip"
#include <qlocation.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceSearchRequest.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceSearchRequest.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceSearchRequest.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeoshape.sip"
#include <qgeoshape.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceSearchRequest.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceSearchRequest.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecategory.sip"
#include <qplacecategory.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceSearchRequest.cpp"


PyDoc_STRVAR(doc_QPlaceSearchRequest_searchTerm, "searchTerm(self) -> str");

extern "C" {static PyObject *meth_QPlaceSearchRequest_searchTerm(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_searchTerm(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->searchTerm());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_searchTerm, doc_QPlaceSearchRequest_searchTerm);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_setSearchTerm, "setSearchTerm(self, term: Optional[str])");

extern "C" {static PyObject *meth_QPlaceSearchRequest_setSearchTerm(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_setSearchTerm(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setSearchTerm(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_setSearchTerm, doc_QPlaceSearchRequest_setSearchTerm);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_categories, "categories(self) -> list[QPlaceCategory]");

extern "C" {static PyObject *meth_QPlaceSearchRequest_categories(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_categories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp))
        {
            QList< ::QPlaceCategory>*sipRes;

            sipRes = new QList< ::QPlaceCategory>(sipCpp->categories());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QPlaceCategory, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_categories, doc_QPlaceSearchRequest_categories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_setCategory, "setCategory(self, category: QPlaceCategory)");

extern "C" {static PyObject *meth_QPlaceSearchRequest_setCategory(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_setCategory(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceCategory* a0;
        ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp, sipType_QPlaceCategory, &a0))
        {
            sipCpp->setCategory(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_setCategory, doc_QPlaceSearchRequest_setCategory);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_setCategories, "setCategories(self, categories: Iterable[QPlaceCategory])");

extern "C" {static PyObject *meth_QPlaceSearchRequest_setCategories(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_setCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QPlaceCategory>* a0;
        int a0State = 0;
        ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp, sipType_QList_0100QPlaceCategory, &a0, &a0State))
        {
            sipCpp->setCategories(*a0);
            sipReleaseType(const_cast<QList< ::QPlaceCategory> *>(a0), sipType_QList_0100QPlaceCategory, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_setCategories, doc_QPlaceSearchRequest_setCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_searchArea, "searchArea(self) -> QGeoShape");

extern "C" {static PyObject *meth_QPlaceSearchRequest_searchArea(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_searchArea(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp))
        {
            ::QGeoShape*sipRes;

            sipRes = new ::QGeoShape(sipCpp->searchArea());

            return sipConvertFromNewType(sipRes, sipType_QGeoShape, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_searchArea, doc_QPlaceSearchRequest_searchArea);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_setSearchArea, "setSearchArea(self, area: QGeoShape)");

extern "C" {static PyObject *meth_QPlaceSearchRequest_setSearchArea(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_setSearchArea(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoShape* a0;
        ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp, sipType_QGeoShape, &a0))
        {
            sipCpp->setSearchArea(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_setSearchArea, doc_QPlaceSearchRequest_setSearchArea);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_recommendationId, "recommendationId(self) -> str");

extern "C" {static PyObject *meth_QPlaceSearchRequest_recommendationId(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_recommendationId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->recommendationId());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_recommendationId, doc_QPlaceSearchRequest_recommendationId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_setRecommendationId, "setRecommendationId(self, recommendationId: Optional[str])");

extern "C" {static PyObject *meth_QPlaceSearchRequest_setRecommendationId(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_setRecommendationId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setRecommendationId(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_setRecommendationId, doc_QPlaceSearchRequest_setRecommendationId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_searchContext, "searchContext(self) -> Any");

extern "C" {static PyObject *meth_QPlaceSearchRequest_searchContext(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_searchContext(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->searchContext());

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_searchContext, doc_QPlaceSearchRequest_searchContext);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_setSearchContext, "setSearchContext(self, context: Any)");

extern "C" {static PyObject *meth_QPlaceSearchRequest_setSearchContext(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_setSearchContext(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariant* a0;
        int a0State = 0;
        ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp, sipType_QVariant, &a0, &a0State))
        {
            sipCpp->setSearchContext(*a0);
            sipReleaseType(const_cast< ::QVariant *>(a0), sipType_QVariant, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_setSearchContext, doc_QPlaceSearchRequest_setSearchContext);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_visibilityScope, "visibilityScope(self) -> QLocation.VisibilityScope");

extern "C" {static PyObject *meth_QPlaceSearchRequest_visibilityScope(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_visibilityScope(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp))
        {
            ::QLocation::VisibilityScope*sipRes;

            sipRes = new ::QLocation::VisibilityScope(sipCpp->visibilityScope());

            return sipConvertFromNewType(sipRes, sipType_QLocation_VisibilityScope, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_visibilityScope, doc_QPlaceSearchRequest_visibilityScope);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_setVisibilityScope, "setVisibilityScope(self, visibilityScopes: Union[QLocation.VisibilityScope, QLocation.Visibility])");

extern "C" {static PyObject *meth_QPlaceSearchRequest_setVisibilityScope(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_setVisibilityScope(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocation::VisibilityScope* a0;
        int a0State = 0;
        ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp, sipType_QLocation_VisibilityScope, &a0, &a0State))
        {
            sipCpp->setVisibilityScope(*a0);
            sipReleaseType(a0, sipType_QLocation_VisibilityScope, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_setVisibilityScope, doc_QPlaceSearchRequest_setVisibilityScope);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_relevanceHint, "relevanceHint(self) -> QPlaceSearchRequest.RelevanceHint");

extern "C" {static PyObject *meth_QPlaceSearchRequest_relevanceHint(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_relevanceHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp))
        {
            ::QPlaceSearchRequest::RelevanceHint sipRes;

            sipRes = sipCpp->relevanceHint();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QPlaceSearchRequest_RelevanceHint);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_relevanceHint, doc_QPlaceSearchRequest_relevanceHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_setRelevanceHint, "setRelevanceHint(self, hint: QPlaceSearchRequest.RelevanceHint)");

extern "C" {static PyObject *meth_QPlaceSearchRequest_setRelevanceHint(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_setRelevanceHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPlaceSearchRequest::RelevanceHint a0;
        ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp, sipType_QPlaceSearchRequest_RelevanceHint, &a0))
        {
            sipCpp->setRelevanceHint(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_setRelevanceHint, doc_QPlaceSearchRequest_setRelevanceHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_limit, "limit(self) -> int");

extern "C" {static PyObject *meth_QPlaceSearchRequest_limit(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_limit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->limit();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_limit, doc_QPlaceSearchRequest_limit);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_setLimit, "setLimit(self, limit: int)");

extern "C" {static PyObject *meth_QPlaceSearchRequest_setLimit(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_setLimit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp, &a0))
        {
            sipCpp->setLimit(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_setLimit, doc_QPlaceSearchRequest_setLimit);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceSearchRequest_clear, "clear(self)");

extern "C" {static PyObject *meth_QPlaceSearchRequest_clear(PyObject *, PyObject *);}
static PyObject *meth_QPlaceSearchRequest_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPlaceSearchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceSearchRequest, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceSearchRequest, sipName_clear, doc_QPlaceSearchRequest_clear);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QPlaceSearchRequest___ne__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceSearchRequest___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceSearchRequest *sipCpp = reinterpret_cast< ::QPlaceSearchRequest *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceSearchRequest));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchRequest* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceSearchRequest, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceSearchRequest::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, ne_slot, sipType_QPlaceSearchRequest, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QPlaceSearchRequest___eq__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceSearchRequest___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceSearchRequest *sipCpp = reinterpret_cast< ::QPlaceSearchRequest *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceSearchRequest));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchRequest* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceSearchRequest, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceSearchRequest::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, eq_slot, sipType_QPlaceSearchRequest, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QPlaceSearchRequest(void *, int);}
static void release_QPlaceSearchRequest(void *sipCppV, int)
{
    delete reinterpret_cast< ::QPlaceSearchRequest *>(sipCppV);
}


extern "C" {static void *array_QPlaceSearchRequest(Py_ssize_t);}
static void *array_QPlaceSearchRequest(Py_ssize_t sipNrElem)
{
    return new ::QPlaceSearchRequest[sipNrElem];
}


extern "C" {static void array_delete_QPlaceSearchRequest(void *);}
static void array_delete_QPlaceSearchRequest(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPlaceSearchRequest *>(sipCpp);
}


extern "C" {static void assign_QPlaceSearchRequest(void *, Py_ssize_t, void *);}
static void assign_QPlaceSearchRequest(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPlaceSearchRequest *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPlaceSearchRequest *>(sipSrc);
}


extern "C" {static void *copy_QPlaceSearchRequest(const void *, Py_ssize_t);}
static void *copy_QPlaceSearchRequest(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPlaceSearchRequest(reinterpret_cast<const ::QPlaceSearchRequest *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPlaceSearchRequest(sipSimpleWrapper *);}
static void dealloc_QPlaceSearchRequest(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPlaceSearchRequest(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QPlaceSearchRequest(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPlaceSearchRequest(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QPlaceSearchRequest *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QPlaceSearchRequest();

            return sipCpp;
        }
    }

    {
        const ::QPlaceSearchRequest* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPlaceSearchRequest, &a0))
        {
            sipCpp = new ::QPlaceSearchRequest(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QPlaceSearchRequest[] = {
    {(void *)slot_QPlaceSearchRequest___ne__, ne_slot},
    {(void *)slot_QPlaceSearchRequest___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QPlaceSearchRequest[] = {
    {sipName_categories, meth_QPlaceSearchRequest_categories, METH_VARARGS, doc_QPlaceSearchRequest_categories},
    {sipName_clear, meth_QPlaceSearchRequest_clear, METH_VARARGS, doc_QPlaceSearchRequest_clear},
    {sipName_limit, meth_QPlaceSearchRequest_limit, METH_VARARGS, doc_QPlaceSearchRequest_limit},
    {sipName_recommendationId, meth_QPlaceSearchRequest_recommendationId, METH_VARARGS, doc_QPlaceSearchRequest_recommendationId},
    {sipName_relevanceHint, meth_QPlaceSearchRequest_relevanceHint, METH_VARARGS, doc_QPlaceSearchRequest_relevanceHint},
    {sipName_searchArea, meth_QPlaceSearchRequest_searchArea, METH_VARARGS, doc_QPlaceSearchRequest_searchArea},
    {sipName_searchContext, meth_QPlaceSearchRequest_searchContext, METH_VARARGS, doc_QPlaceSearchRequest_searchContext},
    {sipName_searchTerm, meth_QPlaceSearchRequest_searchTerm, METH_VARARGS, doc_QPlaceSearchRequest_searchTerm},
    {sipName_setCategories, meth_QPlaceSearchRequest_setCategories, METH_VARARGS, doc_QPlaceSearchRequest_setCategories},
    {sipName_setCategory, meth_QPlaceSearchRequest_setCategory, METH_VARARGS, doc_QPlaceSearchRequest_setCategory},
    {sipName_setLimit, meth_QPlaceSearchRequest_setLimit, METH_VARARGS, doc_QPlaceSearchRequest_setLimit},
    {sipName_setRecommendationId, meth_QPlaceSearchRequest_setRecommendationId, METH_VARARGS, doc_QPlaceSearchRequest_setRecommendationId},
    {sipName_setRelevanceHint, meth_QPlaceSearchRequest_setRelevanceHint, METH_VARARGS, doc_QPlaceSearchRequest_setRelevanceHint},
    {sipName_setSearchArea, meth_QPlaceSearchRequest_setSearchArea, METH_VARARGS, doc_QPlaceSearchRequest_setSearchArea},
    {sipName_setSearchContext, meth_QPlaceSearchRequest_setSearchContext, METH_VARARGS, doc_QPlaceSearchRequest_setSearchContext},
    {sipName_setSearchTerm, meth_QPlaceSearchRequest_setSearchTerm, METH_VARARGS, doc_QPlaceSearchRequest_setSearchTerm},
    {sipName_setVisibilityScope, meth_QPlaceSearchRequest_setVisibilityScope, METH_VARARGS, doc_QPlaceSearchRequest_setVisibilityScope},
    {sipName_visibilityScope, meth_QPlaceSearchRequest_visibilityScope, METH_VARARGS, doc_QPlaceSearchRequest_visibilityScope}
};

static sipEnumMemberDef enummembers_QPlaceSearchRequest[] = {
    {sipName_DistanceHint, static_cast<int>(::QPlaceSearchRequest::DistanceHint), 80},
    {sipName_LexicalPlaceNameHint, static_cast<int>(::QPlaceSearchRequest::LexicalPlaceNameHint), 80},
    {sipName_UnspecifiedHint, static_cast<int>(::QPlaceSearchRequest::UnspecifiedHint), 80},
};

PyDoc_STRVAR(doc_QPlaceSearchRequest, "\1QPlaceSearchRequest()\n"
"QPlaceSearchRequest(other: QPlaceSearchRequest)");


static pyqt5ClassPluginDef plugin_QPlaceSearchRequest = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QPlaceSearchRequest = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPlaceSearchRequest,
        SIP_NULLPTR,
        &plugin_QPlaceSearchRequest,
    },
    {
        sipNameNr_QPlaceSearchRequest,
        {0, 0, 1},
        18, methods_QPlaceSearchRequest,
        3, enummembers_QPlaceSearchRequest,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPlaceSearchRequest,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QPlaceSearchRequest,
    init_type_QPlaceSearchRequest,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPlaceSearchRequest,
    assign_QPlaceSearchRequest,
    array_QPlaceSearchRequest,
    copy_QPlaceSearchRequest,
    release_QPlaceSearchRequest,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPlaceSearchRequest,
    sizeof (::QPlaceSearchRequest),
};
