/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameracapturebufferformatcontrol.sip"
#include <qcameracapturebufferformatcontrol.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qvideoframe.sip"
#include <qvideoframe.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qpymultimedia_qlist.sip"
#include <qvideoframe.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraCaptureBufferFormatControl.cpp"


class sipQCameraCaptureBufferFormatControl : public ::QCameraCaptureBufferFormatControl
{
public:
    sipQCameraCaptureBufferFormatControl(::QObject*);
    virtual ~sipQCameraCaptureBufferFormatControl();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void setBufferFormat(::QVideoFrame::PixelFormat) SIP_OVERRIDE;
    ::QVideoFrame::PixelFormat bufferFormat() const SIP_OVERRIDE;
    ::QList< ::QVideoFrame::PixelFormat> supportedBufferFormats() const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQCameraCaptureBufferFormatControl(const sipQCameraCaptureBufferFormatControl &);
    sipQCameraCaptureBufferFormatControl &operator = (const sipQCameraCaptureBufferFormatControl &);

    char sipPyMethods[10];
};

sipQCameraCaptureBufferFormatControl::sipQCameraCaptureBufferFormatControl(::QObject*a0): ::QCameraCaptureBufferFormatControl(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCameraCaptureBufferFormatControl::~sipQCameraCaptureBufferFormatControl()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQCameraCaptureBufferFormatControl::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QCameraCaptureBufferFormatControl);

    return ::QCameraCaptureBufferFormatControl::metaObject();
}

int sipQCameraCaptureBufferFormatControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QCameraCaptureBufferFormatControl::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QCameraCaptureBufferFormatControl, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQCameraCaptureBufferFormatControl::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QCameraCaptureBufferFormatControl, _clname, &sipCpp) ? sipCpp : ::QCameraCaptureBufferFormatControl::qt_metacast(_clname));
}

void sipQCameraCaptureBufferFormatControl::setBufferFormat(::QVideoFrame::PixelFormat a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, sipName_QCameraCaptureBufferFormatControl, sipName_setBufferFormat);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_43(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QVideoFrame::PixelFormat);

    sipVH_QtMultimedia_43(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVideoFrame::PixelFormat sipQCameraCaptureBufferFormatControl::bufferFormat() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraCaptureBufferFormatControl, sipName_bufferFormat);

    if (!sipMeth)
        return ::QVideoFrame::Format_Invalid;

    extern ::QVideoFrame::PixelFormat sipVH_QtMultimedia_42(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_42(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QList< ::QVideoFrame::PixelFormat> sipQCameraCaptureBufferFormatControl::supportedBufferFormats() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraCaptureBufferFormatControl, sipName_supportedBufferFormats);

    if (!sipMeth)
        return ::QList< ::QVideoFrame::PixelFormat>();

    extern ::QList< ::QVideoFrame::PixelFormat> sipVH_QtMultimedia_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_41(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQCameraCaptureBufferFormatControl::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QCameraCaptureBufferFormatControl::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraCaptureBufferFormatControl::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QCameraCaptureBufferFormatControl::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraCaptureBufferFormatControl::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QCameraCaptureBufferFormatControl::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraCaptureBufferFormatControl::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QCameraCaptureBufferFormatControl::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraCaptureBufferFormatControl::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QCameraCaptureBufferFormatControl::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCameraCaptureBufferFormatControl::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QCameraCaptureBufferFormatControl::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQCameraCaptureBufferFormatControl::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QCameraCaptureBufferFormatControl::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QCameraCaptureBufferFormatControl_supportedBufferFormats, "supportedBufferFormats(self) -> list[QVideoFrame.PixelFormat]");

extern "C" {static PyObject *meth_QCameraCaptureBufferFormatControl_supportedBufferFormats(PyObject *, PyObject *);}
static PyObject *meth_QCameraCaptureBufferFormatControl_supportedBufferFormats(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QCameraCaptureBufferFormatControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraCaptureBufferFormatControl, &sipCpp))
        {
            ::QList< ::QVideoFrame::PixelFormat>*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraCaptureBufferFormatControl, sipName_supportedBufferFormats);
                return SIP_NULLPTR;
            }

            sipRes = new ::QList< ::QVideoFrame::PixelFormat>(sipCpp->supportedBufferFormats());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QVideoFrame_PixelFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraCaptureBufferFormatControl, sipName_supportedBufferFormats, doc_QCameraCaptureBufferFormatControl_supportedBufferFormats);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraCaptureBufferFormatControl_bufferFormat, "bufferFormat(self) -> QVideoFrame.PixelFormat");

extern "C" {static PyObject *meth_QCameraCaptureBufferFormatControl_bufferFormat(PyObject *, PyObject *);}
static PyObject *meth_QCameraCaptureBufferFormatControl_bufferFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QCameraCaptureBufferFormatControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraCaptureBufferFormatControl, &sipCpp))
        {
            ::QVideoFrame::PixelFormat sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraCaptureBufferFormatControl, sipName_bufferFormat);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->bufferFormat();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QVideoFrame_PixelFormat);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraCaptureBufferFormatControl, sipName_bufferFormat, doc_QCameraCaptureBufferFormatControl_bufferFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraCaptureBufferFormatControl_setBufferFormat, "setBufferFormat(self, format: QVideoFrame.PixelFormat)");

extern "C" {static PyObject *meth_QCameraCaptureBufferFormatControl_setBufferFormat(PyObject *, PyObject *);}
static PyObject *meth_QCameraCaptureBufferFormatControl_setBufferFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QVideoFrame::PixelFormat a0;
        ::QCameraCaptureBufferFormatControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraCaptureBufferFormatControl, &sipCpp, sipType_QVideoFrame_PixelFormat, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraCaptureBufferFormatControl, sipName_setBufferFormat);
                return SIP_NULLPTR;
            }

            sipCpp->setBufferFormat(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraCaptureBufferFormatControl, sipName_setBufferFormat, doc_QCameraCaptureBufferFormatControl_setBufferFormat);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QCameraCaptureBufferFormatControl(void *, const sipTypeDef *);}
static void *cast_QCameraCaptureBufferFormatControl(void *sipCppV, const sipTypeDef *targetType)
{
    ::QCameraCaptureBufferFormatControl *sipCpp = reinterpret_cast< ::QCameraCaptureBufferFormatControl *>(sipCppV);

    if (targetType == sipType_QCameraCaptureBufferFormatControl)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaControl)->ctd_cast(static_cast< ::QMediaControl *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QCameraCaptureBufferFormatControl(void *, int);}
static void release_QCameraCaptureBufferFormatControl(void *sipCppV, int)
{
    ::QCameraCaptureBufferFormatControl *sipCpp = reinterpret_cast< ::QCameraCaptureBufferFormatControl *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QCameraCaptureBufferFormatControl(sipSimpleWrapper *);}
static void dealloc_QCameraCaptureBufferFormatControl(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQCameraCaptureBufferFormatControl *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QCameraCaptureBufferFormatControl(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QCameraCaptureBufferFormatControl(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QCameraCaptureBufferFormatControl(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQCameraCaptureBufferFormatControl *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQCameraCaptureBufferFormatControl(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QCameraCaptureBufferFormatControl[] = {{104, 255, 1}};


static PyMethodDef methods_QCameraCaptureBufferFormatControl[] = {
    {sipName_bufferFormat, meth_QCameraCaptureBufferFormatControl_bufferFormat, METH_VARARGS, doc_QCameraCaptureBufferFormatControl_bufferFormat},
    {sipName_setBufferFormat, meth_QCameraCaptureBufferFormatControl_setBufferFormat, METH_VARARGS, doc_QCameraCaptureBufferFormatControl_setBufferFormat},
    {sipName_supportedBufferFormats, meth_QCameraCaptureBufferFormatControl_supportedBufferFormats, METH_VARARGS, doc_QCameraCaptureBufferFormatControl_supportedBufferFormats}
};

PyDoc_STRVAR(doc_QCameraCaptureBufferFormatControl, "\1QCameraCaptureBufferFormatControl(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QCameraCaptureBufferFormatControl[] = {
    {"bufferFormatChanged(QVideoFrame::PixelFormat)", "\1bufferFormatChanged(self, format: QVideoFrame.PixelFormat)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QCameraCaptureBufferFormatControl = {
    &::QCameraCaptureBufferFormatControl::staticMetaObject,
    0,
    signals_QCameraCaptureBufferFormatControl,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QCameraCaptureBufferFormatControl = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCameraCaptureBufferFormatControl,
        SIP_NULLPTR,
        &plugin_QCameraCaptureBufferFormatControl,
    },
    {
        sipNameNr_QCameraCaptureBufferFormatControl,
        {0, 0, 1},
        3, methods_QCameraCaptureBufferFormatControl,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QCameraCaptureBufferFormatControl,
    -1,
    -1,
    supers_QCameraCaptureBufferFormatControl,
    SIP_NULLPTR,
    init_type_QCameraCaptureBufferFormatControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QCameraCaptureBufferFormatControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QCameraCaptureBufferFormatControl,
    cast_QCameraCaptureBufferFormatControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QCameraCaptureBufferFormatControl),
};
