/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtQml/qqmlcontext.sip"
#include <qqmlcontext.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"

#line 59 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtQml/qqmlengine.sip"
#include <qqmlengine.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtQml/qqmlcontext.sip"
#include <qqmlcontext.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtQml/qqmlcontext.sip"
#include <qqmlcontext.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 58 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 61 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 64 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 67 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 70 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 73 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 76 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 79 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 82 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 85 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 88 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 91 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 94 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 97 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlContext.cpp"


class sipQQmlContext : public ::QQmlContext
{
public:
    sipQQmlContext(::QQmlEngine*, ::QObject*);
    sipQQmlContext(::QQmlContext*, ::QObject*);
    virtual ~sipQQmlContext();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQmlContext(const sipQQmlContext &);
    sipQQmlContext &operator = (const sipQQmlContext &);

    char sipPyMethods[7];
};

sipQQmlContext::sipQQmlContext(::QQmlEngine*a0, ::QObject*a1): ::QQmlContext(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlContext::sipQQmlContext(::QQmlContext*a0, ::QObject*a1): ::QQmlContext(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlContext::~sipQQmlContext()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQQmlContext::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtQml_qt_metaobject(sipPySelf, sipType_QQmlContext);

    return ::QQmlContext::metaObject();
}

int sipQQmlContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QQmlContext::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtQml_qt_metacall(sipPySelf, sipType_QQmlContext, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQQmlContext::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtQml_qt_metacast(sipPySelf, sipType_QQmlContext, _clname, &sipCpp) ? sipCpp : ::QQmlContext::qt_metacast(_clname));
}

bool sipQQmlContext::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QQmlContext::event(a0);

    extern bool sipVH_QtQml_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtQml_5(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQQmlContext::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QQmlContext::eventFilter(a0, a1);

    extern bool sipVH_QtQml_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtQml_4(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQQmlContext::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QQmlContext::timerEvent(a0);
        return;
    }

    extern void sipVH_QtQml_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtQml_3(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlContext::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QQmlContext::childEvent(a0);
        return;
    }

    extern void sipVH_QtQml_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtQml_2(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlContext::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QQmlContext::customEvent(a0);
        return;
    }

    extern void sipVH_QtQml_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtQml_1(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlContext::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QQmlContext::connectNotify(a0);
        return;
    }

    extern void sipVH_QtQml_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtQml_0(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQQmlContext::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QQmlContext::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtQml_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtQml_0(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QQmlContext_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QQmlContext_isValid(PyObject *, PyObject *);}
static PyObject *meth_QQmlContext_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlContext *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlContext, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlContext, sipName_isValid, doc_QQmlContext_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlContext_engine, "engine(self) -> Optional[QQmlEngine]");

extern "C" {static PyObject *meth_QQmlContext_engine(PyObject *, PyObject *);}
static PyObject *meth_QQmlContext_engine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlContext *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlContext, &sipCpp))
        {
            ::QQmlEngine*sipRes;

            sipRes = sipCpp->engine();

            return sipConvertFromType(sipRes, sipType_QQmlEngine, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlContext, sipName_engine, doc_QQmlContext_engine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlContext_parentContext, "parentContext(self) -> Optional[QQmlContext]");

extern "C" {static PyObject *meth_QQmlContext_parentContext(PyObject *, PyObject *);}
static PyObject *meth_QQmlContext_parentContext(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlContext *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlContext, &sipCpp))
        {
            ::QQmlContext*sipRes;

            sipRes = sipCpp->parentContext();

            return sipConvertFromType(sipRes, sipType_QQmlContext, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlContext, sipName_parentContext, doc_QQmlContext_parentContext);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlContext_contextObject, "contextObject(self) -> Optional[QObject]");

extern "C" {static PyObject *meth_QQmlContext_contextObject(PyObject *, PyObject *);}
static PyObject *meth_QQmlContext_contextObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlContext *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlContext, &sipCpp))
        {
            ::QObject*sipRes;

            sipRes = sipCpp->contextObject();

            return sipConvertFromType(sipRes, sipType_QObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlContext, sipName_contextObject, doc_QQmlContext_contextObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlContext_setContextObject, "setContextObject(self, a0: Optional[QObject])");

extern "C" {static PyObject *meth_QQmlContext_setContextObject(PyObject *, PyObject *);}
static PyObject *meth_QQmlContext_setContextObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;
        ::QQmlContext *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QQmlContext, &sipCpp, sipType_QObject, &a0))
        {
            sipCpp->setContextObject(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlContext, sipName_setContextObject, doc_QQmlContext_setContextObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlContext_contextProperty, "contextProperty(self, a0: Optional[str]) -> Any");

extern "C" {static PyObject *meth_QQmlContext_contextProperty(PyObject *, PyObject *);}
static PyObject *meth_QQmlContext_contextProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QQmlContext *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQmlContext, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->contextProperty(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlContext, sipName_contextProperty, doc_QQmlContext_contextProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlContext_setContextProperty, "setContextProperty(self, a0: Optional[str], a1: Optional[QObject])\n"
"setContextProperty(self, a0: Optional[str], a1: Any)");

extern "C" {static PyObject *meth_QQmlContext_setContextProperty(PyObject *, PyObject *);}
static PyObject *meth_QQmlContext_setContextProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QObject* a1;
        ::QQmlContext *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J8", &sipSelf, sipType_QQmlContext, &sipCpp, sipType_QString, &a0, &a0State, sipType_QObject, &a1))
        {
            sipCpp->setContextProperty(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QQmlContext *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QQmlContext, &sipCpp, sipType_QString, &a0, &a0State, sipType_QVariant, &a1, &a1State))
        {
            sipCpp->setContextProperty(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlContext, sipName_setContextProperty, doc_QQmlContext_setContextProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlContext_nameForObject, "nameForObject(self, a0: Optional[QObject]) -> str");

extern "C" {static PyObject *meth_QQmlContext_nameForObject(PyObject *, PyObject *);}
static PyObject *meth_QQmlContext_nameForObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;
        const ::QQmlContext *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QQmlContext, &sipCpp, sipType_QObject, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->nameForObject(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlContext, sipName_nameForObject, doc_QQmlContext_nameForObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlContext_resolvedUrl, "resolvedUrl(self, a0: QUrl) -> QUrl");

extern "C" {static PyObject *meth_QQmlContext_resolvedUrl(PyObject *, PyObject *);}
static PyObject *meth_QQmlContext_resolvedUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QQmlContext *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QQmlContext, &sipCpp, sipType_QUrl, &a0))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->resolvedUrl(*a0));

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlContext, sipName_resolvedUrl, doc_QQmlContext_resolvedUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlContext_setBaseUrl, "setBaseUrl(self, a0: QUrl)");

extern "C" {static PyObject *meth_QQmlContext_setBaseUrl(PyObject *, PyObject *);}
static PyObject *meth_QQmlContext_setBaseUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QQmlContext *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QQmlContext, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setBaseUrl(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlContext, sipName_setBaseUrl, doc_QQmlContext_setBaseUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlContext_baseUrl, "baseUrl(self) -> QUrl");

extern "C" {static PyObject *meth_QQmlContext_baseUrl(PyObject *, PyObject *);}
static PyObject *meth_QQmlContext_baseUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQmlContext *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlContext, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->baseUrl());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlContext, sipName_baseUrl, doc_QQmlContext_baseUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlContext_setContextProperties, "setContextProperties(self, properties: Iterable[QQmlContext.PropertyPair])");

extern "C" {static PyObject *meth_QQmlContext_setContextProperties(PyObject *, PyObject *);}
static PyObject *meth_QQmlContext_setContextProperties(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QVector< ::QQmlContext::PropertyPair>* a0;
        int a0State = 0;
        ::QQmlContext *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QQmlContext, &sipCpp, sipType_QVector_0100QQmlContext_PropertyPair, &a0, &a0State))
        {
            sipCpp->setContextProperties(*a0);
            sipReleaseType(const_cast<QVector< ::QQmlContext::PropertyPair> *>(a0), sipType_QVector_0100QQmlContext_PropertyPair, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlContext, sipName_setContextProperties, doc_QQmlContext_setContextProperties);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QQmlContext(void *, const sipTypeDef *);}
static void *cast_QQmlContext(void *sipCppV, const sipTypeDef *targetType)
{
    ::QQmlContext *sipCpp = reinterpret_cast< ::QQmlContext *>(sipCppV);

    if (targetType == sipType_QQmlContext)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQmlContext(void *, int);}
static void release_QQmlContext(void *sipCppV, int)
{
    ::QQmlContext *sipCpp = reinterpret_cast< ::QQmlContext *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QQmlContext(sipSimpleWrapper *);}
static void dealloc_QQmlContext(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQQmlContext *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQmlContext(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QQmlContext(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQmlContext(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQQmlContext *sipCpp = SIP_NULLPTR;

    {
        ::QQmlEngine* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|JH", sipType_QQmlEngine, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQQmlContext(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QQmlContext* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|JH", sipType_QQmlContext, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQQmlContext(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QQmlContext[] = {{9, 0, 1}};


static PyMethodDef methods_QQmlContext[] = {
    {sipName_baseUrl, meth_QQmlContext_baseUrl, METH_VARARGS, doc_QQmlContext_baseUrl},
    {sipName_contextObject, meth_QQmlContext_contextObject, METH_VARARGS, doc_QQmlContext_contextObject},
    {sipName_contextProperty, meth_QQmlContext_contextProperty, METH_VARARGS, doc_QQmlContext_contextProperty},
    {sipName_engine, meth_QQmlContext_engine, METH_VARARGS, doc_QQmlContext_engine},
    {sipName_isValid, meth_QQmlContext_isValid, METH_VARARGS, doc_QQmlContext_isValid},
    {sipName_nameForObject, meth_QQmlContext_nameForObject, METH_VARARGS, doc_QQmlContext_nameForObject},
    {sipName_parentContext, meth_QQmlContext_parentContext, METH_VARARGS, doc_QQmlContext_parentContext},
    {sipName_resolvedUrl, meth_QQmlContext_resolvedUrl, METH_VARARGS, doc_QQmlContext_resolvedUrl},
    {sipName_setBaseUrl, meth_QQmlContext_setBaseUrl, METH_VARARGS, doc_QQmlContext_setBaseUrl},
    {sipName_setContextObject, meth_QQmlContext_setContextObject, METH_VARARGS, doc_QQmlContext_setContextObject},
    {sipName_setContextProperties, meth_QQmlContext_setContextProperties, METH_VARARGS, doc_QQmlContext_setContextProperties},
    {sipName_setContextProperty, meth_QQmlContext_setContextProperty, METH_VARARGS, doc_QQmlContext_setContextProperty}
};

PyDoc_STRVAR(doc_QQmlContext, "\1QQmlContext(engine: Optional[QQmlEngine], parent: Optional[QObject] = None)\n"
"QQmlContext(parentContext: Optional[QQmlContext], parent: Optional[QObject] = None)");


static pyqt5ClassPluginDef plugin_QQmlContext = {
    &::QQmlContext::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQml_QQmlContext = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQmlContext,
        SIP_NULLPTR,
        &plugin_QQmlContext,
    },
    {
        sipNameNr_QQmlContext,
        {0, 0, 1},
        12, methods_QQmlContext,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQmlContext,
    -1,
    -1,
    supers_QQmlContext,
    SIP_NULLPTR,
    init_type_QQmlContext,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQmlContext,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QQmlContext,
    cast_QQmlContext,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QQmlContext),
};
