/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudiodecodercontrol.sip"
#include <qaudiodecodercontrol.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudioformat.sip"
#include <qaudioformat.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudiodecoder.sip"
#include <qaudiodecoder.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudiobuffer.sip"
#include <qaudiobuffer.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioDecoderControl.cpp"


class sipQAudioDecoderControl : public ::QAudioDecoderControl
{
public:
    sipQAudioDecoderControl(::QObject*);
    virtual ~sipQAudioDecoderControl();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::qint64 duration() const SIP_OVERRIDE;
    ::qint64 position() const SIP_OVERRIDE;
    bool bufferAvailable() const SIP_OVERRIDE;
    ::QAudioBuffer read() SIP_OVERRIDE;
    void setAudioFormat(const ::QAudioFormat&) SIP_OVERRIDE;
    ::QAudioFormat audioFormat() const SIP_OVERRIDE;
    void stop() SIP_OVERRIDE;
    void start() SIP_OVERRIDE;
    void setSourceDevice(::QIODevice*) SIP_OVERRIDE;
    ::QIODevice* sourceDevice() const SIP_OVERRIDE;
    void setSourceFilename(const ::QString&) SIP_OVERRIDE;
    ::QString sourceFilename() const SIP_OVERRIDE;
    ::QAudioDecoder::State state() const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAudioDecoderControl(const sipQAudioDecoderControl &);
    sipQAudioDecoderControl &operator = (const sipQAudioDecoderControl &);

    char sipPyMethods[20];
};

sipQAudioDecoderControl::sipQAudioDecoderControl(::QObject*a0): ::QAudioDecoderControl(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAudioDecoderControl::~sipQAudioDecoderControl()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQAudioDecoderControl::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QAudioDecoderControl);

    return ::QAudioDecoderControl::metaObject();
}

int sipQAudioDecoderControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QAudioDecoderControl::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QAudioDecoderControl, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQAudioDecoderControl::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QAudioDecoderControl, _clname, &sipCpp) ? sipCpp : ::QAudioDecoderControl::qt_metacast(_clname));
}

::qint64 sipQAudioDecoderControl::duration() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAudioDecoderControl, sipName_duration);

    if (!sipMeth)
        return 0;

    extern ::qint64 sipVH_QtMultimedia_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_29(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::qint64 sipQAudioDecoderControl::position() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAudioDecoderControl, sipName_position);

    if (!sipMeth)
        return 0;

    extern ::qint64 sipVH_QtMultimedia_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_29(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQAudioDecoderControl::bufferAvailable() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAudioDecoderControl, sipName_bufferAvailable);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_16(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QAudioBuffer sipQAudioDecoderControl::read()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, sipName_QAudioDecoderControl, sipName_read);

    if (!sipMeth)
        return ::QAudioBuffer();

    extern ::QAudioBuffer sipVH_QtMultimedia_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_28(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAudioDecoderControl::setAudioFormat(const ::QAudioFormat& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, sipName_QAudioDecoderControl, sipName_setAudioFormat);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QAudioFormat&);

    sipVH_QtMultimedia_27(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QAudioFormat sipQAudioDecoderControl::audioFormat() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAudioDecoderControl, sipName_audioFormat);

    if (!sipMeth)
        return ::QAudioFormat();

    extern ::QAudioFormat sipVH_QtMultimedia_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_26(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAudioDecoderControl::stop()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, sipName_QAudioDecoderControl, sipName_stop);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAudioDecoderControl::start()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, sipName_QAudioDecoderControl, sipName_start);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAudioDecoderControl::setSourceDevice(::QIODevice*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, sipName_QAudioDecoderControl, sipName_setSourceDevice);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QIODevice*);

    sipVH_QtMultimedia_25(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QIODevice* sipQAudioDecoderControl::sourceDevice() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAudioDecoderControl, sipName_sourceDevice);

    if (!sipMeth)
        return 0;

    extern ::QIODevice* sipVH_QtMultimedia_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_24(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAudioDecoderControl::setSourceFilename(const ::QString& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, sipName_QAudioDecoderControl, sipName_setSourceFilename);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    sipVH_QtMultimedia_23(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QString sipQAudioDecoderControl::sourceFilename() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAudioDecoderControl, sipName_sourceFilename);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtMultimedia_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_22(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QAudioDecoder::State sipQAudioDecoderControl::state() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAudioDecoderControl, sipName_state);

    if (!sipMeth)
        return ::QAudioDecoder::StoppedState;

    extern ::QAudioDecoder::State sipVH_QtMultimedia_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_21(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAudioDecoderControl::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QAudioDecoderControl::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioDecoderControl::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QAudioDecoderControl::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioDecoderControl::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QAudioDecoderControl::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioDecoderControl::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QAudioDecoderControl::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioDecoderControl::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QAudioDecoderControl::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAudioDecoderControl::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QAudioDecoderControl::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQAudioDecoderControl::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QAudioDecoderControl::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QAudioDecoderControl_state, "state(self) -> QAudioDecoder.State");

extern "C" {static PyObject *meth_QAudioDecoderControl_state(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoderControl_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QAudioDecoderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoderControl, &sipCpp))
        {
            ::QAudioDecoder::State sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioDecoderControl, sipName_state);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAudioDecoder_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoderControl, sipName_state, doc_QAudioDecoderControl_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoderControl_sourceFilename, "sourceFilename(self) -> str");

extern "C" {static PyObject *meth_QAudioDecoderControl_sourceFilename(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoderControl_sourceFilename(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QAudioDecoderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoderControl, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioDecoderControl, sipName_sourceFilename);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->sourceFilename());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoderControl, sipName_sourceFilename, doc_QAudioDecoderControl_sourceFilename);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoderControl_setSourceFilename, "setSourceFilename(self, fileName: Optional[str])");

extern "C" {static PyObject *meth_QAudioDecoderControl_setSourceFilename(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoderControl_setSourceFilename(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QAudioDecoderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAudioDecoderControl, &sipCpp, sipType_QString, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioDecoderControl, sipName_setSourceFilename);
                return SIP_NULLPTR;
            }

            sipCpp->setSourceFilename(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoderControl, sipName_setSourceFilename, doc_QAudioDecoderControl_setSourceFilename);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoderControl_sourceDevice, "sourceDevice(self) -> Optional[QIODevice]");

extern "C" {static PyObject *meth_QAudioDecoderControl_sourceDevice(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoderControl_sourceDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QAudioDecoderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoderControl, &sipCpp))
        {
            ::QIODevice*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioDecoderControl, sipName_sourceDevice);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->sourceDevice();

            return sipConvertFromType(sipRes, sipType_QIODevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoderControl, sipName_sourceDevice, doc_QAudioDecoderControl_sourceDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoderControl_setSourceDevice, "setSourceDevice(self, device: Optional[QIODevice])");

extern "C" {static PyObject *meth_QAudioDecoderControl_setSourceDevice(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoderControl_setSourceDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QIODevice* a0;
        ::QAudioDecoderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QAudioDecoderControl, &sipCpp, sipType_QIODevice, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioDecoderControl, sipName_setSourceDevice);
                return SIP_NULLPTR;
            }

            sipCpp->setSourceDevice(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoderControl, sipName_setSourceDevice, doc_QAudioDecoderControl_setSourceDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoderControl_start, "start(self)");

extern "C" {static PyObject *meth_QAudioDecoderControl_start(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoderControl_start(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QAudioDecoderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoderControl, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioDecoderControl, sipName_start);
                return SIP_NULLPTR;
            }

            sipCpp->start();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoderControl, sipName_start, doc_QAudioDecoderControl_start);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoderControl_stop, "stop(self)");

extern "C" {static PyObject *meth_QAudioDecoderControl_stop(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoderControl_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QAudioDecoderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoderControl, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioDecoderControl, sipName_stop);
                return SIP_NULLPTR;
            }

            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoderControl, sipName_stop, doc_QAudioDecoderControl_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoderControl_audioFormat, "audioFormat(self) -> QAudioFormat");

extern "C" {static PyObject *meth_QAudioDecoderControl_audioFormat(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoderControl_audioFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QAudioDecoderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoderControl, &sipCpp))
        {
            ::QAudioFormat*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioDecoderControl, sipName_audioFormat);
                return SIP_NULLPTR;
            }

            sipRes = new ::QAudioFormat(sipCpp->audioFormat());

            return sipConvertFromNewType(sipRes, sipType_QAudioFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoderControl, sipName_audioFormat, doc_QAudioDecoderControl_audioFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoderControl_setAudioFormat, "setAudioFormat(self, format: QAudioFormat)");

extern "C" {static PyObject *meth_QAudioDecoderControl_setAudioFormat(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoderControl_setAudioFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QAudioFormat* a0;
        ::QAudioDecoderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAudioDecoderControl, &sipCpp, sipType_QAudioFormat, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioDecoderControl, sipName_setAudioFormat);
                return SIP_NULLPTR;
            }

            sipCpp->setAudioFormat(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoderControl, sipName_setAudioFormat, doc_QAudioDecoderControl_setAudioFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoderControl_read, "read(self) -> QAudioBuffer");

extern "C" {static PyObject *meth_QAudioDecoderControl_read(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoderControl_read(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QAudioDecoderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoderControl, &sipCpp))
        {
            ::QAudioBuffer*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioDecoderControl, sipName_read);
                return SIP_NULLPTR;
            }

            sipRes = new ::QAudioBuffer(sipCpp->read());

            return sipConvertFromNewType(sipRes, sipType_QAudioBuffer, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoderControl, sipName_read, doc_QAudioDecoderControl_read);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoderControl_bufferAvailable, "bufferAvailable(self) -> bool");

extern "C" {static PyObject *meth_QAudioDecoderControl_bufferAvailable(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoderControl_bufferAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QAudioDecoderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoderControl, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioDecoderControl, sipName_bufferAvailable);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->bufferAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoderControl, sipName_bufferAvailable, doc_QAudioDecoderControl_bufferAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoderControl_position, "position(self) -> int");

extern "C" {static PyObject *meth_QAudioDecoderControl_position(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoderControl_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QAudioDecoderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoderControl, &sipCpp))
        {
            ::qint64 sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioDecoderControl, sipName_position);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->position();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoderControl, sipName_position, doc_QAudioDecoderControl_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioDecoderControl_duration, "duration(self) -> int");

extern "C" {static PyObject *meth_QAudioDecoderControl_duration(PyObject *, PyObject *);}
static PyObject *meth_QAudioDecoderControl_duration(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QAudioDecoderControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioDecoderControl, &sipCpp))
        {
            ::qint64 sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioDecoderControl, sipName_duration);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->duration();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioDecoderControl, sipName_duration, doc_QAudioDecoderControl_duration);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAudioDecoderControl(void *, const sipTypeDef *);}
static void *cast_QAudioDecoderControl(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAudioDecoderControl *sipCpp = reinterpret_cast< ::QAudioDecoderControl *>(sipCppV);

    if (targetType == sipType_QAudioDecoderControl)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaControl)->ctd_cast(static_cast< ::QMediaControl *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAudioDecoderControl(void *, int);}
static void release_QAudioDecoderControl(void *sipCppV, int)
{
    ::QAudioDecoderControl *sipCpp = reinterpret_cast< ::QAudioDecoderControl *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QAudioDecoderControl(sipSimpleWrapper *);}
static void dealloc_QAudioDecoderControl(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAudioDecoderControl *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAudioDecoderControl(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAudioDecoderControl(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAudioDecoderControl(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQAudioDecoderControl *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQAudioDecoderControl(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAudioDecoderControl[] = {{104, 255, 1}};


static PyMethodDef methods_QAudioDecoderControl[] = {
    {sipName_audioFormat, meth_QAudioDecoderControl_audioFormat, METH_VARARGS, doc_QAudioDecoderControl_audioFormat},
    {sipName_bufferAvailable, meth_QAudioDecoderControl_bufferAvailable, METH_VARARGS, doc_QAudioDecoderControl_bufferAvailable},
    {sipName_duration, meth_QAudioDecoderControl_duration, METH_VARARGS, doc_QAudioDecoderControl_duration},
    {sipName_position, meth_QAudioDecoderControl_position, METH_VARARGS, doc_QAudioDecoderControl_position},
    {sipName_read, meth_QAudioDecoderControl_read, METH_VARARGS, doc_QAudioDecoderControl_read},
    {sipName_setAudioFormat, meth_QAudioDecoderControl_setAudioFormat, METH_VARARGS, doc_QAudioDecoderControl_setAudioFormat},
    {sipName_setSourceDevice, meth_QAudioDecoderControl_setSourceDevice, METH_VARARGS, doc_QAudioDecoderControl_setSourceDevice},
    {sipName_setSourceFilename, meth_QAudioDecoderControl_setSourceFilename, METH_VARARGS, doc_QAudioDecoderControl_setSourceFilename},
    {sipName_sourceDevice, meth_QAudioDecoderControl_sourceDevice, METH_VARARGS, doc_QAudioDecoderControl_sourceDevice},
    {sipName_sourceFilename, meth_QAudioDecoderControl_sourceFilename, METH_VARARGS, doc_QAudioDecoderControl_sourceFilename},
    {sipName_start, meth_QAudioDecoderControl_start, METH_VARARGS, doc_QAudioDecoderControl_start},
    {sipName_state, meth_QAudioDecoderControl_state, METH_VARARGS, doc_QAudioDecoderControl_state},
    {sipName_stop, meth_QAudioDecoderControl_stop, METH_VARARGS, doc_QAudioDecoderControl_stop}
};

PyDoc_STRVAR(doc_QAudioDecoderControl, "\1QAudioDecoderControl(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QAudioDecoderControl[] = {
    {"durationChanged(qint64)", "\1durationChanged(self, duration: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"positionChanged(qint64)", "\1positionChanged(self, position: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"finished()", "\1finished(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"bufferAvailableChanged(bool)", "\1bufferAvailableChanged(self, available: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"bufferReady()", "\1bufferReady(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"error(int,QString)", "\1error(self, error: int, errorString: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"sourceChanged()", "\1sourceChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"formatChanged(QAudioFormat)", "\1formatChanged(self, format: QAudioFormat)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QAudioDecoder::State)", "\1stateChanged(self, newState: QAudioDecoder.State)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QAudioDecoderControl = {
    &::QAudioDecoderControl::staticMetaObject,
    0,
    signals_QAudioDecoderControl,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QAudioDecoderControl = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAudioDecoderControl,
        SIP_NULLPTR,
        &plugin_QAudioDecoderControl,
    },
    {
        sipNameNr_QAudioDecoderControl,
        {0, 0, 1},
        13, methods_QAudioDecoderControl,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAudioDecoderControl,
    -1,
    -1,
    supers_QAudioDecoderControl,
    SIP_NULLPTR,
    init_type_QAudioDecoderControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAudioDecoderControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QAudioDecoderControl,
    cast_QAudioDecoderControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QAudioDecoderControl),
};
