/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 31 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoserviceprovider.sip"
#include <qgeoserviceprovider.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 24 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoserviceprovider.sip"
#include <qgeoserviceprovider.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacemanager.sip"
#include <qplacemanager.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoroutingmanager.sip"
#include <qgeoroutingmanager.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeocodingmanager.sip"
#include <qgeocodingmanager.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoserviceprovider.sip"
#include <qgeoserviceprovider.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoserviceprovider.sip"
#include <qgeoserviceprovider.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoserviceprovider.sip"
#include <qgeoserviceprovider.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoserviceprovider.sip"
#include <qgeoserviceprovider.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProvider.cpp"


class sipQGeoServiceProvider : public ::QGeoServiceProvider
{
public:
    sipQGeoServiceProvider(const ::QString&, const ::QVariantMap&, bool);
    virtual ~sipQGeoServiceProvider();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQGeoServiceProvider(const sipQGeoServiceProvider &);
    sipQGeoServiceProvider &operator = (const sipQGeoServiceProvider &);

    char sipPyMethods[7];
};

sipQGeoServiceProvider::sipQGeoServiceProvider(const ::QString& a0, const ::QVariantMap& a1, bool a2): ::QGeoServiceProvider(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGeoServiceProvider::~sipQGeoServiceProvider()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQGeoServiceProvider::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtLocation_qt_metaobject(sipPySelf, sipType_QGeoServiceProvider);

    return ::QGeoServiceProvider::metaObject();
}

int sipQGeoServiceProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QGeoServiceProvider::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtLocation_qt_metacall(sipPySelf, sipType_QGeoServiceProvider, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQGeoServiceProvider::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtLocation_qt_metacast(sipPySelf, sipType_QGeoServiceProvider, _clname, &sipCpp) ? sipCpp : ::QGeoServiceProvider::qt_metacast(_clname));
}

bool sipQGeoServiceProvider::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QGeoServiceProvider::event(a0);

    extern bool sipVH_QtLocation_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtLocation_5(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGeoServiceProvider::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QGeoServiceProvider::eventFilter(a0, a1);

    extern bool sipVH_QtLocation_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtLocation_4(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGeoServiceProvider::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QGeoServiceProvider::timerEvent(a0);
        return;
    }

    extern void sipVH_QtLocation_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtLocation_3(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoServiceProvider::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QGeoServiceProvider::childEvent(a0);
        return;
    }

    extern void sipVH_QtLocation_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtLocation_2(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoServiceProvider::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QGeoServiceProvider::customEvent(a0);
        return;
    }

    extern void sipVH_QtLocation_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtLocation_1(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoServiceProvider::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QGeoServiceProvider::connectNotify(a0);
        return;
    }

    extern void sipVH_QtLocation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtLocation_0(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoServiceProvider::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QGeoServiceProvider::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtLocation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtLocation_0(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QGeoServiceProvider_availableServiceProviders, "availableServiceProviders() -> list[str]");

extern "C" {static PyObject *meth_QGeoServiceProvider_availableServiceProviders(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_availableServiceProviders(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(::QGeoServiceProvider::availableServiceProviders());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_availableServiceProviders, doc_QGeoServiceProvider_availableServiceProviders);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_routingFeatures, "routingFeatures(self) -> QGeoServiceProvider.RoutingFeatures");

extern "C" {static PyObject *meth_QGeoServiceProvider_routingFeatures(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_routingFeatures(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QGeoServiceProvider::RoutingFeatures*sipRes;

            sipRes = new ::QGeoServiceProvider::RoutingFeatures(sipCpp->routingFeatures());

            return sipConvertFromNewType(sipRes, sipType_QGeoServiceProvider_RoutingFeatures, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_routingFeatures, doc_QGeoServiceProvider_routingFeatures);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_geocodingFeatures, "geocodingFeatures(self) -> QGeoServiceProvider.GeocodingFeatures");

extern "C" {static PyObject *meth_QGeoServiceProvider_geocodingFeatures(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_geocodingFeatures(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QGeoServiceProvider::GeocodingFeatures*sipRes;

            sipRes = new ::QGeoServiceProvider::GeocodingFeatures(sipCpp->geocodingFeatures());

            return sipConvertFromNewType(sipRes, sipType_QGeoServiceProvider_GeocodingFeatures, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_geocodingFeatures, doc_QGeoServiceProvider_geocodingFeatures);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_mappingFeatures, "mappingFeatures(self) -> QGeoServiceProvider.MappingFeatures");

extern "C" {static PyObject *meth_QGeoServiceProvider_mappingFeatures(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_mappingFeatures(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QGeoServiceProvider::MappingFeatures*sipRes;

            sipRes = new ::QGeoServiceProvider::MappingFeatures(sipCpp->mappingFeatures());

            return sipConvertFromNewType(sipRes, sipType_QGeoServiceProvider_MappingFeatures, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_mappingFeatures, doc_QGeoServiceProvider_mappingFeatures);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_placesFeatures, "placesFeatures(self) -> QGeoServiceProvider.PlacesFeatures");

extern "C" {static PyObject *meth_QGeoServiceProvider_placesFeatures(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_placesFeatures(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QGeoServiceProvider::PlacesFeatures*sipRes;

            sipRes = new ::QGeoServiceProvider::PlacesFeatures(sipCpp->placesFeatures());

            return sipConvertFromNewType(sipRes, sipType_QGeoServiceProvider_PlacesFeatures, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_placesFeatures, doc_QGeoServiceProvider_placesFeatures);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_geocodingManager, "geocodingManager(self) -> Optional[QGeoCodingManager]");

extern "C" {static PyObject *meth_QGeoServiceProvider_geocodingManager(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_geocodingManager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QGeoCodingManager*sipRes;

            sipRes = sipCpp->geocodingManager();

            return sipConvertFromType(sipRes, sipType_QGeoCodingManager, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_geocodingManager, doc_QGeoServiceProvider_geocodingManager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_routingManager, "routingManager(self) -> Optional[QGeoRoutingManager]");

extern "C" {static PyObject *meth_QGeoServiceProvider_routingManager(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_routingManager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QGeoRoutingManager*sipRes;

            sipRes = sipCpp->routingManager();

            return sipConvertFromType(sipRes, sipType_QGeoRoutingManager, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_routingManager, doc_QGeoServiceProvider_routingManager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_placeManager, "placeManager(self) -> Optional[QPlaceManager]");

extern "C" {static PyObject *meth_QGeoServiceProvider_placeManager(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_placeManager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QPlaceManager*sipRes;

            sipRes = sipCpp->placeManager();

            return sipConvertFromType(sipRes, sipType_QPlaceManager, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_placeManager, doc_QGeoServiceProvider_placeManager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_error, "error(self) -> QGeoServiceProvider.Error");

extern "C" {static PyObject *meth_QGeoServiceProvider_error(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QGeoServiceProvider::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoServiceProvider_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_error, doc_QGeoServiceProvider_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QGeoServiceProvider_errorString(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_errorString, doc_QGeoServiceProvider_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_setParameters, "setParameters(self, parameters: dict[str, Any])");

extern "C" {static PyObject *meth_QGeoServiceProvider_setParameters(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_setParameters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariantMap* a0;
        int a0State = 0;
        ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoServiceProvider, &sipCpp, sipType_QVariantMap, &a0, &a0State))
        {
            sipCpp->setParameters(*a0);
            sipReleaseType(const_cast< ::QVariantMap *>(a0), sipType_QVariantMap, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_setParameters, doc_QGeoServiceProvider_setParameters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_setLocale, "setLocale(self, locale: QLocale)");

extern "C" {static PyObject *meth_QGeoServiceProvider_setLocale(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_setLocale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale* a0;
        ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoServiceProvider, &sipCpp, sipType_QLocale, &a0))
        {
            sipCpp->setLocale(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_setLocale, doc_QGeoServiceProvider_setLocale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_setAllowExperimental, "setAllowExperimental(self, allow: bool)");

extern "C" {static PyObject *meth_QGeoServiceProvider_setAllowExperimental(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_setAllowExperimental(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QGeoServiceProvider, &sipCpp, &a0))
        {
            sipCpp->setAllowExperimental(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_setAllowExperimental, doc_QGeoServiceProvider_setAllowExperimental);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_navigationFeatures, "navigationFeatures(self) -> QGeoServiceProvider.NavigationFeatures");

extern "C" {static PyObject *meth_QGeoServiceProvider_navigationFeatures(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_navigationFeatures(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QGeoServiceProvider::NavigationFeatures*sipRes;

            sipRes = new ::QGeoServiceProvider::NavigationFeatures(sipCpp->navigationFeatures());

            return sipConvertFromNewType(sipRes, sipType_QGeoServiceProvider_NavigationFeatures, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_navigationFeatures, doc_QGeoServiceProvider_navigationFeatures);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_navigationManager, "navigationManager(self) -> Optional[QNavigationManager]");

extern "C" {static PyObject *meth_QGeoServiceProvider_navigationManager(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_navigationManager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QNavigationManager*sipRes;

            sipRes = sipCpp->navigationManager();

            return sipConvertFromType(sipRes, sipType_QNavigationManager, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_navigationManager, doc_QGeoServiceProvider_navigationManager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_mappingError, "mappingError(self) -> QGeoServiceProvider.Error");

extern "C" {static PyObject *meth_QGeoServiceProvider_mappingError(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_mappingError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QGeoServiceProvider::Error sipRes;

            sipRes = sipCpp->mappingError();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoServiceProvider_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_mappingError, doc_QGeoServiceProvider_mappingError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_mappingErrorString, "mappingErrorString(self) -> str");

extern "C" {static PyObject *meth_QGeoServiceProvider_mappingErrorString(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_mappingErrorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->mappingErrorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_mappingErrorString, doc_QGeoServiceProvider_mappingErrorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_geocodingError, "geocodingError(self) -> QGeoServiceProvider.Error");

extern "C" {static PyObject *meth_QGeoServiceProvider_geocodingError(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_geocodingError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QGeoServiceProvider::Error sipRes;

            sipRes = sipCpp->geocodingError();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoServiceProvider_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_geocodingError, doc_QGeoServiceProvider_geocodingError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_geocodingErrorString, "geocodingErrorString(self) -> str");

extern "C" {static PyObject *meth_QGeoServiceProvider_geocodingErrorString(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_geocodingErrorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->geocodingErrorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_geocodingErrorString, doc_QGeoServiceProvider_geocodingErrorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_routingError, "routingError(self) -> QGeoServiceProvider.Error");

extern "C" {static PyObject *meth_QGeoServiceProvider_routingError(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_routingError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QGeoServiceProvider::Error sipRes;

            sipRes = sipCpp->routingError();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoServiceProvider_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_routingError, doc_QGeoServiceProvider_routingError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_routingErrorString, "routingErrorString(self) -> str");

extern "C" {static PyObject *meth_QGeoServiceProvider_routingErrorString(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_routingErrorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->routingErrorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_routingErrorString, doc_QGeoServiceProvider_routingErrorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_placesError, "placesError(self) -> QGeoServiceProvider.Error");

extern "C" {static PyObject *meth_QGeoServiceProvider_placesError(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_placesError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QGeoServiceProvider::Error sipRes;

            sipRes = sipCpp->placesError();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoServiceProvider_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_placesError, doc_QGeoServiceProvider_placesError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_placesErrorString, "placesErrorString(self) -> str");

extern "C" {static PyObject *meth_QGeoServiceProvider_placesErrorString(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_placesErrorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->placesErrorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_placesErrorString, doc_QGeoServiceProvider_placesErrorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_navigationError, "navigationError(self) -> QGeoServiceProvider.Error");

extern "C" {static PyObject *meth_QGeoServiceProvider_navigationError(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_navigationError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QGeoServiceProvider::Error sipRes;

            sipRes = sipCpp->navigationError();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoServiceProvider_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_navigationError, doc_QGeoServiceProvider_navigationError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoServiceProvider_navigationErrorString, "navigationErrorString(self) -> str");

extern "C" {static PyObject *meth_QGeoServiceProvider_navigationErrorString(PyObject *, PyObject *);}
static PyObject *meth_QGeoServiceProvider_navigationErrorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoServiceProvider, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->navigationErrorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoServiceProvider, sipName_navigationErrorString, doc_QGeoServiceProvider_navigationErrorString);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGeoServiceProvider(void *, const sipTypeDef *);}
static void *cast_QGeoServiceProvider(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGeoServiceProvider *sipCpp = reinterpret_cast< ::QGeoServiceProvider *>(sipCppV);

    if (targetType == sipType_QGeoServiceProvider)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoServiceProvider(void *, int);}
static void release_QGeoServiceProvider(void *sipCppV, int)
{
    ::QGeoServiceProvider *sipCpp = reinterpret_cast< ::QGeoServiceProvider *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QGeoServiceProvider(sipSimpleWrapper *);}
static void dealloc_QGeoServiceProvider(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQGeoServiceProvider *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoServiceProvider(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QGeoServiceProvider(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoServiceProvider(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQGeoServiceProvider *sipCpp = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariantMap& a1def = QVariantMap();
        const ::QVariantMap* a1 = &a1def;
        int a1State = 0;
        bool a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parameters,
            sipName_allowExperimental,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|J1b", sipType_QString, &a0, &a0State, sipType_QVariantMap, &a1, &a1State, &a2))
        {
            sipCpp = new sipQGeoServiceProvider(*a0, *a1, a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QVariantMap *>(a1), sipType_QVariantMap, a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGeoServiceProvider[] = {{7, 0, 1}};


static PyMethodDef methods_QGeoServiceProvider[] = {
    {sipName_availableServiceProviders, meth_QGeoServiceProvider_availableServiceProviders, METH_VARARGS, doc_QGeoServiceProvider_availableServiceProviders},
    {sipName_error, meth_QGeoServiceProvider_error, METH_VARARGS, doc_QGeoServiceProvider_error},
    {sipName_errorString, meth_QGeoServiceProvider_errorString, METH_VARARGS, doc_QGeoServiceProvider_errorString},
    {sipName_geocodingError, meth_QGeoServiceProvider_geocodingError, METH_VARARGS, doc_QGeoServiceProvider_geocodingError},
    {sipName_geocodingErrorString, meth_QGeoServiceProvider_geocodingErrorString, METH_VARARGS, doc_QGeoServiceProvider_geocodingErrorString},
    {sipName_geocodingFeatures, meth_QGeoServiceProvider_geocodingFeatures, METH_VARARGS, doc_QGeoServiceProvider_geocodingFeatures},
    {sipName_geocodingManager, meth_QGeoServiceProvider_geocodingManager, METH_VARARGS, doc_QGeoServiceProvider_geocodingManager},
    {sipName_mappingError, meth_QGeoServiceProvider_mappingError, METH_VARARGS, doc_QGeoServiceProvider_mappingError},
    {sipName_mappingErrorString, meth_QGeoServiceProvider_mappingErrorString, METH_VARARGS, doc_QGeoServiceProvider_mappingErrorString},
    {sipName_mappingFeatures, meth_QGeoServiceProvider_mappingFeatures, METH_VARARGS, doc_QGeoServiceProvider_mappingFeatures},
    {sipName_navigationError, meth_QGeoServiceProvider_navigationError, METH_VARARGS, doc_QGeoServiceProvider_navigationError},
    {sipName_navigationErrorString, meth_QGeoServiceProvider_navigationErrorString, METH_VARARGS, doc_QGeoServiceProvider_navigationErrorString},
    {sipName_navigationFeatures, meth_QGeoServiceProvider_navigationFeatures, METH_VARARGS, doc_QGeoServiceProvider_navigationFeatures},
    {sipName_navigationManager, meth_QGeoServiceProvider_navigationManager, METH_VARARGS, doc_QGeoServiceProvider_navigationManager},
    {sipName_placeManager, meth_QGeoServiceProvider_placeManager, METH_VARARGS, doc_QGeoServiceProvider_placeManager},
    {sipName_placesError, meth_QGeoServiceProvider_placesError, METH_VARARGS, doc_QGeoServiceProvider_placesError},
    {sipName_placesErrorString, meth_QGeoServiceProvider_placesErrorString, METH_VARARGS, doc_QGeoServiceProvider_placesErrorString},
    {sipName_placesFeatures, meth_QGeoServiceProvider_placesFeatures, METH_VARARGS, doc_QGeoServiceProvider_placesFeatures},
    {sipName_routingError, meth_QGeoServiceProvider_routingError, METH_VARARGS, doc_QGeoServiceProvider_routingError},
    {sipName_routingErrorString, meth_QGeoServiceProvider_routingErrorString, METH_VARARGS, doc_QGeoServiceProvider_routingErrorString},
    {sipName_routingFeatures, meth_QGeoServiceProvider_routingFeatures, METH_VARARGS, doc_QGeoServiceProvider_routingFeatures},
    {sipName_routingManager, meth_QGeoServiceProvider_routingManager, METH_VARARGS, doc_QGeoServiceProvider_routingManager},
    {sipName_setAllowExperimental, meth_QGeoServiceProvider_setAllowExperimental, METH_VARARGS, doc_QGeoServiceProvider_setAllowExperimental},
    {sipName_setLocale, meth_QGeoServiceProvider_setLocale, METH_VARARGS, doc_QGeoServiceProvider_setLocale},
    {sipName_setParameters, meth_QGeoServiceProvider_setParameters, METH_VARARGS, doc_QGeoServiceProvider_setParameters}
};

static sipEnumMemberDef enummembers_QGeoServiceProvider[] = {
    {sipName_AlternativeRoutesFeature, static_cast<int>(::QGeoServiceProvider::AlternativeRoutesFeature), 36},
    {sipName_AnyGeocodingFeatures, static_cast<int>(::QGeoServiceProvider::AnyGeocodingFeatures), 28},
    {sipName_AnyMappingFeatures, static_cast<int>(::QGeoServiceProvider::AnyMappingFeatures), 30},
    {sipName_AnyNavigationFeatures, static_cast<int>(::QGeoServiceProvider::AnyNavigationFeatures), 32},
    {sipName_AnyPlacesFeatures, static_cast<int>(::QGeoServiceProvider::AnyPlacesFeatures), 34},
    {sipName_AnyRoutingFeatures, static_cast<int>(::QGeoServiceProvider::AnyRoutingFeatures), 36},
    {sipName_ConnectionError, static_cast<int>(::QGeoServiceProvider::ConnectionError), 27},
    {sipName_ExcludeAreasRoutingFeature, static_cast<int>(::QGeoServiceProvider::ExcludeAreasRoutingFeature), 36},
    {sipName_LoaderError, static_cast<int>(::QGeoServiceProvider::LoaderError), 27},
    {sipName_LocalizedGeocodingFeature, static_cast<int>(::QGeoServiceProvider::LocalizedGeocodingFeature), 28},
    {sipName_LocalizedMappingFeature, static_cast<int>(::QGeoServiceProvider::LocalizedMappingFeature), 30},
    {sipName_LocalizedPlacesFeature, static_cast<int>(::QGeoServiceProvider::LocalizedPlacesFeature), 34},
    {sipName_LocalizedRoutingFeature, static_cast<int>(::QGeoServiceProvider::LocalizedRoutingFeature), 36},
    {sipName_MissingRequiredParameterError, static_cast<int>(::QGeoServiceProvider::MissingRequiredParameterError), 27},
    {sipName_NoError, static_cast<int>(::QGeoServiceProvider::NoError), 27},
    {sipName_NoGeocodingFeatures, static_cast<int>(::QGeoServiceProvider::NoGeocodingFeatures), 28},
    {sipName_NoMappingFeatures, static_cast<int>(::QGeoServiceProvider::NoMappingFeatures), 30},
    {sipName_NoNavigationFeatures, static_cast<int>(::QGeoServiceProvider::NoNavigationFeatures), 32},
    {sipName_NoPlacesFeatures, static_cast<int>(::QGeoServiceProvider::NoPlacesFeatures), 34},
    {sipName_NoRoutingFeatures, static_cast<int>(::QGeoServiceProvider::NoRoutingFeatures), 36},
    {sipName_NotSupportedError, static_cast<int>(::QGeoServiceProvider::NotSupportedError), 27},
    {sipName_NotificationsFeature, static_cast<int>(::QGeoServiceProvider::NotificationsFeature), 34},
    {sipName_OfflineGeocodingFeature, static_cast<int>(::QGeoServiceProvider::OfflineGeocodingFeature), 28},
    {sipName_OfflineMappingFeature, static_cast<int>(::QGeoServiceProvider::OfflineMappingFeature), 30},
    {sipName_OfflineNavigationFeature, static_cast<int>(::QGeoServiceProvider::OfflineNavigationFeature), 32},
    {sipName_OfflinePlacesFeature, static_cast<int>(::QGeoServiceProvider::OfflinePlacesFeature), 34},
    {sipName_OfflineRoutingFeature, static_cast<int>(::QGeoServiceProvider::OfflineRoutingFeature), 36},
    {sipName_OnlineGeocodingFeature, static_cast<int>(::QGeoServiceProvider::OnlineGeocodingFeature), 28},
    {sipName_OnlineMappingFeature, static_cast<int>(::QGeoServiceProvider::OnlineMappingFeature), 30},
    {sipName_OnlineNavigationFeature, static_cast<int>(::QGeoServiceProvider::OnlineNavigationFeature), 32},
    {sipName_OnlinePlacesFeature, static_cast<int>(::QGeoServiceProvider::OnlinePlacesFeature), 34},
    {sipName_OnlineRoutingFeature, static_cast<int>(::QGeoServiceProvider::OnlineRoutingFeature), 36},
    {sipName_PlaceMatchingFeature, static_cast<int>(::QGeoServiceProvider::PlaceMatchingFeature), 34},
    {sipName_PlaceRecommendationsFeature, static_cast<int>(::QGeoServiceProvider::PlaceRecommendationsFeature), 34},
    {sipName_RemoveCategoryFeature, static_cast<int>(::QGeoServiceProvider::RemoveCategoryFeature), 34},
    {sipName_RemovePlaceFeature, static_cast<int>(::QGeoServiceProvider::RemovePlaceFeature), 34},
    {sipName_ReverseGeocodingFeature, static_cast<int>(::QGeoServiceProvider::ReverseGeocodingFeature), 28},
    {sipName_RouteUpdatesFeature, static_cast<int>(::QGeoServiceProvider::RouteUpdatesFeature), 36},
    {sipName_SaveCategoryFeature, static_cast<int>(::QGeoServiceProvider::SaveCategoryFeature), 34},
    {sipName_SavePlaceFeature, static_cast<int>(::QGeoServiceProvider::SavePlaceFeature), 34},
    {sipName_SearchSuggestionsFeature, static_cast<int>(::QGeoServiceProvider::SearchSuggestionsFeature), 34},
    {sipName_UnknownParameterError, static_cast<int>(::QGeoServiceProvider::UnknownParameterError), 27},
};

PyDoc_STRVAR(doc_QGeoServiceProvider, "\1QGeoServiceProvider(providerName: Optional[str], parameters: dict[str, Any] = {}, allowExperimental: bool = False)");


static pyqt5ClassPluginDef plugin_QGeoServiceProvider = {
    &::QGeoServiceProvider::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QGeoServiceProvider = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoServiceProvider,
        SIP_NULLPTR,
        &plugin_QGeoServiceProvider,
    },
    {
        sipNameNr_QGeoServiceProvider,
        {0, 0, 1},
        25, methods_QGeoServiceProvider,
        42, enummembers_QGeoServiceProvider,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoServiceProvider,
    -1,
    -1,
    supers_QGeoServiceProvider,
    SIP_NULLPTR,
    init_type_QGeoServiceProvider,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoServiceProvider,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QGeoServiceProvider,
    cast_QGeoServiceProvider,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QGeoServiceProvider),
};
