/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtTextToSpeech.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtTextToSpeech/qtexttospeech.sip"
#include <qtexttospeech.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtTextToSpeech/qvoice.sip"
#include <qvoice.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQTextToSpeech.cpp"


class sipQTextToSpeech : public ::QTextToSpeech
{
public:
    sipQTextToSpeech(::QObject*);
    sipQTextToSpeech(const ::QString&, ::QObject*);
    virtual ~sipQTextToSpeech();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQTextToSpeech(const sipQTextToSpeech &);
    sipQTextToSpeech &operator = (const sipQTextToSpeech &);

    char sipPyMethods[7];
};

sipQTextToSpeech::sipQTextToSpeech(::QObject*a0): ::QTextToSpeech(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQTextToSpeech::sipQTextToSpeech(const ::QString& a0, ::QObject*a1): ::QTextToSpeech(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQTextToSpeech::~sipQTextToSpeech()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQTextToSpeech::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtTextToSpeech_qt_metaobject(sipPySelf, sipType_QTextToSpeech);

    return ::QTextToSpeech::metaObject();
}

int sipQTextToSpeech::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QTextToSpeech::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtTextToSpeech_qt_metacall(sipPySelf, sipType_QTextToSpeech, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQTextToSpeech::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtTextToSpeech_qt_metacast(sipPySelf, sipType_QTextToSpeech, _clname, &sipCpp) ? sipCpp : ::QTextToSpeech::qt_metacast(_clname));
}

bool sipQTextToSpeech::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QTextToSpeech::event(a0);

    extern bool sipVH_QtTextToSpeech_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtTextToSpeech_5(sipGILState, sipImportedVirtErrorHandlers_QtTextToSpeech_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQTextToSpeech::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QTextToSpeech::eventFilter(a0, a1);

    extern bool sipVH_QtTextToSpeech_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtTextToSpeech_4(sipGILState, sipImportedVirtErrorHandlers_QtTextToSpeech_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQTextToSpeech::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QTextToSpeech::timerEvent(a0);
        return;
    }

    extern void sipVH_QtTextToSpeech_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtTextToSpeech_3(sipGILState, sipImportedVirtErrorHandlers_QtTextToSpeech_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTextToSpeech::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QTextToSpeech::childEvent(a0);
        return;
    }

    extern void sipVH_QtTextToSpeech_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtTextToSpeech_2(sipGILState, sipImportedVirtErrorHandlers_QtTextToSpeech_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTextToSpeech::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QTextToSpeech::customEvent(a0);
        return;
    }

    extern void sipVH_QtTextToSpeech_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtTextToSpeech_1(sipGILState, sipImportedVirtErrorHandlers_QtTextToSpeech_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTextToSpeech::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QTextToSpeech::connectNotify(a0);
        return;
    }

    extern void sipVH_QtTextToSpeech_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtTextToSpeech_0(sipGILState, sipImportedVirtErrorHandlers_QtTextToSpeech_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTextToSpeech::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QTextToSpeech::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtTextToSpeech_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtTextToSpeech_0(sipGILState, sipImportedVirtErrorHandlers_QtTextToSpeech_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QTextToSpeech_state, "state(self) -> QTextToSpeech.State");

extern "C" {static PyObject *meth_QTextToSpeech_state(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextToSpeech, &sipCpp))
        {
            ::QTextToSpeech::State sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QTextToSpeech_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_state, doc_QTextToSpeech_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_availableLocales, "availableLocales(self) -> list[QLocale]");

extern "C" {static PyObject *meth_QTextToSpeech_availableLocales(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_availableLocales(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextToSpeech, &sipCpp))
        {
            QVector< ::QLocale>*sipRes;

            sipRes = new QVector< ::QLocale>(sipCpp->availableLocales());

            return sipConvertFromNewType(sipRes, sipType_QVector_0100QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_availableLocales, doc_QTextToSpeech_availableLocales);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_locale, "locale(self) -> QLocale");

extern "C" {static PyObject *meth_QTextToSpeech_locale(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_locale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextToSpeech, &sipCpp))
        {
            ::QLocale*sipRes;

            sipRes = new ::QLocale(sipCpp->locale());

            return sipConvertFromNewType(sipRes, sipType_QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_locale, doc_QTextToSpeech_locale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_voice, "voice(self) -> QVoice");

extern "C" {static PyObject *meth_QTextToSpeech_voice(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_voice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextToSpeech, &sipCpp))
        {
            ::QVoice*sipRes;

            sipRes = new ::QVoice(sipCpp->voice());

            return sipConvertFromNewType(sipRes, sipType_QVoice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_voice, doc_QTextToSpeech_voice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_availableVoices, "availableVoices(self) -> list[QVoice]");

extern "C" {static PyObject *meth_QTextToSpeech_availableVoices(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_availableVoices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextToSpeech, &sipCpp))
        {
            QVector< ::QVoice>*sipRes;

            sipRes = new QVector< ::QVoice>(sipCpp->availableVoices());

            return sipConvertFromNewType(sipRes, sipType_QVector_0100QVoice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_availableVoices, doc_QTextToSpeech_availableVoices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_rate, "rate(self) -> float");

extern "C" {static PyObject *meth_QTextToSpeech_rate(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_rate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextToSpeech, &sipCpp))
        {
            double sipRes;

            sipRes = sipCpp->rate();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_rate, doc_QTextToSpeech_rate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_pitch, "pitch(self) -> float");

extern "C" {static PyObject *meth_QTextToSpeech_pitch(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_pitch(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextToSpeech, &sipCpp))
        {
            double sipRes;

            sipRes = sipCpp->pitch();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_pitch, doc_QTextToSpeech_pitch);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_volume, "volume(self) -> float");

extern "C" {static PyObject *meth_QTextToSpeech_volume(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_volume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextToSpeech, &sipCpp))
        {
            double sipRes;

            sipRes = sipCpp->volume();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_volume, doc_QTextToSpeech_volume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_availableEngines, "availableEngines() -> list[str]");

extern "C" {static PyObject *meth_QTextToSpeech_availableEngines(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_availableEngines(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(::QTextToSpeech::availableEngines());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_availableEngines, doc_QTextToSpeech_availableEngines);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_say, "say(self, text: Optional[str])");

extern "C" {static PyObject *meth_QTextToSpeech_say(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_say(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTextToSpeech, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->say(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_say, doc_QTextToSpeech_say);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_stop, "stop(self)");

extern "C" {static PyObject *meth_QTextToSpeech_stop(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextToSpeech, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_stop, doc_QTextToSpeech_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_pause, "pause(self)");

extern "C" {static PyObject *meth_QTextToSpeech_pause(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_pause(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextToSpeech, &sipCpp))
        {
            sipCpp->pause();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_pause, doc_QTextToSpeech_pause);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_resume, "resume(self)");

extern "C" {static PyObject *meth_QTextToSpeech_resume(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_resume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTextToSpeech, &sipCpp))
        {
            sipCpp->resume();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_resume, doc_QTextToSpeech_resume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_setLocale, "setLocale(self, locale: QLocale)");

extern "C" {static PyObject *meth_QTextToSpeech_setLocale(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_setLocale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale* a0;
        ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QTextToSpeech, &sipCpp, sipType_QLocale, &a0))
        {
            sipCpp->setLocale(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_setLocale, doc_QTextToSpeech_setLocale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_setRate, "setRate(self, rate: float)");

extern "C" {static PyObject *meth_QTextToSpeech_setRate(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_setRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QTextToSpeech, &sipCpp, &a0))
        {
            sipCpp->setRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_setRate, doc_QTextToSpeech_setRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_setPitch, "setPitch(self, pitch: float)");

extern "C" {static PyObject *meth_QTextToSpeech_setPitch(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_setPitch(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QTextToSpeech, &sipCpp, &a0))
        {
            sipCpp->setPitch(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_setPitch, doc_QTextToSpeech_setPitch);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_setVolume, "setVolume(self, volume: float)");

extern "C" {static PyObject *meth_QTextToSpeech_setVolume(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_setVolume(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QTextToSpeech, &sipCpp, &a0))
        {
            sipCpp->setVolume(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_setVolume, doc_QTextToSpeech_setVolume);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTextToSpeech_setVoice, "setVoice(self, voice: QVoice)");

extern "C" {static PyObject *meth_QTextToSpeech_setVoice(PyObject *, PyObject *);}
static PyObject *meth_QTextToSpeech_setVoice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVoice* a0;
        ::QTextToSpeech *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QTextToSpeech, &sipCpp, sipType_QVoice, &a0))
        {
            sipCpp->setVoice(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTextToSpeech, sipName_setVoice, doc_QTextToSpeech_setVoice);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QTextToSpeech(void *, const sipTypeDef *);}
static void *cast_QTextToSpeech(void *sipCppV, const sipTypeDef *targetType)
{
    ::QTextToSpeech *sipCpp = reinterpret_cast< ::QTextToSpeech *>(sipCppV);

    if (targetType == sipType_QTextToSpeech)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QTextToSpeech(void *, int);}
static void release_QTextToSpeech(void *sipCppV, int)
{
    ::QTextToSpeech *sipCpp = reinterpret_cast< ::QTextToSpeech *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QTextToSpeech(Py_ssize_t);}
static void *array_QTextToSpeech(Py_ssize_t sipNrElem)
{
    return new ::QTextToSpeech[sipNrElem];
}


extern "C" {static void array_delete_QTextToSpeech(void *);}
static void array_delete_QTextToSpeech(void *sipCpp)
{
    delete[] reinterpret_cast< ::QTextToSpeech *>(sipCpp);
}


extern "C" {static void dealloc_QTextToSpeech(sipSimpleWrapper *);}
static void dealloc_QTextToSpeech(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQTextToSpeech *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QTextToSpeech(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QTextToSpeech(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QTextToSpeech(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQTextToSpeech *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQTextToSpeech(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QString, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQTextToSpeech(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QTextToSpeech[] = {{4, 0, 1}};


static PyMethodDef methods_QTextToSpeech[] = {
    {sipName_availableEngines, meth_QTextToSpeech_availableEngines, METH_VARARGS, doc_QTextToSpeech_availableEngines},
    {sipName_availableLocales, meth_QTextToSpeech_availableLocales, METH_VARARGS, doc_QTextToSpeech_availableLocales},
    {sipName_availableVoices, meth_QTextToSpeech_availableVoices, METH_VARARGS, doc_QTextToSpeech_availableVoices},
    {sipName_locale, meth_QTextToSpeech_locale, METH_VARARGS, doc_QTextToSpeech_locale},
    {sipName_pause, meth_QTextToSpeech_pause, METH_VARARGS, doc_QTextToSpeech_pause},
    {sipName_pitch, meth_QTextToSpeech_pitch, METH_VARARGS, doc_QTextToSpeech_pitch},
    {sipName_rate, meth_QTextToSpeech_rate, METH_VARARGS, doc_QTextToSpeech_rate},
    {sipName_resume, meth_QTextToSpeech_resume, METH_VARARGS, doc_QTextToSpeech_resume},
    {sipName_say, meth_QTextToSpeech_say, METH_VARARGS, doc_QTextToSpeech_say},
    {sipName_setLocale, meth_QTextToSpeech_setLocale, METH_VARARGS, doc_QTextToSpeech_setLocale},
    {sipName_setPitch, meth_QTextToSpeech_setPitch, METH_VARARGS, doc_QTextToSpeech_setPitch},
    {sipName_setRate, meth_QTextToSpeech_setRate, METH_VARARGS, doc_QTextToSpeech_setRate},
    {sipName_setVoice, meth_QTextToSpeech_setVoice, METH_VARARGS, doc_QTextToSpeech_setVoice},
    {sipName_setVolume, meth_QTextToSpeech_setVolume, METH_VARARGS, doc_QTextToSpeech_setVolume},
    {sipName_state, meth_QTextToSpeech_state, METH_VARARGS, doc_QTextToSpeech_state},
    {sipName_stop, meth_QTextToSpeech_stop, METH_VARARGS, doc_QTextToSpeech_stop},
    {sipName_voice, meth_QTextToSpeech_voice, METH_VARARGS, doc_QTextToSpeech_voice},
    {sipName_volume, meth_QTextToSpeech_volume, METH_VARARGS, doc_QTextToSpeech_volume}
};

static sipEnumMemberDef enummembers_QTextToSpeech[] = {
    {sipName_BackendError, static_cast<int>(::QTextToSpeech::BackendError), 1},
    {sipName_Paused, static_cast<int>(::QTextToSpeech::Paused), 1},
    {sipName_Ready, static_cast<int>(::QTextToSpeech::Ready), 1},
    {sipName_Speaking, static_cast<int>(::QTextToSpeech::Speaking), 1},
};

PyDoc_STRVAR(doc_QTextToSpeech, "\1QTextToSpeech(parent: Optional[QObject] = None)\n"
"QTextToSpeech(engine: Optional[str], parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QTextToSpeech[] = {
    {"voiceChanged(QVoice)", "\1voiceChanged(self, voice: QVoice)", SIP_NULLPTR, SIP_NULLPTR},
    {"volumeChanged(double)", "\1volumeChanged(self, volume: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"volumeChanged(int)", "\1volumeChanged(self, volume: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"pitchChanged(double)", "\1pitchChanged(self, pitch: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"rateChanged(double)", "\1rateChanged(self, rate: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"localeChanged(QLocale)", "\1localeChanged(self, locale: QLocale)", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QTextToSpeech::State)", "\1stateChanged(self, state: QTextToSpeech.State)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QTextToSpeech = {
    &::QTextToSpeech::staticMetaObject,
    0,
    signals_QTextToSpeech,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtTextToSpeech_QTextToSpeech = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QTextToSpeech,
        SIP_NULLPTR,
        &plugin_QTextToSpeech,
    },
    {
        sipNameNr_QTextToSpeech,
        {0, 0, 1},
        18, methods_QTextToSpeech,
        4, enummembers_QTextToSpeech,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QTextToSpeech,
    -1,
    -1,
    supers_QTextToSpeech,
    SIP_NULLPTR,
    init_type_QTextToSpeech,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QTextToSpeech,
    SIP_NULLPTR,
    array_QTextToSpeech,
    SIP_NULLPTR,
    release_QTextToSpeech,
    cast_QTextToSpeech,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QTextToSpeech,
    sizeof (::QTextToSpeech),
};
