/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaencodersettings.sip"
#include <qmediaencodersettings.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioEncoderSettings.cpp"

#line 24 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioEncoderSettings.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioEncoderSettings.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioEncoderSettings.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmultimedia.sip"
#include <qmultimedia.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioEncoderSettings.cpp"


PyDoc_STRVAR(doc_QAudioEncoderSettings_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QAudioEncoderSettings_isNull(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_isNull, doc_QAudioEncoderSettings_isNull);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_encodingMode, "encodingMode(self) -> QMultimedia.EncodingMode");

extern "C" {static PyObject *meth_QAudioEncoderSettings_encodingMode(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_encodingMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp))
        {
            ::QMultimedia::EncodingMode sipRes;

            sipRes = sipCpp->encodingMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMultimedia_EncodingMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_encodingMode, doc_QAudioEncoderSettings_encodingMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_setEncodingMode, "setEncodingMode(self, a0: QMultimedia.EncodingMode)");

extern "C" {static PyObject *meth_QAudioEncoderSettings_setEncodingMode(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_setEncodingMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMultimedia::EncodingMode a0;
        ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp, sipType_QMultimedia_EncodingMode, &a0))
        {
            sipCpp->setEncodingMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_setEncodingMode, doc_QAudioEncoderSettings_setEncodingMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_codec, "codec(self) -> str");

extern "C" {static PyObject *meth_QAudioEncoderSettings_codec(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_codec(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->codec());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_codec, doc_QAudioEncoderSettings_codec);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_setCodec, "setCodec(self, codec: Optional[str])");

extern "C" {static PyObject *meth_QAudioEncoderSettings_setCodec(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_setCodec(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCodec(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_setCodec, doc_QAudioEncoderSettings_setCodec);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_bitRate, "bitRate(self) -> int");

extern "C" {static PyObject *meth_QAudioEncoderSettings_bitRate(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_bitRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->bitRate();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_bitRate, doc_QAudioEncoderSettings_bitRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_setBitRate, "setBitRate(self, bitrate: int)");

extern "C" {static PyObject *meth_QAudioEncoderSettings_setBitRate(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_setBitRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp, &a0))
        {
            sipCpp->setBitRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_setBitRate, doc_QAudioEncoderSettings_setBitRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_channelCount, "channelCount(self) -> int");

extern "C" {static PyObject *meth_QAudioEncoderSettings_channelCount(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_channelCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->channelCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_channelCount, doc_QAudioEncoderSettings_channelCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_setChannelCount, "setChannelCount(self, channels: int)");

extern "C" {static PyObject *meth_QAudioEncoderSettings_setChannelCount(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_setChannelCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp, &a0))
        {
            sipCpp->setChannelCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_setChannelCount, doc_QAudioEncoderSettings_setChannelCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_sampleRate, "sampleRate(self) -> int");

extern "C" {static PyObject *meth_QAudioEncoderSettings_sampleRate(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_sampleRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->sampleRate();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_sampleRate, doc_QAudioEncoderSettings_sampleRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_setSampleRate, "setSampleRate(self, rate: int)");

extern "C" {static PyObject *meth_QAudioEncoderSettings_setSampleRate(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_setSampleRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp, &a0))
        {
            sipCpp->setSampleRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_setSampleRate, doc_QAudioEncoderSettings_setSampleRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_quality, "quality(self) -> QMultimedia.EncodingQuality");

extern "C" {static PyObject *meth_QAudioEncoderSettings_quality(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_quality(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp))
        {
            ::QMultimedia::EncodingQuality sipRes;

            sipRes = sipCpp->quality();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMultimedia_EncodingQuality);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_quality, doc_QAudioEncoderSettings_quality);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_setQuality, "setQuality(self, quality: QMultimedia.EncodingQuality)");

extern "C" {static PyObject *meth_QAudioEncoderSettings_setQuality(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_setQuality(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMultimedia::EncodingQuality a0;
        ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp, sipType_QMultimedia_EncodingQuality, &a0))
        {
            sipCpp->setQuality(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_setQuality, doc_QAudioEncoderSettings_setQuality);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_encodingOption, "encodingOption(self, option: Optional[str]) -> Any");

extern "C" {static PyObject *meth_QAudioEncoderSettings_encodingOption(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_encodingOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->encodingOption(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_encodingOption, doc_QAudioEncoderSettings_encodingOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_encodingOptions, "encodingOptions(self) -> dict[str, Any]");

extern "C" {static PyObject *meth_QAudioEncoderSettings_encodingOptions(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_encodingOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp))
        {
            ::QVariantMap*sipRes;

            sipRes = new ::QVariantMap(sipCpp->encodingOptions());

            return sipConvertFromNewType(sipRes, sipType_QVariantMap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_encodingOptions, doc_QAudioEncoderSettings_encodingOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_setEncodingOption, "setEncodingOption(self, option: Optional[str], value: Any)");

extern "C" {static PyObject *meth_QAudioEncoderSettings_setEncodingOption(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_setEncodingOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp, sipType_QString, &a0, &a0State, sipType_QVariant, &a1, &a1State))
        {
            sipCpp->setEncodingOption(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_setEncodingOption, doc_QAudioEncoderSettings_setEncodingOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioEncoderSettings_setEncodingOptions, "setEncodingOptions(self, options: dict[str, Any])");

extern "C" {static PyObject *meth_QAudioEncoderSettings_setEncodingOptions(PyObject *, PyObject *);}
static PyObject *meth_QAudioEncoderSettings_setEncodingOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariantMap* a0;
        int a0State = 0;
        ::QAudioEncoderSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAudioEncoderSettings, &sipCpp, sipType_QVariantMap, &a0, &a0State))
        {
            sipCpp->setEncodingOptions(*a0);
            sipReleaseType(const_cast< ::QVariantMap *>(a0), sipType_QVariantMap, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioEncoderSettings, sipName_setEncodingOptions, doc_QAudioEncoderSettings_setEncodingOptions);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QAudioEncoderSettings___ne__(PyObject *, PyObject *);}
static PyObject *slot_QAudioEncoderSettings___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QAudioEncoderSettings *sipCpp = reinterpret_cast< ::QAudioEncoderSettings *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QAudioEncoderSettings));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEncoderSettings* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QAudioEncoderSettings, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QAudioEncoderSettings::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, ne_slot, sipType_QAudioEncoderSettings, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QAudioEncoderSettings___eq__(PyObject *, PyObject *);}
static PyObject *slot_QAudioEncoderSettings___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QAudioEncoderSettings *sipCpp = reinterpret_cast< ::QAudioEncoderSettings *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QAudioEncoderSettings));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAudioEncoderSettings* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QAudioEncoderSettings, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QAudioEncoderSettings::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, eq_slot, sipType_QAudioEncoderSettings, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QAudioEncoderSettings(void *, int);}
static void release_QAudioEncoderSettings(void *sipCppV, int)
{
    delete reinterpret_cast< ::QAudioEncoderSettings *>(sipCppV);
}


extern "C" {static void *array_QAudioEncoderSettings(Py_ssize_t);}
static void *array_QAudioEncoderSettings(Py_ssize_t sipNrElem)
{
    return new ::QAudioEncoderSettings[sipNrElem];
}


extern "C" {static void array_delete_QAudioEncoderSettings(void *);}
static void array_delete_QAudioEncoderSettings(void *sipCpp)
{
    delete[] reinterpret_cast< ::QAudioEncoderSettings *>(sipCpp);
}


extern "C" {static void assign_QAudioEncoderSettings(void *, Py_ssize_t, void *);}
static void assign_QAudioEncoderSettings(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QAudioEncoderSettings *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QAudioEncoderSettings *>(sipSrc);
}


extern "C" {static void *copy_QAudioEncoderSettings(const void *, Py_ssize_t);}
static void *copy_QAudioEncoderSettings(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QAudioEncoderSettings(reinterpret_cast<const ::QAudioEncoderSettings *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QAudioEncoderSettings(sipSimpleWrapper *);}
static void dealloc_QAudioEncoderSettings(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAudioEncoderSettings(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QAudioEncoderSettings(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAudioEncoderSettings(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QAudioEncoderSettings *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QAudioEncoderSettings();

            return sipCpp;
        }
    }

    {
        const ::QAudioEncoderSettings* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QAudioEncoderSettings, &a0))
        {
            sipCpp = new ::QAudioEncoderSettings(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QAudioEncoderSettings[] = {
    {(void *)slot_QAudioEncoderSettings___ne__, ne_slot},
    {(void *)slot_QAudioEncoderSettings___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QAudioEncoderSettings[] = {
    {sipName_bitRate, meth_QAudioEncoderSettings_bitRate, METH_VARARGS, doc_QAudioEncoderSettings_bitRate},
    {sipName_channelCount, meth_QAudioEncoderSettings_channelCount, METH_VARARGS, doc_QAudioEncoderSettings_channelCount},
    {sipName_codec, meth_QAudioEncoderSettings_codec, METH_VARARGS, doc_QAudioEncoderSettings_codec},
    {sipName_encodingMode, meth_QAudioEncoderSettings_encodingMode, METH_VARARGS, doc_QAudioEncoderSettings_encodingMode},
    {sipName_encodingOption, meth_QAudioEncoderSettings_encodingOption, METH_VARARGS, doc_QAudioEncoderSettings_encodingOption},
    {sipName_encodingOptions, meth_QAudioEncoderSettings_encodingOptions, METH_VARARGS, doc_QAudioEncoderSettings_encodingOptions},
    {sipName_isNull, meth_QAudioEncoderSettings_isNull, METH_VARARGS, doc_QAudioEncoderSettings_isNull},
    {sipName_quality, meth_QAudioEncoderSettings_quality, METH_VARARGS, doc_QAudioEncoderSettings_quality},
    {sipName_sampleRate, meth_QAudioEncoderSettings_sampleRate, METH_VARARGS, doc_QAudioEncoderSettings_sampleRate},
    {sipName_setBitRate, meth_QAudioEncoderSettings_setBitRate, METH_VARARGS, doc_QAudioEncoderSettings_setBitRate},
    {sipName_setChannelCount, meth_QAudioEncoderSettings_setChannelCount, METH_VARARGS, doc_QAudioEncoderSettings_setChannelCount},
    {sipName_setCodec, meth_QAudioEncoderSettings_setCodec, METH_VARARGS, doc_QAudioEncoderSettings_setCodec},
    {sipName_setEncodingMode, meth_QAudioEncoderSettings_setEncodingMode, METH_VARARGS, doc_QAudioEncoderSettings_setEncodingMode},
    {sipName_setEncodingOption, meth_QAudioEncoderSettings_setEncodingOption, METH_VARARGS, doc_QAudioEncoderSettings_setEncodingOption},
    {sipName_setEncodingOptions, meth_QAudioEncoderSettings_setEncodingOptions, METH_VARARGS, doc_QAudioEncoderSettings_setEncodingOptions},
    {sipName_setQuality, meth_QAudioEncoderSettings_setQuality, METH_VARARGS, doc_QAudioEncoderSettings_setQuality},
    {sipName_setSampleRate, meth_QAudioEncoderSettings_setSampleRate, METH_VARARGS, doc_QAudioEncoderSettings_setSampleRate}
};

PyDoc_STRVAR(doc_QAudioEncoderSettings, "\1QAudioEncoderSettings()\n"
"QAudioEncoderSettings(other: QAudioEncoderSettings)");


static pyqt5ClassPluginDef plugin_QAudioEncoderSettings = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QAudioEncoderSettings = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAudioEncoderSettings,
        SIP_NULLPTR,
        &plugin_QAudioEncoderSettings,
    },
    {
        sipNameNr_QAudioEncoderSettings,
        {0, 0, 1},
        17, methods_QAudioEncoderSettings,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAudioEncoderSettings,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QAudioEncoderSettings,
    init_type_QAudioEncoderSettings,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAudioEncoderSettings,
    assign_QAudioEncoderSettings,
    array_QAudioEncoderSettings,
    copy_QAudioEncoderSettings,
    release_QAudioEncoderSettings,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QAudioEncoderSettings,
    sizeof (::QAudioEncoderSettings),
};
