/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKitWidgets.h"

#line 61 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebframe.sip"
#include <qwebframe.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebelement.sip"
#include <qwebelement.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebelement.sip"
#include <qwebelement.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 61 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebframe.sip"
#include <qwebframe.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebsecurityorigin.sip"
#include <qwebsecurityorigin.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 259 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qprinter.sip"
#include <qprinter.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebframe.sip"
#include <qwebframe.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qnetworkrequest.sip"
#include <qnetworkrequest.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qnetworkaccessmanager.sip"
#include <qnetworkaccessmanager.h>
#line 99 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 102 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 122 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 125 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 128 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 131 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 134 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 137 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebFrame.cpp"


PyDoc_STRVAR(doc_QWebFrame_page, "page(self) -> Optional[QWebPage]");

extern "C" {static PyObject *meth_QWebFrame_page(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_page(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QWebPage*sipRes;

            sipRes = sipCpp->page();

            return sipConvertFromType(sipRes, sipType_QWebPage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_page, doc_QWebFrame_page);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_load, "load(self, url: QUrl)\n"
"load(self, request: QNetworkRequest, operation: QNetworkAccessManager.Operation = QNetworkAccessManager.GetOperation, body: Union[QByteArray, bytes, bytearray] = QByteArray())");

extern "C" {static PyObject *meth_QWebFrame_load(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_load(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QWebFrame *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ9", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->load(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QNetworkRequest* a0;
        ::QNetworkAccessManager::Operation a1 = QNetworkAccessManager::GetOperation;
        const ::QByteArray& a2def = QByteArray();
        const ::QByteArray* a2 = &a2def;
        int a2State = 0;
        ::QWebFrame *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_operation,
            sipName_body,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|EJ1", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QNetworkAccessManager_Operation, &a1, sipType_QByteArray, &a2, &a2State))
        {
            sipCpp->load(*a0, a1, *a2);
            sipReleaseType(const_cast< ::QByteArray *>(a2), sipType_QByteArray, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_load, doc_QWebFrame_load);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_setHtml, "setHtml(self, html: Optional[str], baseUrl: QUrl = QUrl())");

extern "C" {static PyObject *meth_QWebFrame_setHtml(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_setHtml(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QUrl& a1def = QUrl();
        const ::QUrl* a1 = &a1def;
        ::QWebFrame *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_baseUrl,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J9", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QString, &a0, &a0State, sipType_QUrl, &a1))
        {
            sipCpp->setHtml(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_setHtml, doc_QWebFrame_setHtml);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_setContent, "setContent(self, data: Union[QByteArray, bytes, bytearray], mimeType: Optional[str] = '', baseUrl: QUrl = QUrl())");

extern "C" {static PyObject *meth_QWebFrame_setContent(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_setContent(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        const ::QUrl& a2def = QUrl();
        const ::QUrl* a2 = &a2def;
        ::QWebFrame *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mimeType,
            sipName_baseUrl,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1J9", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QByteArray, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QUrl, &a2))
        {
            sipCpp->setContent(*a0, *a1, *a2);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_setContent, doc_QWebFrame_setContent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_addToJavaScriptWindowObject, "addToJavaScriptWindowObject(self, name: Optional[str], object: Optional[QObject], ownership: QWebFrame.ValueOwnership = QWebFrame.QtOwnership)");

extern "C" {static PyObject *meth_QWebFrame_addToJavaScriptWindowObject(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_addToJavaScriptWindowObject(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QObject* a1;
        ::QWebFrame::ValueOwnership a2 = QWebFrame::QtOwnership;
        ::QWebFrame *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_ownership,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1J8|E", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QString, &a0, &a0State, sipType_QObject, &a1, sipType_QWebFrame_ValueOwnership, &a2))
        {
            sipCpp->addToJavaScriptWindowObject(*a0, a1, a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_addToJavaScriptWindowObject, doc_QWebFrame_addToJavaScriptWindowObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_toHtml, "toHtml(self) -> str");

extern "C" {static PyObject *meth_QWebFrame_toHtml(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_toHtml(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toHtml());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_toHtml, doc_QWebFrame_toHtml);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_toPlainText, "toPlainText(self) -> str");

extern "C" {static PyObject *meth_QWebFrame_toPlainText(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_toPlainText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toPlainText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_toPlainText, doc_QWebFrame_toPlainText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_title, "title(self) -> str");

extern "C" {static PyObject *meth_QWebFrame_title(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_title(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->title());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_title, doc_QWebFrame_title);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_setUrl, "setUrl(self, url: QUrl)");

extern "C" {static PyObject *meth_QWebFrame_setUrl(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_setUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setUrl(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_setUrl, doc_QWebFrame_setUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_url, "url(self) -> QUrl");

extern "C" {static PyObject *meth_QWebFrame_url(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_url(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->url());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_url, doc_QWebFrame_url);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_icon, "icon(self) -> QIcon");

extern "C" {static PyObject *meth_QWebFrame_icon(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_icon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QIcon*sipRes;

            sipRes = new ::QIcon(sipCpp->icon());

            return sipConvertFromNewType(sipRes, sipType_QIcon, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_icon, doc_QWebFrame_icon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_frameName, "frameName(self) -> str");

extern "C" {static PyObject *meth_QWebFrame_frameName(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_frameName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->frameName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_frameName, doc_QWebFrame_frameName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_parentFrame, "parentFrame(self) -> Optional[QWebFrame]");

extern "C" {static PyObject *meth_QWebFrame_parentFrame(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_parentFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QWebFrame*sipRes;

            sipRes = sipCpp->parentFrame();

            return sipConvertFromType(sipRes, sipType_QWebFrame, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_parentFrame, doc_QWebFrame_parentFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_childFrames, "childFrames(self) -> list[QWebFrame]");

extern "C" {static PyObject *meth_QWebFrame_childFrames(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_childFrames(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            QList< ::QWebFrame*>*sipRes;

            sipRes = new QList< ::QWebFrame*>(sipCpp->childFrames());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QWebFrame, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_childFrames, doc_QWebFrame_childFrames);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_scrollBarPolicy, "scrollBarPolicy(self, orientation: Qt.Orientation) -> Qt.ScrollBarPolicy");

extern "C" {static PyObject *meth_QWebFrame_scrollBarPolicy(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_scrollBarPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Orientation a0;
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_Qt_Orientation, &a0))
        {
            ::Qt::ScrollBarPolicy sipRes;

            sipRes = sipCpp->scrollBarPolicy(a0);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_ScrollBarPolicy);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_scrollBarPolicy, doc_QWebFrame_scrollBarPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_setScrollBarPolicy, "setScrollBarPolicy(self, orientation: Qt.Orientation, policy: Qt.ScrollBarPolicy)");

extern "C" {static PyObject *meth_QWebFrame_setScrollBarPolicy(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_setScrollBarPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Orientation a0;
        ::Qt::ScrollBarPolicy a1;
        ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEE", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_Qt_Orientation, &a0, sipType_Qt_ScrollBarPolicy, &a1))
        {
            sipCpp->setScrollBarPolicy(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_setScrollBarPolicy, doc_QWebFrame_setScrollBarPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_setScrollBarValue, "setScrollBarValue(self, orientation: Qt.Orientation, value: int)");

extern "C" {static PyObject *meth_QWebFrame_setScrollBarValue(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_setScrollBarValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Orientation a0;
        int a1;
        ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEi", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_Qt_Orientation, &a0, &a1))
        {
            sipCpp->setScrollBarValue(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_setScrollBarValue, doc_QWebFrame_setScrollBarValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_scrollBarValue, "scrollBarValue(self, orientation: Qt.Orientation) -> int");

extern "C" {static PyObject *meth_QWebFrame_scrollBarValue(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_scrollBarValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Orientation a0;
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_Qt_Orientation, &a0))
        {
            int sipRes;

            sipRes = sipCpp->scrollBarValue(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_scrollBarValue, doc_QWebFrame_scrollBarValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_scrollBarMinimum, "scrollBarMinimum(self, orientation: Qt.Orientation) -> int");

extern "C" {static PyObject *meth_QWebFrame_scrollBarMinimum(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_scrollBarMinimum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Orientation a0;
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_Qt_Orientation, &a0))
        {
            int sipRes;

            sipRes = sipCpp->scrollBarMinimum(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_scrollBarMinimum, doc_QWebFrame_scrollBarMinimum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_scrollBarMaximum, "scrollBarMaximum(self, orientation: Qt.Orientation) -> int");

extern "C" {static PyObject *meth_QWebFrame_scrollBarMaximum(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_scrollBarMaximum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Orientation a0;
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_Qt_Orientation, &a0))
        {
            int sipRes;

            sipRes = sipCpp->scrollBarMaximum(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_scrollBarMaximum, doc_QWebFrame_scrollBarMaximum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_pos, "pos(self) -> QPoint");

extern "C" {static PyObject *meth_QWebFrame_pos(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_pos(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint(sipCpp->pos());

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_pos, doc_QWebFrame_pos);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_geometry, "geometry(self) -> QRect");

extern "C" {static PyObject *meth_QWebFrame_geometry(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_geometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect(sipCpp->geometry());

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_geometry, doc_QWebFrame_geometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_contentsSize, "contentsSize(self) -> QSize");

extern "C" {static PyObject *meth_QWebFrame_contentsSize(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_contentsSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->contentsSize());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_contentsSize, doc_QWebFrame_contentsSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_hitTestContent, "hitTestContent(self, pos: QPoint) -> QWebHitTestResult");

extern "C" {static PyObject *meth_QWebFrame_hitTestContent(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_hitTestContent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QPoint, &a0))
        {
            ::QWebHitTestResult*sipRes;

            sipRes = new ::QWebHitTestResult(sipCpp->hitTestContent(*a0));

            return sipConvertFromNewType(sipRes, sipType_QWebHitTestResult, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_hitTestContent, doc_QWebFrame_hitTestContent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_event, "event(self, a0: Optional[QEvent]) -> bool");

extern "C" {static PyObject *meth_QWebFrame_event(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWebFrame::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_event, doc_QWebFrame_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_evaluateJavaScript, "evaluateJavaScript(self, scriptSource: Optional[str]) -> Any");

extern "C" {static PyObject *meth_QWebFrame_evaluateJavaScript(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_evaluateJavaScript(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->evaluateJavaScript(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_evaluateJavaScript, doc_QWebFrame_evaluateJavaScript);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_print_, "print_(self, printer: Optional[QPrinter])");

extern "C" {static PyObject *meth_QWebFrame_print_(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_print_(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrinter* a0;
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QPrinter, &a0))
        {
            sipCpp->print(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_print_, doc_QWebFrame_print_);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_print, "print(self, printer: Optional[QPrinter])");

extern "C" {static PyObject *meth_QWebFrame_print(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_print(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrinter* a0;
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QPrinter, &a0))
        {
            sipCpp->print(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_print, doc_QWebFrame_print);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_metaData, "metaData(self) -> dict[str, list[str]]");

extern "C" {static PyObject *meth_QWebFrame_metaData(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_metaData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            QMultiMap< ::QString, ::QString>*sipRes;

            sipRes = new QMultiMap< ::QString, ::QString>(sipCpp->metaData());

            return sipConvertFromNewType(sipRes, sipType_QMultiMap_0100QString_0100QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_metaData, doc_QWebFrame_metaData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_scroll, "scroll(self, a0: int, a1: int)");

extern "C" {static PyObject *meth_QWebFrame_scroll(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_scroll(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QWebFrame, &sipCpp, &a0, &a1))
        {
            sipCpp->scroll(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_scroll, doc_QWebFrame_scroll);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_scrollPosition, "scrollPosition(self) -> QPoint");

extern "C" {static PyObject *meth_QWebFrame_scrollPosition(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_scrollPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint(sipCpp->scrollPosition());

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_scrollPosition, doc_QWebFrame_scrollPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_setScrollPosition, "setScrollPosition(self, pos: QPoint)");

extern "C" {static PyObject *meth_QWebFrame_setScrollPosition(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_setScrollPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QPoint, &a0))
        {
            sipCpp->setScrollPosition(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_setScrollPosition, doc_QWebFrame_setScrollPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_zoomFactor, "zoomFactor(self) -> float");

extern "C" {static PyObject *meth_QWebFrame_zoomFactor(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_zoomFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->zoomFactor();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_zoomFactor, doc_QWebFrame_zoomFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_setZoomFactor, "setZoomFactor(self, factor: float)");

extern "C" {static PyObject *meth_QWebFrame_setZoomFactor(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_setZoomFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QWebFrame, &sipCpp, &a0))
        {
            sipCpp->setZoomFactor(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_setZoomFactor, doc_QWebFrame_setZoomFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_securityOrigin, "securityOrigin(self) -> QWebSecurityOrigin");

extern "C" {static PyObject *meth_QWebFrame_securityOrigin(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_securityOrigin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QWebSecurityOrigin*sipRes;

            sipRes = new ::QWebSecurityOrigin(sipCpp->securityOrigin());

            return sipConvertFromNewType(sipRes, sipType_QWebSecurityOrigin, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_securityOrigin, doc_QWebFrame_securityOrigin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_requestedUrl, "requestedUrl(self) -> QUrl");

extern "C" {static PyObject *meth_QWebFrame_requestedUrl(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_requestedUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->requestedUrl());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_requestedUrl, doc_QWebFrame_requestedUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_baseUrl, "baseUrl(self) -> QUrl");

extern "C" {static PyObject *meth_QWebFrame_baseUrl(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_baseUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->baseUrl());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_baseUrl, doc_QWebFrame_baseUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_scrollBarGeometry, "scrollBarGeometry(self, orientation: Qt.Orientation) -> QRect");

extern "C" {static PyObject *meth_QWebFrame_scrollBarGeometry(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_scrollBarGeometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Orientation a0;
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_Qt_Orientation, &a0))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect(sipCpp->scrollBarGeometry(a0));

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_scrollBarGeometry, doc_QWebFrame_scrollBarGeometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_render, "render(self, a0: Optional[QPainter], clip: QRegion = QRegion())\n"
"render(self, a0: Optional[QPainter], layer: QWebFrame.RenderLayers, clip: QRegion = QRegion())");

extern "C" {static PyObject *meth_QWebFrame_render(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_render(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPainter* a0;
        const ::QRegion& a1def = QRegion();
        const ::QRegion* a1 = &a1def;
        ::QWebFrame *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_clip,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|J9", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QPainter, &a0, sipType_QRegion, &a1))
        {
            sipCpp->render(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QPainter* a0;
        ::QWebFrame::RenderLayers* a1;
        int a1State = 0;
        const ::QRegion& a2def = QRegion();
        const ::QRegion* a2 = &a2def;
        ::QWebFrame *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_clip,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8J1|J9", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QPainter, &a0, sipType_QWebFrame_RenderLayers, &a1, &a1State, sipType_QRegion, &a2))
        {
            sipCpp->render(a0, *a1, *a2);
            sipReleaseType(a1, sipType_QWebFrame_RenderLayers, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_render, doc_QWebFrame_render);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_hasFocus, "hasFocus(self) -> bool");

extern "C" {static PyObject *meth_QWebFrame_hasFocus(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_hasFocus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasFocus();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_hasFocus, doc_QWebFrame_hasFocus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_setFocus, "setFocus(self)");

extern "C" {static PyObject *meth_QWebFrame_setFocus(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_setFocus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            sipCpp->setFocus();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_setFocus, doc_QWebFrame_setFocus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_documentElement, "documentElement(self) -> QWebElement");

extern "C" {static PyObject *meth_QWebFrame_documentElement(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_documentElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebFrame, &sipCpp))
        {
            ::QWebElement*sipRes;

            sipRes = new ::QWebElement(sipCpp->documentElement());

            return sipConvertFromNewType(sipRes, sipType_QWebElement, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_documentElement, doc_QWebFrame_documentElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_findAllElements, "findAllElements(self, selectorQuery: Optional[str]) -> QWebElementCollection");

extern "C" {static PyObject *meth_QWebFrame_findAllElements(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_findAllElements(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QWebElementCollection*sipRes;

            sipRes = new ::QWebElementCollection(sipCpp->findAllElements(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QWebElementCollection, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_findAllElements, doc_QWebFrame_findAllElements);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_findFirstElement, "findFirstElement(self, selectorQuery: Optional[str]) -> QWebElement");

extern "C" {static PyObject *meth_QWebFrame_findFirstElement(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_findFirstElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QWebElement*sipRes;

            sipRes = new ::QWebElement(sipCpp->findFirstElement(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QWebElement, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_findFirstElement, doc_QWebFrame_findFirstElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebFrame_scrollToAnchor, "scrollToAnchor(self, anchor: Optional[str])");

extern "C" {static PyObject *meth_QWebFrame_scrollToAnchor(PyObject *, PyObject *);}
static PyObject *meth_QWebFrame_scrollToAnchor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebFrame *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebFrame, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->scrollToAnchor(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebFrame, sipName_scrollToAnchor, doc_QWebFrame_scrollToAnchor);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QWebFrame(void *, const sipTypeDef *);}
static void *cast_QWebFrame(void *sipCppV, const sipTypeDef *targetType)
{
    ::QWebFrame *sipCpp = reinterpret_cast< ::QWebFrame *>(sipCppV);

    if (targetType == sipType_QWebFrame)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebFrame(void *, int);}
static void release_QWebFrame(void *, int)
{
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QWebFrame[] = {{4, 0, 1}};


static PyMethodDef methods_QWebFrame[] = {
    {sipName_addToJavaScriptWindowObject, SIP_MLMETH_CAST(meth_QWebFrame_addToJavaScriptWindowObject), METH_VARARGS|METH_KEYWORDS, doc_QWebFrame_addToJavaScriptWindowObject},
    {sipName_baseUrl, meth_QWebFrame_baseUrl, METH_VARARGS, doc_QWebFrame_baseUrl},
    {sipName_childFrames, meth_QWebFrame_childFrames, METH_VARARGS, doc_QWebFrame_childFrames},
    {sipName_contentsSize, meth_QWebFrame_contentsSize, METH_VARARGS, doc_QWebFrame_contentsSize},
    {sipName_documentElement, meth_QWebFrame_documentElement, METH_VARARGS, doc_QWebFrame_documentElement},
    {sipName_evaluateJavaScript, meth_QWebFrame_evaluateJavaScript, METH_VARARGS, doc_QWebFrame_evaluateJavaScript},
    {sipName_event, meth_QWebFrame_event, METH_VARARGS, doc_QWebFrame_event},
    {sipName_findAllElements, meth_QWebFrame_findAllElements, METH_VARARGS, doc_QWebFrame_findAllElements},
    {sipName_findFirstElement, meth_QWebFrame_findFirstElement, METH_VARARGS, doc_QWebFrame_findFirstElement},
    {sipName_frameName, meth_QWebFrame_frameName, METH_VARARGS, doc_QWebFrame_frameName},
    {sipName_geometry, meth_QWebFrame_geometry, METH_VARARGS, doc_QWebFrame_geometry},
    {sipName_hasFocus, meth_QWebFrame_hasFocus, METH_VARARGS, doc_QWebFrame_hasFocus},
    {sipName_hitTestContent, meth_QWebFrame_hitTestContent, METH_VARARGS, doc_QWebFrame_hitTestContent},
    {sipName_icon, meth_QWebFrame_icon, METH_VARARGS, doc_QWebFrame_icon},
    {sipName_load, SIP_MLMETH_CAST(meth_QWebFrame_load), METH_VARARGS|METH_KEYWORDS, doc_QWebFrame_load},
    {sipName_metaData, meth_QWebFrame_metaData, METH_VARARGS, doc_QWebFrame_metaData},
    {sipName_page, meth_QWebFrame_page, METH_VARARGS, doc_QWebFrame_page},
    {sipName_parentFrame, meth_QWebFrame_parentFrame, METH_VARARGS, doc_QWebFrame_parentFrame},
    {sipName_pos, meth_QWebFrame_pos, METH_VARARGS, doc_QWebFrame_pos},
    {sipName_print, meth_QWebFrame_print, METH_VARARGS, doc_QWebFrame_print},
    {sipName_print_, meth_QWebFrame_print_, METH_VARARGS, doc_QWebFrame_print_},
    {sipName_render, SIP_MLMETH_CAST(meth_QWebFrame_render), METH_VARARGS|METH_KEYWORDS, doc_QWebFrame_render},
    {sipName_requestedUrl, meth_QWebFrame_requestedUrl, METH_VARARGS, doc_QWebFrame_requestedUrl},
    {sipName_scroll, meth_QWebFrame_scroll, METH_VARARGS, doc_QWebFrame_scroll},
    {sipName_scrollBarGeometry, meth_QWebFrame_scrollBarGeometry, METH_VARARGS, doc_QWebFrame_scrollBarGeometry},
    {sipName_scrollBarMaximum, meth_QWebFrame_scrollBarMaximum, METH_VARARGS, doc_QWebFrame_scrollBarMaximum},
    {sipName_scrollBarMinimum, meth_QWebFrame_scrollBarMinimum, METH_VARARGS, doc_QWebFrame_scrollBarMinimum},
    {sipName_scrollBarPolicy, meth_QWebFrame_scrollBarPolicy, METH_VARARGS, doc_QWebFrame_scrollBarPolicy},
    {sipName_scrollBarValue, meth_QWebFrame_scrollBarValue, METH_VARARGS, doc_QWebFrame_scrollBarValue},
    {sipName_scrollPosition, meth_QWebFrame_scrollPosition, METH_VARARGS, doc_QWebFrame_scrollPosition},
    {sipName_scrollToAnchor, meth_QWebFrame_scrollToAnchor, METH_VARARGS, doc_QWebFrame_scrollToAnchor},
    {sipName_securityOrigin, meth_QWebFrame_securityOrigin, METH_VARARGS, doc_QWebFrame_securityOrigin},
    {sipName_setContent, SIP_MLMETH_CAST(meth_QWebFrame_setContent), METH_VARARGS|METH_KEYWORDS, doc_QWebFrame_setContent},
    {sipName_setFocus, meth_QWebFrame_setFocus, METH_VARARGS, doc_QWebFrame_setFocus},
    {sipName_setHtml, SIP_MLMETH_CAST(meth_QWebFrame_setHtml), METH_VARARGS|METH_KEYWORDS, doc_QWebFrame_setHtml},
    {sipName_setScrollBarPolicy, meth_QWebFrame_setScrollBarPolicy, METH_VARARGS, doc_QWebFrame_setScrollBarPolicy},
    {sipName_setScrollBarValue, meth_QWebFrame_setScrollBarValue, METH_VARARGS, doc_QWebFrame_setScrollBarValue},
    {sipName_setScrollPosition, meth_QWebFrame_setScrollPosition, METH_VARARGS, doc_QWebFrame_setScrollPosition},
    {sipName_setUrl, meth_QWebFrame_setUrl, METH_VARARGS, doc_QWebFrame_setUrl},
    {sipName_setZoomFactor, meth_QWebFrame_setZoomFactor, METH_VARARGS, doc_QWebFrame_setZoomFactor},
    {sipName_title, meth_QWebFrame_title, METH_VARARGS, doc_QWebFrame_title},
    {sipName_toHtml, meth_QWebFrame_toHtml, METH_VARARGS, doc_QWebFrame_toHtml},
    {sipName_toPlainText, meth_QWebFrame_toPlainText, METH_VARARGS, doc_QWebFrame_toPlainText},
    {sipName_url, meth_QWebFrame_url, METH_VARARGS, doc_QWebFrame_url},
    {sipName_zoomFactor, meth_QWebFrame_zoomFactor, METH_VARARGS, doc_QWebFrame_zoomFactor}
};

static sipEnumMemberDef enummembers_QWebFrame[] = {
    {sipName_AllLayers, static_cast<int>(::QWebFrame::AllLayers), 4},
    {sipName_AutoOwnership, static_cast<int>(::QWebFrame::AutoOwnership), 6},
    {sipName_ContentsLayer, static_cast<int>(::QWebFrame::ContentsLayer), 4},
    {sipName_PanIconLayer, static_cast<int>(::QWebFrame::PanIconLayer), 4},
    {sipName_QtOwnership, static_cast<int>(::QWebFrame::QtOwnership), 6},
    {sipName_ScriptOwnership, static_cast<int>(::QWebFrame::ScriptOwnership), 6},
    {sipName_ScrollBarLayer, static_cast<int>(::QWebFrame::ScrollBarLayer), 4},
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QWebFrame[] = {
    {"pageChanged()", "\1pageChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"loadFinished(bool)", "\1loadFinished(self, ok: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"loadStarted()", "\1loadStarted(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"contentsSizeChanged(QSize)", "\1contentsSizeChanged(self, size: QSize)", SIP_NULLPTR, SIP_NULLPTR},
    {"iconChanged()", "\1iconChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"initialLayoutCompleted()", "\1initialLayoutCompleted(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"urlChanged(QUrl)", "\1urlChanged(self, url: QUrl)", SIP_NULLPTR, SIP_NULLPTR},
    {"titleChanged(QString)", "\1titleChanged(self, title: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"javaScriptWindowObjectCleared()", "\1javaScriptWindowObjectCleared(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QWebFrame = {
    &::QWebFrame::staticMetaObject,
    0,
    signals_QWebFrame,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebFrame = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebFrame,
        SIP_NULLPTR,
        &plugin_QWebFrame,
    },
    {
        sipNameNr_QWebFrame,
        {0, 0, 1},
        45, methods_QWebFrame,
        7, enummembers_QWebFrame,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QWebFrame,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QWebFrame,
    cast_QWebFrame,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
