/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudiooutputselectorcontrol.sip"
#include <qaudiooutputselectorcontrol.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQAudioOutputSelectorControl.cpp"


class sipQAudioOutputSelectorControl : public ::QAudioOutputSelectorControl
{
public:
    sipQAudioOutputSelectorControl(::QObject*);
    virtual ~sipQAudioOutputSelectorControl();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void setActiveOutput(const ::QString&) SIP_OVERRIDE;
    ::QString activeOutput() const SIP_OVERRIDE;
    ::QString defaultOutput() const SIP_OVERRIDE;
    ::QString outputDescription(const ::QString&) const SIP_OVERRIDE;
    QList< ::QString> availableOutputs() const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAudioOutputSelectorControl(const sipQAudioOutputSelectorControl &);
    sipQAudioOutputSelectorControl &operator = (const sipQAudioOutputSelectorControl &);

    char sipPyMethods[12];
};

sipQAudioOutputSelectorControl::sipQAudioOutputSelectorControl(::QObject*a0): ::QAudioOutputSelectorControl(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAudioOutputSelectorControl::~sipQAudioOutputSelectorControl()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQAudioOutputSelectorControl::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QAudioOutputSelectorControl);

    return ::QAudioOutputSelectorControl::metaObject();
}

int sipQAudioOutputSelectorControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QAudioOutputSelectorControl::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QAudioOutputSelectorControl, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQAudioOutputSelectorControl::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QAudioOutputSelectorControl, _clname, &sipCpp) ? sipCpp : ::QAudioOutputSelectorControl::qt_metacast(_clname));
}

void sipQAudioOutputSelectorControl::setActiveOutput(const ::QString& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, sipName_QAudioOutputSelectorControl, sipName_setActiveOutput);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    sipVH_QtMultimedia_23(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QString sipQAudioOutputSelectorControl::activeOutput() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAudioOutputSelectorControl, sipName_activeOutput);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtMultimedia_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_22(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QString sipQAudioOutputSelectorControl::defaultOutput() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAudioOutputSelectorControl, sipName_defaultOutput);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtMultimedia_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_22(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QString sipQAudioOutputSelectorControl::outputDescription(const ::QString& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAudioOutputSelectorControl, sipName_outputDescription);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtMultimedia_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtMultimedia_31(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

QList< ::QString> sipQAudioOutputSelectorControl::availableOutputs() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAudioOutputSelectorControl, sipName_availableOutputs);

    if (!sipMeth)
        return QList< ::QString>();

    extern QList< ::QString> sipVH_QtMultimedia_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_35(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAudioOutputSelectorControl::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QAudioOutputSelectorControl::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioOutputSelectorControl::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QAudioOutputSelectorControl::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioOutputSelectorControl::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QAudioOutputSelectorControl::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioOutputSelectorControl::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QAudioOutputSelectorControl::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAudioOutputSelectorControl::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QAudioOutputSelectorControl::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAudioOutputSelectorControl::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QAudioOutputSelectorControl::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQAudioOutputSelectorControl::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QAudioOutputSelectorControl::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QAudioOutputSelectorControl_availableOutputs, "availableOutputs(self) -> list[str]");

extern "C" {static PyObject *meth_QAudioOutputSelectorControl_availableOutputs(PyObject *, PyObject *);}
static PyObject *meth_QAudioOutputSelectorControl_availableOutputs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QAudioOutputSelectorControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioOutputSelectorControl, &sipCpp))
        {
            QList< ::QString>*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioOutputSelectorControl, sipName_availableOutputs);
                return SIP_NULLPTR;
            }

            sipRes = new QList< ::QString>(sipCpp->availableOutputs());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioOutputSelectorControl, sipName_availableOutputs, doc_QAudioOutputSelectorControl_availableOutputs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioOutputSelectorControl_outputDescription, "outputDescription(self, name: Optional[str]) -> str");

extern "C" {static PyObject *meth_QAudioOutputSelectorControl_outputDescription(PyObject *, PyObject *);}
static PyObject *meth_QAudioOutputSelectorControl_outputDescription(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QAudioOutputSelectorControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAudioOutputSelectorControl, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioOutputSelectorControl, sipName_outputDescription);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->outputDescription(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioOutputSelectorControl, sipName_outputDescription, doc_QAudioOutputSelectorControl_outputDescription);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioOutputSelectorControl_defaultOutput, "defaultOutput(self) -> str");

extern "C" {static PyObject *meth_QAudioOutputSelectorControl_defaultOutput(PyObject *, PyObject *);}
static PyObject *meth_QAudioOutputSelectorControl_defaultOutput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QAudioOutputSelectorControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioOutputSelectorControl, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioOutputSelectorControl, sipName_defaultOutput);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->defaultOutput());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioOutputSelectorControl, sipName_defaultOutput, doc_QAudioOutputSelectorControl_defaultOutput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioOutputSelectorControl_activeOutput, "activeOutput(self) -> str");

extern "C" {static PyObject *meth_QAudioOutputSelectorControl_activeOutput(PyObject *, PyObject *);}
static PyObject *meth_QAudioOutputSelectorControl_activeOutput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QAudioOutputSelectorControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAudioOutputSelectorControl, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioOutputSelectorControl, sipName_activeOutput);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->activeOutput());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioOutputSelectorControl, sipName_activeOutput, doc_QAudioOutputSelectorControl_activeOutput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAudioOutputSelectorControl_setActiveOutput, "setActiveOutput(self, name: Optional[str])");

extern "C" {static PyObject *meth_QAudioOutputSelectorControl_setActiveOutput(PyObject *, PyObject *);}
static PyObject *meth_QAudioOutputSelectorControl_setActiveOutput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QAudioOutputSelectorControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAudioOutputSelectorControl, &sipCpp, sipType_QString, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAudioOutputSelectorControl, sipName_setActiveOutput);
                return SIP_NULLPTR;
            }

            sipCpp->setActiveOutput(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAudioOutputSelectorControl, sipName_setActiveOutput, doc_QAudioOutputSelectorControl_setActiveOutput);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAudioOutputSelectorControl(void *, const sipTypeDef *);}
static void *cast_QAudioOutputSelectorControl(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAudioOutputSelectorControl *sipCpp = reinterpret_cast< ::QAudioOutputSelectorControl *>(sipCppV);

    if (targetType == sipType_QAudioOutputSelectorControl)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaControl)->ctd_cast(static_cast< ::QMediaControl *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAudioOutputSelectorControl(void *, int);}
static void release_QAudioOutputSelectorControl(void *sipCppV, int)
{
    ::QAudioOutputSelectorControl *sipCpp = reinterpret_cast< ::QAudioOutputSelectorControl *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QAudioOutputSelectorControl(sipSimpleWrapper *);}
static void dealloc_QAudioOutputSelectorControl(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAudioOutputSelectorControl *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAudioOutputSelectorControl(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAudioOutputSelectorControl(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAudioOutputSelectorControl(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQAudioOutputSelectorControl *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQAudioOutputSelectorControl(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAudioOutputSelectorControl[] = {{104, 255, 1}};


static PyMethodDef methods_QAudioOutputSelectorControl[] = {
    {sipName_activeOutput, meth_QAudioOutputSelectorControl_activeOutput, METH_VARARGS, doc_QAudioOutputSelectorControl_activeOutput},
    {sipName_availableOutputs, meth_QAudioOutputSelectorControl_availableOutputs, METH_VARARGS, doc_QAudioOutputSelectorControl_availableOutputs},
    {sipName_defaultOutput, meth_QAudioOutputSelectorControl_defaultOutput, METH_VARARGS, doc_QAudioOutputSelectorControl_defaultOutput},
    {sipName_outputDescription, meth_QAudioOutputSelectorControl_outputDescription, METH_VARARGS, doc_QAudioOutputSelectorControl_outputDescription},
    {sipName_setActiveOutput, meth_QAudioOutputSelectorControl_setActiveOutput, METH_VARARGS, doc_QAudioOutputSelectorControl_setActiveOutput}
};

PyDoc_STRVAR(doc_QAudioOutputSelectorControl, "\1QAudioOutputSelectorControl(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QAudioOutputSelectorControl[] = {
    {"availableOutputsChanged()", "\1availableOutputsChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"activeOutputChanged(QString)", "\1activeOutputChanged(self, name: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QAudioOutputSelectorControl = {
    &::QAudioOutputSelectorControl::staticMetaObject,
    0,
    signals_QAudioOutputSelectorControl,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QAudioOutputSelectorControl = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAudioOutputSelectorControl,
        SIP_NULLPTR,
        &plugin_QAudioOutputSelectorControl,
    },
    {
        sipNameNr_QAudioOutputSelectorControl,
        {0, 0, 1},
        5, methods_QAudioOutputSelectorControl,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAudioOutputSelectorControl,
    -1,
    -1,
    supers_QAudioOutputSelectorControl,
    SIP_NULLPTR,
    init_type_QAudioOutputSelectorControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAudioOutputSelectorControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QAudioOutputSelectorControl,
    cast_QAudioOutputSelectorControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QAudioOutputSelectorControl),
};
