/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPositioning.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeolocation.sip"
#include <qgeolocation.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPositioning/sipQtPositioningQGeoLocation.cpp"

#line 24 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPositioning/sipQtPositioningQGeoLocation.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeorectangle.sip"
#include <qgeorectangle.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPositioning/sipQtPositioningQGeoLocation.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeocoordinate.sip"
#include <qgeocoordinate.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPositioning/sipQtPositioningQGeoLocation.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeoaddress.sip"
#include <qgeoaddress.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPositioning/sipQtPositioningQGeoLocation.cpp"


PyDoc_STRVAR(doc_QGeoLocation_address, "address(self) -> QGeoAddress");

extern "C" {static PyObject *meth_QGeoLocation_address(PyObject *, PyObject *);}
static PyObject *meth_QGeoLocation_address(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoLocation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoLocation, &sipCpp))
        {
            ::QGeoAddress*sipRes;

            sipRes = new ::QGeoAddress(sipCpp->address());

            return sipConvertFromNewType(sipRes, sipType_QGeoAddress, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoLocation, sipName_address, doc_QGeoLocation_address);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoLocation_setAddress, "setAddress(self, address: QGeoAddress)");

extern "C" {static PyObject *meth_QGeoLocation_setAddress(PyObject *, PyObject *);}
static PyObject *meth_QGeoLocation_setAddress(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAddress* a0;
        ::QGeoLocation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoLocation, &sipCpp, sipType_QGeoAddress, &a0))
        {
            sipCpp->setAddress(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoLocation, sipName_setAddress, doc_QGeoLocation_setAddress);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoLocation_coordinate, "coordinate(self) -> QGeoCoordinate");

extern "C" {static PyObject *meth_QGeoLocation_coordinate(PyObject *, PyObject *);}
static PyObject *meth_QGeoLocation_coordinate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoLocation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoLocation, &sipCpp))
        {
            ::QGeoCoordinate*sipRes;

            sipRes = new ::QGeoCoordinate(sipCpp->coordinate());

            return sipConvertFromNewType(sipRes, sipType_QGeoCoordinate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoLocation, sipName_coordinate, doc_QGeoLocation_coordinate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoLocation_setCoordinate, "setCoordinate(self, position: QGeoCoordinate)");

extern "C" {static PyObject *meth_QGeoLocation_setCoordinate(PyObject *, PyObject *);}
static PyObject *meth_QGeoLocation_setCoordinate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCoordinate* a0;
        ::QGeoLocation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoLocation, &sipCpp, sipType_QGeoCoordinate, &a0))
        {
            sipCpp->setCoordinate(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoLocation, sipName_setCoordinate, doc_QGeoLocation_setCoordinate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoLocation_boundingBox, "boundingBox(self) -> QGeoRectangle");

extern "C" {static PyObject *meth_QGeoLocation_boundingBox(PyObject *, PyObject *);}
static PyObject *meth_QGeoLocation_boundingBox(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoLocation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoLocation, &sipCpp))
        {
            ::QGeoRectangle*sipRes;

            sipRes = new ::QGeoRectangle(sipCpp->boundingBox());

            return sipConvertFromNewType(sipRes, sipType_QGeoRectangle, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoLocation, sipName_boundingBox, doc_QGeoLocation_boundingBox);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoLocation_setBoundingBox, "setBoundingBox(self, box: QGeoRectangle)");

extern "C" {static PyObject *meth_QGeoLocation_setBoundingBox(PyObject *, PyObject *);}
static PyObject *meth_QGeoLocation_setBoundingBox(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRectangle* a0;
        ::QGeoLocation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoLocation, &sipCpp, sipType_QGeoRectangle, &a0))
        {
            sipCpp->setBoundingBox(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoLocation, sipName_setBoundingBox, doc_QGeoLocation_setBoundingBox);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoLocation_isEmpty, "isEmpty(self) -> bool");

extern "C" {static PyObject *meth_QGeoLocation_isEmpty(PyObject *, PyObject *);}
static PyObject *meth_QGeoLocation_isEmpty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoLocation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoLocation, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEmpty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoLocation, sipName_isEmpty, doc_QGeoLocation_isEmpty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoLocation_extendedAttributes, "extendedAttributes(self) -> dict[str, Any]");

extern "C" {static PyObject *meth_QGeoLocation_extendedAttributes(PyObject *, PyObject *);}
static PyObject *meth_QGeoLocation_extendedAttributes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoLocation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoLocation, &sipCpp))
        {
            ::QVariantMap*sipRes;

            sipRes = new ::QVariantMap(sipCpp->extendedAttributes());

            return sipConvertFromNewType(sipRes, sipType_QVariantMap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoLocation, sipName_extendedAttributes, doc_QGeoLocation_extendedAttributes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoLocation_setExtendedAttributes, "setExtendedAttributes(self, data: dict[str, Any])");

extern "C" {static PyObject *meth_QGeoLocation_setExtendedAttributes(PyObject *, PyObject *);}
static PyObject *meth_QGeoLocation_setExtendedAttributes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariantMap* a0;
        int a0State = 0;
        ::QGeoLocation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoLocation, &sipCpp, sipType_QVariantMap, &a0, &a0State))
        {
            sipCpp->setExtendedAttributes(*a0);
            sipReleaseType(const_cast< ::QVariantMap *>(a0), sipType_QVariantMap, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoLocation, sipName_setExtendedAttributes, doc_QGeoLocation_setExtendedAttributes);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QGeoLocation___ne__(PyObject *, PyObject *);}
static PyObject *slot_QGeoLocation___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoLocation *sipCpp = reinterpret_cast< ::QGeoLocation *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoLocation));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoLocation* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGeoLocation, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QGeoLocation::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtPositioning, ne_slot, sipType_QGeoLocation, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QGeoLocation___eq__(PyObject *, PyObject *);}
static PyObject *slot_QGeoLocation___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoLocation *sipCpp = reinterpret_cast< ::QGeoLocation *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoLocation));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoLocation* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGeoLocation, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QGeoLocation::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtPositioning, eq_slot, sipType_QGeoLocation, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoLocation(void *, int);}
static void release_QGeoLocation(void *sipCppV, int)
{
    delete reinterpret_cast< ::QGeoLocation *>(sipCppV);
}


extern "C" {static void *array_QGeoLocation(Py_ssize_t);}
static void *array_QGeoLocation(Py_ssize_t sipNrElem)
{
    return new ::QGeoLocation[sipNrElem];
}


extern "C" {static void array_delete_QGeoLocation(void *);}
static void array_delete_QGeoLocation(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGeoLocation *>(sipCpp);
}


extern "C" {static void assign_QGeoLocation(void *, Py_ssize_t, void *);}
static void assign_QGeoLocation(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QGeoLocation *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QGeoLocation *>(sipSrc);
}


extern "C" {static void *copy_QGeoLocation(const void *, Py_ssize_t);}
static void *copy_QGeoLocation(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QGeoLocation(reinterpret_cast<const ::QGeoLocation *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QGeoLocation(sipSimpleWrapper *);}
static void dealloc_QGeoLocation(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoLocation(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QGeoLocation(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoLocation(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QGeoLocation *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QGeoLocation();

            return sipCpp;
        }
    }

    {
        const ::QGeoLocation* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QGeoLocation, &a0))
        {
            sipCpp = new ::QGeoLocation(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QGeoLocation[] = {
    {(void *)slot_QGeoLocation___ne__, ne_slot},
    {(void *)slot_QGeoLocation___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QGeoLocation[] = {
    {sipName_address, meth_QGeoLocation_address, METH_VARARGS, doc_QGeoLocation_address},
    {sipName_boundingBox, meth_QGeoLocation_boundingBox, METH_VARARGS, doc_QGeoLocation_boundingBox},
    {sipName_coordinate, meth_QGeoLocation_coordinate, METH_VARARGS, doc_QGeoLocation_coordinate},
    {sipName_extendedAttributes, meth_QGeoLocation_extendedAttributes, METH_VARARGS, doc_QGeoLocation_extendedAttributes},
    {sipName_isEmpty, meth_QGeoLocation_isEmpty, METH_VARARGS, doc_QGeoLocation_isEmpty},
    {sipName_setAddress, meth_QGeoLocation_setAddress, METH_VARARGS, doc_QGeoLocation_setAddress},
    {sipName_setBoundingBox, meth_QGeoLocation_setBoundingBox, METH_VARARGS, doc_QGeoLocation_setBoundingBox},
    {sipName_setCoordinate, meth_QGeoLocation_setCoordinate, METH_VARARGS, doc_QGeoLocation_setCoordinate},
    {sipName_setExtendedAttributes, meth_QGeoLocation_setExtendedAttributes, METH_VARARGS, doc_QGeoLocation_setExtendedAttributes}
};

PyDoc_STRVAR(doc_QGeoLocation, "\1QGeoLocation()\n"
"QGeoLocation(other: QGeoLocation)");


static pyqt5ClassPluginDef plugin_QGeoLocation = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtPositioning_QGeoLocation = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoLocation,
        SIP_NULLPTR,
        &plugin_QGeoLocation,
    },
    {
        sipNameNr_QGeoLocation,
        {0, 0, 1},
        9, methods_QGeoLocation,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoLocation,
    -1,
    -1,
    SIP_NULLPTR,
    slots_QGeoLocation,
    init_type_QGeoLocation,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoLocation,
    assign_QGeoLocation,
    array_QGeoLocation,
    copy_QGeoLocation,
    release_QGeoLocation,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGeoLocation,
    sizeof (::QGeoLocation),
};
