/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 185 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQuick/sipQtQuickQQuickItemUpdatePaintNodeData.cpp"

#line 314 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtQuick/qsgnode.sip"
#include <qsgnode.h>
#line 35 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQuick/sipQtQuickQQuickItemUpdatePaintNodeData.cpp"


/* Call the instance's destructor. */
extern "C" {static void release_QQuickItem_UpdatePaintNodeData(void *, int);}
static void release_QQuickItem_UpdatePaintNodeData(void *sipCppV, int)
{
    delete reinterpret_cast< ::QQuickItem::UpdatePaintNodeData *>(sipCppV);
}


extern "C" {static void assign_QQuickItem_UpdatePaintNodeData(void *, Py_ssize_t, void *);}
static void assign_QQuickItem_UpdatePaintNodeData(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QQuickItem::UpdatePaintNodeData *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QQuickItem::UpdatePaintNodeData *>(sipSrc);
}


extern "C" {static void *copy_QQuickItem_UpdatePaintNodeData(const void *, Py_ssize_t);}
static void *copy_QQuickItem_UpdatePaintNodeData(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QQuickItem::UpdatePaintNodeData(reinterpret_cast<const ::QQuickItem::UpdatePaintNodeData *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QQuickItem_UpdatePaintNodeData(sipSimpleWrapper *);}
static void dealloc_QQuickItem_UpdatePaintNodeData(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQuickItem_UpdatePaintNodeData(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QQuickItem_UpdatePaintNodeData(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQuickItem_UpdatePaintNodeData(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QQuickItem::UpdatePaintNodeData *sipCpp = SIP_NULLPTR;

    {
        const ::QQuickItem::UpdatePaintNodeData* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QQuickItem_UpdatePaintNodeData, &a0))
        {
            sipCpp = new ::QQuickItem::UpdatePaintNodeData(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static PyObject *varget_QQuickItem_UpdatePaintNodeData_transformNode(void *, PyObject *, PyObject *);}
static PyObject *varget_QQuickItem_UpdatePaintNodeData_transformNode(void *sipSelf, PyObject *, PyObject *)
{
    ::QSGTransformNode*sipVal;
    ::QQuickItem::UpdatePaintNodeData *sipCpp = reinterpret_cast< ::QQuickItem::UpdatePaintNodeData *>(sipSelf);

    sipVal = sipCpp->transformNode;

    return sipConvertFromType(sipVal, sipType_QSGTransformNode, SIP_NULLPTR);
}


extern "C" {static int varset_QQuickItem_UpdatePaintNodeData_transformNode(void *, PyObject *, PyObject *);}
static int varset_QQuickItem_UpdatePaintNodeData_transformNode(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QSGTransformNode*sipVal;
    ::QQuickItem::UpdatePaintNodeData *sipCpp = reinterpret_cast< ::QQuickItem::UpdatePaintNodeData *>(sipSelf);

    int sipIsErr = 0;
    sipVal = reinterpret_cast< ::QSGTransformNode *>(sipForceConvertToType(sipPy, sipType_QSGTransformNode, SIP_NULLPTR, 0, SIP_NULLPTR, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->transformNode = sipVal;

    return 0;
}

sipVariableDef variables_QQuickItem_UpdatePaintNodeData[] = {
    {InstanceVariable, sipName_transformNode, (PyMethodDef *)varget_QQuickItem_UpdatePaintNodeData_transformNode, (PyMethodDef *)varset_QQuickItem_UpdatePaintNodeData_transformNode, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QQuickItem_UpdatePaintNodeData, "\1QQuickItem.UpdatePaintNodeData(a0: QQuickItem.UpdatePaintNodeData)");


static pyqt5ClassPluginDef plugin_QQuickItem_UpdatePaintNodeData = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtQuick_QQuickItem_UpdatePaintNodeData = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQuickItem__UpdatePaintNodeData,
        SIP_NULLPTR,
        &plugin_QQuickItem_UpdatePaintNodeData,
    },
    {
        sipNameNr_UpdatePaintNodeData,
        {7, 255, 0},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        1, variables_QQuickItem_UpdatePaintNodeData,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQuickItem_UpdatePaintNodeData,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QQuickItem_UpdatePaintNodeData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQuickItem_UpdatePaintNodeData,
    assign_QQuickItem_UpdatePaintNodeData,
    SIP_NULLPTR,
    copy_QQuickItem_UpdatePaintNodeData,
    release_QQuickItem_UpdatePaintNodeData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QQuickItem::UpdatePaintNodeData),
};
