/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKit.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 31 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactoryMimeType.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 35 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactoryMimeType.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactoryMimeType.cpp"


extern "C" {static PyObject *slot_QWebPluginFactory_MimeType___ne__(PyObject *, PyObject *);}
static PyObject *slot_QWebPluginFactory_MimeType___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QWebPluginFactory::MimeType *sipCpp = reinterpret_cast< ::QWebPluginFactory::MimeType *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QWebPluginFactory_MimeType));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPluginFactory::MimeType* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QWebPluginFactory_MimeType, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QWebPluginFactory::MimeType::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtWebKit, ne_slot, sipType_QWebPluginFactory_MimeType, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QWebPluginFactory_MimeType___eq__(PyObject *, PyObject *);}
static PyObject *slot_QWebPluginFactory_MimeType___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QWebPluginFactory::MimeType *sipCpp = reinterpret_cast< ::QWebPluginFactory::MimeType *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QWebPluginFactory_MimeType));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPluginFactory::MimeType* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QWebPluginFactory_MimeType, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QWebPluginFactory::MimeType::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtWebKit, eq_slot, sipType_QWebPluginFactory_MimeType, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebPluginFactory_MimeType(void *, int);}
static void release_QWebPluginFactory_MimeType(void *sipCppV, int)
{
    delete reinterpret_cast< ::QWebPluginFactory::MimeType *>(sipCppV);
}


extern "C" {static void *array_QWebPluginFactory_MimeType(Py_ssize_t);}
static void *array_QWebPluginFactory_MimeType(Py_ssize_t sipNrElem)
{
    return new ::QWebPluginFactory::MimeType[sipNrElem];
}


extern "C" {static void array_delete_QWebPluginFactory_MimeType(void *);}
static void array_delete_QWebPluginFactory_MimeType(void *sipCpp)
{
    delete[] reinterpret_cast< ::QWebPluginFactory::MimeType *>(sipCpp);
}


extern "C" {static void assign_QWebPluginFactory_MimeType(void *, Py_ssize_t, void *);}
static void assign_QWebPluginFactory_MimeType(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QWebPluginFactory::MimeType *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QWebPluginFactory::MimeType *>(sipSrc);
}


extern "C" {static void *copy_QWebPluginFactory_MimeType(const void *, Py_ssize_t);}
static void *copy_QWebPluginFactory_MimeType(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QWebPluginFactory::MimeType(reinterpret_cast<const ::QWebPluginFactory::MimeType *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QWebPluginFactory_MimeType(sipSimpleWrapper *);}
static void dealloc_QWebPluginFactory_MimeType(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWebPluginFactory_MimeType(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QWebPluginFactory_MimeType(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWebPluginFactory_MimeType(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QWebPluginFactory::MimeType *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QWebPluginFactory::MimeType();

            return sipCpp;
        }
    }

    {
        const ::QWebPluginFactory::MimeType* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QWebPluginFactory_MimeType, &a0))
        {
            sipCpp = new ::QWebPluginFactory::MimeType(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QWebPluginFactory_MimeType[] = {
    {(void *)slot_QWebPluginFactory_MimeType___ne__, ne_slot},
    {(void *)slot_QWebPluginFactory_MimeType___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


extern "C" {static PyObject *varget_QWebPluginFactory_MimeType_description(void *, PyObject *, PyObject *);}
static PyObject *varget_QWebPluginFactory_MimeType_description(void *sipSelf, PyObject *, PyObject *)
{
    ::QString*sipVal;
    ::QWebPluginFactory::MimeType *sipCpp = reinterpret_cast< ::QWebPluginFactory::MimeType *>(sipSelf);

    sipVal = &sipCpp->description;

    return sipConvertFromType(sipVal, sipType_QString, SIP_NULLPTR);
}


extern "C" {static int varset_QWebPluginFactory_MimeType_description(void *, PyObject *, PyObject *);}
static int varset_QWebPluginFactory_MimeType_description(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QString*sipVal;
    ::QWebPluginFactory::MimeType *sipCpp = reinterpret_cast< ::QWebPluginFactory::MimeType *>(sipSelf);

    int sipIsErr = 0;
    int sipValState;
    sipVal = reinterpret_cast< ::QString *>(sipForceConvertToType(sipPy, sipType_QString, SIP_NULLPTR, SIP_NOT_NONE, &sipValState, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->description = *sipVal;

    sipReleaseType(sipVal, sipType_QString, sipValState);

    return 0;
}


extern "C" {static PyObject *varget_QWebPluginFactory_MimeType_fileExtensions(void *, PyObject *, PyObject *);}
static PyObject *varget_QWebPluginFactory_MimeType_fileExtensions(void *sipSelf, PyObject *, PyObject *)
{
    ::QStringList*sipVal;
    ::QWebPluginFactory::MimeType *sipCpp = reinterpret_cast< ::QWebPluginFactory::MimeType *>(sipSelf);

    sipVal = &sipCpp->fileExtensions;

    return sipConvertFromType(sipVal, sipType_QStringList, SIP_NULLPTR);
}


extern "C" {static int varset_QWebPluginFactory_MimeType_fileExtensions(void *, PyObject *, PyObject *);}
static int varset_QWebPluginFactory_MimeType_fileExtensions(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QStringList*sipVal;
    ::QWebPluginFactory::MimeType *sipCpp = reinterpret_cast< ::QWebPluginFactory::MimeType *>(sipSelf);

    int sipIsErr = 0;
    int sipValState;
    sipVal = reinterpret_cast< ::QStringList *>(sipForceConvertToType(sipPy, sipType_QStringList, SIP_NULLPTR, SIP_NOT_NONE, &sipValState, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->fileExtensions = *sipVal;

    sipReleaseType(sipVal, sipType_QStringList, sipValState);

    return 0;
}


extern "C" {static PyObject *varget_QWebPluginFactory_MimeType_name(void *, PyObject *, PyObject *);}
static PyObject *varget_QWebPluginFactory_MimeType_name(void *sipSelf, PyObject *, PyObject *)
{
    ::QString*sipVal;
    ::QWebPluginFactory::MimeType *sipCpp = reinterpret_cast< ::QWebPluginFactory::MimeType *>(sipSelf);

    sipVal = &sipCpp->name;

    return sipConvertFromType(sipVal, sipType_QString, SIP_NULLPTR);
}


extern "C" {static int varset_QWebPluginFactory_MimeType_name(void *, PyObject *, PyObject *);}
static int varset_QWebPluginFactory_MimeType_name(void *sipSelf, PyObject *sipPy, PyObject *)
{
    ::QString*sipVal;
    ::QWebPluginFactory::MimeType *sipCpp = reinterpret_cast< ::QWebPluginFactory::MimeType *>(sipSelf);

    int sipIsErr = 0;
    int sipValState;
    sipVal = reinterpret_cast< ::QString *>(sipForceConvertToType(sipPy, sipType_QString, SIP_NULLPTR, SIP_NOT_NONE, &sipValState, &sipIsErr));

    if (sipIsErr)
        return -1;

    sipCpp->name = *sipVal;

    sipReleaseType(sipVal, sipType_QString, sipValState);

    return 0;
}

sipVariableDef variables_QWebPluginFactory_MimeType[] = {
    {InstanceVariable, sipName_description, (PyMethodDef *)varget_QWebPluginFactory_MimeType_description, (PyMethodDef *)varset_QWebPluginFactory_MimeType_description, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_fileExtensions, (PyMethodDef *)varget_QWebPluginFactory_MimeType_fileExtensions, (PyMethodDef *)varset_QWebPluginFactory_MimeType_fileExtensions, SIP_NULLPTR, SIP_NULLPTR},
    {InstanceVariable, sipName_name, (PyMethodDef *)varget_QWebPluginFactory_MimeType_name, (PyMethodDef *)varset_QWebPluginFactory_MimeType_name, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QWebPluginFactory_MimeType, "\1QWebPluginFactory.MimeType()\n"
"QWebPluginFactory.MimeType(a0: QWebPluginFactory.MimeType)");


static pyqt5ClassPluginDef plugin_QWebPluginFactory_MimeType = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKit_QWebPluginFactory_MimeType = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebPluginFactory__MimeType,
        SIP_NULLPTR,
        &plugin_QWebPluginFactory_MimeType,
    },
    {
        sipNameNr_MimeType,
        {14, 255, 0},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        3, variables_QWebPluginFactory_MimeType,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWebPluginFactory_MimeType,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QWebPluginFactory_MimeType,
    init_type_QWebPluginFactory_MimeType,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWebPluginFactory_MimeType,
    assign_QWebPluginFactory_MimeType,
    array_QWebPluginFactory_MimeType,
    copy_QWebPluginFactory_MimeType,
    release_QWebPluginFactory_MimeType,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QWebPluginFactory_MimeType,
    sizeof (::QWebPluginFactory::MimeType),
};
