/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtDBusAPI_H
#define _QtDBusAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtDBus[0]
#define sipNameNr_QDBusConnectionInterface__ServiceReplacementOptions 59
#define sipName_QDBusConnectionInterface__ServiceReplacementOptions &sipStrings_QtDBus[59]
#define sipNameNr_QDBusConnectionInterface__RegisterServiceReply 111
#define sipName_QDBusConnectionInterface__RegisterServiceReply &sipStrings_QtDBus[111]
#define sipNameNr_QDBusConnectionInterface__ServiceQueueOptions 158
#define sipName_QDBusConnectionInterface__ServiceQueueOptions &sipStrings_QtDBus[158]
#define sipNameNr_QDBusConnection__ConnectionCapabilities 204
#define sipName_QDBusConnection__ConnectionCapabilities &sipStrings_QtDBus[204]
#define sipNameNr_QDBusConnection__ConnectionCapability 244
#define sipName_QDBusConnection__ConnectionCapability &sipStrings_QtDBus[244]
#define sipNameNr_QDBusServiceWatcher__WatchModeFlag 282
#define sipName_QDBusServiceWatcher__WatchModeFlag &sipStrings_QtDBus[282]
#define sipNameNr_setInteractiveAuthorizationAllowed 317
#define sipName_setInteractiveAuthorizationAllowed &sipStrings_QtDBus[317]
#define sipNameNr_isInteractiveAuthorizationAllowed 352
#define sipName_isInteractiveAuthorizationAllowed &sipStrings_QtDBus[352]
#define sipNameNr_QDBusConnection__RegisterOptions 386
#define sipName_QDBusConnection__RegisterOptions &sipStrings_QtDBus[386]
#define sipNameNr_QDBusConnection__RegisterOption 419
#define sipName_QDBusConnection__RegisterOption &sipStrings_QtDBus[419]
#define sipNameNr_QDBusConnection__UnregisterMode 451
#define sipName_QDBusConnection__UnregisterMode &sipStrings_QtDBus[451]
#define sipNameNr_QDBusServiceWatcher__WatchMode 483
#define sipName_QDBusServiceWatcher__WatchMode &sipStrings_QtDBus[483]
#define sipNameNr_ExportNonScriptableInvokables 514
#define sipName_ExportNonScriptableInvokables &sipStrings_QtDBus[514]
#define sipNameNr_ExportNonScriptableProperties 544
#define sipName_ExportNonScriptableProperties &sipStrings_QtDBus[544]
#define sipNameNr_ExportNonScriptableContents 574
#define sipName_ExportNonScriptableContents &sipStrings_QtDBus[574]
#define sipNameNr_ExportNonScriptableSignals 602
#define sipName_ExportNonScriptableSignals &sipStrings_QtDBus[602]
#define sipNameNr_ExportScriptableInvokables 629
#define sipName_ExportScriptableInvokables &sipStrings_QtDBus[629]
#define sipNameNr_ExportScriptableProperties 656
#define sipName_ExportScriptableProperties &sipStrings_QtDBus[656]
#define sipNameNr_QDBusMessage__MessageType 683
#define sipName_QDBusMessage__MessageType &sipStrings_QtDBus[683]
#define sipNameNr_ServiceReplacementOptions 85
#define sipName_ServiceReplacementOptions &sipStrings_QtDBus[85]
#define sipNameNr_UnixFileDescriptorPassing 709
#define sipName_UnixFileDescriptorPassing &sipStrings_QtDBus[709]
#define sipNameNr_asyncCallWithArgumentList 735
#define sipName_asyncCallWithArgumentList &sipStrings_QtDBus[735]
#define sipNameNr_ExportNonScriptableSlots 761
#define sipName_ExportNonScriptableSlots &sipStrings_QtDBus[761]
#define sipNameNr_ExportScriptableContents 786
#define sipName_ExportScriptableContents &sipStrings_QtDBus[786]
#define sipNameNr_QDBusConnection__BusType 811
#define sipName_QDBusConnection__BusType &sipStrings_QtDBus[811]
#define sipNameNr_QDBusConnectionInterface 836
#define sipName_QDBusConnectionInterface &sipStrings_QtDBus[836]
#define sipNameNr_ExportScriptableSignals 861
#define sipName_ExportScriptableSignals &sipStrings_QtDBus[861]
#define sipNameNr_QDBusPendingCallWatcher 885
#define sipName_QDBusPendingCallWatcher &sipStrings_QtDBus[885]
#define sipNameNr_909 909
#define sipName_909 &sipStrings_QtDBus[909]
#define sipNameNr_QDBusUnixFileDescriptor 933
#define sipName_QDBusUnixFileDescriptor &sipStrings_QtDBus[933]
#define sipNameNr_activatableServiceNames 957
#define sipName_activatableServiceNames &sipStrings_QtDBus[957]
#define sipNameNr_ConnectionCapabilities 221
#define sipName_ConnectionCapabilities &sipStrings_QtDBus[221]
#define sipNameNr_QDBusAbstractInterface 981
#define sipName_QDBusAbstractInterface &sipStrings_QtDBus[981]
#define sipNameNr_ReplaceExistingService 1004
#define sipName_ReplaceExistingService &sipStrings_QtDBus[1004]
#define sipNameNr_WatchForUnregistration 1027
#define sipName_WatchForUnregistration &sipStrings_QtDBus[1027]
#define sipNameNr_callWithCallbackFailed 1050
#define sipName_callWithCallbackFailed &sipStrings_QtDBus[1050]
#define sipNameNr_connectionCapabilities 1073
#define sipName_connectionCapabilities &sipStrings_QtDBus[1073]
#define sipNameNr_registeredServiceNames 1096
#define sipName_registeredServiceNames &sipStrings_QtDBus[1096]
#define sipNameNr_ExportScriptableSlots 1119
#define sipName_ExportScriptableSlots &sipStrings_QtDBus[1119]
#define sipNameNr_QDBusError__ErrorType 1141
#define sipName_QDBusError__ErrorType &sipStrings_QtDBus[1141]
#define sipNameNr_ConnectionCapability 261
#define sipName_ConnectionCapability &sipStrings_QtDBus[261]
#define sipNameNr_DontAllowReplacement 1163
#define sipName_DontAllowReplacement &sipStrings_QtDBus[1163]
#define sipNameNr_QDBusAbstractAdaptor 1184
#define sipName_QDBusAbstractAdaptor &sipStrings_QtDBus[1184]
#define sipNameNr_RegisterServiceReply 137
#define sipName_RegisterServiceReply &sipStrings_QtDBus[137]
#define sipNameNr_ServiceNotRegistered 1205
#define sipName_ServiceNotRegistered &sipStrings_QtDBus[1205]
#define sipNameNr_WatchForRegistration 1226
#define sipName_WatchForRegistration &sipStrings_QtDBus[1226]
#define sipNameNr_callWithArgumentList 1247
#define sipName_callWithArgumentList &sipStrings_QtDBus[1247]
#define sipNameNr_createTargetedSignal 1268
#define sipName_createTargetedSignal &sipStrings_QtDBus[1268]
#define sipNameNr_removeWatchedService 1289
#define sipName_removeWatchedService &sipStrings_QtDBus[1289]
#define sipNameNr_ExportAllInvokables 1310
#define sipName_ExportAllInvokables &sipStrings_QtDBus[1310]
#define sipNameNr_ExportAllProperties 1330
#define sipName_ExportAllProperties &sipStrings_QtDBus[1330]
#define sipNameNr_1350 1350
#define sipName_1350 &sipStrings_QtDBus[1350]
#define sipNameNr_QDBusServiceWatcher 1370
#define sipName_QDBusServiceWatcher &sipStrings_QtDBus[1370]
#define sipNameNr_QPyDBusPendingReply 1390
#define sipName_QPyDBusPendingReply &sipStrings_QtDBus[1390]
#define sipNameNr_ServiceQueueOptions 184
#define sipName_ServiceQueueOptions &sipStrings_QtDBus[184]
#define sipNameNr_WatchForOwnerChange 1410
#define sipName_WatchForOwnerChange &sipStrings_QtDBus[1410]
#define sipNameNr_isServiceRegistered 1430
#define sipName_isServiceRegistered &sipStrings_QtDBus[1430]
#define sipNameNr_serviceOwnerChanged 1450
#define sipName_serviceOwnerChanged &sipStrings_QtDBus[1450]
#define sipNameNr_serviceUnregistered 1470
#define sipName_serviceUnregistered &sipStrings_QtDBus[1470]
#define sipNameNr_setAutoRelaySignals 1490
#define sipName_setAutoRelaySignals &sipStrings_QtDBus[1490]
#define sipNameNr_setAutoStartService 1510
#define sipName_setAutoStartService &sipStrings_QtDBus[1510]
#define sipNameNr_ExportChildObjects 1530
#define sipName_ExportChildObjects &sipStrings_QtDBus[1530]
#define sipNameNr_disconnectFromPeer 1549
#define sipName_disconnectFromPeer &sipStrings_QtDBus[1549]
#define sipNameNr_objectRegisteredAt 1568
#define sipName_objectRegisteredAt &sipStrings_QtDBus[1568]
#define sipNameNr_setWatchedServices 1587
#define sipName_setWatchedServices &sipStrings_QtDBus[1587]
#define sipNameNr_ExportAllContents 1606
#define sipName_ExportAllContents &sipStrings_QtDBus[1606]
#define sipNameNr_InvalidObjectPath 1624
#define sipName_InvalidObjectPath &sipStrings_QtDBus[1624]
#define sipNameNr_MethodCallMessage 1642
#define sipName_MethodCallMessage &sipStrings_QtDBus[1642]
#define sipNameNr_QDBusPendingReply 1660
#define sipName_QDBusPendingReply &sipStrings_QtDBus[1660]
#define sipNameNr_ServiceRegistered 1432
#define sipName_ServiceRegistered &sipStrings_QtDBus[1432]
#define sipNameNr_addWatchedService 1678
#define sipName_addWatchedService &sipStrings_QtDBus[1678]
#define sipNameNr_disconnectFromBus 1696
#define sipName_disconnectFromBus &sipStrings_QtDBus[1696]
#define sipNameNr_fromCompletedCall 1714
#define sipName_fromCompletedCall &sipStrings_QtDBus[1714]
#define sipNameNr_serviceRegistered 1732
#define sipName_serviceRegistered &sipStrings_QtDBus[1732]
#define sipNameNr_setFileDescriptor 1750
#define sipName_setFileDescriptor &sipStrings_QtDBus[1750]
#define sipNameNr_sip_simplewrapper 1768
#define sipName_sip_simplewrapper &sipStrings_QtDBus[1768]
#define sipNameNr_unregisterService 1786
#define sipName_unregisterService &sipStrings_QtDBus[1786]
#define sipNameNr_AllowReplacement 1167
#define sipName_AllowReplacement &sipStrings_QtDBus[1167]
#define sipNameNr_DontQueueService 1804
#define sipName_DontQueueService &sipStrings_QtDBus[1804]
#define sipNameNr_ExportAllSignals 1821
#define sipName_ExportAllSignals &sipStrings_QtDBus[1821]
#define sipNameNr_InvalidInterface 1838
#define sipName_InvalidInterface &sipStrings_QtDBus[1838]
#define sipNameNr_InvalidSignature 1855
#define sipName_InvalidSignature &sipStrings_QtDBus[1855]
#define sipNameNr_PropertyReadOnly 1872
#define sipName_PropertyReadOnly &sipStrings_QtDBus[1872]
#define sipNameNr_QDBusPendingCall 1889
#define sipName_QDBusPendingCall &sipStrings_QtDBus[1889]
#define sipNameNr_1906 1906
#define sipName_1906 &sipStrings_QtDBus[1906]
#define sipNameNr_1923 1923
#define sipName_1923 &sipStrings_QtDBus[1923]
#define sipNameNr_1940 1940
#define sipName_1940 &sipStrings_QtDBus[1940]
#define sipNameNr_UnknownInterface 1957
#define sipName_UnknownInterface &sipStrings_QtDBus[1957]
#define sipNameNr_autoRelaySignals 1974
#define sipName_autoRelaySignals &sipStrings_QtDBus[1974]
#define sipNameNr_autoStartService 1991
#define sipName_autoStartService &sipStrings_QtDBus[1991]
#define sipNameNr_callWithCallback 2008
#define sipName_callWithCallback &sipStrings_QtDBus[2008]
#define sipNameNr_createErrorReply 2025
#define sipName_createErrorReply &sipStrings_QtDBus[2025]
#define sipNameNr_createMethodCall 2042
#define sipName_createMethodCall &sipStrings_QtDBus[2042]
#define sipNameNr_disconnectNotify 2059
#define sipName_disconnectNotify &sipStrings_QtDBus[2059]
#define sipNameNr_unregisterObject 2076
#define sipName_unregisterObject &sipStrings_QtDBus[2076]
#define sipNameNr_ExportAllSignal 2093
#define sipName_ExportAllSignal &sipStrings_QtDBus[2093]
#define sipNameNr_QDBus__CallMode 2109
#define sipName_QDBus__CallMode &sipStrings_QtDBus[2109]
#define sipNameNr_QDBusConnection 2125
#define sipName_QDBusConnection &sipStrings_QtDBus[2125]
#define sipNameNr_QDBusObjectPath 2141
#define sipName_QDBusObjectPath &sipStrings_QtDBus[2141]
#define sipNameNr_RegisterOptions 403
#define sipName_RegisterOptions &sipStrings_QtDBus[403]
#define sipNameNr_UnknownProperty 2157
#define sipName_UnknownProperty &sipStrings_QtDBus[2157]
#define sipNameNr_isReplyRequired 2173
#define sipName_isReplyRequired &sipStrings_QtDBus[2173]
#define sipNameNr_registerService 1788
#define sipName_registerService &sipStrings_QtDBus[1788]
#define sipNameNr_setDelayedReply 2189
#define sipName_setDelayedReply &sipStrings_QtDBus[2189]
#define sipNameNr_waitForFinished 2205
#define sipName_waitForFinished &sipStrings_QtDBus[2205]
#define sipNameNr_watchedServices 2221
#define sipName_watchedServices &sipStrings_QtDBus[2221]
#define sipNameNr_ExportAdaptors 2237
#define sipName_ExportAdaptors &sipStrings_QtDBus[2237]
#define sipNameNr_ExportAllSlots 2252
#define sipName_ExportAllSlots &sipStrings_QtDBus[2252]
#define sipNameNr_InvalidMessage 2267
#define sipName_InvalidMessage &sipStrings_QtDBus[2267]
#define sipNameNr_InvalidService 2282
#define sipName_InvalidService &sipStrings_QtDBus[2282]
#define sipNameNr_LimitsExceeded 2297
#define sipName_LimitsExceeded &sipStrings_QtDBus[2297]
#define sipNameNr_QDBusInterface 2312
#define sipName_QDBusInterface &sipStrings_QtDBus[2312]
#define sipNameNr_QDBusSignature 2327
#define sipName_QDBusSignature &sipStrings_QtDBus[2327]
#define sipNameNr_RegisterOption 436
#define sipName_RegisterOption &sipStrings_QtDBus[436]
#define sipNameNr_ServiceUnknown 2342
#define sipName_ServiceUnknown &sipStrings_QtDBus[2342]
#define sipNameNr_UnregisterMode 468
#define sipName_UnregisterMode &sipStrings_QtDBus[468]
#define sipNameNr_UnregisterNode 2357
#define sipName_UnregisterNode &sipStrings_QtDBus[2357]
#define sipNameNr_UnregisterTree 2372
#define sipName_UnregisterTree &sipStrings_QtDBus[2372]
#define sipNameNr_beginStructure 2387
#define sipName_beginStructure &sipStrings_QtDBus[2387]
#define sipNameNr_fileDescriptor 2402
#define sipName_fileDescriptor &sipStrings_QtDBus[2402]
#define sipNameNr_isDelayedReply 2417
#define sipName_isDelayedReply &sipStrings_QtDBus[2417]
#define sipNameNr_localMachineId 2432
#define sipName_localMachineId &sipStrings_QtDBus[2432]
#define sipNameNr_registerObject 2078
#define sipName_registerObject &sipStrings_QtDBus[2078]
#define sipNameNr_ActivationBus 2447
#define sipName_ActivationBus &sipStrings_QtDBus[2447]
#define sipNameNr_InternalError 2461
#define sipName_InternalError &sipStrings_QtDBus[2461]
#define sipNameNr_InvalidMember 2475
#define sipName_InvalidMember &sipStrings_QtDBus[2475]
#define sipNameNr_QDBusArgument 2489
#define sipName_QDBusArgument &sipStrings_QtDBus[2489]
#define sipNameNr_ServiceQueued 2503
#define sipName_ServiceQueued &sipStrings_QtDBus[2503]
#define sipNameNr_SignalMessage 2517
#define sipName_SignalMessage &sipStrings_QtDBus[2517]
#define sipNameNr_UnknownMethod 2531
#define sipName_UnknownMethod &sipStrings_QtDBus[2531]
#define sipNameNr_UnknownObject 2545
#define sipName_UnknownObject &sipStrings_QtDBus[2545]
#define sipNameNr_WatchModeFlag 303
#define sipName_WatchModeFlag &sipStrings_QtDBus[303]
#define sipNameNr_beginMapEntry 2559
#define sipName_beginMapEntry &sipStrings_QtDBus[2559]
#define sipNameNr_connectNotify 2062
#define sipName_connectNotify &sipStrings_QtDBus[2062]
#define sipNameNr_connectToPeer 2573
#define sipName_connectToPeer &sipStrings_QtDBus[2573]
#define sipNameNr_setConnection 2587
#define sipName_setConnection &sipStrings_QtDBus[2587]
#define sipNameNr_AccessDenied 2601
#define sipName_AccessDenied &sipStrings_QtDBus[2601]
#define sipNameNr_AddressInUse 2614
#define sipName_AddressInUse &sipStrings_QtDBus[2614]
#define sipNameNr_BlockWithGui 2627
#define sipName_BlockWithGui &sipStrings_QtDBus[2627]
#define sipNameNr_Disconnected 2640
#define sipName_Disconnected &sipStrings_QtDBus[2640]
#define sipNameNr_ErrorMessage 2653
#define sipName_ErrorMessage &sipStrings_QtDBus[2653]
#define sipNameNr_NotSupported 2666
#define sipName_NotSupported &sipStrings_QtDBus[2666]
#define sipNameNr_PyQt5_QtDBus 2679
#define sipName_PyQt5_QtDBus &sipStrings_QtDBus[2679]
#define sipNameNr_QDBusMessage 2692
#define sipName_QDBusMessage &sipStrings_QtDBus[2692]
#define sipNameNr_QDBusVariant 2705
#define sipName_QDBusVariant &sipStrings_QtDBus[2705]
#define sipNameNr_QPyDBusReply 2718
#define sipName_QPyDBusReply &sipStrings_QtDBus[2718]
#define sipNameNr_QueueService 1808
#define sipName_QueueService &sipStrings_QtDBus[1808]
#define sipNameNr_ReplyMessage 2731
#define sipName_ReplyMessage &sipStrings_QtDBus[2731]
#define sipNameNr_connectToBus 2744
#define sipName_connectToBus &sipStrings_QtDBus[2744]
#define sipNameNr_createSignal 2757
#define sipName_createSignal &sipStrings_QtDBus[2757]
#define sipNameNr_endStructure 2770
#define sipName_endStructure &sipStrings_QtDBus[2770]
#define sipNameNr_errorMessage 2783
#define sipName_errorMessage &sipStrings_QtDBus[2783]
#define sipNameNr_serviceOwner 2796
#define sipName_serviceOwner &sipStrings_QtDBus[2796]
#define sipNameNr_setArguments 2809
#define sipName_setArguments &sipStrings_QtDBus[2809]
#define sipNameNr_setSignature 2822
#define sipName_setSignature &sipStrings_QtDBus[2822]
#define sipNameNr_setWatchMode 2835
#define sipName_setWatchMode &sipStrings_QtDBus[2835]
#define sipNameNr_startService 2848
#define sipName_startService &sipStrings_QtDBus[2848]
#define sipNameNr_InvalidArgs 2861
#define sipName_InvalidArgs &sipStrings_QtDBus[2861]
#define sipNameNr_MessageType 697
#define sipName_MessageType &sipStrings_QtDBus[697]
#define sipNameNr_baseService 2873
#define sipName_baseService &sipStrings_QtDBus[2873]
#define sipNameNr_createError 2885
#define sipName_createError &sipStrings_QtDBus[2885]
#define sipNameNr_createReply 2897
#define sipName_createReply &sipStrings_QtDBus[2897]
#define sipNameNr_customEvent 2909
#define sipName_customEvent &sipStrings_QtDBus[2909]
#define sipNameNr_endMapEntry 2921
#define sipName_endMapEntry &sipStrings_QtDBus[2921]
#define sipNameNr_errorString 2933
#define sipName_errorString &sipStrings_QtDBus[2933]
#define sipNameNr_eventFilter 2945
#define sipName_eventFilter &sipStrings_QtDBus[2945]
#define sipNameNr_isConnected 2957
#define sipName_isConnected &sipStrings_QtDBus[2957]
#define sipNameNr_isSupported 2969
#define sipName_isSupported &sipStrings_QtDBus[2969]
#define sipNameNr_AutoDetect 2981
#define sipName_AutoDetect &sipStrings_QtDBus[2981]
#define sipNameNr_BadAddress 2992
#define sipName_BadAddress &sipStrings_QtDBus[2992]
#define sipNameNr_QDBusError 3003
#define sipName_QDBusError &sipStrings_QtDBus[3003]
#define sipNameNr_QDBusReply 3014
#define sipName_QDBusReply &sipStrings_QtDBus[3014]
#define sipNameNr_SessionBus 3025
#define sipName_SessionBus &sipStrings_QtDBus[3025]
#define sipNameNr___invert__ 3036
#define sipName___invert__ &sipStrings_QtDBus[3036]
#define sipNameNr___lshift__ 3047
#define sipName___lshift__ &sipStrings_QtDBus[3047]
#define sipNameNr_argumentAt 3058
#define sipName_argumentAt &sipStrings_QtDBus[3058]
#define sipNameNr_beginArray 3069
#define sipName_beginArray &sipStrings_QtDBus[3069]
#define sipNameNr_childEvent 3080
#define sipName_childEvent &sipStrings_QtDBus[3080]
#define sipNameNr_connection 3091
#define sipName_connection &sipStrings_QtDBus[3091]
#define sipNameNr_disconnect 3102
#define sipName_disconnect &sipStrings_QtDBus[3102]
#define sipNameNr_isFinished 3113
#define sipName_isFinished &sipStrings_QtDBus[3113]
#define sipNameNr_servicePid 3124
#define sipName_servicePid &sipStrings_QtDBus[3124]
#define sipNameNr_serviceUid 3135
#define sipName_serviceUid &sipStrings_QtDBus[3135]
#define sipNameNr_sessionBus 3146
#define sipName_sessionBus &sipStrings_QtDBus[3146]
#define sipNameNr_setTimeout 3157
#define sipName_setTimeout &sipStrings_QtDBus[3157]
#define sipNameNr_setVariant 3168
#define sipName_setVariant &sipStrings_QtDBus[3168]
#define sipNameNr_timerEvent 3179
#define sipName_timerEvent &sipStrings_QtDBus[3179]
#define sipNameNr_ErrorType 1153
#define sipName_ErrorType &sipStrings_QtDBus[1153]
#define sipNameNr_NoNetwork 3190
#define sipName_NoNetwork &sipStrings_QtDBus[3190]
#define sipNameNr_SystemBus 3200
#define sipName_SystemBus &sipStrings_QtDBus[3200]
#define sipNameNr_WatchMode 504
#define sipName_WatchMode &sipStrings_QtDBus[504]
#define sipNameNr___index__ 3210
#define sipName___index__ &sipStrings_QtDBus[3210]
#define sipNameNr_arguments 3220
#define sipName_arguments &sipStrings_QtDBus[3220]
#define sipNameNr_asyncCall 3230
#define sipName_asyncCall &sipStrings_QtDBus[3230]
#define sipNameNr_errorName 3240
#define sipName_errorName &sipStrings_QtDBus[3240]
#define sipNameNr_fromError 3250
#define sipName_fromError &sipStrings_QtDBus[3250]
#define sipNameNr_interface 3260
#define sipName_interface &sipStrings_QtDBus[3260]
#define sipNameNr_lastError 3270
#define sipName_lastError &sipStrings_QtDBus[3270]
#define sipNameNr_signature 3280
#define sipName_signature &sipStrings_QtDBus[3280]
#define sipNameNr_systemBus 3290
#define sipName_systemBus &sipStrings_QtDBus[3290]
#define sipNameNr_watchMode 3300
#define sipName_watchMode &sipStrings_QtDBus[3300]
#define sipNameNr_CallMode 2116
#define sipName_CallMode &sipStrings_QtDBus[2116]
#define sipNameNr_NoMemory 3310
#define sipName_NoMemory &sipStrings_QtDBus[3310]
#define sipNameNr_NoServer 3319
#define sipName_NoServer &sipStrings_QtDBus[3319]
#define sipNameNr_TimedOut 3328
#define sipName_TimedOut &sipStrings_QtDBus[3328]
#define sipNameNr___bool__ 3337
#define sipName___bool__ &sipStrings_QtDBus[3337]
#define sipNameNr___hash__ 3346
#define sipName___hash__ &sipStrings_QtDBus[3346]
#define sipNameNr___iand__ 3355
#define sipName___iand__ &sipStrings_QtDBus[3355]
#define sipNameNr___ixor__ 3364
#define sipName___ixor__ &sipStrings_QtDBus[3364]
#define sipNameNr_beginMap 3373
#define sipName_beginMap &sipStrings_QtDBus[3373]
#define sipNameNr_endArray 3382
#define sipName_endArray &sipStrings_QtDBus[3382]
#define sipNameNr_finished 3391
#define sipName_finished &sipStrings_QtDBus[3391]
#define sipNameNr_BusType 828
#define sipName_BusType &sipStrings_QtDBus[828]
#define sipNameNr_NoBlock 3400
#define sipName_NoBlock &sipStrings_QtDBus[3400]
#define sipNameNr_NoError 3408
#define sipName_NoError &sipStrings_QtDBus[3408]
#define sipNameNr_NoReply 3416
#define sipName_NoReply &sipStrings_QtDBus[3416]
#define sipNameNr_Timeout 3160
#define sipName_Timeout &sipStrings_QtDBus[3160]
#define sipNameNr___and__ 3424
#define sipName___and__ &sipStrings_QtDBus[3424]
#define sipNameNr___int__ 3432
#define sipName___int__ &sipStrings_QtDBus[3432]
#define sipNameNr___ior__ 3440
#define sipName___ior__ &sipStrings_QtDBus[3440]
#define sipNameNr___xor__ 3448
#define sipName___xor__ &sipStrings_QtDBus[3448]
#define sipNameNr_connect 3105
#define sipName_connect &sipStrings_QtDBus[3105]
#define sipNameNr_isError 3456
#define sipName_isError &sipStrings_QtDBus[3456]
#define sipNameNr_isValid 3464
#define sipName_isValid &sipStrings_QtDBus[3464]
#define sipNameNr_message 3472
#define sipName_message &sipStrings_QtDBus[3472]
#define sipNameNr_options 3480
#define sipName_options &sipStrings_QtDBus[3480]
#define sipNameNr_qoption 3488
#define sipName_qoption &sipStrings_QtDBus[3488]
#define sipNameNr_roption 3496
#define sipName_roption &sipStrings_QtDBus[3496]
#define sipNameNr_service 3504
#define sipName_service &sipStrings_QtDBus[3504]
#define sipNameNr_setPath 3512
#define sipName_setPath &sipStrings_QtDBus[3512]
#define sipNameNr_timeout 3520
#define sipName_timeout &sipStrings_QtDBus[3520]
#define sipNameNr_variant 3528
#define sipName_variant &sipStrings_QtDBus[3528]
#define sipNameNr_watcher 3536
#define sipName_watcher &sipStrings_QtDBus[3536]
#define sipNameNr_Failed 1066
#define sipName_Failed &sipStrings_QtDBus[1066]
#define sipNameNr___eq__ 3544
#define sipName___eq__ &sipStrings_QtDBus[3544]
#define sipNameNr___ge__ 3551
#define sipName___ge__ &sipStrings_QtDBus[3551]
#define sipNameNr___lt__ 3558
#define sipName___lt__ &sipStrings_QtDBus[3558]
#define sipNameNr___ne__ 3565
#define sipName___ne__ &sipStrings_QtDBus[3565]
#define sipNameNr___or__ 3572
#define sipName___or__ &sipStrings_QtDBus[3572]
#define sipNameNr_endMap 3579
#define sipName_endMap &sipStrings_QtDBus[3579]
#define sipNameNr_member 3586
#define sipName_member &sipStrings_QtDBus[3586]
#define sipNameNr_parent 3593
#define sipName_parent &sipStrings_QtDBus[3593]
#define sipNameNr_sender 3600
#define sipName_sender &sipStrings_QtDBus[3600]
#define sipNameNr_Block 3402
#define sipName_Block &sipStrings_QtDBus[3402]
#define sipNameNr_Other 3607
#define sipName_Other &sipStrings_QtDBus[3607]
#define sipNameNr_QDBus 3613
#define sipName_QDBus &sipStrings_QtDBus[3613]
#define sipNameNr_error 3619
#define sipName_error &sipStrings_QtDBus[3619]
#define sipNameNr_event 3625
#define sipName_event &sipStrings_QtDBus[3625]
#define sipNameNr_reply 3631
#define sipName_reply &sipStrings_QtDBus[3631]
#define sipNameNr_value 3637
#define sipName_value &sipStrings_QtDBus[3637]
#define sipNameNr_arg1 3643
#define sipName_arg1 &sipStrings_QtDBus[3643]
#define sipNameNr_arg2 3648
#define sipName_arg2 &sipStrings_QtDBus[3648]
#define sipNameNr_arg3 3653
#define sipName_arg3 &sipStrings_QtDBus[3653]
#define sipNameNr_arg4 3658
#define sipName_arg4 &sipStrings_QtDBus[3658]
#define sipNameNr_arg5 3663
#define sipName_arg5 &sipStrings_QtDBus[3663]
#define sipNameNr_arg6 3668
#define sipName_arg6 &sipStrings_QtDBus[3668]
#define sipNameNr_arg7 3673
#define sipName_arg7 &sipStrings_QtDBus[3673]
#define sipNameNr_arg8 3678
#define sipName_arg8 &sipStrings_QtDBus[3678]
#define sipNameNr_call 3683
#define sipName_call &sipStrings_QtDBus[3683]
#define sipNameNr_mode 3688
#define sipName_mode &sipStrings_QtDBus[3688]
#define sipNameNr_name 3693
#define sipName_name &sipStrings_QtDBus[3693]
#define sipNameNr_path 3698
#define sipName_path &sipStrings_QtDBus[3698]
#define sipNameNr_send 3703
#define sipName_send &sipStrings_QtDBus[3703]
#define sipNameNr_swap 3708
#define sipName_swap &sipStrings_QtDBus[3708]
#define sipNameNr_type 3713
#define sipName_type &sipStrings_QtDBus[3713]
#define sipNameNr_add 3718
#define sipName_add &sipStrings_QtDBus[3718]
#define sipNameNr_id 3132
#define sipName_id &sipStrings_QtDBus[3132]

#define sipMalloc                   sipAPI_QtDBus->api_malloc
#define sipFree                     sipAPI_QtDBus->api_free
#define sipBuildResult              sipAPI_QtDBus->api_build_result
#define sipCallMethod               sipAPI_QtDBus->api_call_method
#define sipCallProcedureMethod      sipAPI_QtDBus->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtDBus->api_call_error_handler
#define sipParseResultEx            sipAPI_QtDBus->api_parse_result_ex
#define sipParseResult              sipAPI_QtDBus->api_parse_result
#define sipParseArgs                sipAPI_QtDBus->api_parse_args
#define sipParseKwdArgs             sipAPI_QtDBus->api_parse_kwd_args
#define sipParsePair                sipAPI_QtDBus->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtDBus->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtDBus->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtDBus->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtDBus->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtDBus->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtDBus->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtDBus->api_add_exception
#define sipNoFunction               sipAPI_QtDBus->api_no_function
#define sipNoMethod                 sipAPI_QtDBus->api_no_method
#define sipAbstractMethod           sipAPI_QtDBus->api_abstract_method
#define sipBadClass                 sipAPI_QtDBus->api_bad_class
#define sipBadCatcherResult         sipAPI_QtDBus->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtDBus->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtDBus->api_bad_operator_arg
#define sipTrace                    sipAPI_QtDBus->api_trace
#define sipTransferBack             sipAPI_QtDBus->api_transfer_back
#define sipTransferTo               sipAPI_QtDBus->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtDBus->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtDBus->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtDBus->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtDBus->api_voidptr_type
#define sipGetPyObject              sipAPI_QtDBus->api_get_pyobject
#define sipGetAddress               sipAPI_QtDBus->api_get_address
#define sipGetMixinAddress          sipAPI_QtDBus->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtDBus->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtDBus->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtDBus->api_call_hook
#define sipEndThread                sipAPI_QtDBus->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtDBus->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtDBus->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtDBus->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtDBus->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtDBus->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtDBus->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtDBus->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtDBus->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtDBus->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtDBus->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtDBus->api_convert_to_bool
#define sipReleaseType              sipAPI_QtDBus->api_release_type
#define sipConvertFromType          sipAPI_QtDBus->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtDBus->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtDBus->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtDBus->api_convert_from_enum
#define sipGetState                 sipAPI_QtDBus->api_get_state
#define sipExportSymbol             sipAPI_QtDBus->api_export_symbol
#define sipImportSymbol             sipAPI_QtDBus->api_import_symbol
#define sipFindType                 sipAPI_QtDBus->api_find_type
#define sipBytes_AsChar             sipAPI_QtDBus->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtDBus->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtDBus->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtDBus->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtDBus->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtDBus->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtDBus->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtDBus->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtDBus->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtDBus->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtDBus->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtDBus->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtDBus->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtDBus->api_get_reference
#define sipKeepReference            sipAPI_QtDBus->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtDBus->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtDBus->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtDBus->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtDBus->api_type_scope
#define sipResolveTypedef           sipAPI_QtDBus->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtDBus->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtDBus->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtDBus->api_init_mixin
#define sipExportModule             sipAPI_QtDBus->api_export_module
#define sipInitModule               sipAPI_QtDBus->api_init_module
#define sipGetInterpreter           sipAPI_QtDBus->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtDBus->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtDBus->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtDBus->api_py_type_dict
#define sipPyTypeName               sipAPI_QtDBus->api_py_type_name
#define sipGetCFunction             sipAPI_QtDBus->api_get_c_function
#define sipGetMethod                sipAPI_QtDBus->api_get_method
#define sipFromMethod               sipAPI_QtDBus->api_from_method
#define sipGetDate                  sipAPI_QtDBus->api_get_date
#define sipFromDate                 sipAPI_QtDBus->api_from_date
#define sipGetDateTime              sipAPI_QtDBus->api_get_datetime
#define sipFromDateTime             sipAPI_QtDBus->api_from_datetime
#define sipGetTime                  sipAPI_QtDBus->api_get_time
#define sipFromTime                 sipAPI_QtDBus->api_from_time
#define sipIsUserType               sipAPI_QtDBus->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtDBus->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtDBus->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtDBus->api_unicode_write
#define sipUnicodeData              sipAPI_QtDBus->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtDBus->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtDBus->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtDBus->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtDBus->api_is_derived_class
#define sipGetUserObject            sipAPI_QtDBus->api_get_user_object
#define sipSetUserObject            sipAPI_QtDBus->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtDBus->api_register_event_handler
#define sipConvertToArray           sipAPI_QtDBus->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtDBus->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtDBus->api_enable_gc
#define sipPrintObject              sipAPI_QtDBus->api_print_object
#define sipLong_AsChar              sipAPI_QtDBus->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtDBus->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtDBus->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtDBus->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtDBus->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtDBus->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtDBus->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtDBus->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtDBus->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtDBus->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtDBus->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtDBus->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtDBus->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtDBus->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtDBus->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtDBus->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtDBus->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtDBus->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtDBus->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtDBus->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtDBus->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtDBus->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtDBus->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtDBus->api_connect_rx
#define sipConvertRx                sipAPI_QtDBus->api_convert_rx
#define sipDisconnectRx             sipAPI_QtDBus->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtDBus->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtDBus->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtDBus->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtDBus->api_same_slot
#define sipSaveSlot                 sipAPI_QtDBus->api_save_slot
#define sipVisitSlot                sipAPI_QtDBus->api_visit_slot
#define sipIsPyMethod               sipAPI_QtDBus->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtDBus[];

#define sipType_QDBusAbstractAdaptor sipExportedTypes_QtDBus[2]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusAbstractAdaptor;

#define sipType_QDBusAbstractInterface sipExportedTypes_QtDBus[3]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusAbstractInterface;

#define sipType_QDBusArgument sipExportedTypes_QtDBus[4]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusArgument;

#define sipType_QDBus sipExportedTypes_QtDBus[0]

#define sipType_QDBus_CallMode sipExportedTypes_QtDBus[1]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBus;

#define sipType_QDBusConnection sipExportedTypes_QtDBus[5]

#define sipType_QDBusConnection_ConnectionCapability sipExportedTypes_QtDBus[8]

#define sipType_QDBusConnection_UnregisterMode sipExportedTypes_QtDBus[11]

#define sipType_QDBusConnection_RegisterOption sipExportedTypes_QtDBus[9]

#define sipType_QDBusConnection_BusType sipExportedTypes_QtDBus[6]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusConnection;

#define sipType_QDBusConnection_RegisterOptions sipExportedTypes_QtDBus[10]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusConnection_RegisterOptions;

#define sipType_QDBusConnection_ConnectionCapabilities sipExportedTypes_QtDBus[7]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusConnection_ConnectionCapabilities;

#define sipType_QDBusConnectionInterface sipExportedTypes_QtDBus[12]

#define sipType_QDBusConnectionInterface_RegisterServiceReply sipExportedTypes_QtDBus[13]

#define sipType_QDBusConnectionInterface_ServiceReplacementOptions sipExportedTypes_QtDBus[15]

#define sipType_QDBusConnectionInterface_ServiceQueueOptions sipExportedTypes_QtDBus[14]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusConnectionInterface;

#define sipType_QDBusError sipExportedTypes_QtDBus[16]

#define sipType_QDBusError_ErrorType sipExportedTypes_QtDBus[17]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusError;

#define sipType_QDBusObjectPath sipExportedTypes_QtDBus[21]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusObjectPath;

#define sipType_QDBusSignature sipExportedTypes_QtDBus[33]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusSignature;

#define sipType_QDBusVariant sipExportedTypes_QtDBus[35]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusVariant;

#define sipType_QDBusInterface sipExportedTypes_QtDBus[18]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusInterface;

#define sipType_QDBusMessage sipExportedTypes_QtDBus[19]

#define sipType_QDBusMessage_MessageType sipExportedTypes_QtDBus[20]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusMessage;

#define sipType_QDBusPendingCall sipExportedTypes_QtDBus[22]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusPendingCall;

#define sipType_QDBusPendingCallWatcher sipExportedTypes_QtDBus[23]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusPendingCallWatcher;

#define sipType_QDBusServiceWatcher sipExportedTypes_QtDBus[30]

#define sipType_QDBusServiceWatcher_WatchModeFlag sipExportedTypes_QtDBus[32]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusServiceWatcher;

#define sipType_QDBusServiceWatcher_WatchMode sipExportedTypes_QtDBus[31]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusServiceWatcher_WatchMode;

#define sipType_QDBusUnixFileDescriptor sipExportedTypes_QtDBus[34]

extern sipClassTypeDef sipTypeDef_QtDBus_QDBusUnixFileDescriptor;

#define sipType_QPyDBusReply sipExportedTypes_QtDBus[37]

extern sipClassTypeDef sipTypeDef_QtDBus_QPyDBusReply;

#define sipType_QPyDBusPendingReply sipExportedTypes_QtDBus[36]

extern sipClassTypeDef sipTypeDef_QtDBus_QPyDBusPendingReply;

#define sipType_QDBusReply_0100QString sipExportedTypes_QtDBus[25]

extern sipMappedTypeDef sipTypeDef_QtDBus_QDBusReply_0100QString;

#define sipType_QDBusReply_0100QStringList sipExportedTypes_QtDBus[26]

extern sipMappedTypeDef sipTypeDef_QtDBus_QDBusReply_0100QStringList;

#define sipType_QDBusReply_0100QDBusConnectionInterface_RegisterServiceReply sipExportedTypes_QtDBus[24]

extern sipMappedTypeDef sipTypeDef_QtDBus_QDBusReply_0100QDBusConnectionInterface_RegisterServiceReply;

#define sipType_QDBusReply_1900 sipExportedTypes_QtDBus[28]

extern sipMappedTypeDef sipTypeDef_QtDBus_QDBusReply_1900;

#define sipType_QDBusReply_2600 sipExportedTypes_QtDBus[27]

extern sipMappedTypeDef sipTypeDef_QtDBus_QDBusReply_2600;

#define sipType_QDBusReply_0400 sipExportedTypes_QtDBus[29]

extern sipMappedTypeDef sipTypeDef_QtDBus_QDBusReply_0400;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtDBus;
extern sipExportedModuleDef sipModuleAPI_QtDBus;
extern sipTypeDef *sipExportedTypes_QtDBus[];

#define sipType_QObject sipImportedTypes_QtDBus_QtCore[5].it_td

#define sipType_QByteArray sipImportedTypes_QtDBus_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtDBus_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtDBus_QtCore[8].it_td

#define sipType_QChildEvent sipImportedTypes_QtDBus_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtDBus_QtCore[4].it_td

#define sipType_QVariant sipImportedTypes_QtDBus_QtCore[9].it_td

#define sipType_QList_0100QVariant sipImportedTypes_QtDBus_QtCore[3].it_td

#define sipType_QStringList sipImportedTypes_QtDBus_QtCore[7].it_td

#define sipType_QString sipImportedTypes_QtDBus_QtCore[6].it_td
extern sipImportedTypeDef sipImportedTypes_QtDBus_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtDBus_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtDBus_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtDBus_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtDBus_qt_metacast;
#line 134 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDBus/qdbusabstractinterface.sip"
#include "qpydbus_api.h"

// Imports from QtCore.
typedef PyObject *(*pyqt5_qtdbus_from_qvariant_by_type_t)(QVariant &, PyObject *);
extern pyqt5_qtdbus_from_qvariant_by_type_t pyqt5_qtdbus_from_qvariant_by_type;

typedef sipErrorState (*pyqt5_qtdbus_get_pyqtslot_parts_t)(PyObject *, QObject **, QByteArray &);
extern pyqt5_qtdbus_get_pyqtslot_parts_t pyqt5_qtdbus_get_pyqtslot_parts;
#line 925 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDBus/sipAPIQtDBus.h"

#endif
