/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtSqlAPI_H
#define _QtSqlAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QSqlRelationalTableModel__JoinMode 0
#define sipName_QSqlRelationalTableModel__JoinMode &sipStrings_QtSql[0]
#define sipNameNr_QSql__NumericalPrecisionPolicy 35
#define sipName_QSql__NumericalPrecisionPolicy &sipStrings_QtSql[35]
#define sipNameNr_QSqlDriver__NotificationSource 66
#define sipName_QSqlDriver__NotificationSource &sipStrings_QtSql[66]
#define sipNameNr_QSqlQuery__BatchExecutionMode 97
#define sipName_QSqlQuery__BatchExecutionMode &sipStrings_QtSql[97]
#define sipNameNr_QSqlTableModel__EditStrategy 127
#define sipName_QSqlTableModel__EditStrategy &sipStrings_QtSql[127]
#define sipNameNr_setNumericalPrecisionPolicy 156
#define sipName_setNumericalPrecisionPolicy &sipStrings_QtSql[156]
#define sipNameNr_unsubscribeFromNotification 184
#define sipName_unsubscribeFromNotification &sipStrings_QtSql[184]
#define sipNameNr_QSqlDriver__IdentifierType 212
#define sipName_QSqlDriver__IdentifierType &sipStrings_QtSql[212]
#define sipNameNr_QSqlDriver__DriverFeature 239
#define sipName_QSqlDriver__DriverFeature &sipStrings_QtSql[239]
#define sipNameNr_QSqlDriver__StatementType 265
#define sipName_QSqlDriver__StatementType &sipStrings_QtSql[265]
#define sipNameNr_QSqlField__RequiredStatus 291
#define sipName_QSqlField__RequiredStatus &sipStrings_QtSql[291]
#define sipNameNr_QSqlResult__BindingSyntax 317
#define sipName_QSqlResult__BindingSyntax &sipStrings_QtSql[317]
#define sipNameNr_subscribedToNotifications 343
#define sipName_subscribedToNotifications &sipStrings_QtSql[343]
#define sipNameNr_NumericalPrecisionPolicy 41
#define sipName_NumericalPrecisionPolicy &sipStrings_QtSql[41]
#define sipNameNr_QSqlRelationalTableModel 369
#define sipName_QSqlRelationalTableModel &sipStrings_QtSql[369]
#define sipNameNr_numericalPrecisionPolicy 394
#define sipName_numericalPrecisionPolicy &sipStrings_QtSql[394]
#define sipNameNr_subscribeToNotification 419
#define sipName_subscribeToNotification &sipStrings_QtSql[419]
#define sipNameNr_PositionalPlaceholders 443
#define sipName_PositionalPlaceholders &sipStrings_QtSql[443]
#define sipNameNr_466 466
#define sipName_466 &sipStrings_QtSql[466]
#define sipNameNr_QSqlRelationalDelegate 489
#define sipName_QSqlRelationalDelegate &sipStrings_QtSql[489]
#define sipNameNr_QSqlDriverCreatorBase 512
#define sipName_QSqlDriverCreatorBase &sipStrings_QtSql[512]
#define sipNameNr_QSqlDriver__DbmsType 534
#define sipName_QSqlDriver__DbmsType &sipStrings_QtSql[534]
#define sipNameNr_QSqlError__ErrorType 555
#define sipName_QSqlError__ErrorType &sipStrings_QtSql[555]
#define sipNameNr_supportedDragActions 576
#define sipName_supportedDragActions &sipStrings_QtSql[576]
#define sipNameNr_supportedDropActions 597
#define sipName_supportedDropActions &sipStrings_QtSql[597]
#define sipNameNr_updateEditorGeometry 618
#define sipName_updateEditorGeometry &sipStrings_QtSql[618]
#define sipNameNr_LowPrecisionNumbers 639
#define sipName_LowPrecisionNumbers &sipStrings_QtSql[639]
#define sipNameNr_QSql__ParamTypeFlag 659
#define sipName_QSql__ParamTypeFlag &sipStrings_QtSql[659]
#define sipNameNr_isIdentifierEscaped 679
#define sipName_isIdentifierEscaped &sipStrings_QtSql[679]
#define sipNameNr_rollbackTransaction 699
#define sipName_rollbackTransaction &sipStrings_QtSql[699]
#define sipNameNr_BatchExecutionMode 108
#define sipName_BatchExecutionMode &sipStrings_QtSql[108]
#define sipNameNr_EventNotifications 719
#define sipName_EventNotifications &sipStrings_QtSql[719]
#define sipNameNr_LowPrecisionDouble 738
#define sipName_LowPrecisionDouble &sipStrings_QtSql[738]
#define sipNameNr_MultipleResultSets 757
#define sipName_MultipleResultSets &sipStrings_QtSql[757]
#define sipNameNr_NotificationSource 78
#define sipName_NotificationSource &sipStrings_QtSql[78]
#define sipNameNr_beginInsertColumns 776
#define sipName_beginInsertColumns &sipStrings_QtSql[776]
#define sipNameNr_beginRemoveColumns 795
#define sipName_beginRemoveColumns &sipStrings_QtSql[795]
#define sipNameNr_deleteRowFromTable 814
#define sipName_deleteRowFromTable &sipStrings_QtSql[814]
#define sipNameNr_insertRowIntoTable 833
#define sipName_insertRowIntoTable &sipStrings_QtSql[833]
#define sipNameNr_LowPrecisionInt32 852
#define sipName_LowPrecisionInt32 &sipStrings_QtSql[852]
#define sipNameNr_LowPrecisionInt64 870
#define sipName_LowPrecisionInt64 &sipStrings_QtSql[870]
#define sipNameNr_NamedPlaceholders 888
#define sipName_NamedPlaceholders &sipStrings_QtSql[888]
#define sipNameNr_PositionalBinding 906
#define sipName_PositionalBinding &sipStrings_QtSql[906]
#define sipNameNr_924 924
#define sipName_924 &sipStrings_QtSql[924]
#define sipNameNr_commitTransaction 942
#define sipName_commitTransaction &sipStrings_QtSql[942]
#define sipNameNr_isDriverAvailable 960
#define sipName_isDriverAvailable &sipStrings_QtSql[960]
#define sipNameNr_registerSqlDriver 978
#define sipName_registerSqlDriver &sipStrings_QtSql[978]
#define sipNameNr_setConnectOptions 996
#define sipName_setConnectOptions &sipStrings_QtSql[996]
#define sipNameNr_setRequiredStatus 1014
#define sipName_setRequiredStatus &sipStrings_QtSql[1014]
#define sipNameNr_sip_simplewrapper 1032
#define sipName_sip_simplewrapper &sipStrings_QtSql[1032]
#define sipNameNr_TransactionError 1050
#define sipName_TransactionError &sipStrings_QtSql[1050]
#define sipNameNr_beginTransaction 1067
#define sipName_beginTransaction &sipStrings_QtSql[1067]
#define sipNameNr_disconnectNotify 1084
#define sipName_disconnectNotify &sipStrings_QtSql[1084]
#define sipNameNr_endInsertColumns 1101
#define sipName_endInsertColumns &sipStrings_QtSql[1101]
#define sipNameNr_endRemoveColumns 1118
#define sipName_endRemoveColumns &sipStrings_QtSql[1118]
#define sipNameNr_escapeIdentifier 1135
#define sipName_escapeIdentifier &sipStrings_QtSql[1135]
#define sipNameNr_updateRowInTable 1152
#define sipName_updateRowInTable &sipStrings_QtSql[1152]
#define sipNameNr_BatchOperations 1169
#define sipName_BatchOperations &sipStrings_QtSql[1169]
#define sipNameNr_ConnectionError 1185
#define sipName_ConnectionError &sipStrings_QtSql[1185]
#define sipNameNr_DeleteStatement 1201
#define sipName_DeleteStatement &sipStrings_QtSql[1201]
#define sipNameNr_InsertStatement 1217
#define sipName_InsertStatement &sipStrings_QtSql[1217]
#define sipNameNr_PreparedQueries 1233
#define sipName_PreparedQueries &sipStrings_QtSql[1233]
#define sipNameNr_QSql__ParamType 1249
#define sipName_QSql__ParamType &sipStrings_QtSql[1249]
#define sipNameNr_QSql__TableType 1265
#define sipName_QSql__TableType &sipStrings_QtSql[1265]
#define sipNameNr_SelectStatement 1281
#define sipName_SelectStatement &sipStrings_QtSql[1281]
#define sipNameNr_UpdateStatement 1297
#define sipName_UpdateStatement &sipStrings_QtSql[1297]
#define sipNameNr_ValuesAsColumns 1313
#define sipName_ValuesAsColumns &sipStrings_QtSql[1313]
#define sipNameNr_beginInsertRows 1329
#define sipName_beginInsertRows &sipStrings_QtSql[1329]
#define sipNameNr_beginRemoveRows 1345
#define sipName_beginRemoveRows &sipStrings_QtSql[1345]
#define sipNameNr_beginResetModel 1361
#define sipName_beginResetModel &sipStrings_QtSql[1361]
#define sipNameNr_boundValueCount 1377
#define sipName_boundValueCount &sipStrings_QtSql[1377]
#define sipNameNr_canDropMimeData 1393
#define sipName_canDropMimeData &sipStrings_QtSql[1393]
#define sipNameNr_connectionNames 1409
#define sipName_connectionNames &sipStrings_QtSql[1409]
#define sipNameNr_nativeErrorCode 1425
#define sipName_nativeErrorCode &sipStrings_QtSql[1425]
#define sipNameNr_numRowsAffected 1441
#define sipName_numRowsAffected &sipStrings_QtSql[1441]
#define sipNameNr_selectStatement 1457
#define sipName_selectStatement &sipStrings_QtSql[1457]
#define sipNameNr_setDatabaseName 1473
#define sipName_setDatabaseName &sipStrings_QtSql[1473]
#define sipNameNr_setDatabaseText 1489
#define sipName_setDatabaseText &sipStrings_QtSql[1489]
#define sipNameNr_setDefaultValue 1505
#define sipName_setDefaultValue &sipStrings_QtSql[1505]
#define sipNameNr_setEditStrategy 1521
#define sipName_setEditStrategy &sipStrings_QtSql[1521]
#define sipNameNr_stripDelimiters 1537
#define sipName_stripDelimiters &sipStrings_QtSql[1537]
#define sipNameNr_BeforeFirstRow 1553
#define sipName_BeforeFirstRow &sipStrings_QtSql[1553]
#define sipNameNr_IdentifierType 224
#define sipName_IdentifierType &sipStrings_QtSql[224]
#define sipNameNr_OnManualSubmit 1568
#define sipName_OnManualSubmit &sipStrings_QtSql[1568]
#define sipNameNr_QSql__Location 1583
#define sipName_QSql__Location &sipStrings_QtSql[1583]
#define sipNameNr_QSqlQueryModel 1598
#define sipName_QSqlQueryModel &sipStrings_QtSql[1598]
#define sipNameNr_QSqlTableModel 1613
#define sipName_QSqlTableModel &sipStrings_QtSql[1613]
#define sipNameNr_RequiredStatus 302
#define sipName_RequiredStatus &sipStrings_QtSql[302]
#define sipNameNr_StatementError 1628
#define sipName_StatementError &sipStrings_QtSql[1628]
#define sipNameNr_WhereStatement 1643
#define sipName_WhereStatement &sipStrings_QtSql[1643]
#define sipNameNr_boundValueName 1658
#define sipName_boundValueName &sipStrings_QtSql[1658]
#define sipNameNr_connectOptions 1673
#define sipName_connectOptions &sipStrings_QtSql[1673]
#define sipNameNr_connectionName 1688
#define sipName_connectionName &sipStrings_QtSql[1688]
#define sipNameNr_drawDecoration 1703
#define sipName_drawDecoration &sipStrings_QtSql[1703]
#define sipNameNr_removeDatabase 1718
#define sipName_removeDatabase &sipStrings_QtSql[1718]
#define sipNameNr_requiredStatus 1733
#define sipName_requiredStatus &sipStrings_QtSql[1733]
#define sipNameNr_setForwardOnly 1748
#define sipName_setForwardOnly &sipStrings_QtSql[1748]
#define sipNameNr_BindingSyntax 329
#define sipName_BindingSyntax &sipStrings_QtSql[329]
#define sipNameNr_DriverFeature 251
#define sipName_DriverFeature &sipStrings_QtSql[251]
#define sipNameNr_HighPrecision 1763
#define sipName_HighPrecision &sipStrings_QtSql[1763]
#define sipNameNr_OnFieldChange 1777
#define sipName_OnFieldChange &sipStrings_QtSql[1777]
#define sipNameNr_ParamTypeFlag 665
#define sipName_ParamTypeFlag &sipStrings_QtSql[665]
#define sipNameNr_SimpleLocking 1791
#define sipName_SimpleLocking &sipStrings_QtSql[1791]
#define sipNameNr_StatementType 277
#define sipName_StatementType &sipStrings_QtSql[277]
#define sipNameNr_UnknownSource 1805
#define sipName_UnknownSource &sipStrings_QtSql[1805]
#define sipNameNr_bindValueType 1819
#define sipName_bindValueType &sipStrings_QtSql[1819]
#define sipNameNr_bindingSyntax 1833
#define sipName_bindingSyntax &sipStrings_QtSql[1833]
#define sipNameNr_cloneDatabase 1847
#define sipName_cloneDatabase &sipStrings_QtSql[1847]
#define sipNameNr_connectNotify 1087
#define sipName_connectNotify &sipStrings_QtSql[1087]
#define sipNameNr_destroyEditor 1861
#define sipName_destroyEditor &sipStrings_QtSql[1861]
#define sipNameNr_displayColumn 1875
#define sipName_displayColumn &sipStrings_QtSql[1875]
#define sipNameNr_endInsertRows 1889
#define sipName_endInsertRows &sipStrings_QtSql[1889]
#define sipNameNr_endRemoveRows 1903
#define sipName_endRemoveRows &sipStrings_QtSql[1903]
#define sipNameNr_endResetModel 1917
#define sipName_endResetModel &sipStrings_QtSql[1917]
#define sipNameNr_executedQuery 1931
#define sipName_executedQuery &sipStrings_QtSql[1931]
#define sipNameNr_fetchPrevious 1945
#define sipName_fetchPrevious &sipStrings_QtSql[1945]
#define sipNameNr_insertColumns 1959
#define sipName_insertColumns &sipStrings_QtSql[1959]
#define sipNameNr_isForwardOnly 1973
#define sipName_isForwardOnly &sipStrings_QtSql[1973]
#define sipNameNr_orderByClause 1987
#define sipName_orderByClause &sipStrings_QtSql[1987]
#define sipNameNr_primaryValues 2001
#define sipName_primaryValues &sipStrings_QtSql[2001]
#define sipNameNr_relationModel 2015
#define sipName_relationModel &sipStrings_QtSql[2015]
#define sipNameNr_removeColumns 2029
#define sipName_removeColumns &sipStrings_QtSql[2029]
#define sipNameNr_setCursorName 2043
#define sipName_setCursorName &sipStrings_QtSql[2043]
#define sipNameNr_setDescending 2057
#define sipName_setDescending &sipStrings_QtSql[2057]
#define sipNameNr_setDriverText 2071
#define sipName_setDriverText &sipStrings_QtSql[2071]
#define sipNameNr_setEditorData 2085
#define sipName_setEditorData &sipStrings_QtSql[2085]
#define sipNameNr_setHeaderData 2099
#define sipName_setHeaderData &sipStrings_QtSql[2099]
#define sipNameNr_setPrimaryKey 2113
#define sipName_setPrimaryKey &sipStrings_QtSql[2113]
#define sipNameNr_AfterLastRow 2127
#define sipName_AfterLastRow &sipStrings_QtSql[2127]
#define sipNameNr_EditStrategy 143
#define sipName_EditStrategy &sipStrings_QtSql[143]
#define sipNameNr_LastInsertId 2140
#define sipName_LastInsertId &sipStrings_QtSql[2140]
#define sipNameNr_NamedBinding 2153
#define sipName_NamedBinding &sipStrings_QtSql[2153]
#define sipNameNr_QSqlDatabase 2166
#define sipName_QSqlDatabase &sipStrings_QtSql[2166]
#define sipNameNr_QSqlRelation 2179
#define sipName_QSqlRelation &sipStrings_QtSql[2179]
#define sipNameNr_SystemTables 2192
#define sipName_SystemTables &sipStrings_QtSql[2192]
#define sipNameNr_Transactions 2205
#define sipName_Transactions &sipStrings_QtSql[2205]
#define sipNameNr_UnknownError 2218
#define sipName_UnknownError &sipStrings_QtSql[2218]
#define sipNameNr_ValuesAsRows 2231
#define sipName_ValuesAsRows &sipStrings_QtSql[2231]
#define sipNameNr_addBindValue 2244
#define sipName_addBindValue &sipStrings_QtSql[2244]
#define sipNameNr_beforeDelete 2257
#define sipName_beforeDelete &sipStrings_QtSql[2257]
#define sipNameNr_beforeInsert 2270
#define sipName_beforeInsert &sipStrings_QtSql[2270]
#define sipNameNr_beforeUpdate 2283
#define sipName_beforeUpdate &sipStrings_QtSql[2283]
#define sipNameNr_canFetchMore 2296
#define sipName_canFetchMore &sipStrings_QtSql[2296]
#define sipNameNr_createEditor 2309
#define sipName_createEditor &sipStrings_QtSql[2309]
#define sipNameNr_createObject 2322
#define sipName_createObject &sipStrings_QtSql[2322]
#define sipNameNr_createResult 2335
#define sipName_createResult &sipStrings_QtSql[2335]
#define sipNameNr_databaseName 2348
#define sipName_databaseName &sipStrings_QtSql[2348]
#define sipNameNr_databaseText 2361
#define sipName_databaseText &sipStrings_QtSql[2361]
#define sipNameNr_defaultValue 2374
#define sipName_defaultValue &sipStrings_QtSql[2374]
#define sipNameNr_dropMimeData 2387
#define sipName_dropMimeData &sipStrings_QtSql[2387]
#define sipNameNr_editStrategy 2400
#define sipName_editStrategy &sipStrings_QtSql[2400]
#define sipNameNr_hasOutValues 2413
#define sipName_hasOutValues &sipStrings_QtSql[2413]
#define sipNameNr_indexInQuery 2426
#define sipName_indexInQuery &sipStrings_QtSql[2426]
#define sipNameNr_insertRecord 2439
#define sipName_insertRecord &sipStrings_QtSql[2439]
#define sipNameNr_isDescending 2452
#define sipName_isDescending &sipStrings_QtSql[2452]
#define sipNameNr_lastInsertId 2465
#define sipName_lastInsertId &sipStrings_QtSql[2465]
#define sipNameNr_notification 2478
#define sipName_notification &sipStrings_QtSql[2478]
#define sipNameNr_primaryIndex 2491
#define sipName_primaryIndex &sipStrings_QtSql[2491]
#define sipNameNr_setAutoValue 2504
#define sipName_setAutoValue &sipStrings_QtSql[2504]
#define sipNameNr_setGenerated 2517
#define sipName_setGenerated &sipStrings_QtSql[2517]
#define sipNameNr_setLastError 2530
#define sipName_setLastError &sipStrings_QtSql[2530]
#define sipNameNr_setModelData 2543
#define sipName_setModelData &sipStrings_QtSql[2543]
#define sipNameNr_setOpenError 2556
#define sipName_setOpenError &sipStrings_QtSql[2556]
#define sipNameNr_setPrecision 2569
#define sipName_setPrecision &sipStrings_QtSql[2569]
#define sipNameNr_setTableName 2582
#define sipName_setTableName &sipStrings_QtSql[2582]
#define sipNameNr_sqlStatement 2595
#define sipName_sqlStatement &sipStrings_QtSql[2595]
#define sipNameNr_FinishQuery 2608
#define sipName_FinishQuery &sipStrings_QtSql[2608]
#define sipNameNr_MSSqlServer 2620
#define sipName_MSSqlServer &sipStrings_QtSql[2620]
#define sipNameNr_MySqlServer 2632
#define sipName_MySqlServer &sipStrings_QtSql[2632]
#define sipNameNr_OnRowChange 2644
#define sipName_OnRowChange &sipStrings_QtSql[2644]
#define sipNameNr_OtherSource 2656
#define sipName_OtherSource &sipStrings_QtSql[2656]
#define sipNameNr_PyQt5_QtSql 2668
#define sipName_PyQt5_QtSql &sipStrings_QtSql[2668]
#define sipNameNr_UnknownDbms 2680
#define sipName_UnknownDbms &sipStrings_QtSql[2680]
#define sipNameNr_addDatabase 2692
#define sipName_addDatabase &sipStrings_QtSql[2692]
#define sipNameNr_boundValues 2704
#define sipName_boundValues &sipStrings_QtSql[2704]
#define sipNameNr_clearValues 2716
#define sipName_clearValues &sipStrings_QtSql[2716]
#define sipNameNr_columnCount 2728
#define sipName_columnCount &sipStrings_QtSql[2728]
#define sipNameNr_customEvent 2740
#define sipName_customEvent &sipStrings_QtSql[2740]
#define sipNameNr_drawDisplay 2752
#define sipName_drawDisplay &sipStrings_QtSql[2752]
#define sipNameNr_editorEvent 2764
#define sipName_editorEvent &sipStrings_QtSql[2764]
#define sipNameNr_eventFilter 2776
#define sipName_eventFilter &sipStrings_QtSql[2776]
#define sipNameNr_formatValue 2788
#define sipName_formatValue &sipStrings_QtSql[2788]
#define sipNameNr_hasChildren 2800
#define sipName_hasChildren &sipStrings_QtSql[2800]
#define sipNameNr_indexColumn 2812
#define sipName_indexColumn &sipStrings_QtSql[2812]
#define sipNameNr_isAutoValue 2824
#define sipName_isAutoValue &sipStrings_QtSql[2824]
#define sipNameNr_isGenerated 2836
#define sipName_isGenerated &sipStrings_QtSql[2836]
#define sipNameNr_isOpenError 2848
#define sipName_isOpenError &sipStrings_QtSql[2848]
#define sipNameNr_moveColumns 802
#define sipName_moveColumns &sipStrings_QtSql[802]
#define sipNameNr_primeInsert 2860
#define sipName_primeInsert &sipStrings_QtSql[2860]
#define sipNameNr_queryChange 2872
#define sipName_queryChange &sipStrings_QtSql[2872]
#define sipNameNr_savePrepare 2884
#define sipName_savePrepare &sipStrings_QtSql[2884]
#define sipNameNr_setHostName 2896
#define sipName_setHostName &sipStrings_QtSql[2896]
#define sipNameNr_setItemData 2908
#define sipName_setItemData &sipStrings_QtSql[2908]
#define sipNameNr_setJoinMode 2920
#define sipName_setJoinMode &sipStrings_QtSql[2920]
#define sipNameNr_setPassword 2932
#define sipName_setPassword &sipStrings_QtSql[2932]
#define sipNameNr_setReadOnly 2944
#define sipName_setReadOnly &sipStrings_QtSql[2944]
#define sipNameNr_setRelation 2956
#define sipName_setRelation &sipStrings_QtSql[2956]
#define sipNameNr_setRequired 2968
#define sipName_setRequired &sipStrings_QtSql[2968]
#define sipNameNr_setUserName 2980
#define sipName_setUserName &sipStrings_QtSql[2980]
#define sipNameNr_transaction 2992
#define sipName_transaction &sipStrings_QtSql[2992]
#define sipNameNr_trimStrings 3004
#define sipName_trimStrings &sipStrings_QtSql[3004]
#define sipNameNr_PostgreSQL 3016
#define sipName_PostgreSQL &sipStrings_QtSql[3016]
#define sipNameNr_QSqlDriver 3027
#define sipName_QSqlDriver &sipStrings_QtSql[3027]
#define sipNameNr_QSqlRecord 3038
#define sipName_QSqlRecord &sipStrings_QtSql[3038]
#define sipNameNr_QSqlResult 3049
#define sipName_QSqlResult &sipStrings_QtSql[3049]
#define sipNameNr_SelfSource 3060
#define sipName_SelfSource &sipStrings_QtSql[3060]
#define sipNameNr___invert__ 3071
#define sipName___invert__ &sipStrings_QtSql[3071]
#define sipNameNr_boundValue 3082
#define sipName_boundValue &sipStrings_QtSql[3082]
#define sipNameNr_childEvent 3093
#define sipName_childEvent &sipStrings_QtSql[3093]
#define sipNameNr_cursorName 3104
#define sipName_cursorName &sipStrings_QtSql[3104]
#define sipNameNr_driverName 3115
#define sipName_driverName &sipStrings_QtSql[3115]
#define sipNameNr_driverText 3126
#define sipName_driverText &sipStrings_QtSql[3126]
#define sipNameNr_fetchFirst 3137
#define sipName_fetchFirst &sipStrings_QtSql[3137]
#define sipNameNr_fieldIndex 3148
#define sipName_fieldIndex &sipStrings_QtSql[3148]
#define sipNameNr_hasFeature 3159
#define sipName_hasFeature &sipStrings_QtSql[3159]
#define sipNameNr_headerData 3170
#define sipName_headerData &sipStrings_QtSql[3170]
#define sipNameNr_insertRows 3181
#define sipName_insertRows &sipStrings_QtSql[3181]
#define sipNameNr_isReadOnly 3192
#define sipName_isReadOnly &sipStrings_QtSql[3192]
#define sipNameNr_nextResult 3203
#define sipName_nextResult &sipStrings_QtSql[3203]
#define sipNameNr_primaryKey 3214
#define sipName_primaryKey &sipStrings_QtSql[3214]
#define sipNameNr_removeRows 3225
#define sipName_removeRows &sipStrings_QtSql[3225]
#define sipNameNr_setSqlType 3236
#define sipName_setSqlType &sipStrings_QtSql[3236]
#define sipNameNr_timerEvent 3247
#define sipName_timerEvent &sipStrings_QtSql[3247]
#define sipNameNr_AllTables 3258
#define sipName_AllTables &sipStrings_QtSql[3258]
#define sipNameNr_ErrorType 566
#define sipName_ErrorType &sipStrings_QtSql[566]
#define sipNameNr_FieldName 3268
#define sipName_FieldName &sipStrings_QtSql[3268]
#define sipNameNr_InnerJoin 3278
#define sipName_InnerJoin &sipStrings_QtSql[3278]
#define sipNameNr_Interbase 3288
#define sipName_Interbase &sipStrings_QtSql[3288]
#define sipNameNr_ParamType 1255
#define sipName_ParamType &sipStrings_QtSql[1255]
#define sipNameNr_QSqlError 3298
#define sipName_QSqlError &sipStrings_QtSql[3298]
#define sipNameNr_QSqlField 3308
#define sipName_QSqlField &sipStrings_QtSql[3308]
#define sipNameNr_QSqlIndex 3318
#define sipName_QSqlIndex &sipStrings_QtSql[3318]
#define sipNameNr_QSqlQuery 3328
#define sipName_QSqlQuery &sipStrings_QtSql[3328]
#define sipNameNr_QuerySize 3338
#define sipName_QuerySize &sipStrings_QtSql[3338]
#define sipNameNr_TableName 2585
#define sipName_TableName &sipStrings_QtSql[2585]
#define sipNameNr_TableType 1271
#define sipName_TableType &sipStrings_QtSql[1271]
#define sipNameNr___index__ 3348
#define sipName___index__ &sipStrings_QtSql[3348]
#define sipNameNr_bindValue 3358
#define sipName_bindValue &sipStrings_QtSql[3358]
#define sipNameNr_drawCheck 3368
#define sipName_drawCheck &sipStrings_QtSql[3368]
#define sipNameNr_drawFocus 3378
#define sipName_drawFocus &sipStrings_QtSql[3378]
#define sipNameNr_errorCode 3388
#define sipName_errorCode &sipStrings_QtSql[3388]
#define sipNameNr_execBatch 3398
#define sipName_execBatch &sipStrings_QtSql[3398]
#define sipNameNr_fetchLast 3408
#define sipName_fetchLast &sipStrings_QtSql[3408]
#define sipNameNr_fetchMore 3418
#define sipName_fetchMore &sipStrings_QtSql[3418]
#define sipNameNr_fetchNext 3428
#define sipName_fetchNext &sipStrings_QtSql[3428]
#define sipNameNr_fieldName 3438
#define sipName_fieldName &sipStrings_QtSql[3438]
#define sipNameNr_helpEvent 3448
#define sipName_helpEvent &sipStrings_QtSql[3448]
#define sipNameNr_keyValues 3458
#define sipName_keyValues &sipStrings_QtSql[3458]
#define sipNameNr_lastError 3468
#define sipName_lastError &sipStrings_QtSql[3468]
#define sipNameNr_lastQuery 3478
#define sipName_lastQuery &sipStrings_QtSql[3478]
#define sipNameNr_mimeTypes 3488
#define sipName_mimeTypes &sipStrings_QtSql[3488]
#define sipNameNr_precision 3498
#define sipName_precision &sipStrings_QtSql[3498]
#define sipNameNr_revertAll 3508
#define sipName_revertAll &sipStrings_QtSql[3508]
#define sipNameNr_revertRow 3518
#define sipName_revertRow &sipStrings_QtSql[3518]
#define sipNameNr_roleNames 3528
#define sipName_roleNames &sipStrings_QtSql[3528]
#define sipNameNr_selectRow 3538
#define sipName_selectRow &sipStrings_QtSql[3538]
#define sipNameNr_setActive 3548
#define sipName_setActive &sipStrings_QtSql[3548]
#define sipNameNr_setFilter 3558
#define sipName_setFilter &sipStrings_QtSql[3558]
#define sipNameNr_setLength 3568
#define sipName_setLength &sipStrings_QtSql[3568]
#define sipNameNr_setNumber 3578
#define sipName_setNumber &sipStrings_QtSql[3578]
#define sipNameNr_setRecord 3588
#define sipName_setRecord &sipStrings_QtSql[3588]
#define sipNameNr_setSelect 3598
#define sipName_setSelect &sipStrings_QtSql[3598]
#define sipNameNr_submitAll 3608
#define sipName_submitAll &sipStrings_QtSql[3608]
#define sipNameNr_tableName 3618
#define sipName_tableName &sipStrings_QtSql[3618]
#define sipNameNr_DbmsType 546
#define sipName_DbmsType &sipStrings_QtSql[546]
#define sipNameNr_JoinMode 26
#define sipName_JoinMode &sipStrings_QtSql[26]
#define sipNameNr_LeftJoin 3628
#define sipName_LeftJoin &sipStrings_QtSql[3628]
#define sipNameNr_Location 1589
#define sipName_Location &sipStrings_QtSql[1589]
#define sipNameNr_Optional 3637
#define sipName_Optional &sipStrings_QtSql[3637]
#define sipNameNr_Required 2971
#define sipName_Required &sipStrings_QtSql[2971]
#define sipNameNr___bool__ 3646
#define sipName___bool__ &sipStrings_QtSql[3646]
#define sipNameNr___hash__ 3655
#define sipName___hash__ &sipStrings_QtSql[3655]
#define sipNameNr___iand__ 3664
#define sipName___iand__ &sipStrings_QtSql[3664]
#define sipNameNr___ixor__ 3673
#define sipName___ixor__ &sipStrings_QtSql[3673]
#define sipNameNr_contains 3682
#define sipName_contains &sipStrings_QtSql[3682]
#define sipNameNr_database 3691
#define sipName_database &sipStrings_QtSql[3691]
#define sipNameNr_dbmsType 3700
#define sipName_dbmsType &sipStrings_QtSql[3700]
#define sipNameNr_hostName 3709
#define sipName_hostName &sipStrings_QtSql[3709]
#define sipNameNr_isActive 3718
#define sipName_isActive &sipStrings_QtSql[3718]
#define sipNameNr_isSelect 3727
#define sipName_isSelect &sipStrings_QtSql[3727]
#define sipNameNr_itemData 3736
#define sipName_itemData &sipStrings_QtSql[3736]
#define sipNameNr_mimeData 3745
#define sipName_mimeData &sipStrings_QtSql[3745]
#define sipNameNr_moveRows 1352
#define sipName_moveRows &sipStrings_QtSql[1352]
#define sipNameNr_password 3754
#define sipName_password &sipStrings_QtSql[3754]
#define sipNameNr_previous 3763
#define sipName_previous &sipStrings_QtSql[3763]
#define sipNameNr_relation 3772
#define sipName_relation &sipStrings_QtSql[3772]
#define sipNameNr_relative 3781
#define sipName_relative &sipStrings_QtSql[3781]
#define sipNameNr_rollback 3790
#define sipName_rollback &sipStrings_QtSql[3790]
#define sipNameNr_rowCount 3799
#define sipName_rowCount &sipStrings_QtSql[3799]
#define sipNameNr_setQuery 3808
#define sipName_setQuery &sipStrings_QtSql[3808]
#define sipNameNr_setTable 3817
#define sipName_setTable &sipStrings_QtSql[3817]
#define sipNameNr_setValue 3826
#define sipName_setValue &sipStrings_QtSql[3826]
#define sipNameNr_sizeHint 3835
#define sipName_sizeHint &sipStrings_QtSql[3835]
#define sipNameNr_userName 3844
#define sipName_userName &sipStrings_QtSql[3844]
#define sipNameNr_NoError 3853
#define sipName_NoError &sipStrings_QtSql[3853]
#define sipNameNr_Unicode 3861
#define sipName_Unicode &sipStrings_QtSql[3861]
#define sipNameNr_Unknown 3869
#define sipName_Unknown &sipStrings_QtSql[3869]
#define sipNameNr___and__ 3877
#define sipName___and__ &sipStrings_QtSql[3877]
#define sipNameNr___int__ 3885
#define sipName___int__ &sipStrings_QtSql[3885]
#define sipNameNr___ior__ 3893
#define sipName___ior__ &sipStrings_QtSql[3893]
#define sipNameNr___len__ 3901
#define sipName___len__ &sipStrings_QtSql[3901]
#define sipNameNr___xor__ 3909
#define sipName___xor__ &sipStrings_QtSql[3909]
#define sipNameNr_drivers 3917
#define sipName_drivers &sipStrings_QtSql[3917]
#define sipNameNr_indexOf 3925
#define sipName_indexOf &sipStrings_QtSql[3925]
#define sipNameNr_isDirty 3933
#define sipName_isDirty &sipStrings_QtSql[3933]
#define sipNameNr_isEmpty 3941
#define sipName_isEmpty &sipStrings_QtSql[3941]
#define sipNameNr_isValid 3949
#define sipName_isValid &sipStrings_QtSql[3949]
#define sipNameNr_options 3957
#define sipName_options &sipStrings_QtSql[3957]
#define sipNameNr_prepare 3965
#define sipName_prepare &sipStrings_QtSql[3965]
#define sipNameNr_replace 3973
#define sipName_replace &sipStrings_QtSql[3973]
#define sipNameNr_setData 3981
#define sipName_setData &sipStrings_QtSql[3981]
#define sipNameNr_setName 3989
#define sipName_setName &sipStrings_QtSql[3989]
#define sipNameNr_setNull 3997
#define sipName_setNull &sipStrings_QtSql[3997]
#define sipNameNr_setOpen 4005
#define sipName_setOpen &sipStrings_QtSql[4005]
#define sipNameNr_setPort 4013
#define sipName_setPort &sipStrings_QtSql[4013]
#define sipNameNr_setSort 4021
#define sipName_setSort &sipStrings_QtSql[4021]
#define sipNameNr_setType 4029
#define sipName_setType &sipStrings_QtSql[4029]
#define sipNameNr_sibling 4037
#define sipName_sibling &sipStrings_QtSql[4037]
#define sipNameNr_Binary 4045
#define sipName_Binary &sipStrings_QtSql[4045]
#define sipNameNr_Oracle 4052
#define sipName_Oracle &sipStrings_QtSql[4052]
#define sipNameNr_SQLite 4059
#define sipName_SQLite &sipStrings_QtSql[4059]
#define sipNameNr_Sybase 4066
#define sipName_Sybase &sipStrings_QtSql[4066]
#define sipNameNr_Tables 2198
#define sipName_Tables &sipStrings_QtSql[2198]
#define sipNameNr___eq__ 4073
#define sipName___eq__ &sipStrings_QtSql[4073]
#define sipNameNr___ne__ 4080
#define sipName___ne__ &sipStrings_QtSql[4080]
#define sipNameNr___or__ 4087
#define sipName___or__ &sipStrings_QtSql[4087]
#define sipNameNr_append 4094
#define sipName_append &sipStrings_QtSql[4094]
#define sipNameNr_commit 4101
#define sipName_commit &sipStrings_QtSql[4101]
#define sipNameNr_driver 4108
#define sipName_driver &sipStrings_QtSql[4108]
#define sipNameNr_filter 4115
#define sipName_filter &sipStrings_QtSql[4115]
#define sipNameNr_finish 4122
#define sipName_finish &sipStrings_QtSql[4122]
#define sipNameNr_handle 4129
#define sipName_handle &sipStrings_QtSql[4129]
#define sipNameNr_insert 4136
#define sipName_insert &sipStrings_QtSql[4136]
#define sipNameNr_isNull 4143
#define sipName_isNull &sipStrings_QtSql[4143]
#define sipNameNr_isOpen 4150
#define sipName_isOpen &sipStrings_QtSql[4150]
#define sipNameNr_length 4157
#define sipName_length &sipStrings_QtSql[4157]
#define sipNameNr_number 4164
#define sipName_number &sipStrings_QtSql[4164]
#define sipNameNr_parent 4171
#define sipName_parent &sipStrings_QtSql[4171]
#define sipNameNr_record 4178
#define sipName_record &sipStrings_QtSql[4178]
#define sipNameNr_remove 4185
#define sipName_remove &sipStrings_QtSql[4185]
#define sipNameNr_result 4192
#define sipName_result &sipStrings_QtSql[4192]
#define sipNameNr_revert 4199
#define sipName_revert &sipStrings_QtSql[4199]
#define sipNameNr_select 4206
#define sipName_select &sipStrings_QtSql[4206]
#define sipNameNr_submit 4213
#define sipName_submit &sipStrings_QtSql[4213]
#define sipNameNr_tables 4220
#define sipName_tables &sipStrings_QtSql[4220]
#define sipNameNr_typeID 4227
#define sipName_typeID &sipStrings_QtSql[4227]
#define sipNameNr_InOut 4234
#define sipName_InOut &sipStrings_QtSql[4234]
#define sipNameNr_Views 4240
#define sipName_Views &sipStrings_QtSql[4240]
#define sipNameNr_buddy 4246
#define sipName_buddy &sipStrings_QtSql[4246]
#define sipNameNr_clear 4252
#define sipName_clear &sipStrings_QtSql[4252]
#define sipNameNr_close 4258
#define sipName_close &sipStrings_QtSql[4258]
#define sipNameNr_count 4264
#define sipName_count &sipStrings_QtSql[4264]
#define sipNameNr_event 4270
#define sipName_event &sipStrings_QtSql[4270]
#define sipNameNr_exec_ 4276
#define sipName_exec_ &sipStrings_QtSql[4276]
#define sipNameNr_fetch 4282
#define sipName_fetch &sipStrings_QtSql[4282]
#define sipNameNr_field 4288
#define sipName_field &sipStrings_QtSql[4288]
#define sipNameNr_first 4294
#define sipName_first &sipStrings_QtSql[4294]
#define sipNameNr_flags 4300
#define sipName_flags &sipStrings_QtSql[4300]
#define sipNameNr_index 4306
#define sipName_index &sipStrings_QtSql[4306]
#define sipNameNr_match 4312
#define sipName_match &sipStrings_QtSql[4312]
#define sipNameNr_paint 4318
#define sipName_paint &sipStrings_QtSql[4318]
#define sipNameNr_query 4324
#define sipName_query &sipStrings_QtSql[4324]
#define sipNameNr_reset 4330
#define sipName_reset &sipStrings_QtSql[4330]
#define sipNameNr_setAt 4336
#define sipName_setAt &sipStrings_QtSql[4336]
#define sipNameNr_value 4342
#define sipName_value &sipStrings_QtSql[4342]
#define sipNameNr_BLOB 4348
#define sipName_BLOB &sipStrings_QtSql[4348]
#define sipNameNr_QSql 4353
#define sipName_QSql &sipStrings_QtSql[4353]
#define sipNameNr_data 4358
#define sipName_data &sipStrings_QtSql[4358]
#define sipNameNr_exec 4363
#define sipName_exec &sipStrings_QtSql[4363]
#define sipNameNr_host 4368
#define sipName_host &sipStrings_QtSql[4368]
#define sipNameNr_last 4373
#define sipName_last &sipStrings_QtSql[4373]
#define sipNameNr_mode 4378
#define sipName_mode &sipStrings_QtSql[4378]
#define sipNameNr_name 4383
#define sipName_name &sipStrings_QtSql[4383]
#define sipNameNr_next 4388
#define sipName_next &sipStrings_QtSql[4388]
#define sipNameNr_open 4393
#define sipName_open &sipStrings_QtSql[4393]
#define sipNameNr_port 4398
#define sipName_port &sipStrings_QtSql[4398]
#define sipNameNr_role 4403
#define sipName_role &sipStrings_QtSql[4403]
#define sipNameNr_seek 4408
#define sipName_seek &sipStrings_QtSql[4408]
#define sipNameNr_size 4413
#define sipName_size &sipStrings_QtSql[4413]
#define sipNameNr_sort 4418
#define sipName_sort &sipStrings_QtSql[4418]
#define sipNameNr_span 4423
#define sipName_span &sipStrings_QtSql[4423]
#define sipNameNr_swap 4428
#define sipName_swap &sipStrings_QtSql[4428]
#define sipNameNr_text 4433
#define sipName_text &sipStrings_QtSql[4433]
#define sipNameNr_type 4438
#define sipName_type &sipStrings_QtSql[4438]
#define sipNameNr_user 4443
#define sipName_user &sipStrings_QtSql[4443]
#define sipNameNr_DB2 4448
#define sipName_DB2 &sipStrings_QtSql[4448]
#define sipNameNr_Out 4236
#define sipName_Out &sipStrings_QtSql[4236]
#define sipNameNr_In 4452
#define sipName_In &sipStrings_QtSql[4452]
#define sipNameNr_at 4455
#define sipName_at &sipStrings_QtSql[4455]
#define sipNameNr_db 4458
#define sipName_db &sipStrings_QtSql[4458]

#define sipMalloc                   sipAPI_QtSql->api_malloc
#define sipFree                     sipAPI_QtSql->api_free
#define sipBuildResult              sipAPI_QtSql->api_build_result
#define sipCallMethod               sipAPI_QtSql->api_call_method
#define sipCallProcedureMethod      sipAPI_QtSql->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtSql->api_call_error_handler
#define sipParseResultEx            sipAPI_QtSql->api_parse_result_ex
#define sipParseResult              sipAPI_QtSql->api_parse_result
#define sipParseArgs                sipAPI_QtSql->api_parse_args
#define sipParseKwdArgs             sipAPI_QtSql->api_parse_kwd_args
#define sipParsePair                sipAPI_QtSql->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtSql->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtSql->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtSql->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtSql->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtSql->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtSql->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtSql->api_add_exception
#define sipNoFunction               sipAPI_QtSql->api_no_function
#define sipNoMethod                 sipAPI_QtSql->api_no_method
#define sipAbstractMethod           sipAPI_QtSql->api_abstract_method
#define sipBadClass                 sipAPI_QtSql->api_bad_class
#define sipBadCatcherResult         sipAPI_QtSql->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtSql->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtSql->api_bad_operator_arg
#define sipTrace                    sipAPI_QtSql->api_trace
#define sipTransferBack             sipAPI_QtSql->api_transfer_back
#define sipTransferTo               sipAPI_QtSql->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtSql->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtSql->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtSql->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtSql->api_voidptr_type
#define sipGetPyObject              sipAPI_QtSql->api_get_pyobject
#define sipGetAddress               sipAPI_QtSql->api_get_address
#define sipGetMixinAddress          sipAPI_QtSql->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtSql->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtSql->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtSql->api_call_hook
#define sipEndThread                sipAPI_QtSql->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtSql->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtSql->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtSql->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtSql->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtSql->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtSql->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtSql->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtSql->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtSql->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtSql->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtSql->api_convert_to_bool
#define sipReleaseType              sipAPI_QtSql->api_release_type
#define sipConvertFromType          sipAPI_QtSql->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtSql->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtSql->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtSql->api_convert_from_enum
#define sipGetState                 sipAPI_QtSql->api_get_state
#define sipExportSymbol             sipAPI_QtSql->api_export_symbol
#define sipImportSymbol             sipAPI_QtSql->api_import_symbol
#define sipFindType                 sipAPI_QtSql->api_find_type
#define sipBytes_AsChar             sipAPI_QtSql->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtSql->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtSql->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtSql->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtSql->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtSql->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtSql->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtSql->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtSql->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtSql->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtSql->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtSql->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtSql->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtSql->api_get_reference
#define sipKeepReference            sipAPI_QtSql->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtSql->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtSql->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtSql->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtSql->api_type_scope
#define sipResolveTypedef           sipAPI_QtSql->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtSql->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtSql->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtSql->api_init_mixin
#define sipExportModule             sipAPI_QtSql->api_export_module
#define sipInitModule               sipAPI_QtSql->api_init_module
#define sipGetInterpreter           sipAPI_QtSql->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtSql->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtSql->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtSql->api_py_type_dict
#define sipPyTypeName               sipAPI_QtSql->api_py_type_name
#define sipGetCFunction             sipAPI_QtSql->api_get_c_function
#define sipGetMethod                sipAPI_QtSql->api_get_method
#define sipFromMethod               sipAPI_QtSql->api_from_method
#define sipGetDate                  sipAPI_QtSql->api_get_date
#define sipFromDate                 sipAPI_QtSql->api_from_date
#define sipGetDateTime              sipAPI_QtSql->api_get_datetime
#define sipFromDateTime             sipAPI_QtSql->api_from_datetime
#define sipGetTime                  sipAPI_QtSql->api_get_time
#define sipFromTime                 sipAPI_QtSql->api_from_time
#define sipIsUserType               sipAPI_QtSql->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtSql->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtSql->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtSql->api_unicode_write
#define sipUnicodeData              sipAPI_QtSql->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtSql->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtSql->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtSql->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtSql->api_is_derived_class
#define sipGetUserObject            sipAPI_QtSql->api_get_user_object
#define sipSetUserObject            sipAPI_QtSql->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtSql->api_register_event_handler
#define sipConvertToArray           sipAPI_QtSql->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtSql->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtSql->api_enable_gc
#define sipPrintObject              sipAPI_QtSql->api_print_object
#define sipLong_AsChar              sipAPI_QtSql->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtSql->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtSql->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtSql->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtSql->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtSql->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtSql->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtSql->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtSql->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtSql->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtSql->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtSql->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtSql->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtSql->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtSql->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtSql->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtSql->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtSql->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtSql->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtSql->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtSql->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtSql->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtSql->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtSql->api_connect_rx
#define sipConvertRx                sipAPI_QtSql->api_convert_rx
#define sipDisconnectRx             sipAPI_QtSql->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtSql->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtSql->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtSql->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtSql->api_same_slot
#define sipSaveSlot                 sipAPI_QtSql->api_save_slot
#define sipVisitSlot                sipAPI_QtSql->api_visit_slot
#define sipIsPyMethod               sipAPI_QtSql->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtSql[];

#define sipType_QSqlDriverCreatorBase sipExportedTypes_QtSql[14]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlDriverCreatorBase;

#define sipType_QSqlDatabase sipExportedTypes_QtSql[7]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlDatabase;

#define sipType_QSqlDriver sipExportedTypes_QtSql[8]

#define sipType_QSqlDriver_DbmsType sipExportedTypes_QtSql[9]

#define sipType_QSqlDriver_NotificationSource sipExportedTypes_QtSql[12]

#define sipType_QSqlDriver_IdentifierType sipExportedTypes_QtSql[11]

#define sipType_QSqlDriver_StatementType sipExportedTypes_QtSql[13]

#define sipType_QSqlDriver_DriverFeature sipExportedTypes_QtSql[10]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlDriver;

#define sipType_QSqlError sipExportedTypes_QtSql[15]

#define sipType_QSqlError_ErrorType sipExportedTypes_QtSql[16]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlError;

#define sipType_QSqlField sipExportedTypes_QtSql[17]

#define sipType_QSqlField_RequiredStatus sipExportedTypes_QtSql[18]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlField;

#define sipType_QSqlRecord sipExportedTypes_QtSql[23]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlRecord;

#define sipType_QSqlIndex sipExportedTypes_QtSql[19]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlIndex;

#define sipType_QSqlQuery sipExportedTypes_QtSql[20]

#define sipType_QSqlQuery_BatchExecutionMode sipExportedTypes_QtSql[21]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlQuery;

#define sipType_QSqlQueryModel sipExportedTypes_QtSql[22]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlQueryModel;

#define sipType_QSqlRelationalDelegate sipExportedTypes_QtSql[25]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlRelationalDelegate;

#define sipType_QSqlRelation sipExportedTypes_QtSql[24]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlRelation;

#define sipType_QSqlTableModel sipExportedTypes_QtSql[30]

#define sipType_QSqlTableModel_EditStrategy sipExportedTypes_QtSql[31]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlTableModel;

#define sipType_QSqlRelationalTableModel sipExportedTypes_QtSql[26]

#define sipType_QSqlRelationalTableModel_JoinMode sipExportedTypes_QtSql[27]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlRelationalTableModel;

#define sipType_QSqlResult sipExportedTypes_QtSql[28]

#define sipType_QSqlResult_BindingSyntax sipExportedTypes_QtSql[29]

extern sipClassTypeDef sipTypeDef_QtSql_QSqlResult;

#define sipType_QSql sipExportedTypes_QtSql[1]

#define sipType_QSql_NumericalPrecisionPolicy sipExportedTypes_QtSql[3]

#define sipType_QSql_TableType sipExportedTypes_QtSql[6]

#define sipType_QSql_ParamTypeFlag sipExportedTypes_QtSql[5]

#define sipType_QSql_Location sipExportedTypes_QtSql[2]

extern sipClassTypeDef sipTypeDef_QtSql_QSql;

#define sipType_QSql_ParamType sipExportedTypes_QtSql[4]

extern sipClassTypeDef sipTypeDef_QtSql_QSql_ParamType;

#define sipType_QVector_0100QVariant sipExportedTypes_QtSql[32]

extern sipMappedTypeDef sipTypeDef_QtSql_QVector_0100QVariant;

#define sipType_QMap_0100QString_0100QVariant sipExportedTypes_QtSql[0]

extern sipMappedTypeDef sipTypeDef_QtSql_QMap_0100QString_0100QVariant;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtSql;
extern sipExportedModuleDef sipModuleAPI_QtSql;
extern sipTypeDef *sipExportedTypes_QtSql[];

#define sipType_Qt_CheckState sipImportedTypes_QtSql_QtCore[18].it_td

#define sipType_Qt_DropAction sipImportedTypes_QtSql_QtCore[19].it_td

#define sipType_Qt_SortOrder sipImportedTypes_QtSql_QtCore[24].it_td

#define sipType_Qt_Orientation sipImportedTypes_QtSql_QtCore[23].it_td

#define sipType_Qt_DropActions sipImportedTypes_QtSql_QtCore[20].it_td

#define sipType_Qt_ItemFlags sipImportedTypes_QtSql_QtCore[21].it_td

#define sipType_Qt_MatchFlags sipImportedTypes_QtSql_QtCore[22].it_td

#define sipType_QObject sipImportedTypes_QtSql_QtCore[10].it_td

#define sipType_QModelIndex sipImportedTypes_QtSql_QtCore[9].it_td

#define sipType_QAbstractItemModel sipImportedTypes_QtSql_QtCore[0].it_td

#define sipType_QAbstractTableModel sipImportedTypes_QtSql_QtCore[1].it_td

#define sipType_QEvent sipImportedTypes_QtSql_QtCore[3].it_td

#define sipType_QTimerEvent sipImportedTypes_QtSql_QtCore[15].it_td

#define sipType_QChildEvent sipImportedTypes_QtSql_QtCore[2].it_td

#define sipType_QMetaMethod sipImportedTypes_QtSql_QtCore[7].it_td

#define sipType_QMimeData sipImportedTypes_QtSql_QtCore[8].it_td

#define sipType_QRect sipImportedTypes_QtSql_QtCore[11].it_td

#define sipType_QSize sipImportedTypes_QtSql_QtCore[12].it_td

#define sipType_QVariant sipImportedTypes_QtSql_QtCore[16].it_td

#define sipType_QVariant_Type sipImportedTypes_QtSql_QtCore[17].it_td

#define sipType_QHash_1800_0100QByteArray sipImportedTypes_QtSql_QtCore[4].it_td

#define sipType_QMap_1800_0100QVariant sipImportedTypes_QtSql_QtCore[6].it_td

#define sipType_QList_0100QModelIndex sipImportedTypes_QtSql_QtCore[5].it_td

#define sipType_QStringList sipImportedTypes_QtSql_QtCore[14].it_td

#define sipType_QString sipImportedTypes_QtSql_QtCore[13].it_td
extern sipImportedTypeDef sipImportedTypes_QtSql_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtSql_QtCore[];

#define sipType_QPixmap sipImportedTypes_QtSql_QtGui[2].it_td

#define sipType_QHelpEvent sipImportedTypes_QtSql_QtGui[0].it_td

#define sipType_QPainter sipImportedTypes_QtSql_QtGui[1].it_td
extern sipImportedTypeDef sipImportedTypes_QtSql_QtGui[];

#define sipType_QWidget sipImportedTypes_QtSql_QtWidgets[4].it_td

#define sipType_QAbstractItemDelegate sipImportedTypes_QtSql_QtWidgets[0].it_td

#define sipType_QAbstractItemView sipImportedTypes_QtSql_QtWidgets[1].it_td

#define sipType_QItemDelegate sipImportedTypes_QtSql_QtWidgets[2].it_td

#define sipType_QStyleOptionViewItem sipImportedTypes_QtSql_QtWidgets[3].it_td
extern sipImportedTypeDef sipImportedTypes_QtSql_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtSql_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtSql_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtSql_qt_metacast;

#endif
