/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtPositioningAPI_H
#define _QtPositioningAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QGeoAreaMonitorSource__AreaMonitorFeatures 0
#define sipName_QGeoAreaMonitorSource__AreaMonitorFeatures &sipStrings_QtPositioning[0]
#define sipNameNr_QGeoPositionInfoSource__PositioningMethods 43
#define sipName_QGeoPositionInfoSource__PositioningMethods &sipStrings_QtPositioning[43]
#define sipNameNr_QGeoAreaMonitorSource__AreaMonitorFeature 86
#define sipName_QGeoAreaMonitorSource__AreaMonitorFeature &sipStrings_QtPositioning[86]
#define sipNameNr_QGeoPositionInfoSource__PositioningMethod 128
#define sipName_QGeoPositionInfoSource__PositioningMethod &sipStrings_QtPositioning[128]
#define sipNameNr_DegreesMinutesSecondsWithHemisphere 170
#define sipName_DegreesMinutesSecondsWithHemisphere &sipStrings_QtPositioning[170]
#define sipNameNr_QNmeaPositionInfoSource__UpdateMode 206
#define sipName_QNmeaPositionInfoSource__UpdateMode &sipStrings_QtPositioning[206]
#define sipNameNr_fromSatellitePositioningMethodsOnly 242
#define sipName_fromSatellitePositioningMethodsOnly &sipStrings_QtPositioning[242]
#define sipNameNr_QGeoSatelliteInfo__SatelliteSystem 278
#define sipName_QGeoSatelliteInfo__SatelliteSystem &sipStrings_QtPositioning[278]
#define sipNameNr_supportedPositioningMethodsChanged 313
#define sipName_supportedPositioningMethodsChanged &sipStrings_QtPositioning[313]
#define sipNameNr_QGeoCoordinate__CoordinateFormat 348
#define sipName_QGeoCoordinate__CoordinateFormat &sipStrings_QtPositioning[348]
#define sipNameNr_NonSatellitePositioningMethods 381
#define sipName_NonSatellitePositioningMethods &sipStrings_QtPositioning[381]
#define sipNameNr_QGeoCoordinate__CoordinateType 412
#define sipName_QGeoCoordinate__CoordinateType &sipStrings_QtPositioning[412]
#define sipNameNr_QGeoSatelliteInfoSource__Error 443
#define sipName_QGeoSatelliteInfoSource__Error &sipStrings_QtPositioning[443]
#define sipNameNr_setPreferredPositioningMethods 474
#define sipName_setPreferredPositioningMethods &sipStrings_QtPositioning[474]
#define sipNameNr_QGeoPositionInfoSource__Error 505
#define sipName_QGeoPositionInfoSource__Error &sipStrings_QtPositioning[505]
#define sipNameNr_DegreesMinutesWithHemisphere 535
#define sipName_DegreesMinutesWithHemisphere &sipStrings_QtPositioning[535]
#define sipNameNr_PersistentAreaMonitorFeature 564
#define sipName_PersistentAreaMonitorFeature &sipStrings_QtPositioning[564]
#define sipNameNr_QGeoAreaMonitorSource__Error 593
#define sipName_QGeoAreaMonitorSource__Error &sipStrings_QtPositioning[593]
#define sipNameNr_QGeoSatelliteInfo__Attribute 622
#define sipName_QGeoSatelliteInfo__Attribute &sipStrings_QtPositioning[622]
#define sipNameNr_supportedAreaMonitorFeatures 651
#define sipName_supportedAreaMonitorFeatures &sipStrings_QtPositioning[651]
#define sipNameNr_QGeoPositionInfo__Attribute 680
#define sipName_QGeoPositionInfo__Attribute &sipStrings_QtPositioning[680]
#define sipNameNr_SatellitePositioningMethods 384
#define sipName_SatellitePositioningMethods &sipStrings_QtPositioning[384]
#define sipNameNr_preferredPositioningMethods 708
#define sipName_preferredPositioningMethods &sipStrings_QtPositioning[708]
#define sipNameNr_setUserEquivalentRangeError 736
#define sipName_setUserEquivalentRangeError &sipStrings_QtPositioning[736]
#define sipNameNr_supportedPositioningMethods 764
#define sipName_supportedPositioningMethods &sipStrings_QtPositioning[764]
#define sipNameNr_792 792
#define sipName_792 &sipStrings_QtPositioning[792]
#define sipNameNr_setNotificationParameters 819
#define sipName_setNotificationParameters &sipStrings_QtPositioning[819]
#define sipNameNr_InsufficientPositionInfo 845
#define sipName_InsufficientPositionInfo &sipStrings_QtPositioning[845]
#define sipNameNr_870 870
#define sipName_870 &sipStrings_QtPositioning[870]
#define sipNameNr_parsePosInfoFromNmeaData 895
#define sipName_parsePosInfoFromNmeaData &sipStrings_QtPositioning[895]
#define sipNameNr_userEquivalentRangeError 920
#define sipName_userEquivalentRangeError &sipStrings_QtPositioning[920]
#define sipNameNr_QGeoSatelliteInfoSource 945
#define sipName_QGeoSatelliteInfoSource &sipStrings_QtPositioning[945]
#define sipNameNr_QNmeaPositionInfoSource 969
#define sipName_QNmeaPositionInfoSource &sipStrings_QtPositioning[969]
#define sipNameNr_satellitesInViewUpdated 993
#define sipName_satellitesInViewUpdated &sipStrings_QtPositioning[993]
#define sipNameNr_QGeoPositionInfoSource 1017
#define sipName_QGeoPositionInfoSource &sipStrings_QtPositioning[1017]
#define sipNameNr_notificationParameters 1040
#define sipName_notificationParameters &sipStrings_QtPositioning[1040]
#define sipNameNr_satellitesInUseUpdated 1063
#define sipName_satellitesInUseUpdated &sipStrings_QtPositioning[1063]
#define sipNameNr_setSatelliteIdentifier 1086
#define sipName_setSatelliteIdentifier &sipStrings_QtPositioning[1086]
#define sipNameNr_AllPositioningMethods 1109
#define sipName_AllPositioningMethods &sipStrings_QtPositioning[1109]
#define sipNameNr_AnyAreaMonitorFeature 1131
#define sipName_AnyAreaMonitorFeature &sipStrings_QtPositioning[1131]
#define sipNameNr_DegreesMinutesSeconds 1153
#define sipName_DegreesMinutesSeconds &sipStrings_QtPositioning[1153]
#define sipNameNr_DegreesWithHemisphere 1175
#define sipName_DegreesWithHemisphere &sipStrings_QtPositioning[1175]
#define sipNameNr_QGeoAreaMonitorSource 1197
#define sipName_QGeoAreaMonitorSource &sipStrings_QtPositioning[1197]
#define sipNameNr_1219 1219
#define sipName_1219 &sipStrings_QtPositioning[1219]
#define sipNameNr_minimumUpdateInterval 1241
#define sipName_minimumUpdateInterval &sipStrings_QtPositioning[1241]
#define sipNameNr_setExtendedAttributes 1263
#define sipName_setExtendedAttributes &sipStrings_QtPositioning[1263]
#define sipNameNr_setPositionInfoSource 1285
#define sipName_setPositionInfoSource &sipStrings_QtPositioning[1285]
#define sipNameNr_NoPositioningMethods 1307
#define sipName_NoPositioningMethods &sipStrings_QtPositioning[1307]
#define sipNameNr_QGeoShape__ShapeType 1328
#define sipName_QGeoShape__ShapeType &sipStrings_QtPositioning[1328]
#define sipNameNr_atDistanceAndAzimuth 1349
#define sipName_atDistanceAndAzimuth &sipStrings_QtPositioning[1349]
#define sipNameNr_boundingGeoRectangle 1370
#define sipName_boundingGeoRectangle &sipStrings_QtPositioning[1370]
#define sipNameNr_AreaMonitorFeatures 23
#define sipName_AreaMonitorFeatures &sipStrings_QtPositioning[23]
#define sipNameNr_PyQt5_QtPositioning 1391
#define sipName_PyQt5_QtPositioning &sipStrings_QtPositioning[1391]
#define sipNameNr_QGeoAreaMonitorInfo 1411
#define sipName_QGeoAreaMonitorInfo &sipStrings_QtPositioning[1411]
#define sipNameNr_createDefaultSource 1431
#define sipName_createDefaultSource &sipStrings_QtPositioning[1431]
#define sipNameNr_satelliteIdentifier 1451
#define sipName_satelliteIdentifier &sipStrings_QtPositioning[1451]
#define sipNameNr_AreaMonitorFeature 109
#define sipName_AreaMonitorFeature &sipStrings_QtPositioning[109]
#define sipNameNr_HorizontalAccuracy 1471
#define sipName_HorizontalAccuracy &sipStrings_QtPositioning[1471]
#define sipNameNr_PositioningMethods 67
#define sipName_PositioningMethods &sipStrings_QtPositioning[67]
#define sipNameNr_UnknownSourceError 1490
#define sipName_UnknownSourceError &sipStrings_QtPositioning[1490]
#define sipNameNr_containsCoordinate 1509
#define sipName_containsCoordinate &sipStrings_QtPositioning[1509]
#define sipNameNr_extendedAttributes 1528
#define sipName_extendedAttributes &sipStrings_QtPositioning[1528]
#define sipNameNr_positionInfoSource 1547
#define sipName_positionInfoSource &sipStrings_QtPositioning[1547]
#define sipNameNr_setBackendProperty 1566
#define sipName_setBackendProperty &sipStrings_QtPositioning[1566]
#define sipNameNr_setSatelliteSystem 1585
#define sipName_setSatelliteSystem &sipStrings_QtPositioning[1585]
#define sipNameNr_InvalidCoordinate 1604
#define sipName_InvalidCoordinate &sipStrings_QtPositioning[1604]
#define sipNameNr_MagneticVariation 1622
#define sipName_MagneticVariation &sipStrings_QtPositioning[1622]
#define sipNameNr_PositioningMethod 152
#define sipName_PositioningMethod &sipStrings_QtPositioning[152]
#define sipNameNr_QGeoSatelliteInfo 1640
#define sipName_QGeoSatelliteInfo &sipStrings_QtPositioning[1640]
#define sipNameNr_lastKnownPosition 1658
#define sipName_lastKnownPosition &sipStrings_QtPositioning[1658]
#define sipNameNr_replaceCoordinate 1676
#define sipName_replaceCoordinate &sipStrings_QtPositioning[1676]
#define sipNameNr_setSignalStrength 1694
#define sipName_setSignalStrength &sipStrings_QtPositioning[1694]
#define sipNameNr_setUpdateInterval 1712
#define sipName_setUpdateInterval &sipStrings_QtPositioning[1712]
#define sipNameNr_CoordinateFormat 364
#define sipName_CoordinateFormat &sipStrings_QtPositioning[364]
#define sipNameNr_QGeoPositionInfo 1730
#define sipName_QGeoPositionInfo &sipStrings_QtPositioning[1730]
#define sipNameNr_VerticalAccuracy 1747
#define sipName_VerticalAccuracy &sipStrings_QtPositioning[1747]
#define sipNameNr_availableSources 1764
#define sipName_availableSources &sipStrings_QtPositioning[1764]
#define sipNameNr_disconnectNotify 1781
#define sipName_disconnectNotify &sipStrings_QtPositioning[1781]
#define sipNameNr_insertCoordinate 1798
#define sipName_insertCoordinate &sipStrings_QtPositioning[1798]
#define sipNameNr_removeCoordinate 1815
#define sipName_removeCoordinate &sipStrings_QtPositioning[1815]
#define sipNameNr_SatelliteSystem 297
#define sipName_SatelliteSystem &sipStrings_QtPositioning[297]
#define sipNameNr_backendProperty 1832
#define sipName_backendProperty &sipStrings_QtPositioning[1832]
#define sipNameNr_extendRectangle 1848
#define sipName_extendRectangle &sipStrings_QtPositioning[1848]
#define sipNameNr_isTextGenerated 1864
#define sipName_isTextGenerated &sipStrings_QtPositioning[1864]
#define sipNameNr_positionUpdated 1880
#define sipName_positionUpdated &sipStrings_QtPositioning[1880]
#define sipNameNr_removeAttribute 1896
#define sipName_removeAttribute &sipStrings_QtPositioning[1896]
#define sipNameNr_satelliteSystem 1912
#define sipName_satelliteSystem &sipStrings_QtPositioning[1912]
#define sipNameNr_startMonitoring 1928
#define sipName_startMonitoring &sipStrings_QtPositioning[1928]
#define sipNameNr_CoordinateType 428
#define sipName_CoordinateType &sipStrings_QtPositioning[428]
#define sipNameNr_DegreesMinutes 1944
#define sipName_DegreesMinutes &sipStrings_QtPositioning[1944]
#define sipNameNr_QGeoCoordinate 1959
#define sipName_QGeoCoordinate &sipStrings_QtPositioning[1959]
#define sipNameNr_SimulationMode 1974
#define sipName_SimulationMode &sipStrings_QtPositioning[1974]
#define sipNameNr_activeMonitors 1989
#define sipName_activeMonitors &sipStrings_QtPositioning[1989]
#define sipNameNr_monitorExpired 2004
#define sipName_monitorExpired &sipStrings_QtPositioning[2004]
#define sipNameNr_requestTimeout 2019
#define sipName_requestTimeout &sipStrings_QtPositioning[2019]
#define sipNameNr_setBottomRight 2034
#define sipName_setBottomRight &sipStrings_QtPositioning[2034]
#define sipNameNr_setBoundingBox 2049
#define sipName_setBoundingBox &sipStrings_QtPositioning[2049]
#define sipNameNr_setCountryCode 2064
#define sipName_setCountryCode &sipStrings_QtPositioning[2064]
#define sipNameNr_signalStrength 2079
#define sipName_signalStrength &sipStrings_QtPositioning[2079]
#define sipNameNr_stopMonitoring 2094
#define sipName_stopMonitoring &sipStrings_QtPositioning[2094]
#define sipNameNr_updateInterval 2109
#define sipName_updateInterval &sipStrings_QtPositioning[2109]
#define sipNameNr_QGeoRectangle 2124
#define sipName_QGeoRectangle &sipStrings_QtPositioning[2124]
#define sipNameNr_RectangleType 2138
#define sipName_RectangleType &sipStrings_QtPositioning[2138]
#define sipNameNr_VerticalSpeed 2152
#define sipName_VerticalSpeed &sipStrings_QtPositioning[2152]
#define sipNameNr_addCoordinate 2166
#define sipName_addCoordinate &sipStrings_QtPositioning[2166]
#define sipNameNr_connectNotify 1784
#define sipName_connectNotify &sipStrings_QtPositioning[1784]
#define sipNameNr_requestUpdate 2180
#define sipName_requestUpdate &sipStrings_QtPositioning[2180]
#define sipNameNr_setBottomLeft 2194
#define sipName_setBottomLeft &sipStrings_QtPositioning[2194]
#define sipNameNr_setCoordinate 2208
#define sipName_setCoordinate &sipStrings_QtPositioning[2208]
#define sipNameNr_setExpiration 2222
#define sipName_setExpiration &sipStrings_QtPositioning[2222]
#define sipNameNr_setPersistent 2236
#define sipName_setPersistent &sipStrings_QtPositioning[2236]
#define sipNameNr_setPostalCode 2250
#define sipName_setPostalCode &sipStrings_QtPositioning[2250]
#define sipNameNr_updateTimeout 2264
#define sipName_updateTimeout &sipStrings_QtPositioning[2264]
#define sipNameNr_Coordinate2D 2278
#define sipName_Coordinate2D &sipStrings_QtPositioning[2278]
#define sipNameNr_Coordinate3D 2291
#define sipName_Coordinate3D &sipStrings_QtPositioning[2291]
#define sipNameNr_QGeoLocation 2304
#define sipName_QGeoLocation &sipStrings_QtPositioning[2304]
#define sipNameNr_RealTimeMode 2317
#define sipName_RealTimeMode &sipStrings_QtPositioning[2317]
#define sipNameNr_coordinateAt 2330
#define sipName_coordinateAt &sipStrings_QtPositioning[2330]
#define sipNameNr_createSource 2343
#define sipName_createSource &sipStrings_QtPositioning[2343]
#define sipNameNr_extendCircle 2356
#define sipName_extendCircle &sipStrings_QtPositioning[2356]
#define sipNameNr_hasAttribute 2369
#define sipName_hasAttribute &sipStrings_QtPositioning[2369]
#define sipNameNr_isPersistent 2382
#define sipName_isPersistent &sipStrings_QtPositioning[2382]
#define sipNameNr_setAttribute 2395
#define sipName_setAttribute &sipStrings_QtPositioning[2395]
#define sipNameNr_setLongitude 2408
#define sipName_setLongitude &sipStrings_QtPositioning[2408]
#define sipNameNr_setPerimeter 2421
#define sipName_setPerimeter &sipStrings_QtPositioning[2421]
#define sipNameNr_setTimestamp 2434
#define sipName_setTimestamp &sipStrings_QtPositioning[2434]
#define sipNameNr_startUpdates 2447
#define sipName_startUpdates &sipStrings_QtPositioning[2447]
#define sipNameNr_AccessError 2460
#define sipName_AccessError &sipStrings_QtPositioning[2460]
#define sipNameNr_ClosedError 2472
#define sipName_ClosedError &sipStrings_QtPositioning[2472]
#define sipNameNr_GroundSpeed 2484
#define sipName_GroundSpeed &sipStrings_QtPositioning[2484]
#define sipNameNr_PolygonType 2496
#define sipName_PolygonType &sipStrings_QtPositioning[2496]
#define sipNameNr_QGeoAddress 2508
#define sipName_QGeoAddress &sipStrings_QtPositioning[2508]
#define sipNameNr_QGeoPolygon 2520
#define sipName_QGeoPolygon &sipStrings_QtPositioning[2520]
#define sipNameNr_UnknownType 2532
#define sipName_UnknownType &sipStrings_QtPositioning[2532]
#define sipNameNr_areaEntered 2544
#define sipName_areaEntered &sipStrings_QtPositioning[2544]
#define sipNameNr_bottomRight 2556
#define sipName_bottomRight &sipStrings_QtPositioning[2556]
#define sipNameNr_boundingBox 2568
#define sipName_boundingBox &sipStrings_QtPositioning[2568]
#define sipNameNr_countryCode 2580
#define sipName_countryCode &sipStrings_QtPositioning[2580]
#define sipNameNr_customEvent 2592
#define sipName_customEvent &sipStrings_QtPositioning[2592]
#define sipNameNr_eventFilter 2604
#define sipName_eventFilter &sipStrings_QtPositioning[2604]
#define sipNameNr_extendShape 2616
#define sipName_extendShape &sipStrings_QtPositioning[2616]
#define sipNameNr_setAltitude 2628
#define sipName_setAltitude &sipStrings_QtPositioning[2628]
#define sipNameNr_setDistrict 2640
#define sipName_setDistrict &sipStrings_QtPositioning[2640]
#define sipNameNr_setLatitude 2652
#define sipName_setLatitude &sipStrings_QtPositioning[2652]
#define sipNameNr_setTopRight 2664
#define sipName_setTopRight &sipStrings_QtPositioning[2664]
#define sipNameNr_stopUpdates 2676
#define sipName_stopUpdates &sipStrings_QtPositioning[2676]
#define sipNameNr_CircleType 2688
#define sipName_CircleType &sipStrings_QtPositioning[2688]
#define sipNameNr_QGeoCircle 2699
#define sipName_QGeoCircle &sipStrings_QtPositioning[2699]
#define sipNameNr_UpdateMode 231
#define sipName_UpdateMode &sipStrings_QtPositioning[231]
#define sipNameNr___invert__ 2710
#define sipName___invert__ &sipStrings_QtPositioning[2710]
#define sipNameNr___lshift__ 2721
#define sipName___lshift__ &sipStrings_QtPositioning[2721]
#define sipNameNr___rshift__ 2732
#define sipName___rshift__ &sipStrings_QtPositioning[2732]
#define sipNameNr_areaExited 2743
#define sipName_areaExited &sipStrings_QtPositioning[2743]
#define sipNameNr_bottomLeft 2754
#define sipName_bottomLeft &sipStrings_QtPositioning[2754]
#define sipNameNr_childEvent 2765
#define sipName_childEvent &sipStrings_QtPositioning[2765]
#define sipNameNr_coordinate 2776
#define sipName_coordinate &sipStrings_QtPositioning[2776]
#define sipNameNr_distanceTo 2787
#define sipName_distanceTo &sipStrings_QtPositioning[2787]
#define sipNameNr_distanceUp 2798
#define sipName_distanceUp &sipStrings_QtPositioning[2798]
#define sipNameNr_expiration 2809
#define sipName_expiration &sipStrings_QtPositioning[2809]
#define sipNameNr_holesCount 2820
#define sipName_holesCount &sipStrings_QtPositioning[2820]
#define sipNameNr_identifier 2831
#define sipName_identifier &sipStrings_QtPositioning[2831]
#define sipNameNr_intersects 2842
#define sipName_intersects &sipStrings_QtPositioning[2842]
#define sipNameNr_postalCode 2853
#define sipName_postalCode &sipStrings_QtPositioning[2853]
#define sipNameNr_removeHole 2864
#define sipName_removeHole &sipStrings_QtPositioning[2864]
#define sipNameNr_setAddress 2875
#define sipName_setAddress &sipStrings_QtPositioning[2875]
#define sipNameNr_setCountry 2886
#define sipName_setCountry &sipStrings_QtPositioning[2886]
#define sipNameNr_setTopLeft 2897
#define sipName_setTopLeft &sipStrings_QtPositioning[2897]
#define sipNameNr_sourceName 2908
#define sipName_sourceName &sipStrings_QtPositioning[2908]
#define sipNameNr_timerEvent 2919
#define sipName_timerEvent &sipStrings_QtPositioning[2919]
#define sipNameNr_translated 2930
#define sipName_translated &sipStrings_QtPositioning[2930]
#define sipNameNr_updateMode 2941
#define sipName_updateMode &sipStrings_QtPositioning[2941]
#define sipNameNr_Attribute 641
#define sipName_Attribute &sipStrings_QtPositioning[641]
#define sipNameNr_Direction 2952
#define sipName_Direction &sipStrings_QtPositioning[2952]
#define sipNameNr_Elevation 2962
#define sipName_Elevation &sipStrings_QtPositioning[2962]
#define sipNameNr_QGeoShape 2972
#define sipName_QGeoShape &sipStrings_QtPositioning[2972]
#define sipNameNr_ShapeType 1339
#define sipName_ShapeType &sipStrings_QtPositioning[1339]
#define sipNameNr_Undefined 2982
#define sipName_Undefined &sipStrings_QtPositioning[2982]
#define sipNameNr___index__ 2992
#define sipName___index__ &sipStrings_QtPositioning[2992]
#define sipNameNr_attribute 3002
#define sipName_attribute &sipStrings_QtPositioning[3002]
#define sipNameNr_azimuthTo 3012
#define sipName_azimuthTo &sipStrings_QtPositioning[3012]
#define sipNameNr_clearPath 3022
#define sipName_clearPath &sipStrings_QtPositioning[3022]
#define sipNameNr_indexFrom 3032
#define sipName_indexFrom &sipStrings_QtPositioning[3032]
#define sipNameNr_longitude 3042
#define sipName_longitude &sipStrings_QtPositioning[3042]
#define sipNameNr_perimeter 3052
#define sipName_perimeter &sipStrings_QtPositioning[3052]
#define sipNameNr_setCenter 3062
#define sipName_setCenter &sipStrings_QtPositioning[3062]
#define sipNameNr_setCounty 3072
#define sipName_setCounty &sipStrings_QtPositioning[3072]
#define sipNameNr_setDevice 3082
#define sipName_setDevice &sipStrings_QtPositioning[3082]
#define sipNameNr_setHeight 3092
#define sipName_setHeight &sipStrings_QtPositioning[3092]
#define sipNameNr_setRadius 3102
#define sipName_setRadius &sipStrings_QtPositioning[3102]
#define sipNameNr_setStreet 3112
#define sipName_setStreet &sipStrings_QtPositioning[3112]
#define sipNameNr_timestamp 3122
#define sipName_timestamp &sipStrings_QtPositioning[3122]
#define sipNameNr_translate 3132
#define sipName_translate &sipStrings_QtPositioning[3132]
#define sipNameNr_PathType 3142
#define sipName_PathType &sipStrings_QtPositioning[3142]
#define sipNameNr_QGeoPath 3151
#define sipName_QGeoPath &sipStrings_QtPositioning[3151]
#define sipNameNr___bool__ 3160
#define sipName___bool__ &sipStrings_QtPositioning[3160]
#define sipNameNr___hash__ 3169
#define sipName___hash__ &sipStrings_QtPositioning[3169]
#define sipNameNr___iand__ 3178
#define sipName___iand__ &sipStrings_QtPositioning[3178]
#define sipNameNr___ixor__ 3187
#define sipName___ixor__ &sipStrings_QtPositioning[3187]
#define sipNameNr_altitude 3196
#define sipName_altitude &sipStrings_QtPositioning[3196]
#define sipNameNr_contains 3205
#define sipName_contains &sipStrings_QtPositioning[3205]
#define sipNameNr_district 3214
#define sipName_district &sipStrings_QtPositioning[3214]
#define sipNameNr_holePath 3223
#define sipName_holePath &sipStrings_QtPositioning[3223]
#define sipNameNr_latitude 3232
#define sipName_latitude &sipStrings_QtPositioning[3232]
#define sipNameNr_setState 3241
#define sipName_setState &sipStrings_QtPositioning[3241]
#define sipNameNr_setWidth 3250
#define sipName_setWidth &sipStrings_QtPositioning[3250]
#define sipNameNr_toString 3259
#define sipName_toString &sipStrings_QtPositioning[3259]
#define sipNameNr_topRight 3268
#define sipName_topRight &sipStrings_QtPositioning[3268]
#define sipNameNr_Azimuth 1362
#define sipName_Azimuth &sipStrings_QtPositioning[1362]
#define sipNameNr_Degrees 3277
#define sipName_Degrees &sipStrings_QtPositioning[3277]
#define sipNameNr_GLONASS 3285
#define sipName_GLONASS &sipStrings_QtPositioning[3285]
#define sipNameNr_NoError 3293
#define sipName_NoError &sipStrings_QtPositioning[3293]
#define sipNameNr___and__ 3301
#define sipName___and__ &sipStrings_QtPositioning[3301]
#define sipNameNr___int__ 3309
#define sipName___int__ &sipStrings_QtPositioning[3309]
#define sipNameNr___ior__ 3317
#define sipName___ior__ &sipStrings_QtPositioning[3317]
#define sipNameNr___xor__ 3325
#define sipName___xor__ &sipStrings_QtPositioning[3325]
#define sipNameNr_addHole 3333
#define sipName_addHole &sipStrings_QtPositioning[3333]
#define sipNameNr_address 3341
#define sipName_address &sipStrings_QtPositioning[3341]
#define sipNameNr_country 3349
#define sipName_country &sipStrings_QtPositioning[3349]
#define sipNameNr_indexTo 3357
#define sipName_indexTo &sipStrings_QtPositioning[3357]
#define sipNameNr_isEmpty 3365
#define sipName_isEmpty &sipStrings_QtPositioning[3365]
#define sipNameNr_isValid 3373
#define sipName_isValid &sipStrings_QtPositioning[3373]
#define sipNameNr_setArea 3381
#define sipName_setArea &sipStrings_QtPositioning[3381]
#define sipNameNr_setCity 3389
#define sipName_setCity &sipStrings_QtPositioning[3389]
#define sipNameNr_setName 3397
#define sipName_setName &sipStrings_QtPositioning[3397]
#define sipNameNr_setPath 3405
#define sipName_setPath &sipStrings_QtPositioning[3405]
#define sipNameNr_setText 3413
#define sipName_setText &sipStrings_QtPositioning[3413]
#define sipNameNr_timeout 3421
#define sipName_timeout &sipStrings_QtPositioning[3421]
#define sipNameNr_topLeft 3429
#define sipName_topLeft &sipStrings_QtPositioning[3429]
#define sipNameNr___eq__ 3437
#define sipName___eq__ &sipStrings_QtPositioning[3437]
#define sipNameNr___ne__ 3444
#define sipName___ne__ &sipStrings_QtPositioning[3444]
#define sipNameNr___or__ 3451
#define sipName___or__ &sipStrings_QtPositioning[3451]
#define sipNameNr_center 3458
#define sipName_center &sipStrings_QtPositioning[3458]
#define sipNameNr_county 3465
#define sipName_county &sipStrings_QtPositioning[3465]
#define sipNameNr_device 3472
#define sipName_device &sipStrings_QtPositioning[3472]
#define sipNameNr_format 3479
#define sipName_format &sipStrings_QtPositioning[3479]
#define sipNameNr_height 3486
#define sipName_height &sipStrings_QtPositioning[3486]
#define sipNameNr_length 3493
#define sipName_length &sipStrings_QtPositioning[3493]
#define sipNameNr_parent 3500
#define sipName_parent &sipStrings_QtPositioning[3500]
#define sipNameNr_radius 3507
#define sipName_radius &sipStrings_QtPositioning[3507]
#define sipNameNr_street 3514
#define sipName_street &sipStrings_QtPositioning[3514]
#define sipNameNr_united 3521
#define sipName_united &sipStrings_QtPositioning[3521]
#define sipNameNr_Error 468
#define sipName_Error &sipStrings_QtPositioning[468]
#define sipNameNr_clear 3528
#define sipName_clear &sipStrings_QtPositioning[3528]
#define sipNameNr_error 3534
#define sipName_error &sipStrings_QtPositioning[3534]
#define sipNameNr_event 3540
#define sipName_event &sipStrings_QtPositioning[3540]
#define sipNameNr_state 3546
#define sipName_state &sipStrings_QtPositioning[3546]
#define sipNameNr_width 3552
#define sipName_width &sipStrings_QtPositioning[3552]
#define sipNameNr_area 3558
#define sipName_area &sipStrings_QtPositioning[3558]
#define sipNameNr_city 3563
#define sipName_city &sipStrings_QtPositioning[3563]
#define sipNameNr_hole 3568
#define sipName_hole &sipStrings_QtPositioning[3568]
#define sipNameNr_name 3573
#define sipName_name &sipStrings_QtPositioning[3573]
#define sipNameNr_path 3578
#define sipName_path &sipStrings_QtPositioning[3578]
#define sipNameNr_size 3583
#define sipName_size &sipStrings_QtPositioning[3583]
#define sipNameNr_text 3588
#define sipName_text &sipStrings_QtPositioning[3588]
#define sipNameNr_type 3593
#define sipName_type &sipStrings_QtPositioning[3593]
#define sipNameNr_GPS 3598
#define sipName_GPS &sipStrings_QtPositioning[3598]

#define sipMalloc                   sipAPI_QtPositioning->api_malloc
#define sipFree                     sipAPI_QtPositioning->api_free
#define sipBuildResult              sipAPI_QtPositioning->api_build_result
#define sipCallMethod               sipAPI_QtPositioning->api_call_method
#define sipCallProcedureMethod      sipAPI_QtPositioning->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtPositioning->api_call_error_handler
#define sipParseResultEx            sipAPI_QtPositioning->api_parse_result_ex
#define sipParseResult              sipAPI_QtPositioning->api_parse_result
#define sipParseArgs                sipAPI_QtPositioning->api_parse_args
#define sipParseKwdArgs             sipAPI_QtPositioning->api_parse_kwd_args
#define sipParsePair                sipAPI_QtPositioning->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtPositioning->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtPositioning->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtPositioning->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtPositioning->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtPositioning->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtPositioning->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtPositioning->api_add_exception
#define sipNoFunction               sipAPI_QtPositioning->api_no_function
#define sipNoMethod                 sipAPI_QtPositioning->api_no_method
#define sipAbstractMethod           sipAPI_QtPositioning->api_abstract_method
#define sipBadClass                 sipAPI_QtPositioning->api_bad_class
#define sipBadCatcherResult         sipAPI_QtPositioning->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtPositioning->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtPositioning->api_bad_operator_arg
#define sipTrace                    sipAPI_QtPositioning->api_trace
#define sipTransferBack             sipAPI_QtPositioning->api_transfer_back
#define sipTransferTo               sipAPI_QtPositioning->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtPositioning->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtPositioning->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtPositioning->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtPositioning->api_voidptr_type
#define sipGetPyObject              sipAPI_QtPositioning->api_get_pyobject
#define sipGetAddress               sipAPI_QtPositioning->api_get_address
#define sipGetMixinAddress          sipAPI_QtPositioning->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtPositioning->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtPositioning->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtPositioning->api_call_hook
#define sipEndThread                sipAPI_QtPositioning->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtPositioning->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtPositioning->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtPositioning->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtPositioning->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtPositioning->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtPositioning->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtPositioning->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtPositioning->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtPositioning->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtPositioning->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtPositioning->api_convert_to_bool
#define sipReleaseType              sipAPI_QtPositioning->api_release_type
#define sipConvertFromType          sipAPI_QtPositioning->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtPositioning->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtPositioning->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtPositioning->api_convert_from_enum
#define sipGetState                 sipAPI_QtPositioning->api_get_state
#define sipExportSymbol             sipAPI_QtPositioning->api_export_symbol
#define sipImportSymbol             sipAPI_QtPositioning->api_import_symbol
#define sipFindType                 sipAPI_QtPositioning->api_find_type
#define sipBytes_AsChar             sipAPI_QtPositioning->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtPositioning->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtPositioning->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtPositioning->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtPositioning->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtPositioning->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtPositioning->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtPositioning->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtPositioning->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtPositioning->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtPositioning->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtPositioning->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtPositioning->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtPositioning->api_get_reference
#define sipKeepReference            sipAPI_QtPositioning->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtPositioning->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtPositioning->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtPositioning->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtPositioning->api_type_scope
#define sipResolveTypedef           sipAPI_QtPositioning->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtPositioning->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtPositioning->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtPositioning->api_init_mixin
#define sipExportModule             sipAPI_QtPositioning->api_export_module
#define sipInitModule               sipAPI_QtPositioning->api_init_module
#define sipGetInterpreter           sipAPI_QtPositioning->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtPositioning->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtPositioning->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtPositioning->api_py_type_dict
#define sipPyTypeName               sipAPI_QtPositioning->api_py_type_name
#define sipGetCFunction             sipAPI_QtPositioning->api_get_c_function
#define sipGetMethod                sipAPI_QtPositioning->api_get_method
#define sipFromMethod               sipAPI_QtPositioning->api_from_method
#define sipGetDate                  sipAPI_QtPositioning->api_get_date
#define sipFromDate                 sipAPI_QtPositioning->api_from_date
#define sipGetDateTime              sipAPI_QtPositioning->api_get_datetime
#define sipFromDateTime             sipAPI_QtPositioning->api_from_datetime
#define sipGetTime                  sipAPI_QtPositioning->api_get_time
#define sipFromTime                 sipAPI_QtPositioning->api_from_time
#define sipIsUserType               sipAPI_QtPositioning->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtPositioning->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtPositioning->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtPositioning->api_unicode_write
#define sipUnicodeData              sipAPI_QtPositioning->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtPositioning->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtPositioning->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtPositioning->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtPositioning->api_is_derived_class
#define sipGetUserObject            sipAPI_QtPositioning->api_get_user_object
#define sipSetUserObject            sipAPI_QtPositioning->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtPositioning->api_register_event_handler
#define sipConvertToArray           sipAPI_QtPositioning->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtPositioning->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtPositioning->api_enable_gc
#define sipPrintObject              sipAPI_QtPositioning->api_print_object
#define sipLong_AsChar              sipAPI_QtPositioning->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtPositioning->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtPositioning->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtPositioning->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtPositioning->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtPositioning->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtPositioning->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtPositioning->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtPositioning->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtPositioning->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtPositioning->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtPositioning->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtPositioning->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtPositioning->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtPositioning->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtPositioning->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtPositioning->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtPositioning->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtPositioning->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtPositioning->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtPositioning->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtPositioning->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtPositioning->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtPositioning->api_connect_rx
#define sipConvertRx                sipAPI_QtPositioning->api_convert_rx
#define sipDisconnectRx             sipAPI_QtPositioning->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtPositioning->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtPositioning->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtPositioning->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtPositioning->api_same_slot
#define sipSaveSlot                 sipAPI_QtPositioning->api_save_slot
#define sipVisitSlot                sipAPI_QtPositioning->api_visit_slot
#define sipIsPyMethod               sipAPI_QtPositioning->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtPositioning[];

#define sipType_QGeoAddress sipExportedTypes_QtPositioning[0]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoAddress;

#define sipType_QGeoAreaMonitorInfo sipExportedTypes_QtPositioning[1]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoAreaMonitorInfo;

#define sipType_QGeoAreaMonitorSource sipExportedTypes_QtPositioning[2]

#define sipType_QGeoAreaMonitorSource_AreaMonitorFeature sipExportedTypes_QtPositioning[3]

#define sipType_QGeoAreaMonitorSource_Error sipExportedTypes_QtPositioning[5]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoAreaMonitorSource;

#define sipType_QGeoAreaMonitorSource_AreaMonitorFeatures sipExportedTypes_QtPositioning[4]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoAreaMonitorSource_AreaMonitorFeatures;

#define sipType_QGeoShape sipExportedTypes_QtPositioning[25]

#define sipType_QGeoShape_ShapeType sipExportedTypes_QtPositioning[26]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoShape;

#define sipType_QGeoCircle sipExportedTypes_QtPositioning[6]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoCircle;

#define sipType_QGeoCoordinate sipExportedTypes_QtPositioning[7]

#define sipType_QGeoCoordinate_CoordinateFormat sipExportedTypes_QtPositioning[8]

#define sipType_QGeoCoordinate_CoordinateType sipExportedTypes_QtPositioning[9]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoCoordinate;

#define sipType_QGeoLocation sipExportedTypes_QtPositioning[10]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoLocation;

#define sipType_QGeoPath sipExportedTypes_QtPositioning[11]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoPath;

#define sipType_QGeoPolygon sipExportedTypes_QtPositioning[12]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoPolygon;

#define sipType_QGeoPositionInfo sipExportedTypes_QtPositioning[13]

#define sipType_QGeoPositionInfo_Attribute sipExportedTypes_QtPositioning[14]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoPositionInfo;

#define sipType_QGeoPositionInfoSource sipExportedTypes_QtPositioning[15]

#define sipType_QGeoPositionInfoSource_PositioningMethod sipExportedTypes_QtPositioning[17]

#define sipType_QGeoPositionInfoSource_Error sipExportedTypes_QtPositioning[16]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoPositionInfoSource;

#define sipType_QGeoPositionInfoSource_PositioningMethods sipExportedTypes_QtPositioning[18]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoPositionInfoSource_PositioningMethods;

#define sipType_QGeoRectangle sipExportedTypes_QtPositioning[19]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoRectangle;

#define sipType_QGeoSatelliteInfo sipExportedTypes_QtPositioning[20]

#define sipType_QGeoSatelliteInfo_SatelliteSystem sipExportedTypes_QtPositioning[22]

#define sipType_QGeoSatelliteInfo_Attribute sipExportedTypes_QtPositioning[21]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoSatelliteInfo;

#define sipType_QGeoSatelliteInfoSource sipExportedTypes_QtPositioning[23]

#define sipType_QGeoSatelliteInfoSource_Error sipExportedTypes_QtPositioning[24]

extern sipClassTypeDef sipTypeDef_QtPositioning_QGeoSatelliteInfoSource;

#define sipType_QNmeaPositionInfoSource sipExportedTypes_QtPositioning[30]

#define sipType_QNmeaPositionInfoSource_UpdateMode sipExportedTypes_QtPositioning[31]

extern sipClassTypeDef sipTypeDef_QtPositioning_QNmeaPositionInfoSource;

#define sipType_QList_0100QGeoSatelliteInfo sipExportedTypes_QtPositioning[29]

extern sipMappedTypeDef sipTypeDef_QtPositioning_QList_0100QGeoSatelliteInfo;

#define sipType_QList_0100QGeoCoordinate sipExportedTypes_QtPositioning[28]

extern sipMappedTypeDef sipTypeDef_QtPositioning_QList_0100QGeoCoordinate;

#define sipType_QList_0100QGeoAreaMonitorInfo sipExportedTypes_QtPositioning[27]

extern sipMappedTypeDef sipTypeDef_QtPositioning_QList_0100QGeoAreaMonitorInfo;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtPositioning;
extern sipExportedModuleDef sipModuleAPI_QtPositioning;
extern sipTypeDef *sipExportedTypes_QtPositioning[];

#define sipType_QObject sipImportedTypes_QtPositioning_QtCore[7].it_td

#define sipType_QIODevice sipImportedTypes_QtPositioning_QtCore[4].it_td

#define sipType_QEvent sipImportedTypes_QtPositioning_QtCore[3].it_td

#define sipType_QTimerEvent sipImportedTypes_QtPositioning_QtCore[10].it_td

#define sipType_QChildEvent sipImportedTypes_QtPositioning_QtCore[0].it_td

#define sipType_QDataStream sipImportedTypes_QtPositioning_QtCore[1].it_td

#define sipType_QDateTime sipImportedTypes_QtPositioning_QtCore[2].it_td

#define sipType_QMetaMethod sipImportedTypes_QtPositioning_QtCore[6].it_td

#define sipType_QVariant sipImportedTypes_QtPositioning_QtCore[11].it_td

#define sipType_QList_0100QVariant sipImportedTypes_QtPositioning_QtCore[5].it_td

#define sipType_QVariantMap sipImportedTypes_QtPositioning_QtCore[12].it_td

#define sipType_QStringList sipImportedTypes_QtPositioning_QtCore[9].it_td

#define sipType_QString sipImportedTypes_QtPositioning_QtCore[8].it_td
extern sipImportedTypeDef sipImportedTypes_QtPositioning_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtPositioning_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtPositioning_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtPositioning_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtPositioning_qt_metacast;

#endif
