/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtXmlPatterns.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qxmlquery.sip"
#include <qxmlquery.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlQuery.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qxmlnamepool.sip"
#include <qxmlnamepool.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qnetworkaccessmanager.sip"
#include <qnetworkaccessmanager.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qxmlname.sip"
#include <qxmlname.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlQuery.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlQuery.cpp"
#line 117 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qabstractxmlnodemodel.sip"
#include <qabstractxmlnodemodel.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlQuery.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qabstracturiresolver.sip"
#include <qabstracturiresolver.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qxmlresultitems.sip"
#include <qxmlresultitems.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qabstractxmlreceiver.sip"
#include <qabstractxmlreceiver.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlQuery.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qabstractmessagehandler.sip"
#include <qabstractmessagehandler.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlQuery.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qxmlquery.sip"
// Needed by the evaluateToStringList() %MethodCode.
#include <qstringlist.h>
#line 67 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlQuery.cpp"


PyDoc_STRVAR(doc_QXmlQuery_setMessageHandler, "setMessageHandler(self, messageHandler: Optional[QAbstractMessageHandler])");

extern "C" {static PyObject *meth_QXmlQuery_setMessageHandler(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_setMessageHandler(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractMessageHandler* a0;
        PyObject *a0Keep;
        ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QXmlQuery, &sipCpp, &a0Keep, sipType_QAbstractMessageHandler, &a0))
        {
            sipCpp->setMessageHandler(a0);

            sipKeepReference(sipSelf, -1, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_setMessageHandler, doc_QXmlQuery_setMessageHandler);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_messageHandler, "messageHandler(self) -> Optional[QAbstractMessageHandler]");

extern "C" {static PyObject *meth_QXmlQuery_messageHandler(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_messageHandler(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlQuery, &sipCpp))
        {
            ::QAbstractMessageHandler*sipRes;

            sipRes = sipCpp->messageHandler();

            return sipConvertFromType(sipRes, sipType_QAbstractMessageHandler, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_messageHandler, doc_QXmlQuery_messageHandler);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_setQuery, "setQuery(self, sourceCode: Optional[str], documentUri: QUrl = QUrl())\n"
"setQuery(self, sourceCode: Optional[QIODevice], documentUri: QUrl = QUrl())\n"
"setQuery(self, queryURI: QUrl, baseUri: QUrl = QUrl())");

extern "C" {static PyObject *meth_QXmlQuery_setQuery(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_setQuery(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QUrl& a1def = QUrl();
        const ::QUrl* a1 = &a1def;
        ::QXmlQuery *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_documentUri,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J9", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QString, &a0, &a0State, sipType_QUrl, &a1))
        {
            sipCpp->setQuery(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QIODevice* a0;
        const ::QUrl& a1def = QUrl();
        const ::QUrl* a1 = &a1def;
        ::QXmlQuery *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_documentUri,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|J9", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QIODevice, &a0, sipType_QUrl, &a1))
        {
            sipCpp->setQuery(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QUrl* a0;
        const ::QUrl& a1def = QUrl();
        const ::QUrl* a1 = &a1def;
        ::QXmlQuery *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_baseUri,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|J9", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QUrl, &a0, sipType_QUrl, &a1))
        {
            sipCpp->setQuery(*a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_setQuery, doc_QXmlQuery_setQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_namePool, "namePool(self) -> QXmlNamePool");

extern "C" {static PyObject *meth_QXmlQuery_namePool(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_namePool(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlQuery, &sipCpp))
        {
            ::QXmlNamePool*sipRes;

            sipRes = new ::QXmlNamePool(sipCpp->namePool());

            return sipConvertFromNewType(sipRes, sipType_QXmlNamePool, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_namePool, doc_QXmlQuery_namePool);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_bindVariable, "bindVariable(self, name: QXmlName, value: QXmlItem)\n"
"bindVariable(self, name: QXmlName, a1: Optional[QIODevice])\n"
"bindVariable(self, name: QXmlName, query: QXmlQuery)\n"
"bindVariable(self, localName: Optional[str], value: QXmlItem)\n"
"bindVariable(self, localName: Optional[str], a1: Optional[QIODevice])\n"
"bindVariable(self, localName: Optional[str], query: QXmlQuery)");

extern "C" {static PyObject *meth_QXmlQuery_bindVariable(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_bindVariable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlName* a0;
        const ::QXmlItem* a1;
        ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QXmlName, &a0, sipType_QXmlItem, &a1))
        {
            sipCpp->bindVariable(*a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QXmlName* a0;
        ::QIODevice* a1;
        ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J8", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QXmlName, &a0, sipType_QIODevice, &a1))
        {
            sipCpp->bindVariable(*a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QXmlName* a0;
        const ::QXmlQuery* a1;
        ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QXmlName, &a0, sipType_QXmlQuery, &a1))
        {
            sipCpp->bindVariable(*a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QXmlItem* a1;
        ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J9", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QString, &a0, &a0State, sipType_QXmlItem, &a1))
        {
            sipCpp->bindVariable(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QIODevice* a1;
        ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J8", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QString, &a0, &a0State, sipType_QIODevice, &a1))
        {
            sipCpp->bindVariable(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QXmlQuery* a1;
        ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J9", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QString, &a0, &a0State, sipType_QXmlQuery, &a1))
        {
            sipCpp->bindVariable(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_bindVariable, doc_QXmlQuery_bindVariable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QXmlQuery_isValid(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlQuery, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_isValid, doc_QXmlQuery_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_evaluateTo, "evaluateTo(self, result: Optional[QXmlResultItems])\n"
"evaluateTo(self, callback: Optional[QAbstractXmlReceiver]) -> bool\n"
"evaluateTo(self, target: Optional[QIODevice]) -> bool");

extern "C" {static PyObject *meth_QXmlQuery_evaluateTo(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_evaluateTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QXmlResultItems* a0;
        const ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QXmlResultItems, &a0))
        {
            sipCpp->evaluateTo(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QAbstractXmlReceiver* a0;
        const ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QAbstractXmlReceiver, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->evaluateTo(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QIODevice* a0;
        const ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QIODevice, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->evaluateTo(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_evaluateTo, doc_QXmlQuery_evaluateTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_evaluateToStringList, "evaluateToStringList(self) -> list[str]");

extern "C" {static PyObject *meth_QXmlQuery_evaluateToStringList(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_evaluateToStringList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlQuery, &sipCpp))
        {
            PyObject * sipRes = SIP_NULLPTR;

#line 63 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qxmlquery.sip"
        static const sipTypeDef *sipType_QStringList = 0;
        
        if (!sipType_QStringList)
            sipType_QStringList = sipFindType("QStringList");
        
        bool ok;
        QStringList *result = new QStringList;
        
        Py_BEGIN_ALLOW_THREADS
        ok = sipCpp->evaluateTo(result);
        Py_END_ALLOW_THREADS
        
        if (ok)
        {
            sipRes = sipConvertFromNewType(result, sipType_QStringList, NULL);
        }
        else
        {
            delete result;
            sipRes = Py_None;
            Py_INCREF(Py_None);
        }
#line 455 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlQuery.cpp"

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_evaluateToStringList, doc_QXmlQuery_evaluateToStringList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_evaluateToString, "evaluateToString(self) -> str");

extern "C" {static PyObject *meth_QXmlQuery_evaluateToString(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_evaluateToString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlQuery, &sipCpp))
        {
            PyObject * sipRes = SIP_NULLPTR;

#line 90 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qxmlquery.sip"
        static const sipTypeDef *sipType_QStringList = 0;
        
        if (!sipType_QStringList)
            sipType_QStringList = sipFindType("QStringList");
        
        bool ok;
        QString *result = new QString;
        
        Py_BEGIN_ALLOW_THREADS
        ok = sipCpp->evaluateTo(result);
        Py_END_ALLOW_THREADS
        
        if (ok)
        {
            sipRes = sipConvertFromNewType(result, sipType_QString, NULL);
        }
        else
        {
            delete result;
            sipRes = Py_None;
            Py_INCREF(Py_None);
        }
#line 504 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlQuery.cpp"

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_evaluateToString, doc_QXmlQuery_evaluateToString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_setUriResolver, "setUriResolver(self, resolver: Optional[QAbstractUriResolver])");

extern "C" {static PyObject *meth_QXmlQuery_setUriResolver(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_setUriResolver(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractUriResolver* a0;
        PyObject *a0Keep;
        ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QXmlQuery, &sipCpp, &a0Keep, sipType_QAbstractUriResolver, &a0))
        {
            sipCpp->setUriResolver(a0);

            sipKeepReference(sipSelf, -2, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_setUriResolver, doc_QXmlQuery_setUriResolver);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_uriResolver, "uriResolver(self) -> Optional[QAbstractUriResolver]");

extern "C" {static PyObject *meth_QXmlQuery_uriResolver(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_uriResolver(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlQuery, &sipCpp))
        {
            const ::QAbstractUriResolver*sipRes;

            sipRes = sipCpp->uriResolver();

            return sipConvertFromType(const_cast< ::QAbstractUriResolver *>(sipRes), sipType_QAbstractUriResolver, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_uriResolver, doc_QXmlQuery_uriResolver);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_setFocus, "setFocus(self, item: QXmlItem)\n"
"setFocus(self, documentURI: QUrl) -> bool\n"
"setFocus(self, document: Optional[QIODevice]) -> bool\n"
"setFocus(self, focus: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QXmlQuery_setFocus(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_setFocus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlItem* a0;
        ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QXmlItem, &a0))
        {
            sipCpp->setFocus(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QUrl* a0;
        ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QUrl, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->setFocus(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QIODevice* a0;
        ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QIODevice, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->setFocus(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->setFocus(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_setFocus, doc_QXmlQuery_setFocus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_setInitialTemplateName, "setInitialTemplateName(self, name: QXmlName)\n"
"setInitialTemplateName(self, name: Optional[str])");

extern "C" {static PyObject *meth_QXmlQuery_setInitialTemplateName(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_setInitialTemplateName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlName* a0;
        ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QXmlName, &a0))
        {
            sipCpp->setInitialTemplateName(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlQuery, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setInitialTemplateName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_setInitialTemplateName, doc_QXmlQuery_setInitialTemplateName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_initialTemplateName, "initialTemplateName(self) -> QXmlName");

extern "C" {static PyObject *meth_QXmlQuery_initialTemplateName(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_initialTemplateName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlQuery, &sipCpp))
        {
            ::QXmlName*sipRes;

            sipRes = new ::QXmlName(sipCpp->initialTemplateName());

            return sipConvertFromNewType(sipRes, sipType_QXmlName, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_initialTemplateName, doc_QXmlQuery_initialTemplateName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_setNetworkAccessManager, "setNetworkAccessManager(self, newManager: Optional[QNetworkAccessManager])");

extern "C" {static PyObject *meth_QXmlQuery_setNetworkAccessManager(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_setNetworkAccessManager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QNetworkAccessManager* a0;
        PyObject *a0Keep;
        ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QXmlQuery, &sipCpp, &a0Keep, sipType_QNetworkAccessManager, &a0))
        {
            sipCpp->setNetworkAccessManager(a0);

            sipKeepReference(sipSelf, -3, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_setNetworkAccessManager, doc_QXmlQuery_setNetworkAccessManager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_networkAccessManager, "networkAccessManager(self) -> Optional[QNetworkAccessManager]");

extern "C" {static PyObject *meth_QXmlQuery_networkAccessManager(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_networkAccessManager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlQuery, &sipCpp))
        {
            ::QNetworkAccessManager*sipRes;

            sipRes = sipCpp->networkAccessManager();

            return sipConvertFromType(sipRes, sipType_QNetworkAccessManager, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_networkAccessManager, doc_QXmlQuery_networkAccessManager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlQuery_queryLanguage, "queryLanguage(self) -> QXmlQuery.QueryLanguage");

extern "C" {static PyObject *meth_QXmlQuery_queryLanguage(PyObject *, PyObject *);}
static PyObject *meth_QXmlQuery_queryLanguage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlQuery *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlQuery, &sipCpp))
        {
            ::QXmlQuery::QueryLanguage sipRes;

            sipRes = sipCpp->queryLanguage();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QXmlQuery_QueryLanguage);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlQuery, sipName_queryLanguage, doc_QXmlQuery_queryLanguage);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QXmlQuery(void *, int);}
static void release_QXmlQuery(void *sipCppV, int)
{
    delete reinterpret_cast< ::QXmlQuery *>(sipCppV);
}


extern "C" {static void *array_QXmlQuery(Py_ssize_t);}
static void *array_QXmlQuery(Py_ssize_t sipNrElem)
{
    return new ::QXmlQuery[sipNrElem];
}


extern "C" {static void array_delete_QXmlQuery(void *);}
static void array_delete_QXmlQuery(void *sipCpp)
{
    delete[] reinterpret_cast< ::QXmlQuery *>(sipCpp);
}


extern "C" {static void assign_QXmlQuery(void *, Py_ssize_t, void *);}
static void assign_QXmlQuery(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QXmlQuery *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QXmlQuery *>(sipSrc);
}


extern "C" {static void *copy_QXmlQuery(const void *, Py_ssize_t);}
static void *copy_QXmlQuery(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QXmlQuery(reinterpret_cast<const ::QXmlQuery *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QXmlQuery(sipSimpleWrapper *);}
static void dealloc_QXmlQuery(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QXmlQuery(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QXmlQuery(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QXmlQuery(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QXmlQuery *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QXmlQuery();

            return sipCpp;
        }
    }

    {
        const ::QXmlQuery* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QXmlQuery, &a0))
        {
            sipCpp = new ::QXmlQuery(*a0);

            return sipCpp;
        }
    }

    {
        const ::QXmlNamePool* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QXmlNamePool, &a0))
        {
            sipCpp = new ::QXmlQuery(*a0);

            return sipCpp;
        }
    }

    {
        ::QXmlQuery::QueryLanguage a0;
        const ::QXmlNamePool& a1def = QXmlNamePool();
        const ::QXmlNamePool* a1 = &a1def;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_pool,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "E|J9", sipType_QXmlQuery_QueryLanguage, &a0, sipType_QXmlNamePool, &a1))
        {
            sipCpp = new ::QXmlQuery(a0, *a1);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QXmlQuery[] = {
    {sipName_bindVariable, meth_QXmlQuery_bindVariable, METH_VARARGS, doc_QXmlQuery_bindVariable},
    {sipName_evaluateTo, meth_QXmlQuery_evaluateTo, METH_VARARGS, doc_QXmlQuery_evaluateTo},
    {sipName_evaluateToString, meth_QXmlQuery_evaluateToString, METH_VARARGS, doc_QXmlQuery_evaluateToString},
    {sipName_evaluateToStringList, meth_QXmlQuery_evaluateToStringList, METH_VARARGS, doc_QXmlQuery_evaluateToStringList},
    {sipName_initialTemplateName, meth_QXmlQuery_initialTemplateName, METH_VARARGS, doc_QXmlQuery_initialTemplateName},
    {sipName_isValid, meth_QXmlQuery_isValid, METH_VARARGS, doc_QXmlQuery_isValid},
    {sipName_messageHandler, meth_QXmlQuery_messageHandler, METH_VARARGS, doc_QXmlQuery_messageHandler},
    {sipName_namePool, meth_QXmlQuery_namePool, METH_VARARGS, doc_QXmlQuery_namePool},
    {sipName_networkAccessManager, meth_QXmlQuery_networkAccessManager, METH_VARARGS, doc_QXmlQuery_networkAccessManager},
    {sipName_queryLanguage, meth_QXmlQuery_queryLanguage, METH_VARARGS, doc_QXmlQuery_queryLanguage},
    {sipName_setFocus, meth_QXmlQuery_setFocus, METH_VARARGS, doc_QXmlQuery_setFocus},
    {sipName_setInitialTemplateName, meth_QXmlQuery_setInitialTemplateName, METH_VARARGS, doc_QXmlQuery_setInitialTemplateName},
    {sipName_setMessageHandler, meth_QXmlQuery_setMessageHandler, METH_VARARGS, doc_QXmlQuery_setMessageHandler},
    {sipName_setNetworkAccessManager, meth_QXmlQuery_setNetworkAccessManager, METH_VARARGS, doc_QXmlQuery_setNetworkAccessManager},
    {sipName_setQuery, SIP_MLMETH_CAST(meth_QXmlQuery_setQuery), METH_VARARGS|METH_KEYWORDS, doc_QXmlQuery_setQuery},
    {sipName_setUriResolver, meth_QXmlQuery_setUriResolver, METH_VARARGS, doc_QXmlQuery_setUriResolver},
    {sipName_uriResolver, meth_QXmlQuery_uriResolver, METH_VARARGS, doc_QXmlQuery_uriResolver}
};

static sipEnumMemberDef enummembers_QXmlQuery[] = {
    {sipName_XQuery10, static_cast<int>(::QXmlQuery::XQuery10), 17},
    {sipName_XSLT20, static_cast<int>(::QXmlQuery::XSLT20), 17},
};

PyDoc_STRVAR(doc_QXmlQuery, "\1QXmlQuery()\n"
"QXmlQuery(other: QXmlQuery)\n"
"QXmlQuery(np: QXmlNamePool)\n"
"QXmlQuery(queryLanguage: QXmlQuery.QueryLanguage, pool: QXmlNamePool = QXmlNamePool())");


static pyqt5ClassPluginDef plugin_QXmlQuery = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtXmlPatterns_QXmlQuery = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QXmlQuery,
        SIP_NULLPTR,
        &plugin_QXmlQuery,
    },
    {
        sipNameNr_QXmlQuery,
        {0, 0, 1},
        17, methods_QXmlQuery,
        2, enummembers_QXmlQuery,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QXmlQuery,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QXmlQuery,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QXmlQuery,
    assign_QXmlQuery,
    array_QXmlQuery,
    copy_QXmlQuery,
    release_QXmlQuery,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QXmlQuery,
    sizeof (::QXmlQuery),
};
