/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDBus.h"

#line 24 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDBus/qpydbusreply.sip"
#include <qpydbusreply.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDBus/sipQtDBusQPyDBusReply.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDBus/qdbusmessage.sip"
#include <qdbusmessage.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDBus/sipQtDBusQPyDBusReply.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDBus/qdbuspendingcall.sip"
#include <qdbuspendingcall.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDBus/sipQtDBusQPyDBusReply.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDBus/qdbuserror.sip"
#include <qdbuserror.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDBus/sipQtDBusQPyDBusReply.cpp"


PyDoc_STRVAR(doc_QPyDBusReply_error, "error(self) -> QDBusError");

extern "C" {static PyObject *meth_QPyDBusReply_error(PyObject *, PyObject *);}
static PyObject *meth_QPyDBusReply_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPyDBusReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPyDBusReply, &sipCpp))
        {
            ::QDBusError*sipRes;

            sipRes = new ::QDBusError(sipCpp->error());

            return sipConvertFromNewType(sipRes, sipType_QDBusError, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDBusReply, sipName_error, doc_QPyDBusReply_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPyDBusReply_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QPyDBusReply_isValid(PyObject *, PyObject *);}
static PyObject *meth_QPyDBusReply_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPyDBusReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPyDBusReply, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDBusReply, sipName_isValid, doc_QPyDBusReply_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPyDBusReply_value, "value(self, type: Any = None) -> Any");

extern "C" {static PyObject *meth_QPyDBusReply_value(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QPyDBusReply_value(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0 = 0;
        const ::QPyDBusReply *sipCpp;

        static const char *sipKwdList[] = {
            sipName_type,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|P0", &sipSelf, sipType_QPyDBusReply, &sipCpp, &a0))
        {
            PyObject * sipRes;

            sipRes = sipCpp->value(a0);

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDBusReply, sipName_value, doc_QPyDBusReply_value);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPyDBusReply(void *, int);}
static void release_QPyDBusReply(void *sipCppV, int)
{
    delete reinterpret_cast< ::QPyDBusReply *>(sipCppV);
}


extern "C" {static void assign_QPyDBusReply(void *, Py_ssize_t, void *);}
static void assign_QPyDBusReply(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPyDBusReply *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPyDBusReply *>(sipSrc);
}


extern "C" {static void *copy_QPyDBusReply(const void *, Py_ssize_t);}
static void *copy_QPyDBusReply(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPyDBusReply(reinterpret_cast<const ::QPyDBusReply *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPyDBusReply(sipSimpleWrapper *);}
static void dealloc_QPyDBusReply(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPyDBusReply(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QPyDBusReply(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPyDBusReply(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QPyDBusReply *sipCpp = SIP_NULLPTR;

    {
        const ::QDBusMessage* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QDBusMessage, &a0))
        {
            sipCpp = new ::QPyDBusReply(*a0);

            return sipCpp;
        }
    }

    {
        const ::QDBusPendingCall* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QDBusPendingCall, &a0))
        {
            sipCpp = new ::QPyDBusReply(*a0);

            return sipCpp;
        }
    }

    {
        const ::QDBusError* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QDBusError, &a0))
        {
            sipCpp = new ::QPyDBusReply(*a0);

            return sipCpp;
        }
    }

    {
        const ::QPyDBusReply* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPyDBusReply, &a0))
        {
            sipCpp = new ::QPyDBusReply(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QPyDBusReply[] = {
    {sipName_error, meth_QPyDBusReply_error, METH_VARARGS, doc_QPyDBusReply_error},
    {sipName_isValid, meth_QPyDBusReply_isValid, METH_VARARGS, doc_QPyDBusReply_isValid},
    {sipName_value, SIP_MLMETH_CAST(meth_QPyDBusReply_value), METH_VARARGS|METH_KEYWORDS, doc_QPyDBusReply_value}
};

PyDoc_STRVAR(doc_QPyDBusReply, "\1QDBusReply(reply: QDBusMessage)\n"
"QDBusReply(call: QDBusPendingCall)\n"
"QDBusReply(error: QDBusError)\n"
"QDBusReply(other: QDBusReply)");


static pyqt5ClassPluginDef plugin_QPyDBusReply = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDBus_QPyDBusReply = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPyDBusReply,
        SIP_NULLPTR,
        &plugin_QPyDBusReply,
    },
    {
        sipNameNr_QDBusReply,
        {0, 0, 1},
        3, methods_QPyDBusReply,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPyDBusReply,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QPyDBusReply,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPyDBusReply,
    assign_QPyDBusReply,
    SIP_NULLPTR,
    copy_QPyDBusReply,
    release_QPyDBusReply,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QPyDBusReply),
};
