/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmultimedia.sip"
#include <qmultimedia.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMultimedia.cpp"


static sipEnumMemberDef enummembers_QMultimedia[] = {
    {sipName_Available, static_cast<int>(::QMultimedia::Available), 134},
    {sipName_AverageBitRateEncoding, static_cast<int>(::QMultimedia::AverageBitRateEncoding), 135},
    {sipName_Busy, static_cast<int>(::QMultimedia::Busy), 134},
    {sipName_ConstantBitRateEncoding, static_cast<int>(::QMultimedia::ConstantBitRateEncoding), 135},
    {sipName_ConstantQualityEncoding, static_cast<int>(::QMultimedia::ConstantQualityEncoding), 135},
    {sipName_HighQuality, static_cast<int>(::QMultimedia::HighQuality), 136},
    {sipName_LowQuality, static_cast<int>(::QMultimedia::LowQuality), 136},
    {sipName_MaybeSupported, static_cast<int>(::QMultimedia::MaybeSupported), 137},
    {sipName_NormalQuality, static_cast<int>(::QMultimedia::NormalQuality), 136},
    {sipName_NotSupported, static_cast<int>(::QMultimedia::NotSupported), 137},
    {sipName_PreferredService, static_cast<int>(::QMultimedia::PreferredService), 137},
    {sipName_ProbablySupported, static_cast<int>(::QMultimedia::ProbablySupported), 137},
    {sipName_ResourceError, static_cast<int>(::QMultimedia::ResourceError), 134},
    {sipName_ServiceMissing, static_cast<int>(::QMultimedia::ServiceMissing), 134},
    {sipName_TwoPassEncoding, static_cast<int>(::QMultimedia::TwoPassEncoding), 135},
    {sipName_VeryHighQuality, static_cast<int>(::QMultimedia::VeryHighQuality), 136},
    {sipName_VeryLowQuality, static_cast<int>(::QMultimedia::VeryLowQuality), 136},
};


static pyqt5ClassPluginDef plugin_QMultimedia = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QMultimedia = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_NAMESPACE,
        sipNameNr_QMultimedia,
        SIP_NULLPTR,
        &plugin_QMultimedia,
    },
    {
        sipNameNr_QMultimedia,
        {0, 0, 1},
        0, SIP_NULLPTR,
        17, enummembers_QMultimedia,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
