/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPositioning.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeopath.sip"
#include <qgeopath.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPositioning/sipQtPositioningQGeoPath.cpp"

#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPositioning/sipQtPositioningQGeoPath.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeocoordinate.sip"
#include <qgeocoordinate.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPositioning/sipQtPositioningQGeoPath.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeoshape.sip"
#include <qgeoshape.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPositioning/sipQtPositioningQGeoPath.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPositioning/sipQtPositioningQGeoPath.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeorectangle.sip"
#include <qgeorectangle.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPositioning/sipQtPositioningQGeoPath.cpp"


PyDoc_STRVAR(doc_QGeoPath_setPath, "setPath(self, path: Iterable[QGeoCoordinate])");

extern "C" {static PyObject *meth_QGeoPath_setPath(PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_setPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QGeoCoordinate>* a0;
        int a0State = 0;
        ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoPath, &sipCpp, sipType_QList_0100QGeoCoordinate, &a0, &a0State))
        {
            sipCpp->setPath(*a0);
            sipReleaseType(const_cast<QList< ::QGeoCoordinate> *>(a0), sipType_QList_0100QGeoCoordinate, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_setPath, doc_QGeoPath_setPath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoPath_path, "path(self) -> list[QGeoCoordinate]");

extern "C" {static PyObject *meth_QGeoPath_path(PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_path(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoPath, &sipCpp))
        {
            QList< ::QGeoCoordinate>*sipRes;

            sipRes = new QList< ::QGeoCoordinate>(sipCpp->path());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QGeoCoordinate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_path, doc_QGeoPath_path);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoPath_setWidth, "setWidth(self, width: float)");

extern "C" {static PyObject *meth_QGeoPath_setWidth(PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_setWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QGeoPath, &sipCpp, &a0))
        {
            sipCpp->setWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_setWidth, doc_QGeoPath_setWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoPath_width, "width(self) -> float");

extern "C" {static PyObject *meth_QGeoPath_width(PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_width(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoPath, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->width();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_width, doc_QGeoPath_width);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoPath_translate, "translate(self, degreesLatitude: float, degreesLongitude: float)");

extern "C" {static PyObject *meth_QGeoPath_translate(PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_translate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        double a1;
        ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QGeoPath, &sipCpp, &a0, &a1))
        {
            sipCpp->translate(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_translate, doc_QGeoPath_translate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoPath_translated, "translated(self, degreesLatitude: float, degreesLongitude: float) -> QGeoPath");

extern "C" {static PyObject *meth_QGeoPath_translated(PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_translated(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        double a1;
        const ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QGeoPath, &sipCpp, &a0, &a1))
        {
            ::QGeoPath*sipRes;

            sipRes = new ::QGeoPath(sipCpp->translated(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QGeoPath, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_translated, doc_QGeoPath_translated);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoPath_length, "length(self, indexFrom: int = 0, indexTo: int = -1) -> float");

extern "C" {static PyObject *meth_QGeoPath_length(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_length(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = 0;
        int a1 = -1;
        const ::QGeoPath *sipCpp;

        static const char *sipKwdList[] = {
            sipName_indexFrom,
            sipName_indexTo,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|ii", &sipSelf, sipType_QGeoPath, &sipCpp, &a0, &a1))
        {
            double sipRes;

            sipRes = sipCpp->length(a0, a1);

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_length, doc_QGeoPath_length);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoPath_addCoordinate, "addCoordinate(self, coordinate: QGeoCoordinate)");

extern "C" {static PyObject *meth_QGeoPath_addCoordinate(PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_addCoordinate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCoordinate* a0;
        ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoPath, &sipCpp, sipType_QGeoCoordinate, &a0))
        {
            sipCpp->addCoordinate(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_addCoordinate, doc_QGeoPath_addCoordinate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoPath_insertCoordinate, "insertCoordinate(self, index: int, coordinate: QGeoCoordinate)");

extern "C" {static PyObject *meth_QGeoPath_insertCoordinate(PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_insertCoordinate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QGeoCoordinate* a1;
        ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ9", &sipSelf, sipType_QGeoPath, &sipCpp, &a0, sipType_QGeoCoordinate, &a1))
        {
            sipCpp->insertCoordinate(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_insertCoordinate, doc_QGeoPath_insertCoordinate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoPath_replaceCoordinate, "replaceCoordinate(self, index: int, coordinate: QGeoCoordinate)");

extern "C" {static PyObject *meth_QGeoPath_replaceCoordinate(PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_replaceCoordinate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QGeoCoordinate* a1;
        ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ9", &sipSelf, sipType_QGeoPath, &sipCpp, &a0, sipType_QGeoCoordinate, &a1))
        {
            sipCpp->replaceCoordinate(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_replaceCoordinate, doc_QGeoPath_replaceCoordinate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoPath_coordinateAt, "coordinateAt(self, index: int) -> QGeoCoordinate");

extern "C" {static PyObject *meth_QGeoPath_coordinateAt(PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_coordinateAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QGeoPath, &sipCpp, &a0))
        {
            ::QGeoCoordinate*sipRes;

            sipRes = new ::QGeoCoordinate(sipCpp->coordinateAt(a0));

            return sipConvertFromNewType(sipRes, sipType_QGeoCoordinate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_coordinateAt, doc_QGeoPath_coordinateAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoPath_containsCoordinate, "containsCoordinate(self, coordinate: QGeoCoordinate) -> bool");

extern "C" {static PyObject *meth_QGeoPath_containsCoordinate(PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_containsCoordinate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCoordinate* a0;
        const ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoPath, &sipCpp, sipType_QGeoCoordinate, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->containsCoordinate(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_containsCoordinate, doc_QGeoPath_containsCoordinate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoPath_removeCoordinate, "removeCoordinate(self, coordinate: QGeoCoordinate)\n"
"removeCoordinate(self, index: int)");

extern "C" {static PyObject *meth_QGeoPath_removeCoordinate(PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_removeCoordinate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCoordinate* a0;
        ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoPath, &sipCpp, sipType_QGeoCoordinate, &a0))
        {
            sipCpp->removeCoordinate(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QGeoPath, &sipCpp, &a0))
        {
            sipCpp->removeCoordinate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_removeCoordinate, doc_QGeoPath_removeCoordinate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoPath_toString, "toString(self) -> str");

extern "C" {static PyObject *meth_QGeoPath_toString(PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_toString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoPath, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_toString, doc_QGeoPath_toString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoPath_size, "size(self) -> int");

extern "C" {static PyObject *meth_QGeoPath_size(PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_size(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoPath, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->size();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_size, doc_QGeoPath_size);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoPath_clearPath, "clearPath(self)");

extern "C" {static PyObject *meth_QGeoPath_clearPath(PyObject *, PyObject *);}
static PyObject *meth_QGeoPath_clearPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoPath, &sipCpp))
        {
            sipCpp->clearPath();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoPath, sipName_clearPath, doc_QGeoPath_clearPath);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QGeoPath___ne__(PyObject *, PyObject *);}
static PyObject *slot_QGeoPath___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoPath *sipCpp = reinterpret_cast< ::QGeoPath *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoPath));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoPath* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGeoPath, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QGeoPath::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtPositioning, ne_slot, sipType_QGeoPath, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QGeoPath___eq__(PyObject *, PyObject *);}
static PyObject *slot_QGeoPath___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoPath *sipCpp = reinterpret_cast< ::QGeoPath *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoPath));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoPath* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGeoPath, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QGeoPath::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtPositioning, eq_slot, sipType_QGeoPath, sipSelf, sipArg);
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGeoPath(void *, const sipTypeDef *);}
static void *cast_QGeoPath(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGeoPath *sipCpp = reinterpret_cast< ::QGeoPath *>(sipCppV);

    if (targetType == sipType_QGeoPath)
        return sipCppV;

    if (targetType == sipType_QGeoShape)
        return static_cast< ::QGeoShape *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoPath(void *, int);}
static void release_QGeoPath(void *sipCppV, int)
{
    delete reinterpret_cast< ::QGeoPath *>(sipCppV);
}


extern "C" {static void *array_QGeoPath(Py_ssize_t);}
static void *array_QGeoPath(Py_ssize_t sipNrElem)
{
    return new ::QGeoPath[sipNrElem];
}


extern "C" {static void array_delete_QGeoPath(void *);}
static void array_delete_QGeoPath(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGeoPath *>(sipCpp);
}


extern "C" {static void assign_QGeoPath(void *, Py_ssize_t, void *);}
static void assign_QGeoPath(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QGeoPath *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QGeoPath *>(sipSrc);
}


extern "C" {static void *copy_QGeoPath(const void *, Py_ssize_t);}
static void *copy_QGeoPath(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QGeoPath(reinterpret_cast<const ::QGeoPath *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QGeoPath(sipSimpleWrapper *);}
static void dealloc_QGeoPath(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoPath(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QGeoPath(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoPath(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QGeoPath *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QGeoPath();

            return sipCpp;
        }
    }

    {
        const QList< ::QGeoCoordinate>* a0;
        int a0State = 0;
        ::qreal a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_width,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|d", sipType_QList_0100QGeoCoordinate, &a0, &a0State, &a1))
        {
            sipCpp = new ::QGeoPath(*a0, a1);
            sipReleaseType(const_cast<QList< ::QGeoCoordinate> *>(a0), sipType_QList_0100QGeoCoordinate, a0State);

            return sipCpp;
        }
    }

    {
        const ::QGeoPath* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QGeoPath, &a0))
        {
            sipCpp = new ::QGeoPath(*a0);

            return sipCpp;
        }
    }

    {
        const ::QGeoShape* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QGeoShape, &a0))
        {
            sipCpp = new ::QGeoPath(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGeoPath[] = {{25, 255, 1}};


/* Define this type's Python slots. */
static sipPySlotDef slots_QGeoPath[] = {
    {(void *)slot_QGeoPath___ne__, ne_slot},
    {(void *)slot_QGeoPath___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QGeoPath[] = {
    {sipName_addCoordinate, meth_QGeoPath_addCoordinate, METH_VARARGS, doc_QGeoPath_addCoordinate},
    {sipName_clearPath, meth_QGeoPath_clearPath, METH_VARARGS, doc_QGeoPath_clearPath},
    {sipName_containsCoordinate, meth_QGeoPath_containsCoordinate, METH_VARARGS, doc_QGeoPath_containsCoordinate},
    {sipName_coordinateAt, meth_QGeoPath_coordinateAt, METH_VARARGS, doc_QGeoPath_coordinateAt},
    {sipName_insertCoordinate, meth_QGeoPath_insertCoordinate, METH_VARARGS, doc_QGeoPath_insertCoordinate},
    {sipName_length, SIP_MLMETH_CAST(meth_QGeoPath_length), METH_VARARGS|METH_KEYWORDS, doc_QGeoPath_length},
    {sipName_path, meth_QGeoPath_path, METH_VARARGS, doc_QGeoPath_path},
    {sipName_removeCoordinate, meth_QGeoPath_removeCoordinate, METH_VARARGS, doc_QGeoPath_removeCoordinate},
    {sipName_replaceCoordinate, meth_QGeoPath_replaceCoordinate, METH_VARARGS, doc_QGeoPath_replaceCoordinate},
    {sipName_setPath, meth_QGeoPath_setPath, METH_VARARGS, doc_QGeoPath_setPath},
    {sipName_setWidth, meth_QGeoPath_setWidth, METH_VARARGS, doc_QGeoPath_setWidth},
    {sipName_size, meth_QGeoPath_size, METH_VARARGS, doc_QGeoPath_size},
    {sipName_toString, meth_QGeoPath_toString, METH_VARARGS, doc_QGeoPath_toString},
    {sipName_translate, meth_QGeoPath_translate, METH_VARARGS, doc_QGeoPath_translate},
    {sipName_translated, meth_QGeoPath_translated, METH_VARARGS, doc_QGeoPath_translated},
    {sipName_width, meth_QGeoPath_width, METH_VARARGS, doc_QGeoPath_width}
};

PyDoc_STRVAR(doc_QGeoPath, "\1QGeoPath()\n"
"QGeoPath(path: Iterable[QGeoCoordinate], width: float = 0)\n"
"QGeoPath(other: QGeoPath)\n"
"QGeoPath(other: QGeoShape)");


static pyqt5ClassPluginDef plugin_QGeoPath = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtPositioning_QGeoPath = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoPath,
        SIP_NULLPTR,
        &plugin_QGeoPath,
    },
    {
        sipNameNr_QGeoPath,
        {0, 0, 1},
        16, methods_QGeoPath,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoPath,
    -1,
    -1,
    supers_QGeoPath,
    slots_QGeoPath,
    init_type_QGeoPath,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoPath,
    assign_QGeoPath,
    array_QGeoPath,
    copy_QGeoPath,
    release_QGeoPath,
    cast_QGeoPath,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGeoPath,
    sizeof (::QGeoPath),
};
