/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstylepainter.sip"
#include <qstylepainter.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 712 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qglyphrun.sip"
#include <qglyphrun.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qstatictext.sip"
#include <qstatictext.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 512 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qtransform.sip"
#include <qtransform.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qimage.sip"
#include <qimage.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qline.sip"
#include <qline.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qline.sip"
#include <qline.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 123 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qtextoption.sip"
#include <qtextoption.h>
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpicture.sip"
#include <qpicture.h>
#line 122 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 329 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpolygon.sip"
#include <qpolygon.h>
#line 125 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpolygon.sip"
#include <qpolygon.h>
#line 128 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 131 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpen.sip"
#include <qpen.h>
#line 134 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 137 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 140 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 143 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQStylePainter.cpp"


PyDoc_STRVAR(doc_QStylePainter_begin, "begin(self, w: Optional[QWidget]) -> bool\n"
"begin(self, pd: Optional[QPaintDevice], w: Optional[QWidget]) -> bool");

extern "C" {static PyObject *meth_QStylePainter_begin(PyObject *, PyObject *);}
static PyObject *meth_QStylePainter_begin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        ::QStylePainter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QStylePainter, &sipCpp, sipType_QWidget, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->begin(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QPaintDevice* a0;
        ::QWidget* a1;
        ::QStylePainter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J8", &sipSelf, sipType_QStylePainter, &sipCpp, sipType_QPaintDevice, &a0, sipType_QWidget, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->begin(a0, a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStylePainter, sipName_begin, doc_QStylePainter_begin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStylePainter_style, "style(self) -> Optional[QStyle]");

extern "C" {static PyObject *meth_QStylePainter_style(PyObject *, PyObject *);}
static PyObject *meth_QStylePainter_style(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStylePainter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStylePainter, &sipCpp))
        {
            ::QStyle*sipRes;

            sipRes = sipCpp->style();

            return sipConvertFromType(sipRes, sipType_QStyle, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStylePainter, sipName_style, doc_QStylePainter_style);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStylePainter_drawPrimitive, "drawPrimitive(self, pe: QStyle.PrimitiveElement, opt: QStyleOption)");

extern "C" {static PyObject *meth_QStylePainter_drawPrimitive(PyObject *, PyObject *);}
static PyObject *meth_QStylePainter_drawPrimitive(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStyle::PrimitiveElement a0;
        const ::QStyleOption* a1;
        ::QStylePainter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ9", &sipSelf, sipType_QStylePainter, &sipCpp, sipType_QStyle_PrimitiveElement, &a0, sipType_QStyleOption, &a1))
        {
            sipCpp->drawPrimitive(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStylePainter, sipName_drawPrimitive, doc_QStylePainter_drawPrimitive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStylePainter_drawControl, "drawControl(self, ce: QStyle.ControlElement, opt: QStyleOption)");

extern "C" {static PyObject *meth_QStylePainter_drawControl(PyObject *, PyObject *);}
static PyObject *meth_QStylePainter_drawControl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStyle::ControlElement a0;
        const ::QStyleOption* a1;
        ::QStylePainter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ9", &sipSelf, sipType_QStylePainter, &sipCpp, sipType_QStyle_ControlElement, &a0, sipType_QStyleOption, &a1))
        {
            sipCpp->drawControl(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStylePainter, sipName_drawControl, doc_QStylePainter_drawControl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStylePainter_drawComplexControl, "drawComplexControl(self, cc: QStyle.ComplexControl, opt: QStyleOptionComplex)");

extern "C" {static PyObject *meth_QStylePainter_drawComplexControl(PyObject *, PyObject *);}
static PyObject *meth_QStylePainter_drawComplexControl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStyle::ComplexControl a0;
        const ::QStyleOptionComplex* a1;
        ::QStylePainter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ9", &sipSelf, sipType_QStylePainter, &sipCpp, sipType_QStyle_ComplexControl, &a0, sipType_QStyleOptionComplex, &a1))
        {
            sipCpp->drawComplexControl(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStylePainter, sipName_drawComplexControl, doc_QStylePainter_drawComplexControl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStylePainter_drawItemText, "drawItemText(self, rect: QRect, flags: int, pal: QPalette, enabled: bool, text: Optional[str], textRole: QPalette.ColorRole = QPalette.NoRole)");

extern "C" {static PyObject *meth_QStylePainter_drawItemText(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStylePainter_drawItemText(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRect* a0;
        int a1;
        const ::QPalette* a2;
        bool a3;
        const ::QString* a4;
        int a4State = 0;
        ::QPalette::ColorRole a5 = QPalette::NoRole;
        ::QStylePainter *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_textRole,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9iJ9bJ1|E", &sipSelf, sipType_QStylePainter, &sipCpp, sipType_QRect, &a0, &a1, sipType_QPalette, &a2, &a3, sipType_QString, &a4, &a4State, sipType_QPalette_ColorRole, &a5))
        {
            sipCpp->drawItemText(*a0, a1, *a2, a3, *a4, a5);
            sipReleaseType(const_cast< ::QString *>(a4), sipType_QString, a4State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStylePainter, sipName_drawItemText, doc_QStylePainter_drawItemText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStylePainter_drawItemPixmap, "drawItemPixmap(self, r: QRect, flags: int, pixmap: QPixmap)");

extern "C" {static PyObject *meth_QStylePainter_drawItemPixmap(PyObject *, PyObject *);}
static PyObject *meth_QStylePainter_drawItemPixmap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRect* a0;
        int a1;
        const ::QPixmap* a2;
        ::QStylePainter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9iJ9", &sipSelf, sipType_QStylePainter, &sipCpp, sipType_QRect, &a0, &a1, sipType_QPixmap, &a2))
        {
            sipCpp->drawItemPixmap(*a0, a1, *a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStylePainter, sipName_drawItemPixmap, doc_QStylePainter_drawItemPixmap);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QStylePainter(void *, const sipTypeDef *);}
static void *cast_QStylePainter(void *sipCppV, const sipTypeDef *targetType)
{
    ::QStylePainter *sipCpp = reinterpret_cast< ::QStylePainter *>(sipCppV);

    if (targetType == sipType_QStylePainter)
        return sipCppV;

    if (targetType == sipType_QPainter)
        return static_cast< ::QPainter *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QStylePainter(void *, int);}
static void release_QStylePainter(void *sipCppV, int)
{
    delete reinterpret_cast< ::QStylePainter *>(sipCppV);
}


extern "C" {static void *array_QStylePainter(Py_ssize_t);}
static void *array_QStylePainter(Py_ssize_t sipNrElem)
{
    return new ::QStylePainter[sipNrElem];
}


extern "C" {static void array_delete_QStylePainter(void *);}
static void array_delete_QStylePainter(void *sipCpp)
{
    delete[] reinterpret_cast< ::QStylePainter *>(sipCpp);
}


extern "C" {static void dealloc_QStylePainter(sipSimpleWrapper *);}
static void dealloc_QStylePainter(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QStylePainter(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QStylePainter(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QStylePainter(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QStylePainter *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QStylePainter();

            return sipCpp;
        }
    }

    {
        ::QWidget* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J8", sipType_QWidget, &a0))
        {
            sipCpp = new ::QStylePainter(a0);

            return sipCpp;
        }
    }

    {
        ::QPaintDevice* a0;
        ::QWidget* a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J8J8", sipType_QPaintDevice, &a0, sipType_QWidget, &a1))
        {
            sipCpp = new ::QStylePainter(a0, a1);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QStylePainter[] = {{39, 1, 1}};


static PyMethodDef methods_QStylePainter[] = {
    {sipName_begin, meth_QStylePainter_begin, METH_VARARGS, doc_QStylePainter_begin},
    {sipName_drawComplexControl, meth_QStylePainter_drawComplexControl, METH_VARARGS, doc_QStylePainter_drawComplexControl},
    {sipName_drawControl, meth_QStylePainter_drawControl, METH_VARARGS, doc_QStylePainter_drawControl},
    {sipName_drawItemPixmap, meth_QStylePainter_drawItemPixmap, METH_VARARGS, doc_QStylePainter_drawItemPixmap},
    {sipName_drawItemText, SIP_MLMETH_CAST(meth_QStylePainter_drawItemText), METH_VARARGS|METH_KEYWORDS, doc_QStylePainter_drawItemText},
    {sipName_drawPrimitive, meth_QStylePainter_drawPrimitive, METH_VARARGS, doc_QStylePainter_drawPrimitive},
    {sipName_style, meth_QStylePainter_style, METH_VARARGS, doc_QStylePainter_style}
};

PyDoc_STRVAR(doc_QStylePainter, "\1QStylePainter()\n"
"QStylePainter(w: Optional[QWidget])\n"
"QStylePainter(pd: Optional[QPaintDevice], w: Optional[QWidget])");


static pyqt5ClassPluginDef plugin_QStylePainter = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QStylePainter = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QStylePainter,
        SIP_NULLPTR,
        &plugin_QStylePainter,
    },
    {
        sipNameNr_QStylePainter,
        {0, 0, 1},
        7, methods_QStylePainter,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QStylePainter,
    -1,
    -1,
    supers_QStylePainter,
    SIP_NULLPTR,
    init_type_QStylePainter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QStylePainter,
    SIP_NULLPTR,
    array_QStylePainter,
    SIP_NULLPTR,
    release_QStylePainter,
    cast_QStylePainter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QStylePainter,
    sizeof (::QStylePainter),
};
