/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtSensorsAPI_H
#define _QtSensorsAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QAccelerometer__AccelerationMode 0
#define sipName_QAccelerometer__AccelerationMode &sipStrings_QtSensors[0]
#define sipNameNr_QAmbientLightReading__LightLevel 33
#define sipName_QAmbientLightReading__LightLevel &sipStrings_QtSensors[33]
#define sipNameNr_QOrientationReading__Orientation 66
#define sipName_QOrientationReading__Orientation &sipStrings_QtSensors[66]
#define sipNameNr_QSensor__AxesOrientationMode 99
#define sipName_QSensor__AxesOrientationMode &sipStrings_QtSensors[99]
#define sipNameNr_returnDoubleTapEventsChanged 128
#define sipName_returnDoubleTapEventsChanged &sipStrings_QtSensors[128]
#define sipNameNr_QAmbientTemperatureReading 157
#define sipName_QAmbientTemperatureReading &sipStrings_QtSensors[157]
#define sipNameNr_axesOrientationModeChanged 184
#define sipName_axesOrientationModeChanged &sipStrings_QtSensors[184]
#define sipNameNr_efficientBufferSizeChanged 211
#define sipName_efficientBufferSizeChanged &sipStrings_QtSensors[211]
#define sipNameNr_PressureSensorTemperature 238
#define sipName_PressureSensorTemperature &sipStrings_QtSensors[238]
#define sipNameNr_QAmbientTemperatureFilter 264
#define sipName_QAmbientTemperatureFilter &sipStrings_QtSensors[264]
#define sipNameNr_QAmbientTemperatureSensor 290
#define sipName_QAmbientTemperatureSensor &sipStrings_QtSensors[290]
#define sipNameNr_QTapReading__TapDirection 316
#define sipName_QTapReading__TapDirection &sipStrings_QtSensors[316]
#define sipNameNr_currentOrientationChanged 342
#define sipName_currentOrientationChanged &sipStrings_QtSensors[342]
#define sipNameNr_setReturnDoubleTapEvents 368
#define sipName_setReturnDoubleTapEvents &sipStrings_QtSensors[368]
#define sipNameNr_accelerationModeChanged 393
#define sipName_accelerationModeChanged &sipStrings_QtSensors[393]
#define sipNameNr_availableSensorsChanged 417
#define sipName_availableSensorsChanged &sipStrings_QtSensors[417]
#define sipNameNr_returnGeoValuesChanged 441
#define sipName_returnGeoValuesChanged &sipStrings_QtSensors[441]
#define sipNameNr_setAxesOrientationMode 464
#define sipName_setAxesOrientationMode &sipStrings_QtSensors[464]
#define sipNameNr_setEfficientBufferSize 487
#define sipName_setEfficientBufferSize &sipStrings_QtSensors[487]
#define sipNameNr_userOrientationChanged 510
#define sipName_userOrientationChanged &sipStrings_QtSensors[510]
#define sipNameNr_QAccelerometerReading 533
#define sipName_QAccelerometerReading &sipStrings_QtSensors[533]
#define sipNameNr_555 555
#define sipName_555 &sipStrings_QtSensors[555]
#define sipNameNr_returnDoubleTapEvents 577
#define sipName_returnDoubleTapEvents &sipStrings_QtSensors[577]
#define sipNameNr_setCurrentOrientation 599
#define sipName_setCurrentOrientation &sipStrings_QtSensors[599]
#define sipNameNr_skipDuplicatesChanged 621
#define sipName_skipDuplicatesChanged &sipStrings_QtSensors[621]
#define sipNameNr_AutomaticOrientation 643
#define sipName_AutomaticOrientation &sipStrings_QtSensors[643]
#define sipNameNr_QAccelerometerFilter 664
#define sipName_QAccelerometerFilter &sipStrings_QtSensors[664]
#define sipNameNr_QAmbientLightReading 685
#define sipName_QAmbientLightReading &sipStrings_QtSensors[685]
#define sipNameNr_QMagnetometerReading 706
#define sipName_QMagnetometerReading &sipStrings_QtSensors[706]
#define sipNameNr_defaultSensorForType 727
#define sipName_defaultSensorForType &sipStrings_QtSensors[727]
#define sipNameNr_isConnectedToBackend 748
#define sipName_isConnectedToBackend &sipStrings_QtSensors[748]
#define sipNameNr_maxBufferSizeChanged 769
#define sipName_maxBufferSizeChanged &sipStrings_QtSensors[769]
#define sipNameNr_AxesOrientationMode 108
#define sipName_AxesOrientationMode &sipStrings_QtSensors[108]
#define sipNameNr_QAmbientLightFilter 790
#define sipName_QAmbientLightFilter &sipStrings_QtSensors[790]
#define sipNameNr_QAmbientLightSensor 810
#define sipName_QAmbientLightSensor &sipStrings_QtSensors[810]
#define sipNameNr_QIRProximityReading 830
#define sipName_QIRProximityReading &sipStrings_QtSensors[830]
#define sipNameNr_850 850
#define sipName_850 &sipStrings_QtSensors[850]
#define sipNameNr_QMagnetometerFilter 870
#define sipName_QMagnetometerFilter &sipStrings_QtSensors[870]
#define sipNameNr_QOrientationReading 890
#define sipName_QOrientationReading &sipStrings_QtSensors[890]
#define sipNameNr_axesOrientationMode 910
#define sipName_axesOrientationMode &sipStrings_QtSensors[910]
#define sipNameNr_efficientBufferSize 930
#define sipName_efficientBufferSize &sipStrings_QtSensors[930]
#define sipNameNr_setAbsoluteHumidity 950
#define sipName_setAbsoluteHumidity &sipStrings_QtSensors[950]
#define sipNameNr_setAccelerationMode 970
#define sipName_setAccelerationMode &sipStrings_QtSensors[970]
#define sipNameNr_setCalibrationLevel 990
#define sipName_setCalibrationLevel &sipStrings_QtSensors[990]
#define sipNameNr_setRelativeHumidity 1010
#define sipName_setRelativeHumidity &sipStrings_QtSensors[1010]
#define sipNameNr_QIRProximityFilter 1030
#define sipName_QIRProximityFilter &sipStrings_QtSensors[1030]
#define sipNameNr_QIRProximitySensor 1049
#define sipName_QIRProximitySensor &sipStrings_QtSensors[1049]
#define sipNameNr_QOrientationFilter 1068
#define sipName_QOrientationFilter &sipStrings_QtSensors[1068]
#define sipNameNr_QOrientationSensor 1087
#define sipName_QOrientationSensor &sipStrings_QtSensors[1087]
#define sipNameNr_availableDataRates 1106
#define sipName_availableDataRates &sipStrings_QtSensors[1106]
#define sipNameNr_currentOrientation 1125
#define sipName_currentOrientation &sipStrings_QtSensors[1125]
#define sipNameNr_fieldOfViewChanged 1144
#define sipName_fieldOfViewChanged &sipStrings_QtSensors[1144]
#define sipNameNr_isFeatureSupported 1163
#define sipName_isFeatureSupported &sipStrings_QtSensors[1163]
#define sipNameNr_setReturnGeoValues 1182
#define sipName_setReturnGeoValues &sipStrings_QtSensors[1182]
#define sipNameNr_setUserOrientation 1201
#define sipName_setUserOrientation &sipStrings_QtSensors[1201]
#define sipNameNr_QAltimeterReading 1220
#define sipName_QAltimeterReading &sipStrings_QtSensors[1220]
#define sipNameNr_QGyroscopeReading 1238
#define sipName_QGyroscopeReading &sipStrings_QtSensors[1238]
#define sipNameNr_QProximityReading 1256
#define sipName_QProximityReading &sipStrings_QtSensors[1256]
#define sipNameNr_bufferSizeChanged 1274
#define sipName_bufferSizeChanged &sipStrings_QtSensors[1274]
#define sipNameNr_setFrontLidClosed 1292
#define sipName_setFrontLidClosed &sipStrings_QtSensors[1292]
#define sipNameNr_setSkipDuplicates 1310
#define sipName_setSkipDuplicates &sipStrings_QtSensors[1310]
#define sipNameNr_sip_simplewrapper 1328
#define sipName_sip_simplewrapper &sipStrings_QtSensors[1328]
#define sipNameNr_AccelerationMode 16
#define sipName_AccelerationMode &sipStrings_QtSensors[16]
#define sipNameNr_FixedOrientation 1346
#define sipName_FixedOrientation &sipStrings_QtSensors[1346]
#define sipNameNr_QAltimeterFilter 1363
#define sipName_QAltimeterFilter &sipStrings_QtSensors[1363]
#define sipNameNr_QDistanceReading 1380
#define sipName_QDistanceReading &sipStrings_QtSensors[1380]
#define sipNameNr_QGyroscopeFilter 1397
#define sipName_QGyroscopeFilter &sipStrings_QtSensors[1397]
#define sipNameNr_QHumidityReading 1414
#define sipName_QHumidityReading &sipStrings_QtSensors[1414]
#define sipNameNr_QPressureReading 1431
#define sipName_QPressureReading &sipStrings_QtSensors[1431]
#define sipNameNr_QProximityFilter 1448
#define sipName_QProximityFilter &sipStrings_QtSensors[1448]
#define sipNameNr_QProximitySensor 1465
#define sipName_QProximitySensor &sipStrings_QtSensors[1465]
#define sipNameNr_QRotationReading 1482
#define sipName_QRotationReading &sipStrings_QtSensors[1482]
#define sipNameNr_QSensor__Feature 1499
#define sipName_QSensor__Feature &sipStrings_QtSensors[1499]
#define sipNameNr_absoluteHumidity 1516
#define sipName_absoluteHumidity &sipStrings_QtSensors[1516]
#define sipNameNr_accelerationMode 1533
#define sipName_accelerationMode &sipStrings_QtSensors[1533]
#define sipNameNr_calibrationLevel 1550
#define sipName_calibrationLevel &sipStrings_QtSensors[1550]
#define sipNameNr_connectToBackend 1567
#define sipName_connectToBackend &sipStrings_QtSensors[1567]
#define sipNameNr_disconnectNotify 1584
#define sipName_disconnectNotify &sipStrings_QtSensors[1584]
#define sipNameNr_relativeHumidity 1601
#define sipName_relativeHumidity &sipStrings_QtSensors[1601]
#define sipNameNr_setBackLidClosed 1618
#define sipName_setBackLidClosed &sipStrings_QtSensors[1618]
#define sipNameNr_setMaxBufferSize 1635
#define sipName_setMaxBufferSize &sipStrings_QtSensors[1635]
#define sipNameNr_AxesOrientation 1652
#define sipName_AxesOrientation &sipStrings_QtSensors[1652]
#define sipNameNr_PyQt5_QtSensors 1668
#define sipName_PyQt5_QtSensors &sipStrings_QtSensors[1668]
#define sipNameNr_QCompassReading 1684
#define sipName_QCompassReading &sipStrings_QtSensors[1684]
#define sipNameNr_QDistanceFilter 1700
#define sipName_QDistanceFilter &sipStrings_QtSensors[1700]
#define sipNameNr_QDistanceSensor 1716
#define sipName_QDistanceSensor &sipStrings_QtSensors[1716]
#define sipNameNr_QHolsterReading 1732
#define sipName_QHolsterReading &sipStrings_QtSensors[1732]
#define sipNameNr_QHumidityFilter 1748
#define sipName_QHumidityFilter &sipStrings_QtSensors[1748]
#define sipNameNr_QHumiditySensor 1764
#define sipName_QHumiditySensor &sipStrings_QtSensors[1764]
#define sipNameNr_QPressureFilter 1780
#define sipName_QPressureFilter &sipStrings_QtSensors[1780]
#define sipNameNr_QPressureSensor 1796
#define sipName_QPressureSensor &sipStrings_QtSensors[1796]
#define sipNameNr_QRotationFilter 1812
#define sipName_QRotationFilter &sipStrings_QtSensors[1812]
#define sipNameNr_QRotationSensor 1828
#define sipName_QRotationSensor &sipStrings_QtSensors[1828]
#define sipNameNr_UserOrientation 1204
#define sipName_UserOrientation &sipStrings_QtSensors[1204]
#define sipNameNr_alwaysOnChanged 1844
#define sipName_alwaysOnChanged &sipStrings_QtSensors[1844]
#define sipNameNr_dataRateChanged 1860
#define sipName_dataRateChanged &sipStrings_QtSensors[1860]
#define sipNameNr_frontLidChanged 1876
#define sipName_frontLidChanged &sipStrings_QtSensors[1876]
#define sipNameNr_returnGeoValues 1892
#define sipName_returnGeoValues &sipStrings_QtSensors[1892]
#define sipNameNr_setTapDirection 1908
#define sipName_setTapDirection &sipStrings_QtSensors[1908]
#define sipNameNr_userOrientation 1924
#define sipName_userOrientation &sipStrings_QtSensors[1924]
#define sipNameNr_QAccelerometer 1940
#define sipName_QAccelerometer &sipStrings_QtSensors[1940]
#define sipNameNr_QCompassFilter 1955
#define sipName_QCompassFilter &sipStrings_QtSensors[1955]
#define sipNameNr_QHolsterFilter 1970
#define sipName_QHolsterFilter &sipStrings_QtSensors[1970]
#define sipNameNr_QHolsterSensor 1985
#define sipName_QHolsterSensor &sipStrings_QtSensors[1985]
#define sipNameNr_QSensorReading 2000
#define sipName_QSensorReading &sipStrings_QtSensors[2000]
#define sipNameNr_SkipDuplicates 1313
#define sipName_SkipDuplicates &sipStrings_QtSensors[1313]
#define sipNameNr_backLidChanged 2015
#define sipName_backLidChanged &sipStrings_QtSensors[2015]
#define sipNameNr_frontLidClosed 2030
#define sipName_frontLidClosed &sipStrings_QtSensors[2030]
#define sipNameNr_readingChanged 2045
#define sipName_readingChanged &sipStrings_QtSensors[2045]
#define sipNameNr_sensorsForType 2060
#define sipName_sensorsForType &sipStrings_QtSensors[2060]
#define sipNameNr_setFieldOfView 2075
#define sipName_setFieldOfView &sipStrings_QtSensors[2075]
#define sipNameNr_setOrientation 2090
#define sipName_setOrientation &sipStrings_QtSensors[2090]
#define sipNameNr_setOutputRange 2105
#define sipName_setOutputRange &sipStrings_QtSensors[2105]
#define sipNameNr_setReflectance 2120
#define sipName_setReflectance &sipStrings_QtSensors[2120]
#define sipNameNr_setTemperature 2135
#define sipName_setTemperature &sipStrings_QtSensors[2135]
#define sipNameNr_skipDuplicates 2150
#define sipName_skipDuplicates &sipStrings_QtSensors[2150]
#define sipNameNr_QLightReading 2165
#define sipName_QLightReading &sipStrings_QtSensors[2165]
#define sipNameNr_QMagnetometer 2179
#define sipName_QMagnetometer &sipStrings_QtSensors[2179]
#define sipNameNr_QSensorFilter 2193
#define sipName_QSensorFilter &sipStrings_QtSensors[2193]
#define sipNameNr_activeChanged 2207
#define sipName_activeChanged &sipStrings_QtSensors[2207]
#define sipNameNr_backLidClosed 2221
#define sipName_backLidClosed &sipStrings_QtSensors[2221]
#define sipNameNr_connectNotify 1587
#define sipName_connectNotify &sipStrings_QtSensors[1587]
#define sipNameNr_maxBufferSize 2235
#define sipName_maxBufferSize &sipStrings_QtSensors[2235]
#define sipNameNr_setBufferSize 2249
#define sipName_setBufferSize &sipStrings_QtSensors[2249]
#define sipNameNr_setIdentifier 2263
#define sipName_setIdentifier &sipStrings_QtSensors[2263]
#define sipNameNr_setLightLevel 2277
#define sipName_setLightLevel &sipStrings_QtSensors[2277]
#define sipNameNr_QLightFilter 2291
#define sipName_QLightFilter &sipStrings_QtSensors[2291]
#define sipNameNr_QLightSensor 2304
#define sipName_QLightSensor &sipStrings_QtSensors[2304]
#define sipNameNr_QTiltReading 2317
#define sipName_QTiltReading &sipStrings_QtSensors[2317]
#define sipNameNr_TapDirection 329
#define sipName_TapDirection &sipStrings_QtSensors[329]
#define sipNameNr_outputRanges 2330
#define sipName_outputRanges &sipStrings_QtSensors[2330]
#define sipNameNr_qoutputrange 2343
#define sipName_qoutputrange &sipStrings_QtSensors[2343]
#define sipNameNr_removeFilter 2356
#define sipName_removeFilter &sipStrings_QtSensors[2356]
#define sipNameNr_setDoubleTap 2369
#define sipName_setDoubleTap &sipStrings_QtSensors[2369]
#define sipNameNr_setFromEuler 2382
#define sipName_setFromEuler &sipStrings_QtSensors[2382]
#define sipNameNr_setHolstered 2395
#define sipName_setHolstered &sipStrings_QtSensors[2395]
#define sipNameNr_setTimestamp 2408
#define sipName_setTimestamp &sipStrings_QtSensors[2408]
#define sipNameNr_setXRotation 2421
#define sipName_setXRotation &sipStrings_QtSensors[2421]
#define sipNameNr_setYRotation 2434
#define sipName_setYRotation &sipStrings_QtSensors[2434]
#define sipNameNr_tapDirection 2447
#define sipName_tapDirection &sipStrings_QtSensors[2447]
#define sipNameNr_FieldOfView 2078
#define sipName_FieldOfView &sipStrings_QtSensors[2078]
#define sipNameNr_Orientation 87
#define sipName_Orientation &sipStrings_QtSensors[87]
#define sipNameNr_QLidReading 2460
#define sipName_QLidReading &sipStrings_QtSensors[2460]
#define sipNameNr_QTapReading 2472
#define sipName_QTapReading &sipStrings_QtSensors[2472]
#define sipNameNr_QTiltFilter 2484
#define sipName_QTiltFilter &sipStrings_QtSensors[2484]
#define sipNameNr_QTiltSensor 2496
#define sipName_QTiltSensor &sipStrings_QtSensors[2496]
#define sipNameNr_busyChanged 2508
#define sipName_busyChanged &sipStrings_QtSensors[2508]
#define sipNameNr_customEvent 2520
#define sipName_customEvent &sipStrings_QtSensors[2520]
#define sipNameNr_description 2532
#define sipName_description &sipStrings_QtSensors[2532]
#define sipNameNr_eventFilter 2544
#define sipName_eventFilter &sipStrings_QtSensors[2544]
#define sipNameNr_fieldOfView 2556
#define sipName_fieldOfView &sipStrings_QtSensors[2556]
#define sipNameNr_hasZChanged 2568
#define sipName_hasZChanged &sipStrings_QtSensors[2568]
#define sipNameNr_isDoubleTap 2580
#define sipName_isDoubleTap &sipStrings_QtSensors[2580]
#define sipNameNr_orientation 2592
#define sipName_orientation &sipStrings_QtSensors[2592]
#define sipNameNr_outputRange 2604
#define sipName_outputRange &sipStrings_QtSensors[2604]
#define sipNameNr_reflectance 2616
#define sipName_reflectance &sipStrings_QtSensors[2616]
#define sipNameNr_sensorError 2628
#define sipName_sensorError &sipStrings_QtSensors[2628]
#define sipNameNr_sensorTypes 2640
#define sipName_sensorTypes &sipStrings_QtSensors[2640]
#define sipNameNr_setAltitude 2652
#define sipName_setAltitude &sipStrings_QtSensors[2652]
#define sipNameNr_setAlwaysOn 2664
#define sipName_setAlwaysOn &sipStrings_QtSensors[2664]
#define sipNameNr_setDataRate 2676
#define sipName_setDataRate &sipStrings_QtSensors[2676]
#define sipNameNr_setDistance 2688
#define sipName_setDistance &sipStrings_QtSensors[2688]
#define sipNameNr_setPressure 2700
#define sipName_setPressure &sipStrings_QtSensors[2700]
#define sipNameNr_temperature 2712
#define sipName_temperature &sipStrings_QtSensors[2712]
#define sipNameNr_LightLevel 55
#define sipName_LightLevel &sipStrings_QtSensors[55]
#define sipNameNr_QAltimeter 2724
#define sipName_QAltimeter &sipStrings_QtSensors[2724]
#define sipNameNr_QGyroscope 2735
#define sipName_QGyroscope &sipStrings_QtSensors[2735]
#define sipNameNr_QLidFilter 2746
#define sipName_QLidFilter &sipStrings_QtSensors[2746]
#define sipNameNr_QLidSensor 2757
#define sipName_QLidSensor &sipStrings_QtSensors[2757]
#define sipNameNr_QTapFilter 2768
#define sipName_QTapFilter &sipStrings_QtSensors[2768]
#define sipNameNr_QTapSensor 2779
#define sipName_QTapSensor &sipStrings_QtSensors[2779]
#define sipNameNr_bufferSize 2790
#define sipName_bufferSize &sipStrings_QtSensors[2790]
#define sipNameNr_childEvent 2801
#define sipName_childEvent &sipStrings_QtSensors[2801]
#define sipNameNr_identifier 2812
#define sipName_identifier &sipStrings_QtSensors[2812]
#define sipNameNr_isAlwaysOn 2823
#define sipName_isAlwaysOn &sipStrings_QtSensors[2823]
#define sipNameNr_lightLevel 2834
#define sipName_lightLevel &sipStrings_QtSensors[2834]
#define sipNameNr_setAzimuth 2845
#define sipName_setAzimuth &sipStrings_QtSensors[2845]
#define sipNameNr_timerEvent 2856
#define sipName_timerEvent &sipStrings_QtSensors[2856]
#define sipNameNr_valueCount 2867
#define sipName_valueCount &sipStrings_QtSensors[2867]
#define sipNameNr_Buffering 2878
#define sipName_Buffering &sipStrings_QtSensors[2878]
#define sipNameNr_GeoValues 1191
#define sipName_GeoValues &sipStrings_QtSensors[1191]
#define sipNameNr_Undefined 2888
#define sipName_Undefined &sipStrings_QtSensors[2888]
#define sipNameNr_addFilter 2898
#define sipName_addFilter &sipStrings_QtSensors[2898]
#define sipNameNr_calibrate 2908
#define sipName_calibrate &sipStrings_QtSensors[2908]
#define sipNameNr_holstered 2918
#define sipName_holstered &sipStrings_QtSensors[2918]
#define sipNameNr_setActive 2928
#define sipName_setActive &sipStrings_QtSensors[2928]
#define sipNameNr_timestamp 2938
#define sipName_timestamp &sipStrings_QtSensors[2938]
#define sipNameNr_xRotation 2948
#define sipName_xRotation &sipStrings_QtSensors[2948]
#define sipNameNr_yRotation 2958
#define sipName_yRotation &sipStrings_QtSensors[2958]
#define sipNameNr_AlwaysOn 2667
#define sipName_AlwaysOn &sipStrings_QtSensors[2667]
#define sipNameNr_Combined 2968
#define sipName_Combined &sipStrings_QtSensors[2968]
#define sipNameNr_FaceDown 2977
#define sipName_FaceDown &sipStrings_QtSensors[2977]
#define sipNameNr_QCompass 2986
#define sipName_QCompass &sipStrings_QtSensors[2986]
#define sipNameNr_Twilight 2995
#define sipName_Twilight &sipStrings_QtSensors[2995]
#define sipNameNr_accuracy 3004
#define sipName_accuracy &sipStrings_QtSensors[3004]
#define sipNameNr_altitude 3013
#define sipName_altitude &sipStrings_QtSensors[3013]
#define sipNameNr_dataRate 3022
#define sipName_dataRate &sipStrings_QtSensors[3022]
#define sipNameNr_distance 3031
#define sipName_distance &sipStrings_QtSensors[3031]
#define sipNameNr_isActive 3040
#define sipName_isActive &sipStrings_QtSensors[3040]
#define sipNameNr_pressure 3049
#define sipName_pressure &sipStrings_QtSensors[3049]
#define sipNameNr_setClose 3058
#define sipName_setClose &sipStrings_QtSensors[3058]
#define sipNameNr_Feature 1508
#define sipName_Feature &sipStrings_QtSensors[1508]
#define sipNameNr_Gravity 3067
#define sipName_Gravity &sipStrings_QtSensors[3067]
#define sipNameNr_QSensor 3075
#define sipName_QSensor &sipStrings_QtSensors[3075]
#define sipNameNr_RightUp 3083
#define sipName_RightUp &sipStrings_QtSensors[3083]
#define sipNameNr_TopDown 3091
#define sipName_TopDown &sipStrings_QtSensors[3091]
#define sipNameNr_azimuth 3099
#define sipName_azimuth &sipStrings_QtSensors[3099]
#define sipNameNr_filters 3107
#define sipName_filters &sipStrings_QtSensors[3107]
#define sipNameNr_maximum 3115
#define sipName_maximum &sipStrings_QtSensors[3115]
#define sipNameNr_minimum 3123
#define sipName_minimum &sipStrings_QtSensors[3123]
#define sipNameNr_reading 3131
#define sipName_reading &sipStrings_QtSensors[3131]
#define sipNameNr_setHasZ 3139
#define sipName_setHasZ &sipStrings_QtSensors[3139]
#define sipNameNr_Bright 3147
#define sipName_Bright &sipStrings_QtSensors[3147]
#define sipNameNr_FaceUp 3154
#define sipName_FaceUp &sipStrings_QtSensors[3154]
#define sipNameNr_LeftUp 3161
#define sipName_LeftUp &sipStrings_QtSensors[3161]
#define sipNameNr_X_Both 3168
#define sipName_X_Both &sipStrings_QtSensors[3168]
#define sipNameNr_Y_Both 3175
#define sipName_Y_Both &sipStrings_QtSensors[3175]
#define sipNameNr_Z_Both 3182
#define sipName_Z_Both &sipStrings_QtSensors[3182]
#define sipNameNr_filter 3189
#define sipName_filter &sipStrings_QtSensors[3189]
#define sipNameNr_isBusy 3196
#define sipName_isBusy &sipStrings_QtSensors[3196]
#define sipNameNr_parent 3203
#define sipName_parent &sipStrings_QtSensors[3203]
#define sipNameNr_setLux 3210
#define sipName_setLux &sipStrings_QtSensors[3210]
#define sipNameNr_Light 3217
#define sipName_Light &sipStrings_QtSensors[3217]
#define sipNameNr_Sunny 3223
#define sipName_Sunny &sipStrings_QtSensors[3223]
#define sipNameNr_TopUp 3229
#define sipName_TopUp &sipStrings_QtSensors[3229]
#define sipNameNr_X_Neg 3235
#define sipName_X_Neg &sipStrings_QtSensors[3235]
#define sipNameNr_X_Pos 3241
#define sipName_X_Pos &sipStrings_QtSensors[3241]
#define sipNameNr_Y_Neg 3247
#define sipName_Y_Neg &sipStrings_QtSensors[3247]
#define sipNameNr_Y_Pos 3253
#define sipName_Y_Pos &sipStrings_QtSensors[3253]
#define sipNameNr_Z_Neg 3259
#define sipName_Z_Neg &sipStrings_QtSensors[3259]
#define sipNameNr_Z_Pos 3265
#define sipName_Z_Pos &sipStrings_QtSensors[3265]
#define sipNameNr_close 3271
#define sipName_close &sipStrings_QtSensors[3271]
#define sipNameNr_error 3277
#define sipName_error &sipStrings_QtSensors[3277]
#define sipNameNr_event 3283
#define sipName_event &sipStrings_QtSensors[3283]
#define sipNameNr_start 3289
#define sipName_start &sipStrings_QtSensors[3289]
#define sipNameNr_value 3295
#define sipName_value &sipStrings_QtSensors[3295]
#define sipNameNr_Dark 3301
#define sipName_Dark &sipStrings_QtSensors[3301]
#define sipNameNr_User 3306
#define sipName_User &sipStrings_QtSensors[3306]
#define sipNameNr_hasZ 3311
#define sipName_hasZ &sipStrings_QtSensors[3311]
#define sipNameNr_setX 3316
#define sipName_setX &sipStrings_QtSensors[3316]
#define sipNameNr_setY 3321
#define sipName_setY &sipStrings_QtSensors[3321]
#define sipNameNr_setZ 3326
#define sipName_setZ &sipStrings_QtSensors[3326]
#define sipNameNr_stop 3331
#define sipName_stop &sipStrings_QtSensors[3331]
#define sipNameNr_type 3336
#define sipName_type &sipStrings_QtSensors[3336]
#define sipNameNr_lux 3341
#define sipName_lux &sipStrings_QtSensors[3341]
#define sipNameNr_X 3319
#define sipName_X &sipStrings_QtSensors[3319]
#define sipNameNr_Y 3324
#define sipName_Y &sipStrings_QtSensors[3324]
#define sipNameNr_Z 3145
#define sipName_Z &sipStrings_QtSensors[3145]
#define sipNameNr_x 3215
#define sipName_x &sipStrings_QtSensors[3215]
#define sipNameNr_y 968
#define sipName_y &sipStrings_QtSensors[968]
#define sipNameNr_z 3345
#define sipName_z &sipStrings_QtSensors[3345]

#define sipMalloc                   sipAPI_QtSensors->api_malloc
#define sipFree                     sipAPI_QtSensors->api_free
#define sipBuildResult              sipAPI_QtSensors->api_build_result
#define sipCallMethod               sipAPI_QtSensors->api_call_method
#define sipCallProcedureMethod      sipAPI_QtSensors->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtSensors->api_call_error_handler
#define sipParseResultEx            sipAPI_QtSensors->api_parse_result_ex
#define sipParseResult              sipAPI_QtSensors->api_parse_result
#define sipParseArgs                sipAPI_QtSensors->api_parse_args
#define sipParseKwdArgs             sipAPI_QtSensors->api_parse_kwd_args
#define sipParsePair                sipAPI_QtSensors->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtSensors->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtSensors->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtSensors->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtSensors->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtSensors->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtSensors->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtSensors->api_add_exception
#define sipNoFunction               sipAPI_QtSensors->api_no_function
#define sipNoMethod                 sipAPI_QtSensors->api_no_method
#define sipAbstractMethod           sipAPI_QtSensors->api_abstract_method
#define sipBadClass                 sipAPI_QtSensors->api_bad_class
#define sipBadCatcherResult         sipAPI_QtSensors->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtSensors->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtSensors->api_bad_operator_arg
#define sipTrace                    sipAPI_QtSensors->api_trace
#define sipTransferBack             sipAPI_QtSensors->api_transfer_back
#define sipTransferTo               sipAPI_QtSensors->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtSensors->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtSensors->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtSensors->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtSensors->api_voidptr_type
#define sipGetPyObject              sipAPI_QtSensors->api_get_pyobject
#define sipGetAddress               sipAPI_QtSensors->api_get_address
#define sipGetMixinAddress          sipAPI_QtSensors->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtSensors->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtSensors->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtSensors->api_call_hook
#define sipEndThread                sipAPI_QtSensors->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtSensors->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtSensors->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtSensors->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtSensors->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtSensors->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtSensors->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtSensors->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtSensors->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtSensors->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtSensors->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtSensors->api_convert_to_bool
#define sipReleaseType              sipAPI_QtSensors->api_release_type
#define sipConvertFromType          sipAPI_QtSensors->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtSensors->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtSensors->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtSensors->api_convert_from_enum
#define sipGetState                 sipAPI_QtSensors->api_get_state
#define sipExportSymbol             sipAPI_QtSensors->api_export_symbol
#define sipImportSymbol             sipAPI_QtSensors->api_import_symbol
#define sipFindType                 sipAPI_QtSensors->api_find_type
#define sipBytes_AsChar             sipAPI_QtSensors->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtSensors->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtSensors->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtSensors->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtSensors->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtSensors->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtSensors->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtSensors->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtSensors->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtSensors->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtSensors->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtSensors->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtSensors->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtSensors->api_get_reference
#define sipKeepReference            sipAPI_QtSensors->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtSensors->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtSensors->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtSensors->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtSensors->api_type_scope
#define sipResolveTypedef           sipAPI_QtSensors->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtSensors->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtSensors->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtSensors->api_init_mixin
#define sipExportModule             sipAPI_QtSensors->api_export_module
#define sipInitModule               sipAPI_QtSensors->api_init_module
#define sipGetInterpreter           sipAPI_QtSensors->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtSensors->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtSensors->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtSensors->api_py_type_dict
#define sipPyTypeName               sipAPI_QtSensors->api_py_type_name
#define sipGetCFunction             sipAPI_QtSensors->api_get_c_function
#define sipGetMethod                sipAPI_QtSensors->api_get_method
#define sipFromMethod               sipAPI_QtSensors->api_from_method
#define sipGetDate                  sipAPI_QtSensors->api_get_date
#define sipFromDate                 sipAPI_QtSensors->api_from_date
#define sipGetDateTime              sipAPI_QtSensors->api_get_datetime
#define sipFromDateTime             sipAPI_QtSensors->api_from_datetime
#define sipGetTime                  sipAPI_QtSensors->api_get_time
#define sipFromTime                 sipAPI_QtSensors->api_from_time
#define sipIsUserType               sipAPI_QtSensors->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtSensors->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtSensors->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtSensors->api_unicode_write
#define sipUnicodeData              sipAPI_QtSensors->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtSensors->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtSensors->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtSensors->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtSensors->api_is_derived_class
#define sipGetUserObject            sipAPI_QtSensors->api_get_user_object
#define sipSetUserObject            sipAPI_QtSensors->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtSensors->api_register_event_handler
#define sipConvertToArray           sipAPI_QtSensors->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtSensors->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtSensors->api_enable_gc
#define sipPrintObject              sipAPI_QtSensors->api_print_object
#define sipLong_AsChar              sipAPI_QtSensors->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtSensors->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtSensors->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtSensors->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtSensors->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtSensors->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtSensors->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtSensors->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtSensors->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtSensors->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtSensors->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtSensors->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtSensors->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtSensors->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtSensors->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtSensors->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtSensors->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtSensors->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtSensors->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtSensors->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtSensors->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtSensors->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtSensors->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtSensors->api_connect_rx
#define sipConvertRx                sipAPI_QtSensors->api_convert_rx
#define sipDisconnectRx             sipAPI_QtSensors->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtSensors->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtSensors->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtSensors->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtSensors->api_same_slot
#define sipSaveSlot                 sipAPI_QtSensors->api_save_slot
#define sipVisitSlot                sipAPI_QtSensors->api_visit_slot
#define sipIsPyMethod               sipAPI_QtSensors->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtSensors[];

#define sipType_QSensorReading sipExportedTypes_QtSensors[60]

extern sipClassTypeDef sipTypeDef_QtSensors_QSensorReading;

#define sipType_QAccelerometerReading sipExportedTypes_QtSensors[3]

extern sipClassTypeDef sipTypeDef_QtSensors_QAccelerometerReading;

#define sipType_QSensorFilter sipExportedTypes_QtSensors[59]

extern sipClassTypeDef sipTypeDef_QtSensors_QSensorFilter;

#define sipType_QAccelerometerFilter sipExportedTypes_QtSensors[2]

extern sipClassTypeDef sipTypeDef_QtSensors_QAccelerometerFilter;

#define sipType_QSensor sipExportedTypes_QtSensors[56]

#define sipType_QSensor_AxesOrientationMode sipExportedTypes_QtSensors[57]

#define sipType_QSensor_Feature sipExportedTypes_QtSensors[58]

extern sipClassTypeDef sipTypeDef_QtSensors_QSensor;

#define sipType_QAccelerometer sipExportedTypes_QtSensors[0]

#define sipType_QAccelerometer_AccelerationMode sipExportedTypes_QtSensors[1]

extern sipClassTypeDef sipTypeDef_QtSensors_QAccelerometer;

#define sipType_QAltimeterReading sipExportedTypes_QtSensors[6]

extern sipClassTypeDef sipTypeDef_QtSensors_QAltimeterReading;

#define sipType_QAltimeterFilter sipExportedTypes_QtSensors[5]

extern sipClassTypeDef sipTypeDef_QtSensors_QAltimeterFilter;

#define sipType_QAltimeter sipExportedTypes_QtSensors[4]

extern sipClassTypeDef sipTypeDef_QtSensors_QAltimeter;

#define sipType_QAmbientLightReading sipExportedTypes_QtSensors[8]

#define sipType_QAmbientLightReading_LightLevel sipExportedTypes_QtSensors[9]

extern sipClassTypeDef sipTypeDef_QtSensors_QAmbientLightReading;

#define sipType_QAmbientLightFilter sipExportedTypes_QtSensors[7]

extern sipClassTypeDef sipTypeDef_QtSensors_QAmbientLightFilter;

#define sipType_QAmbientLightSensor sipExportedTypes_QtSensors[10]

extern sipClassTypeDef sipTypeDef_QtSensors_QAmbientLightSensor;

#define sipType_QAmbientTemperatureReading sipExportedTypes_QtSensors[12]

extern sipClassTypeDef sipTypeDef_QtSensors_QAmbientTemperatureReading;

#define sipType_QAmbientTemperatureFilter sipExportedTypes_QtSensors[11]

extern sipClassTypeDef sipTypeDef_QtSensors_QAmbientTemperatureFilter;

#define sipType_QAmbientTemperatureSensor sipExportedTypes_QtSensors[13]

extern sipClassTypeDef sipTypeDef_QtSensors_QAmbientTemperatureSensor;

#define sipType_QCompassReading sipExportedTypes_QtSensors[16]

extern sipClassTypeDef sipTypeDef_QtSensors_QCompassReading;

#define sipType_QCompassFilter sipExportedTypes_QtSensors[15]

extern sipClassTypeDef sipTypeDef_QtSensors_QCompassFilter;

#define sipType_QCompass sipExportedTypes_QtSensors[14]

extern sipClassTypeDef sipTypeDef_QtSensors_QCompass;

#define sipType_QDistanceReading sipExportedTypes_QtSensors[18]

extern sipClassTypeDef sipTypeDef_QtSensors_QDistanceReading;

#define sipType_QDistanceFilter sipExportedTypes_QtSensors[17]

extern sipClassTypeDef sipTypeDef_QtSensors_QDistanceFilter;

#define sipType_QDistanceSensor sipExportedTypes_QtSensors[19]

extern sipClassTypeDef sipTypeDef_QtSensors_QDistanceSensor;

#define sipType_QGyroscopeReading sipExportedTypes_QtSensors[22]

extern sipClassTypeDef sipTypeDef_QtSensors_QGyroscopeReading;

#define sipType_QGyroscopeFilter sipExportedTypes_QtSensors[21]

extern sipClassTypeDef sipTypeDef_QtSensors_QGyroscopeFilter;

#define sipType_QGyroscope sipExportedTypes_QtSensors[20]

extern sipClassTypeDef sipTypeDef_QtSensors_QGyroscope;

#define sipType_QHolsterReading sipExportedTypes_QtSensors[24]

extern sipClassTypeDef sipTypeDef_QtSensors_QHolsterReading;

#define sipType_QHolsterFilter sipExportedTypes_QtSensors[23]

extern sipClassTypeDef sipTypeDef_QtSensors_QHolsterFilter;

#define sipType_QHolsterSensor sipExportedTypes_QtSensors[25]

extern sipClassTypeDef sipTypeDef_QtSensors_QHolsterSensor;

#define sipType_QHumidityReading sipExportedTypes_QtSensors[27]

extern sipClassTypeDef sipTypeDef_QtSensors_QHumidityReading;

#define sipType_QHumidityFilter sipExportedTypes_QtSensors[26]

extern sipClassTypeDef sipTypeDef_QtSensors_QHumidityFilter;

#define sipType_QHumiditySensor sipExportedTypes_QtSensors[28]

extern sipClassTypeDef sipTypeDef_QtSensors_QHumiditySensor;

#define sipType_QIRProximityReading sipExportedTypes_QtSensors[30]

extern sipClassTypeDef sipTypeDef_QtSensors_QIRProximityReading;

#define sipType_QIRProximityFilter sipExportedTypes_QtSensors[29]

extern sipClassTypeDef sipTypeDef_QtSensors_QIRProximityFilter;

#define sipType_QIRProximitySensor sipExportedTypes_QtSensors[31]

extern sipClassTypeDef sipTypeDef_QtSensors_QIRProximitySensor;

#define sipType_QLidReading sipExportedTypes_QtSensors[33]

extern sipClassTypeDef sipTypeDef_QtSensors_QLidReading;

#define sipType_QLidFilter sipExportedTypes_QtSensors[32]

extern sipClassTypeDef sipTypeDef_QtSensors_QLidFilter;

#define sipType_QLidSensor sipExportedTypes_QtSensors[34]

extern sipClassTypeDef sipTypeDef_QtSensors_QLidSensor;

#define sipType_QLightReading sipExportedTypes_QtSensors[36]

extern sipClassTypeDef sipTypeDef_QtSensors_QLightReading;

#define sipType_QLightFilter sipExportedTypes_QtSensors[35]

extern sipClassTypeDef sipTypeDef_QtSensors_QLightFilter;

#define sipType_QLightSensor sipExportedTypes_QtSensors[37]

extern sipClassTypeDef sipTypeDef_QtSensors_QLightSensor;

#define sipType_QMagnetometerReading sipExportedTypes_QtSensors[42]

extern sipClassTypeDef sipTypeDef_QtSensors_QMagnetometerReading;

#define sipType_QMagnetometerFilter sipExportedTypes_QtSensors[41]

extern sipClassTypeDef sipTypeDef_QtSensors_QMagnetometerFilter;

#define sipType_QMagnetometer sipExportedTypes_QtSensors[40]

extern sipClassTypeDef sipTypeDef_QtSensors_QMagnetometer;

#define sipType_QOrientationReading sipExportedTypes_QtSensors[44]

#define sipType_QOrientationReading_Orientation sipExportedTypes_QtSensors[45]

extern sipClassTypeDef sipTypeDef_QtSensors_QOrientationReading;

#define sipType_QOrientationFilter sipExportedTypes_QtSensors[43]

extern sipClassTypeDef sipTypeDef_QtSensors_QOrientationFilter;

#define sipType_QOrientationSensor sipExportedTypes_QtSensors[46]

extern sipClassTypeDef sipTypeDef_QtSensors_QOrientationSensor;

#define sipType_QPressureReading sipExportedTypes_QtSensors[48]

extern sipClassTypeDef sipTypeDef_QtSensors_QPressureReading;

#define sipType_QPressureFilter sipExportedTypes_QtSensors[47]

extern sipClassTypeDef sipTypeDef_QtSensors_QPressureFilter;

#define sipType_QPressureSensor sipExportedTypes_QtSensors[49]

extern sipClassTypeDef sipTypeDef_QtSensors_QPressureSensor;

#define sipType_QProximityReading sipExportedTypes_QtSensors[51]

extern sipClassTypeDef sipTypeDef_QtSensors_QProximityReading;

#define sipType_QProximityFilter sipExportedTypes_QtSensors[50]

extern sipClassTypeDef sipTypeDef_QtSensors_QProximityFilter;

#define sipType_QProximitySensor sipExportedTypes_QtSensors[52]

extern sipClassTypeDef sipTypeDef_QtSensors_QProximitySensor;

#define sipType_qoutputrange sipExportedTypes_QtSensors[68]

extern sipClassTypeDef sipTypeDef_QtSensors_qoutputrange;

#define sipType_QTapReading sipExportedTypes_QtSensors[62]

#define sipType_QTapReading_TapDirection sipExportedTypes_QtSensors[63]

extern sipClassTypeDef sipTypeDef_QtSensors_QTapReading;

#define sipType_QTapFilter sipExportedTypes_QtSensors[61]

extern sipClassTypeDef sipTypeDef_QtSensors_QTapFilter;

#define sipType_QTapSensor sipExportedTypes_QtSensors[64]

extern sipClassTypeDef sipTypeDef_QtSensors_QTapSensor;

#define sipType_QTiltReading sipExportedTypes_QtSensors[66]

extern sipClassTypeDef sipTypeDef_QtSensors_QTiltReading;

#define sipType_QTiltFilter sipExportedTypes_QtSensors[65]

extern sipClassTypeDef sipTypeDef_QtSensors_QTiltFilter;

#define sipType_QTiltSensor sipExportedTypes_QtSensors[67]

extern sipClassTypeDef sipTypeDef_QtSensors_QTiltSensor;

#define sipType_QRotationReading sipExportedTypes_QtSensors[54]

extern sipClassTypeDef sipTypeDef_QtSensors_QRotationReading;

#define sipType_QRotationFilter sipExportedTypes_QtSensors[53]

extern sipClassTypeDef sipTypeDef_QtSensors_QRotationFilter;

#define sipType_QRotationSensor sipExportedTypes_QtSensors[55]

extern sipClassTypeDef sipTypeDef_QtSensors_QRotationSensor;

#define sipType_QList_0101QSensorFilter sipExportedTypes_QtSensors[38]

extern sipMappedTypeDef sipTypeDef_QtSensors_QList_0101QSensorFilter;

#define sipType_QList_0100qoutputrange sipExportedTypes_QtSensors[39]

extern sipMappedTypeDef sipTypeDef_QtSensors_QList_0100qoutputrange;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtSensors;
extern sipExportedModuleDef sipModuleAPI_QtSensors;
extern sipTypeDef *sipExportedTypes_QtSensors[];

#define sipType_QObject sipImportedTypes_QtSensors_QtCore[6].it_td

#define sipType_QByteArray sipImportedTypes_QtSensors_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtSensors_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtSensors_QtCore[8].it_td

#define sipType_QChildEvent sipImportedTypes_QtSensors_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtSensors_QtCore[5].it_td

#define sipType_QVariant sipImportedTypes_QtSensors_QtCore[9].it_td

#define sipType_QList_0100QByteArray sipImportedTypes_QtSensors_QtCore[3].it_td

#define sipType_QList_0600QPair_1800_1800 sipImportedTypes_QtSensors_QtCore[4].it_td

#define sipType_QString sipImportedTypes_QtSensors_QtCore[7].it_td
extern sipImportedTypeDef sipImportedTypes_QtSensors_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtSensors_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtSensors_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtSensors_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtSensors_qt_metacast;

#endif
