/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKit.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebelement.sip"
#include <qwebelement.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebElement.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebElement.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebElement.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebElement.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebElement.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebElement.cpp"
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebelement.sip"
#include <qwebelement.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebElement.cpp"


PyDoc_STRVAR(doc_QWebElement_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QWebElement_isNull(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_isNull, doc_QWebElement_isNull);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_findAll, "findAll(self, selectorQuery: Optional[str]) -> QWebElementCollection");

extern "C" {static PyObject *meth_QWebElement_findAll(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_findAll(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QWebElementCollection*sipRes;

            sipRes = new ::QWebElementCollection(sipCpp->findAll(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QWebElementCollection, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_findAll, doc_QWebElement_findAll);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_findFirst, "findFirst(self, selectorQuery: Optional[str]) -> QWebElement");

extern "C" {static PyObject *meth_QWebElement_findFirst(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_findFirst(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QWebElement*sipRes;

            sipRes = new ::QWebElement(sipCpp->findFirst(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QWebElement, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_findFirst, doc_QWebElement_findFirst);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_setPlainText, "setPlainText(self, text: Optional[str])");

extern "C" {static PyObject *meth_QWebElement_setPlainText(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_setPlainText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setPlainText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_setPlainText, doc_QWebElement_setPlainText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_toPlainText, "toPlainText(self) -> str");

extern "C" {static PyObject *meth_QWebElement_toPlainText(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_toPlainText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toPlainText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_toPlainText, doc_QWebElement_toPlainText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_setOuterXml, "setOuterXml(self, markup: Optional[str])");

extern "C" {static PyObject *meth_QWebElement_setOuterXml(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_setOuterXml(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setOuterXml(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_setOuterXml, doc_QWebElement_setOuterXml);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_toOuterXml, "toOuterXml(self) -> str");

extern "C" {static PyObject *meth_QWebElement_toOuterXml(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_toOuterXml(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toOuterXml());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_toOuterXml, doc_QWebElement_toOuterXml);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_setInnerXml, "setInnerXml(self, markup: Optional[str])");

extern "C" {static PyObject *meth_QWebElement_setInnerXml(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_setInnerXml(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setInnerXml(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_setInnerXml, doc_QWebElement_setInnerXml);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_toInnerXml, "toInnerXml(self) -> str");

extern "C" {static PyObject *meth_QWebElement_toInnerXml(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_toInnerXml(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toInnerXml());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_toInnerXml, doc_QWebElement_toInnerXml);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_setAttribute, "setAttribute(self, name: Optional[str], value: Optional[str])");

extern "C" {static PyObject *meth_QWebElement_setAttribute(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_setAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            sipCpp->setAttribute(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_setAttribute, doc_QWebElement_setAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_setAttributeNS, "setAttributeNS(self, namespaceUri: Optional[str], name: Optional[str], value: Optional[str])");

extern "C" {static PyObject *meth_QWebElement_setAttributeNS(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_setAttributeNS(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1J1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State))
        {
            sipCpp->setAttributeNS(*a0, *a1, *a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_setAttributeNS, doc_QWebElement_setAttributeNS);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_attribute, "attribute(self, name: Optional[str], defaultValue: Optional[str] = '') -> str");

extern "C" {static PyObject *meth_QWebElement_attribute(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebElement_attribute(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        const ::QWebElement *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_defaultValue,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->attribute(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_attribute, doc_QWebElement_attribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_attributeNS, "attributeNS(self, namespaceUri: Optional[str], name: Optional[str], defaultValue: Optional[str] = '') -> str");

extern "C" {static PyObject *meth_QWebElement_attributeNS(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebElement_attributeNS(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString& a2def = QString();
        const ::QString* a2 = &a2def;
        int a2State = 0;
        const ::QWebElement *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_defaultValue,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1J1|J1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->attributeNS(*a0, *a1, *a2));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_attributeNS, doc_QWebElement_attributeNS);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_hasAttribute, "hasAttribute(self, name: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QWebElement_hasAttribute(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_hasAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->hasAttribute(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_hasAttribute, doc_QWebElement_hasAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_hasAttributeNS, "hasAttributeNS(self, namespaceUri: Optional[str], name: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QWebElement_hasAttributeNS(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_hasAttributeNS(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->hasAttributeNS(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_hasAttributeNS, doc_QWebElement_hasAttributeNS);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_removeAttribute, "removeAttribute(self, name: Optional[str])");

extern "C" {static PyObject *meth_QWebElement_removeAttribute(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_removeAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->removeAttribute(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_removeAttribute, doc_QWebElement_removeAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_removeAttributeNS, "removeAttributeNS(self, namespaceUri: Optional[str], name: Optional[str])");

extern "C" {static PyObject *meth_QWebElement_removeAttributeNS(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_removeAttributeNS(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            sipCpp->removeAttributeNS(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_removeAttributeNS, doc_QWebElement_removeAttributeNS);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_hasAttributes, "hasAttributes(self) -> bool");

extern "C" {static PyObject *meth_QWebElement_hasAttributes(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_hasAttributes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasAttributes();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_hasAttributes, doc_QWebElement_hasAttributes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_attributeNames, "attributeNames(self, namespaceUri: Optional[str] = '') -> list[str]");

extern "C" {static PyObject *meth_QWebElement_attributeNames(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebElement_attributeNames(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString& a0def = QString();
        const ::QString* a0 = &a0def;
        int a0State = 0;
        const ::QWebElement *sipCpp;

        static const char *sipKwdList[] = {
            sipName_namespaceUri,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->attributeNames(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_attributeNames, doc_QWebElement_attributeNames);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_classes, "classes(self) -> list[str]");

extern "C" {static PyObject *meth_QWebElement_classes(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_classes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->classes());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_classes, doc_QWebElement_classes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_hasClass, "hasClass(self, name: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QWebElement_hasClass(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_hasClass(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->hasClass(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_hasClass, doc_QWebElement_hasClass);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_addClass, "addClass(self, name: Optional[str])");

extern "C" {static PyObject *meth_QWebElement_addClass(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_addClass(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->addClass(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_addClass, doc_QWebElement_addClass);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_removeClass, "removeClass(self, name: Optional[str])");

extern "C" {static PyObject *meth_QWebElement_removeClass(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_removeClass(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->removeClass(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_removeClass, doc_QWebElement_removeClass);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_toggleClass, "toggleClass(self, name: Optional[str])");

extern "C" {static PyObject *meth_QWebElement_toggleClass(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_toggleClass(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->toggleClass(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_toggleClass, doc_QWebElement_toggleClass);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_hasFocus, "hasFocus(self) -> bool");

extern "C" {static PyObject *meth_QWebElement_hasFocus(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_hasFocus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasFocus();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_hasFocus, doc_QWebElement_hasFocus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_setFocus, "setFocus(self)");

extern "C" {static PyObject *meth_QWebElement_setFocus(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_setFocus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            sipCpp->setFocus();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_setFocus, doc_QWebElement_setFocus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_geometry, "geometry(self) -> QRect");

extern "C" {static PyObject *meth_QWebElement_geometry(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_geometry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect(sipCpp->geometry());

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_geometry, doc_QWebElement_geometry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_tagName, "tagName(self) -> str");

extern "C" {static PyObject *meth_QWebElement_tagName(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_tagName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->tagName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_tagName, doc_QWebElement_tagName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_prefix, "prefix(self) -> str");

extern "C" {static PyObject *meth_QWebElement_prefix(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_prefix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->prefix());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_prefix, doc_QWebElement_prefix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_localName, "localName(self) -> str");

extern "C" {static PyObject *meth_QWebElement_localName(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_localName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->localName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_localName, doc_QWebElement_localName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_namespaceUri, "namespaceUri(self) -> str");

extern "C" {static PyObject *meth_QWebElement_namespaceUri(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_namespaceUri(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->namespaceUri());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_namespaceUri, doc_QWebElement_namespaceUri);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_parent, "parent(self) -> QWebElement");

extern "C" {static PyObject *meth_QWebElement_parent(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_parent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QWebElement*sipRes;

            sipRes = new ::QWebElement(sipCpp->parent());

            return sipConvertFromNewType(sipRes, sipType_QWebElement, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_parent, doc_QWebElement_parent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_firstChild, "firstChild(self) -> QWebElement");

extern "C" {static PyObject *meth_QWebElement_firstChild(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_firstChild(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QWebElement*sipRes;

            sipRes = new ::QWebElement(sipCpp->firstChild());

            return sipConvertFromNewType(sipRes, sipType_QWebElement, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_firstChild, doc_QWebElement_firstChild);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_lastChild, "lastChild(self) -> QWebElement");

extern "C" {static PyObject *meth_QWebElement_lastChild(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_lastChild(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QWebElement*sipRes;

            sipRes = new ::QWebElement(sipCpp->lastChild());

            return sipConvertFromNewType(sipRes, sipType_QWebElement, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_lastChild, doc_QWebElement_lastChild);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_nextSibling, "nextSibling(self) -> QWebElement");

extern "C" {static PyObject *meth_QWebElement_nextSibling(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_nextSibling(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QWebElement*sipRes;

            sipRes = new ::QWebElement(sipCpp->nextSibling());

            return sipConvertFromNewType(sipRes, sipType_QWebElement, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_nextSibling, doc_QWebElement_nextSibling);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_previousSibling, "previousSibling(self) -> QWebElement");

extern "C" {static PyObject *meth_QWebElement_previousSibling(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_previousSibling(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QWebElement*sipRes;

            sipRes = new ::QWebElement(sipCpp->previousSibling());

            return sipConvertFromNewType(sipRes, sipType_QWebElement, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_previousSibling, doc_QWebElement_previousSibling);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_document, "document(self) -> QWebElement");

extern "C" {static PyObject *meth_QWebElement_document(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_document(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QWebElement*sipRes;

            sipRes = new ::QWebElement(sipCpp->document());

            return sipConvertFromNewType(sipRes, sipType_QWebElement, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_document, doc_QWebElement_document);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_webFrame, "webFrame(self) -> Optional[QWebFrame]");

extern "C" {static PyObject *meth_QWebElement_webFrame(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_webFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QWebFrame*sipRes;

            sipRes = sipCpp->webFrame();

            return sipConvertFromType(sipRes, sipType_QWebFrame, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_webFrame, doc_QWebElement_webFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_appendInside, "appendInside(self, markup: Optional[str])\n"
"appendInside(self, element: QWebElement)");

extern "C" {static PyObject *meth_QWebElement_appendInside(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_appendInside(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->appendInside(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QWebElement* a0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QWebElement, &a0))
        {
            sipCpp->appendInside(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_appendInside, doc_QWebElement_appendInside);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_prependInside, "prependInside(self, markup: Optional[str])\n"
"prependInside(self, element: QWebElement)");

extern "C" {static PyObject *meth_QWebElement_prependInside(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_prependInside(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->prependInside(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QWebElement* a0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QWebElement, &a0))
        {
            sipCpp->prependInside(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_prependInside, doc_QWebElement_prependInside);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_appendOutside, "appendOutside(self, markup: Optional[str])\n"
"appendOutside(self, element: QWebElement)");

extern "C" {static PyObject *meth_QWebElement_appendOutside(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_appendOutside(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->appendOutside(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QWebElement* a0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QWebElement, &a0))
        {
            sipCpp->appendOutside(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_appendOutside, doc_QWebElement_appendOutside);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_prependOutside, "prependOutside(self, markup: Optional[str])\n"
"prependOutside(self, element: QWebElement)");

extern "C" {static PyObject *meth_QWebElement_prependOutside(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_prependOutside(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->prependOutside(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QWebElement* a0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QWebElement, &a0))
        {
            sipCpp->prependOutside(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_prependOutside, doc_QWebElement_prependOutside);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_encloseContentsWith, "encloseContentsWith(self, element: QWebElement)\n"
"encloseContentsWith(self, markup: Optional[str])");

extern "C" {static PyObject *meth_QWebElement_encloseContentsWith(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_encloseContentsWith(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement* a0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QWebElement, &a0))
        {
            sipCpp->encloseContentsWith(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->encloseContentsWith(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_encloseContentsWith, doc_QWebElement_encloseContentsWith);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_encloseWith, "encloseWith(self, markup: Optional[str])\n"
"encloseWith(self, element: QWebElement)");

extern "C" {static PyObject *meth_QWebElement_encloseWith(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_encloseWith(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->encloseWith(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QWebElement* a0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QWebElement, &a0))
        {
            sipCpp->encloseWith(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_encloseWith, doc_QWebElement_encloseWith);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_replace, "replace(self, markup: Optional[str])\n"
"replace(self, element: QWebElement)");

extern "C" {static PyObject *meth_QWebElement_replace(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_replace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->replace(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QWebElement* a0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QWebElement, &a0))
        {
            sipCpp->replace(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_replace, doc_QWebElement_replace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_clone, "clone(self) -> QWebElement");

extern "C" {static PyObject *meth_QWebElement_clone(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_clone(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QWebElement*sipRes;

            sipRes = new ::QWebElement(sipCpp->clone());

            return sipConvertFromNewType(sipRes, sipType_QWebElement, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_clone, doc_QWebElement_clone);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_takeFromDocument, "takeFromDocument(self) -> QWebElement");

extern "C" {static PyObject *meth_QWebElement_takeFromDocument(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_takeFromDocument(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            ::QWebElement*sipRes;

            sipRes = &sipCpp->takeFromDocument();

            return sipConvertFromType(sipRes, sipType_QWebElement, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_takeFromDocument, doc_QWebElement_takeFromDocument);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_removeFromDocument, "removeFromDocument(self)");

extern "C" {static PyObject *meth_QWebElement_removeFromDocument(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_removeFromDocument(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            sipCpp->removeFromDocument();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_removeFromDocument, doc_QWebElement_removeFromDocument);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_removeAllChildren, "removeAllChildren(self)");

extern "C" {static PyObject *meth_QWebElement_removeAllChildren(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_removeAllChildren(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebElement, &sipCpp))
        {
            sipCpp->removeAllChildren();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_removeAllChildren, doc_QWebElement_removeAllChildren);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_evaluateJavaScript, "evaluateJavaScript(self, scriptSource: Optional[str]) -> Any");

extern "C" {static PyObject *meth_QWebElement_evaluateJavaScript(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_evaluateJavaScript(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->evaluateJavaScript(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_evaluateJavaScript, doc_QWebElement_evaluateJavaScript);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_styleProperty, "styleProperty(self, name: Optional[str], strategy: QWebElement.StyleResolveStrategy) -> str");

extern "C" {static PyObject *meth_QWebElement_styleProperty(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_styleProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebElement::StyleResolveStrategy a1;
        const ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1E", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QWebElement_StyleResolveStrategy, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->styleProperty(*a0, a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_styleProperty, doc_QWebElement_styleProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_setStyleProperty, "setStyleProperty(self, name: Optional[str], value: Optional[str])");

extern "C" {static PyObject *meth_QWebElement_setStyleProperty(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_setStyleProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            sipCpp->setStyleProperty(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_setStyleProperty, doc_QWebElement_setStyleProperty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebElement_render, "render(self, painter: Optional[QPainter])\n"
"render(self, painter: Optional[QPainter], clip: QRect)");

extern "C" {static PyObject *meth_QWebElement_render(PyObject *, PyObject *);}
static PyObject *meth_QWebElement_render(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPainter* a0;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QPainter, &a0))
        {
            sipCpp->render(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QPainter* a0;
        const ::QRect* a1;
        ::QWebElement *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J9", &sipSelf, sipType_QWebElement, &sipCpp, sipType_QPainter, &a0, sipType_QRect, &a1))
        {
            sipCpp->render(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebElement, sipName_render, doc_QWebElement_render);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QWebElement___ne__(PyObject *, PyObject *);}
static PyObject *slot_QWebElement___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QWebElement *sipCpp = reinterpret_cast< ::QWebElement *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QWebElement));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QWebElement, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QWebElement::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtWebKit, ne_slot, sipType_QWebElement, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QWebElement___eq__(PyObject *, PyObject *);}
static PyObject *slot_QWebElement___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QWebElement *sipCpp = reinterpret_cast< ::QWebElement *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QWebElement));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebElement* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QWebElement, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QWebElement::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtWebKit, eq_slot, sipType_QWebElement, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebElement(void *, int);}
static void release_QWebElement(void *sipCppV, int)
{
    delete reinterpret_cast< ::QWebElement *>(sipCppV);
}


extern "C" {static void *array_QWebElement(Py_ssize_t);}
static void *array_QWebElement(Py_ssize_t sipNrElem)
{
    return new ::QWebElement[sipNrElem];
}


extern "C" {static void array_delete_QWebElement(void *);}
static void array_delete_QWebElement(void *sipCpp)
{
    delete[] reinterpret_cast< ::QWebElement *>(sipCpp);
}


extern "C" {static void assign_QWebElement(void *, Py_ssize_t, void *);}
static void assign_QWebElement(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QWebElement *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QWebElement *>(sipSrc);
}


extern "C" {static void *copy_QWebElement(const void *, Py_ssize_t);}
static void *copy_QWebElement(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QWebElement(reinterpret_cast<const ::QWebElement *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QWebElement(sipSimpleWrapper *);}
static void dealloc_QWebElement(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWebElement(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QWebElement(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWebElement(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QWebElement *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QWebElement();

            return sipCpp;
        }
    }

    {
        const ::QWebElement* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QWebElement, &a0))
        {
            sipCpp = new ::QWebElement(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QWebElement[] = {
    {(void *)slot_QWebElement___ne__, ne_slot},
    {(void *)slot_QWebElement___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QWebElement[] = {
    {sipName_addClass, meth_QWebElement_addClass, METH_VARARGS, doc_QWebElement_addClass},
    {sipName_appendInside, meth_QWebElement_appendInside, METH_VARARGS, doc_QWebElement_appendInside},
    {sipName_appendOutside, meth_QWebElement_appendOutside, METH_VARARGS, doc_QWebElement_appendOutside},
    {sipName_attribute, SIP_MLMETH_CAST(meth_QWebElement_attribute), METH_VARARGS|METH_KEYWORDS, doc_QWebElement_attribute},
    {sipName_attributeNS, SIP_MLMETH_CAST(meth_QWebElement_attributeNS), METH_VARARGS|METH_KEYWORDS, doc_QWebElement_attributeNS},
    {sipName_attributeNames, SIP_MLMETH_CAST(meth_QWebElement_attributeNames), METH_VARARGS|METH_KEYWORDS, doc_QWebElement_attributeNames},
    {sipName_classes, meth_QWebElement_classes, METH_VARARGS, doc_QWebElement_classes},
    {sipName_clone, meth_QWebElement_clone, METH_VARARGS, doc_QWebElement_clone},
    {sipName_document, meth_QWebElement_document, METH_VARARGS, doc_QWebElement_document},
    {sipName_encloseContentsWith, meth_QWebElement_encloseContentsWith, METH_VARARGS, doc_QWebElement_encloseContentsWith},
    {sipName_encloseWith, meth_QWebElement_encloseWith, METH_VARARGS, doc_QWebElement_encloseWith},
    {sipName_evaluateJavaScript, meth_QWebElement_evaluateJavaScript, METH_VARARGS, doc_QWebElement_evaluateJavaScript},
    {sipName_findAll, meth_QWebElement_findAll, METH_VARARGS, doc_QWebElement_findAll},
    {sipName_findFirst, meth_QWebElement_findFirst, METH_VARARGS, doc_QWebElement_findFirst},
    {sipName_firstChild, meth_QWebElement_firstChild, METH_VARARGS, doc_QWebElement_firstChild},
    {sipName_geometry, meth_QWebElement_geometry, METH_VARARGS, doc_QWebElement_geometry},
    {sipName_hasAttribute, meth_QWebElement_hasAttribute, METH_VARARGS, doc_QWebElement_hasAttribute},
    {sipName_hasAttributeNS, meth_QWebElement_hasAttributeNS, METH_VARARGS, doc_QWebElement_hasAttributeNS},
    {sipName_hasAttributes, meth_QWebElement_hasAttributes, METH_VARARGS, doc_QWebElement_hasAttributes},
    {sipName_hasClass, meth_QWebElement_hasClass, METH_VARARGS, doc_QWebElement_hasClass},
    {sipName_hasFocus, meth_QWebElement_hasFocus, METH_VARARGS, doc_QWebElement_hasFocus},
    {sipName_isNull, meth_QWebElement_isNull, METH_VARARGS, doc_QWebElement_isNull},
    {sipName_lastChild, meth_QWebElement_lastChild, METH_VARARGS, doc_QWebElement_lastChild},
    {sipName_localName, meth_QWebElement_localName, METH_VARARGS, doc_QWebElement_localName},
    {sipName_namespaceUri, meth_QWebElement_namespaceUri, METH_VARARGS, doc_QWebElement_namespaceUri},
    {sipName_nextSibling, meth_QWebElement_nextSibling, METH_VARARGS, doc_QWebElement_nextSibling},
    {sipName_parent, meth_QWebElement_parent, METH_VARARGS, doc_QWebElement_parent},
    {sipName_prefix, meth_QWebElement_prefix, METH_VARARGS, doc_QWebElement_prefix},
    {sipName_prependInside, meth_QWebElement_prependInside, METH_VARARGS, doc_QWebElement_prependInside},
    {sipName_prependOutside, meth_QWebElement_prependOutside, METH_VARARGS, doc_QWebElement_prependOutside},
    {sipName_previousSibling, meth_QWebElement_previousSibling, METH_VARARGS, doc_QWebElement_previousSibling},
    {sipName_removeAllChildren, meth_QWebElement_removeAllChildren, METH_VARARGS, doc_QWebElement_removeAllChildren},
    {sipName_removeAttribute, meth_QWebElement_removeAttribute, METH_VARARGS, doc_QWebElement_removeAttribute},
    {sipName_removeAttributeNS, meth_QWebElement_removeAttributeNS, METH_VARARGS, doc_QWebElement_removeAttributeNS},
    {sipName_removeClass, meth_QWebElement_removeClass, METH_VARARGS, doc_QWebElement_removeClass},
    {sipName_removeFromDocument, meth_QWebElement_removeFromDocument, METH_VARARGS, doc_QWebElement_removeFromDocument},
    {sipName_render, meth_QWebElement_render, METH_VARARGS, doc_QWebElement_render},
    {sipName_replace, meth_QWebElement_replace, METH_VARARGS, doc_QWebElement_replace},
    {sipName_setAttribute, meth_QWebElement_setAttribute, METH_VARARGS, doc_QWebElement_setAttribute},
    {sipName_setAttributeNS, meth_QWebElement_setAttributeNS, METH_VARARGS, doc_QWebElement_setAttributeNS},
    {sipName_setFocus, meth_QWebElement_setFocus, METH_VARARGS, doc_QWebElement_setFocus},
    {sipName_setInnerXml, meth_QWebElement_setInnerXml, METH_VARARGS, doc_QWebElement_setInnerXml},
    {sipName_setOuterXml, meth_QWebElement_setOuterXml, METH_VARARGS, doc_QWebElement_setOuterXml},
    {sipName_setPlainText, meth_QWebElement_setPlainText, METH_VARARGS, doc_QWebElement_setPlainText},
    {sipName_setStyleProperty, meth_QWebElement_setStyleProperty, METH_VARARGS, doc_QWebElement_setStyleProperty},
    {sipName_styleProperty, meth_QWebElement_styleProperty, METH_VARARGS, doc_QWebElement_styleProperty},
    {sipName_tagName, meth_QWebElement_tagName, METH_VARARGS, doc_QWebElement_tagName},
    {sipName_takeFromDocument, meth_QWebElement_takeFromDocument, METH_VARARGS, doc_QWebElement_takeFromDocument},
    {sipName_toInnerXml, meth_QWebElement_toInnerXml, METH_VARARGS, doc_QWebElement_toInnerXml},
    {sipName_toOuterXml, meth_QWebElement_toOuterXml, METH_VARARGS, doc_QWebElement_toOuterXml},
    {sipName_toPlainText, meth_QWebElement_toPlainText, METH_VARARGS, doc_QWebElement_toPlainText},
    {sipName_toggleClass, meth_QWebElement_toggleClass, METH_VARARGS, doc_QWebElement_toggleClass},
    {sipName_webFrame, meth_QWebElement_webFrame, METH_VARARGS, doc_QWebElement_webFrame}
};

static sipEnumMemberDef enummembers_QWebElement[] = {
    {sipName_CascadedStyle, static_cast<int>(::QWebElement::CascadedStyle), 8},
    {sipName_ComputedStyle, static_cast<int>(::QWebElement::ComputedStyle), 8},
    {sipName_InlineStyle, static_cast<int>(::QWebElement::InlineStyle), 8},
};

PyDoc_STRVAR(doc_QWebElement, "\1QWebElement()\n"
"QWebElement(a0: QWebElement)");


static pyqt5ClassPluginDef plugin_QWebElement = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKit_QWebElement = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebElement,
        SIP_NULLPTR,
        &plugin_QWebElement,
    },
    {
        sipNameNr_QWebElement,
        {0, 0, 1},
        53, methods_QWebElement,
        3, enummembers_QWebElement,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWebElement,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QWebElement,
    init_type_QWebElement,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWebElement,
    assign_QWebElement,
    array_QWebElement,
    copy_QWebElement,
    release_QWebElement,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QWebElement,
    sizeof (::QWebElement),
};
