/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtX11Extras.h"

#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtX11Extras/qx11info_x11.sip"
#include <qx11info_x11.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtX11Extras/sipQtX11ExtrasQX11Info.cpp"

#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtX11Extras/sipQtX11ExtrasQX11Info.cpp"


PyDoc_STRVAR(doc_QX11Info_isPlatformX11, "isPlatformX11() -> bool");

extern "C" {static PyObject *meth_QX11Info_isPlatformX11(PyObject *, PyObject *);}
static PyObject *meth_QX11Info_isPlatformX11(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            bool sipRes;

            sipRes = ::QX11Info::isPlatformX11();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QX11Info, sipName_isPlatformX11, doc_QX11Info_isPlatformX11);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QX11Info_appDpiX, "appDpiX(screen: int = -1) -> int");

extern "C" {static PyObject *meth_QX11Info_appDpiX(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QX11Info_appDpiX(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = -1;

        static const char *sipKwdList[] = {
            sipName_screen,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "|i", &a0))
        {
            int sipRes;

            sipRes = ::QX11Info::appDpiX(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QX11Info, sipName_appDpiX, doc_QX11Info_appDpiX);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QX11Info_appDpiY, "appDpiY(screen: int = -1) -> int");

extern "C" {static PyObject *meth_QX11Info_appDpiY(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QX11Info_appDpiY(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = -1;

        static const char *sipKwdList[] = {
            sipName_screen,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "|i", &a0))
        {
            int sipRes;

            sipRes = ::QX11Info::appDpiY(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QX11Info, sipName_appDpiY, doc_QX11Info_appDpiY);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QX11Info_appRootWindow, "appRootWindow(screen: int = -1) -> int");

extern "C" {static PyObject *meth_QX11Info_appRootWindow(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QX11Info_appRootWindow(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = -1;

        static const char *sipKwdList[] = {
            sipName_screen,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "|i", &a0))
        {
            unsigned long sipRes;

            sipRes = ::QX11Info::appRootWindow(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QX11Info, sipName_appRootWindow, doc_QX11Info_appRootWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QX11Info_appScreen, "appScreen() -> int");

extern "C" {static PyObject *meth_QX11Info_appScreen(PyObject *, PyObject *);}
static PyObject *meth_QX11Info_appScreen(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            int sipRes;

            sipRes = ::QX11Info::appScreen();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QX11Info, sipName_appScreen, doc_QX11Info_appScreen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QX11Info_appTime, "appTime() -> int");

extern "C" {static PyObject *meth_QX11Info_appTime(PyObject *, PyObject *);}
static PyObject *meth_QX11Info_appTime(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            unsigned long sipRes;

            sipRes = ::QX11Info::appTime();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QX11Info, sipName_appTime, doc_QX11Info_appTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QX11Info_appUserTime, "appUserTime() -> int");

extern "C" {static PyObject *meth_QX11Info_appUserTime(PyObject *, PyObject *);}
static PyObject *meth_QX11Info_appUserTime(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            unsigned long sipRes;

            sipRes = ::QX11Info::appUserTime();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QX11Info, sipName_appUserTime, doc_QX11Info_appUserTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QX11Info_setAppTime, "setAppTime(time: int)");

extern "C" {static PyObject *meth_QX11Info_setAppTime(PyObject *, PyObject *);}
static PyObject *meth_QX11Info_setAppTime(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        unsigned long a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "m", &a0))
        {
            ::QX11Info::setAppTime(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QX11Info, sipName_setAppTime, doc_QX11Info_setAppTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QX11Info_setAppUserTime, "setAppUserTime(time: int)");

extern "C" {static PyObject *meth_QX11Info_setAppUserTime(PyObject *, PyObject *);}
static PyObject *meth_QX11Info_setAppUserTime(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        unsigned long a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "m", &a0))
        {
            ::QX11Info::setAppUserTime(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QX11Info, sipName_setAppUserTime, doc_QX11Info_setAppUserTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QX11Info_getTimestamp, "getTimestamp() -> int");

extern "C" {static PyObject *meth_QX11Info_getTimestamp(PyObject *, PyObject *);}
static PyObject *meth_QX11Info_getTimestamp(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            unsigned long sipRes;

            sipRes = ::QX11Info::getTimestamp();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QX11Info, sipName_getTimestamp, doc_QX11Info_getTimestamp);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QX11Info_nextStartupId, "nextStartupId() -> QByteArray");

extern "C" {static PyObject *meth_QX11Info_nextStartupId(PyObject *, PyObject *);}
static PyObject *meth_QX11Info_nextStartupId(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(::QX11Info::nextStartupId());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QX11Info, sipName_nextStartupId, doc_QX11Info_nextStartupId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QX11Info_setNextStartupId, "setNextStartupId(id: Union[QByteArray, bytes, bytearray])");

extern "C" {static PyObject *meth_QX11Info_setNextStartupId(PyObject *, PyObject *);}
static PyObject *meth_QX11Info_setNextStartupId(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QByteArray, &a0, &a0State))
        {
            ::QX11Info::setNextStartupId(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QX11Info, sipName_setNextStartupId, doc_QX11Info_setNextStartupId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QX11Info_display, "display() -> Optional[Display]");

extern "C" {static PyObject *meth_QX11Info_display(PyObject *, PyObject *);}
static PyObject *meth_QX11Info_display(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::Display*sipRes;

            sipRes = ::QX11Info::display();

            return sipConvertFromType(sipRes, sipType_Display, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QX11Info, sipName_display, doc_QX11Info_display);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QX11Info_connection, "connection() -> Optional[xcb_connection_t]");

extern "C" {static PyObject *meth_QX11Info_connection(PyObject *, PyObject *);}
static PyObject *meth_QX11Info_connection(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::xcb_connection_t*sipRes;

            sipRes = ::QX11Info::connection();

            return sipConvertFromType(sipRes, sipType_xcb_connection_t, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QX11Info, sipName_connection, doc_QX11Info_connection);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QX11Info(void *, int);}
static void release_QX11Info(void *sipCppV, int)
{
    delete reinterpret_cast< ::QX11Info *>(sipCppV);
}


extern "C" {static void assign_QX11Info(void *, Py_ssize_t, void *);}
static void assign_QX11Info(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QX11Info *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QX11Info *>(sipSrc);
}


extern "C" {static void *copy_QX11Info(const void *, Py_ssize_t);}
static void *copy_QX11Info(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QX11Info(reinterpret_cast<const ::QX11Info *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QX11Info(sipSimpleWrapper *);}
static void dealloc_QX11Info(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QX11Info(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QX11Info(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QX11Info(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QX11Info *sipCpp = SIP_NULLPTR;

    {
        const ::QX11Info* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QX11Info, &a0))
        {
            sipCpp = new ::QX11Info(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QX11Info[] = {
    {sipName_appDpiX, SIP_MLMETH_CAST(meth_QX11Info_appDpiX), METH_VARARGS|METH_KEYWORDS, doc_QX11Info_appDpiX},
    {sipName_appDpiY, SIP_MLMETH_CAST(meth_QX11Info_appDpiY), METH_VARARGS|METH_KEYWORDS, doc_QX11Info_appDpiY},
    {sipName_appRootWindow, SIP_MLMETH_CAST(meth_QX11Info_appRootWindow), METH_VARARGS|METH_KEYWORDS, doc_QX11Info_appRootWindow},
    {sipName_appScreen, meth_QX11Info_appScreen, METH_VARARGS, doc_QX11Info_appScreen},
    {sipName_appTime, meth_QX11Info_appTime, METH_VARARGS, doc_QX11Info_appTime},
    {sipName_appUserTime, meth_QX11Info_appUserTime, METH_VARARGS, doc_QX11Info_appUserTime},
    {sipName_connection, meth_QX11Info_connection, METH_VARARGS, doc_QX11Info_connection},
    {sipName_display, meth_QX11Info_display, METH_VARARGS, doc_QX11Info_display},
    {sipName_getTimestamp, meth_QX11Info_getTimestamp, METH_VARARGS, doc_QX11Info_getTimestamp},
    {sipName_isPlatformX11, meth_QX11Info_isPlatformX11, METH_VARARGS, doc_QX11Info_isPlatformX11},
    {sipName_nextStartupId, meth_QX11Info_nextStartupId, METH_VARARGS, doc_QX11Info_nextStartupId},
    {sipName_setAppTime, meth_QX11Info_setAppTime, METH_VARARGS, doc_QX11Info_setAppTime},
    {sipName_setAppUserTime, meth_QX11Info_setAppUserTime, METH_VARARGS, doc_QX11Info_setAppUserTime},
    {sipName_setNextStartupId, meth_QX11Info_setNextStartupId, METH_VARARGS, doc_QX11Info_setNextStartupId}
};

PyDoc_STRVAR(doc_QX11Info, "\1QX11Info(a0: QX11Info)");


static pyqt5ClassPluginDef plugin_QX11Info = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtX11Extras_QX11Info = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QX11Info,
        SIP_NULLPTR,
        &plugin_QX11Info,
    },
    {
        sipNameNr_QX11Info,
        {0, 0, 1},
        14, methods_QX11Info,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QX11Info,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QX11Info,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QX11Info,
    assign_QX11Info,
    SIP_NULLPTR,
    copy_QX11Info,
    release_QX11Info,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QX11Info),
};
