/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDesigner.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/customwidget.sip"
#include <QtDesigner>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerCustomWidgetInterface.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerCustomWidgetInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/abstractformeditor.sip"
#include <abstractformeditor.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerCustomWidgetInterface.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerCustomWidgetInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQDesignerCustomWidgetInterface.cpp"


class sipQDesignerCustomWidgetInterface : public ::QDesignerCustomWidgetInterface
{
public:
    sipQDesignerCustomWidgetInterface();
    sipQDesignerCustomWidgetInterface(const ::QDesignerCustomWidgetInterface&);
    virtual ~sipQDesignerCustomWidgetInterface();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QString codeTemplate() const SIP_OVERRIDE;
    ::QString domXml() const SIP_OVERRIDE;
    void initialize(::QDesignerFormEditorInterface*) SIP_OVERRIDE;
    bool isInitialized() const SIP_OVERRIDE;
    ::QWidget* createWidget(::QWidget*) SIP_OVERRIDE;
    bool isContainer() const SIP_OVERRIDE;
    ::QIcon icon() const SIP_OVERRIDE;
    ::QString includeFile() const SIP_OVERRIDE;
    ::QString whatsThis() const SIP_OVERRIDE;
    ::QString toolTip() const SIP_OVERRIDE;
    ::QString group() const SIP_OVERRIDE;
    ::QString name() const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQDesignerCustomWidgetInterface(const sipQDesignerCustomWidgetInterface &);
    sipQDesignerCustomWidgetInterface &operator = (const sipQDesignerCustomWidgetInterface &);

    char sipPyMethods[12];
};

sipQDesignerCustomWidgetInterface::sipQDesignerCustomWidgetInterface(): ::QDesignerCustomWidgetInterface(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQDesignerCustomWidgetInterface::sipQDesignerCustomWidgetInterface(const ::QDesignerCustomWidgetInterface& a0): ::QDesignerCustomWidgetInterface(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQDesignerCustomWidgetInterface::~sipQDesignerCustomWidgetInterface()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

::QString sipQDesignerCustomWidgetInterface::codeTemplate() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_codeTemplate);

    if (!sipMeth)
        return ::QDesignerCustomWidgetInterface::codeTemplate();

    extern ::QString sipVH_QtDesigner_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_41(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QString sipQDesignerCustomWidgetInterface::domXml() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_domXml);

    if (!sipMeth)
        return ::QDesignerCustomWidgetInterface::domXml();

    extern ::QString sipVH_QtDesigner_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_41(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQDesignerCustomWidgetInterface::initialize(::QDesignerFormEditorInterface*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_initialize);

    if (!sipMeth)
    {
        ::QDesignerCustomWidgetInterface::initialize(a0);
        return;
    }

    extern void sipVH_QtDesigner_82(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDesignerFormEditorInterface*);

    sipVH_QtDesigner_82(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQDesignerCustomWidgetInterface::isInitialized() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isInitialized);

    if (!sipMeth)
        return ::QDesignerCustomWidgetInterface::isInitialized();

    extern bool sipVH_QtDesigner_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_3(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QWidget* sipQDesignerCustomWidgetInterface::createWidget(::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, sipName_QDesignerCustomWidgetInterface, sipName_createWidget);

    if (!sipMeth)
        return 0;

    extern ::QWidget* sipVH_QtDesigner_81(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*);

    return sipVH_QtDesigner_81(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQDesignerCustomWidgetInterface::isContainer() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerCustomWidgetInterface, sipName_isContainer);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_3(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QIcon sipQDesignerCustomWidgetInterface::icon() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerCustomWidgetInterface, sipName_icon);

    if (!sipMeth)
        return ::QIcon();

    extern ::QIcon sipVH_QtDesigner_80(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_80(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QString sipQDesignerCustomWidgetInterface::includeFile() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerCustomWidgetInterface, sipName_includeFile);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtDesigner_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_41(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QString sipQDesignerCustomWidgetInterface::whatsThis() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerCustomWidgetInterface, sipName_whatsThis);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtDesigner_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_41(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QString sipQDesignerCustomWidgetInterface::toolTip() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerCustomWidgetInterface, sipName_toolTip);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtDesigner_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_41(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QString sipQDesignerCustomWidgetInterface::group() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerCustomWidgetInterface, sipName_group);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtDesigner_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_41(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QString sipQDesignerCustomWidgetInterface::name() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QDesignerCustomWidgetInterface, sipName_name);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtDesigner_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_41(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QDesignerCustomWidgetInterface_name, "name(self) -> str");

extern "C" {static PyObject *meth_QDesignerCustomWidgetInterface_name(PyObject *, PyObject *);}
static PyObject *meth_QDesignerCustomWidgetInterface_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerCustomWidgetInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerCustomWidgetInterface, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerCustomWidgetInterface, sipName_name);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerCustomWidgetInterface, sipName_name, doc_QDesignerCustomWidgetInterface_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerCustomWidgetInterface_group, "group(self) -> str");

extern "C" {static PyObject *meth_QDesignerCustomWidgetInterface_group(PyObject *, PyObject *);}
static PyObject *meth_QDesignerCustomWidgetInterface_group(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerCustomWidgetInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerCustomWidgetInterface, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerCustomWidgetInterface, sipName_group);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->group());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerCustomWidgetInterface, sipName_group, doc_QDesignerCustomWidgetInterface_group);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerCustomWidgetInterface_toolTip, "toolTip(self) -> str");

extern "C" {static PyObject *meth_QDesignerCustomWidgetInterface_toolTip(PyObject *, PyObject *);}
static PyObject *meth_QDesignerCustomWidgetInterface_toolTip(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerCustomWidgetInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerCustomWidgetInterface, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerCustomWidgetInterface, sipName_toolTip);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->toolTip());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerCustomWidgetInterface, sipName_toolTip, doc_QDesignerCustomWidgetInterface_toolTip);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerCustomWidgetInterface_whatsThis, "whatsThis(self) -> str");

extern "C" {static PyObject *meth_QDesignerCustomWidgetInterface_whatsThis(PyObject *, PyObject *);}
static PyObject *meth_QDesignerCustomWidgetInterface_whatsThis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerCustomWidgetInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerCustomWidgetInterface, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerCustomWidgetInterface, sipName_whatsThis);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->whatsThis());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerCustomWidgetInterface, sipName_whatsThis, doc_QDesignerCustomWidgetInterface_whatsThis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerCustomWidgetInterface_includeFile, "includeFile(self) -> str");

extern "C" {static PyObject *meth_QDesignerCustomWidgetInterface_includeFile(PyObject *, PyObject *);}
static PyObject *meth_QDesignerCustomWidgetInterface_includeFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerCustomWidgetInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerCustomWidgetInterface, &sipCpp))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerCustomWidgetInterface, sipName_includeFile);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->includeFile());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerCustomWidgetInterface, sipName_includeFile, doc_QDesignerCustomWidgetInterface_includeFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerCustomWidgetInterface_icon, "icon(self) -> QIcon");

extern "C" {static PyObject *meth_QDesignerCustomWidgetInterface_icon(PyObject *, PyObject *);}
static PyObject *meth_QDesignerCustomWidgetInterface_icon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerCustomWidgetInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerCustomWidgetInterface, &sipCpp))
        {
            ::QIcon*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerCustomWidgetInterface, sipName_icon);
                return SIP_NULLPTR;
            }

            sipRes = new ::QIcon(sipCpp->icon());

            return sipConvertFromNewType(sipRes, sipType_QIcon, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerCustomWidgetInterface, sipName_icon, doc_QDesignerCustomWidgetInterface_icon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerCustomWidgetInterface_isContainer, "isContainer(self) -> bool");

extern "C" {static PyObject *meth_QDesignerCustomWidgetInterface_isContainer(PyObject *, PyObject *);}
static PyObject *meth_QDesignerCustomWidgetInterface_isContainer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QDesignerCustomWidgetInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerCustomWidgetInterface, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerCustomWidgetInterface, sipName_isContainer);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isContainer();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerCustomWidgetInterface, sipName_isContainer, doc_QDesignerCustomWidgetInterface_isContainer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerCustomWidgetInterface_createWidget, "createWidget(self, parent: Optional[QWidget]) -> Optional[QWidget]");

extern "C" {static PyObject *meth_QDesignerCustomWidgetInterface_createWidget(PyObject *, PyObject *);}
static PyObject *meth_QDesignerCustomWidgetInterface_createWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QWidget* a0;
        sipWrapper *sipOwner = SIP_NULLPTR;
        ::QDesignerCustomWidgetInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJH", &sipSelf, sipType_QDesignerCustomWidgetInterface, &sipCpp, sipType_QWidget, &a0, &sipOwner))
        {
            ::QWidget*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QDesignerCustomWidgetInterface, sipName_createWidget);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->createWidget(a0);

            return sipConvertFromNewType(sipRes, sipType_QWidget, (PyObject *)sipOwner);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerCustomWidgetInterface, sipName_createWidget, doc_QDesignerCustomWidgetInterface_createWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerCustomWidgetInterface_isInitialized, "isInitialized(self) -> bool");

extern "C" {static PyObject *meth_QDesignerCustomWidgetInterface_isInitialized(PyObject *, PyObject *);}
static PyObject *meth_QDesignerCustomWidgetInterface_isInitialized(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QDesignerCustomWidgetInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerCustomWidgetInterface, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QDesignerCustomWidgetInterface::isInitialized() : sipCpp->isInitialized());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerCustomWidgetInterface, sipName_isInitialized, doc_QDesignerCustomWidgetInterface_isInitialized);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerCustomWidgetInterface_initialize, "initialize(self, core: Optional[QDesignerFormEditorInterface])");

extern "C" {static PyObject *meth_QDesignerCustomWidgetInterface_initialize(PyObject *, PyObject *);}
static PyObject *meth_QDesignerCustomWidgetInterface_initialize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QDesignerFormEditorInterface* a0;
        ::QDesignerCustomWidgetInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QDesignerCustomWidgetInterface, &sipCpp, sipType_QDesignerFormEditorInterface, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QDesignerCustomWidgetInterface::initialize(a0) : sipCpp->initialize(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerCustomWidgetInterface, sipName_initialize, doc_QDesignerCustomWidgetInterface_initialize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerCustomWidgetInterface_domXml, "domXml(self) -> str");

extern "C" {static PyObject *meth_QDesignerCustomWidgetInterface_domXml(PyObject *, PyObject *);}
static PyObject *meth_QDesignerCustomWidgetInterface_domXml(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QDesignerCustomWidgetInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerCustomWidgetInterface, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString((sipSelfWasArg ? sipCpp->::QDesignerCustomWidgetInterface::domXml() : sipCpp->domXml()));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerCustomWidgetInterface, sipName_domXml, doc_QDesignerCustomWidgetInterface_domXml);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDesignerCustomWidgetInterface_codeTemplate, "codeTemplate(self) -> str");

extern "C" {static PyObject *meth_QDesignerCustomWidgetInterface_codeTemplate(PyObject *, PyObject *);}
static PyObject *meth_QDesignerCustomWidgetInterface_codeTemplate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QDesignerCustomWidgetInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDesignerCustomWidgetInterface, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString((sipSelfWasArg ? sipCpp->::QDesignerCustomWidgetInterface::codeTemplate() : sipCpp->codeTemplate()));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDesignerCustomWidgetInterface, sipName_codeTemplate, doc_QDesignerCustomWidgetInterface_codeTemplate);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDesignerCustomWidgetInterface(void *, int);}
static void release_QDesignerCustomWidgetInterface(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQDesignerCustomWidgetInterface *>(sipCppV);
    else
        delete reinterpret_cast< ::QDesignerCustomWidgetInterface *>(sipCppV);
}


extern "C" {static void dealloc_QDesignerCustomWidgetInterface(sipSimpleWrapper *);}
static void dealloc_QDesignerCustomWidgetInterface(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQDesignerCustomWidgetInterface *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDesignerCustomWidgetInterface(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QDesignerCustomWidgetInterface(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDesignerCustomWidgetInterface(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQDesignerCustomWidgetInterface *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQDesignerCustomWidgetInterface();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QDesignerCustomWidgetInterface* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QDesignerCustomWidgetInterface, &a0))
        {
            sipCpp = new sipQDesignerCustomWidgetInterface(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QDesignerCustomWidgetInterface[] = {
    {sipName_codeTemplate, meth_QDesignerCustomWidgetInterface_codeTemplate, METH_VARARGS, doc_QDesignerCustomWidgetInterface_codeTemplate},
    {sipName_createWidget, meth_QDesignerCustomWidgetInterface_createWidget, METH_VARARGS, doc_QDesignerCustomWidgetInterface_createWidget},
    {sipName_domXml, meth_QDesignerCustomWidgetInterface_domXml, METH_VARARGS, doc_QDesignerCustomWidgetInterface_domXml},
    {sipName_group, meth_QDesignerCustomWidgetInterface_group, METH_VARARGS, doc_QDesignerCustomWidgetInterface_group},
    {sipName_icon, meth_QDesignerCustomWidgetInterface_icon, METH_VARARGS, doc_QDesignerCustomWidgetInterface_icon},
    {sipName_includeFile, meth_QDesignerCustomWidgetInterface_includeFile, METH_VARARGS, doc_QDesignerCustomWidgetInterface_includeFile},
    {sipName_initialize, meth_QDesignerCustomWidgetInterface_initialize, METH_VARARGS, doc_QDesignerCustomWidgetInterface_initialize},
    {sipName_isContainer, meth_QDesignerCustomWidgetInterface_isContainer, METH_VARARGS, doc_QDesignerCustomWidgetInterface_isContainer},
    {sipName_isInitialized, meth_QDesignerCustomWidgetInterface_isInitialized, METH_VARARGS, doc_QDesignerCustomWidgetInterface_isInitialized},
    {sipName_name, meth_QDesignerCustomWidgetInterface_name, METH_VARARGS, doc_QDesignerCustomWidgetInterface_name},
    {sipName_toolTip, meth_QDesignerCustomWidgetInterface_toolTip, METH_VARARGS, doc_QDesignerCustomWidgetInterface_toolTip},
    {sipName_whatsThis, meth_QDesignerCustomWidgetInterface_whatsThis, METH_VARARGS, doc_QDesignerCustomWidgetInterface_whatsThis}
};

PyDoc_STRVAR(doc_QDesignerCustomWidgetInterface, "\1QDesignerCustomWidgetInterface()\n"
"QDesignerCustomWidgetInterface(a0: QDesignerCustomWidgetInterface)");


static pyqt5ClassPluginDef plugin_QDesignerCustomWidgetInterface = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDesigner_QDesignerCustomWidgetInterface = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDesignerCustomWidgetInterface,
        SIP_NULLPTR,
        &plugin_QDesignerCustomWidgetInterface,
    },
    {
        sipNameNr_QDesignerCustomWidgetInterface,
        {0, 0, 1},
        12, methods_QDesignerCustomWidgetInterface,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDesignerCustomWidgetInterface,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QDesignerCustomWidgetInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDesignerCustomWidgetInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QDesignerCustomWidgetInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QDesignerCustomWidgetInterface),
};
