/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtXmlPatterns.h"

#line 76 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qabstractxmlnodemodel.sip"
#include <qabstractxmlnodemodel.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQAbstractXmlNodeModel.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qabstractxmlnodemodel.sip"
#include <qabstractxmlnodemodel.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQAbstractXmlNodeModel.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQAbstractXmlNodeModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qsourcelocation.sip"
#include <qsourcelocation.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQAbstractXmlNodeModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qxmlname.sip"
#include <qxmlname.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQAbstractXmlNodeModel.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQAbstractXmlNodeModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQAbstractXmlNodeModel.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQAbstractXmlNodeModel.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQAbstractXmlNodeModel.cpp"


class sipQAbstractXmlNodeModel : public ::QAbstractXmlNodeModel
{
public:
    sipQAbstractXmlNodeModel();
    virtual ~sipQAbstractXmlNodeModel();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    QVector< ::QXmlNodeModelIndex> attributes(const ::QXmlNodeModelIndex&) const SIP_OVERRIDE;
    ::QXmlNodeModelIndex nextFromSimpleAxis(::QAbstractXmlNodeModel::SimpleAxis, const ::QXmlNodeModelIndex&) const SIP_OVERRIDE;
    QVector< ::QXmlNodeModelIndex> nodesByIdref(const ::QXmlName&) const SIP_OVERRIDE;
    ::QXmlNodeModelIndex elementById(const ::QXmlName&) const SIP_OVERRIDE;
    QVector< ::QXmlName> namespaceBindings(const ::QXmlNodeModelIndex&) const SIP_OVERRIDE;
    ::QVariant typedValue(const ::QXmlNodeModelIndex&) const SIP_OVERRIDE;
    ::QString stringValue(const ::QXmlNodeModelIndex&) const SIP_OVERRIDE;
    ::QXmlName name(const ::QXmlNodeModelIndex&) const SIP_OVERRIDE;
    ::QXmlNodeModelIndex root(const ::QXmlNodeModelIndex&) const SIP_OVERRIDE;
    ::QXmlNodeModelIndex::DocumentOrder compareOrder(const ::QXmlNodeModelIndex&, const ::QXmlNodeModelIndex&) const SIP_OVERRIDE;
    ::QXmlNodeModelIndex::NodeKind kind(const ::QXmlNodeModelIndex&) const SIP_OVERRIDE;
    ::QUrl documentUri(const ::QXmlNodeModelIndex&) const SIP_OVERRIDE;
    ::QUrl baseUri(const ::QXmlNodeModelIndex&) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAbstractXmlNodeModel(const sipQAbstractXmlNodeModel &);
    sipQAbstractXmlNodeModel &operator = (const sipQAbstractXmlNodeModel &);

    char sipPyMethods[13];
};

sipQAbstractXmlNodeModel::sipQAbstractXmlNodeModel(): ::QAbstractXmlNodeModel(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAbstractXmlNodeModel::~sipQAbstractXmlNodeModel()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

QVector< ::QXmlNodeModelIndex> sipQAbstractXmlNodeModel::attributes(const ::QXmlNodeModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAbstractXmlNodeModel, sipName_attributes);

    if (!sipMeth)
        return QVector< ::QXmlNodeModelIndex>();

    extern QVector< ::QXmlNodeModelIndex> sipVH_QtXmlPatterns_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlNodeModelIndex&);

    return sipVH_QtXmlPatterns_19(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QXmlNodeModelIndex sipQAbstractXmlNodeModel::nextFromSimpleAxis(::QAbstractXmlNodeModel::SimpleAxis a0, const ::QXmlNodeModelIndex& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAbstractXmlNodeModel, sipName_nextFromSimpleAxis);

    if (!sipMeth)
        return ::QXmlNodeModelIndex();

    extern ::QXmlNodeModelIndex sipVH_QtXmlPatterns_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QAbstractXmlNodeModel::SimpleAxis, const ::QXmlNodeModelIndex&);

    return sipVH_QtXmlPatterns_18(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

QVector< ::QXmlNodeModelIndex> sipQAbstractXmlNodeModel::nodesByIdref(const ::QXmlName& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAbstractXmlNodeModel, sipName_nodesByIdref);

    if (!sipMeth)
        return QVector< ::QXmlNodeModelIndex>();

    extern QVector< ::QXmlNodeModelIndex> sipVH_QtXmlPatterns_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlName&);

    return sipVH_QtXmlPatterns_17(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QXmlNodeModelIndex sipQAbstractXmlNodeModel::elementById(const ::QXmlName& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAbstractXmlNodeModel, sipName_elementById);

    if (!sipMeth)
        return ::QXmlNodeModelIndex();

    extern ::QXmlNodeModelIndex sipVH_QtXmlPatterns_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlName&);

    return sipVH_QtXmlPatterns_16(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

QVector< ::QXmlName> sipQAbstractXmlNodeModel::namespaceBindings(const ::QXmlNodeModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAbstractXmlNodeModel, sipName_namespaceBindings);

    if (!sipMeth)
        return QVector< ::QXmlName>();

    extern QVector< ::QXmlName> sipVH_QtXmlPatterns_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlNodeModelIndex&);

    return sipVH_QtXmlPatterns_15(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQAbstractXmlNodeModel::typedValue(const ::QXmlNodeModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAbstractXmlNodeModel, sipName_typedValue);

    if (!sipMeth)
        return ::QVariant();

    extern ::QVariant sipVH_QtXmlPatterns_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlNodeModelIndex&);

    return sipVH_QtXmlPatterns_14(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QString sipQAbstractXmlNodeModel::stringValue(const ::QXmlNodeModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAbstractXmlNodeModel, sipName_stringValue);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtXmlPatterns_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlNodeModelIndex&);

    return sipVH_QtXmlPatterns_13(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QXmlName sipQAbstractXmlNodeModel::name(const ::QXmlNodeModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAbstractXmlNodeModel, sipName_name);

    if (!sipMeth)
        return ::QXmlName();

    extern ::QXmlName sipVH_QtXmlPatterns_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlNodeModelIndex&);

    return sipVH_QtXmlPatterns_12(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QXmlNodeModelIndex sipQAbstractXmlNodeModel::root(const ::QXmlNodeModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAbstractXmlNodeModel, sipName_root);

    if (!sipMeth)
        return ::QXmlNodeModelIndex();

    extern ::QXmlNodeModelIndex sipVH_QtXmlPatterns_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlNodeModelIndex&);

    return sipVH_QtXmlPatterns_11(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QXmlNodeModelIndex::DocumentOrder sipQAbstractXmlNodeModel::compareOrder(const ::QXmlNodeModelIndex& a0, const ::QXmlNodeModelIndex& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAbstractXmlNodeModel, sipName_compareOrder);

    if (!sipMeth)
        return ::QXmlNodeModelIndex::Precedes;

    extern ::QXmlNodeModelIndex::DocumentOrder sipVH_QtXmlPatterns_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlNodeModelIndex&, const ::QXmlNodeModelIndex&);

    return sipVH_QtXmlPatterns_10(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QXmlNodeModelIndex::NodeKind sipQAbstractXmlNodeModel::kind(const ::QXmlNodeModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAbstractXmlNodeModel, sipName_kind);

    if (!sipMeth)
        return ::QXmlNodeModelIndex::Attribute;

    extern ::QXmlNodeModelIndex::NodeKind sipVH_QtXmlPatterns_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlNodeModelIndex&);

    return sipVH_QtXmlPatterns_9(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QUrl sipQAbstractXmlNodeModel::documentUri(const ::QXmlNodeModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAbstractXmlNodeModel, sipName_documentUri);

    if (!sipMeth)
        return ::QUrl();

    extern ::QUrl sipVH_QtXmlPatterns_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlNodeModelIndex&);

    return sipVH_QtXmlPatterns_8(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QUrl sipQAbstractXmlNodeModel::baseUri(const ::QXmlNodeModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QAbstractXmlNodeModel, sipName_baseUri);

    if (!sipMeth)
        return ::QUrl();

    extern ::QUrl sipVH_QtXmlPatterns_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlNodeModelIndex&);

    return sipVH_QtXmlPatterns_8(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QAbstractXmlNodeModel_baseUri, "baseUri(self, ni: QXmlNodeModelIndex) -> QUrl");

extern "C" {static PyObject *meth_QAbstractXmlNodeModel_baseUri(PyObject *, PyObject *);}
static PyObject *meth_QAbstractXmlNodeModel_baseUri(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QXmlNodeModelIndex* a0;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, sipType_QXmlNodeModelIndex, &a0))
        {
            ::QUrl*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractXmlNodeModel, sipName_baseUri);
                return SIP_NULLPTR;
            }

            sipRes = new ::QUrl(sipCpp->baseUri(*a0));

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractXmlNodeModel, sipName_baseUri, doc_QAbstractXmlNodeModel_baseUri);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractXmlNodeModel_documentUri, "documentUri(self, ni: QXmlNodeModelIndex) -> QUrl");

extern "C" {static PyObject *meth_QAbstractXmlNodeModel_documentUri(PyObject *, PyObject *);}
static PyObject *meth_QAbstractXmlNodeModel_documentUri(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QXmlNodeModelIndex* a0;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, sipType_QXmlNodeModelIndex, &a0))
        {
            ::QUrl*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractXmlNodeModel, sipName_documentUri);
                return SIP_NULLPTR;
            }

            sipRes = new ::QUrl(sipCpp->documentUri(*a0));

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractXmlNodeModel, sipName_documentUri, doc_QAbstractXmlNodeModel_documentUri);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractXmlNodeModel_kind, "kind(self, ni: QXmlNodeModelIndex) -> QXmlNodeModelIndex.NodeKind");

extern "C" {static PyObject *meth_QAbstractXmlNodeModel_kind(PyObject *, PyObject *);}
static PyObject *meth_QAbstractXmlNodeModel_kind(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QXmlNodeModelIndex* a0;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, sipType_QXmlNodeModelIndex, &a0))
        {
            ::QXmlNodeModelIndex::NodeKind sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractXmlNodeModel, sipName_kind);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->kind(*a0);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QXmlNodeModelIndex_NodeKind);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractXmlNodeModel, sipName_kind, doc_QAbstractXmlNodeModel_kind);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractXmlNodeModel_compareOrder, "compareOrder(self, ni1: QXmlNodeModelIndex, ni2: QXmlNodeModelIndex) -> QXmlNodeModelIndex.DocumentOrder");

extern "C" {static PyObject *meth_QAbstractXmlNodeModel_compareOrder(PyObject *, PyObject *);}
static PyObject *meth_QAbstractXmlNodeModel_compareOrder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QXmlNodeModelIndex* a0;
        const ::QXmlNodeModelIndex* a1;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, sipType_QXmlNodeModelIndex, &a0, sipType_QXmlNodeModelIndex, &a1))
        {
            ::QXmlNodeModelIndex::DocumentOrder sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractXmlNodeModel, sipName_compareOrder);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->compareOrder(*a0, *a1);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QXmlNodeModelIndex_DocumentOrder);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractXmlNodeModel, sipName_compareOrder, doc_QAbstractXmlNodeModel_compareOrder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractXmlNodeModel_root, "root(self, n: QXmlNodeModelIndex) -> QXmlNodeModelIndex");

extern "C" {static PyObject *meth_QAbstractXmlNodeModel_root(PyObject *, PyObject *);}
static PyObject *meth_QAbstractXmlNodeModel_root(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QXmlNodeModelIndex* a0;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, sipType_QXmlNodeModelIndex, &a0))
        {
            ::QXmlNodeModelIndex*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractXmlNodeModel, sipName_root);
                return SIP_NULLPTR;
            }

            sipRes = new ::QXmlNodeModelIndex(sipCpp->root(*a0));

            return sipConvertFromNewType(sipRes, sipType_QXmlNodeModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractXmlNodeModel, sipName_root, doc_QAbstractXmlNodeModel_root);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractXmlNodeModel_name, "name(self, ni: QXmlNodeModelIndex) -> QXmlName");

extern "C" {static PyObject *meth_QAbstractXmlNodeModel_name(PyObject *, PyObject *);}
static PyObject *meth_QAbstractXmlNodeModel_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QXmlNodeModelIndex* a0;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, sipType_QXmlNodeModelIndex, &a0))
        {
            ::QXmlName*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractXmlNodeModel, sipName_name);
                return SIP_NULLPTR;
            }

            sipRes = new ::QXmlName(sipCpp->name(*a0));

            return sipConvertFromNewType(sipRes, sipType_QXmlName, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractXmlNodeModel, sipName_name, doc_QAbstractXmlNodeModel_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractXmlNodeModel_stringValue, "stringValue(self, n: QXmlNodeModelIndex) -> str");

extern "C" {static PyObject *meth_QAbstractXmlNodeModel_stringValue(PyObject *, PyObject *);}
static PyObject *meth_QAbstractXmlNodeModel_stringValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QXmlNodeModelIndex* a0;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, sipType_QXmlNodeModelIndex, &a0))
        {
            ::QString*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractXmlNodeModel, sipName_stringValue);
                return SIP_NULLPTR;
            }

            sipRes = new ::QString(sipCpp->stringValue(*a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractXmlNodeModel, sipName_stringValue, doc_QAbstractXmlNodeModel_stringValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractXmlNodeModel_typedValue, "typedValue(self, n: QXmlNodeModelIndex) -> Any");

extern "C" {static PyObject *meth_QAbstractXmlNodeModel_typedValue(PyObject *, PyObject *);}
static PyObject *meth_QAbstractXmlNodeModel_typedValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QXmlNodeModelIndex* a0;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, sipType_QXmlNodeModelIndex, &a0))
        {
            ::QVariant*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractXmlNodeModel, sipName_typedValue);
                return SIP_NULLPTR;
            }

            sipRes = new ::QVariant(sipCpp->typedValue(*a0));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractXmlNodeModel, sipName_typedValue, doc_QAbstractXmlNodeModel_typedValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractXmlNodeModel_namespaceBindings, "namespaceBindings(self, n: QXmlNodeModelIndex) -> list[QXmlName]");

extern "C" {static PyObject *meth_QAbstractXmlNodeModel_namespaceBindings(PyObject *, PyObject *);}
static PyObject *meth_QAbstractXmlNodeModel_namespaceBindings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QXmlNodeModelIndex* a0;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, sipType_QXmlNodeModelIndex, &a0))
        {
            QVector< ::QXmlName>*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractXmlNodeModel, sipName_namespaceBindings);
                return SIP_NULLPTR;
            }

            sipRes = new QVector< ::QXmlName>(sipCpp->namespaceBindings(*a0));

            return sipConvertFromNewType(sipRes, sipType_QVector_0100QXmlName, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractXmlNodeModel, sipName_namespaceBindings, doc_QAbstractXmlNodeModel_namespaceBindings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractXmlNodeModel_elementById, "elementById(self, NCName: QXmlName) -> QXmlNodeModelIndex");

extern "C" {static PyObject *meth_QAbstractXmlNodeModel_elementById(PyObject *, PyObject *);}
static PyObject *meth_QAbstractXmlNodeModel_elementById(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QXmlName* a0;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, sipType_QXmlName, &a0))
        {
            ::QXmlNodeModelIndex*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractXmlNodeModel, sipName_elementById);
                return SIP_NULLPTR;
            }

            sipRes = new ::QXmlNodeModelIndex(sipCpp->elementById(*a0));

            return sipConvertFromNewType(sipRes, sipType_QXmlNodeModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractXmlNodeModel, sipName_elementById, doc_QAbstractXmlNodeModel_elementById);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractXmlNodeModel_nodesByIdref, "nodesByIdref(self, NCName: QXmlName) -> list[QXmlNodeModelIndex]");

extern "C" {static PyObject *meth_QAbstractXmlNodeModel_nodesByIdref(PyObject *, PyObject *);}
static PyObject *meth_QAbstractXmlNodeModel_nodesByIdref(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QXmlName* a0;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, sipType_QXmlName, &a0))
        {
            QVector< ::QXmlNodeModelIndex>*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractXmlNodeModel, sipName_nodesByIdref);
                return SIP_NULLPTR;
            }

            sipRes = new QVector< ::QXmlNodeModelIndex>(sipCpp->nodesByIdref(*a0));

            return sipConvertFromNewType(sipRes, sipType_QVector_0100QXmlNodeModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractXmlNodeModel, sipName_nodesByIdref, doc_QAbstractXmlNodeModel_nodesByIdref);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractXmlNodeModel_sourceLocation, "sourceLocation(self, index: QXmlNodeModelIndex) -> QSourceLocation");

extern "C" {static PyObject *meth_QAbstractXmlNodeModel_sourceLocation(PyObject *, PyObject *);}
static PyObject *meth_QAbstractXmlNodeModel_sourceLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlNodeModelIndex* a0;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, sipType_QXmlNodeModelIndex, &a0))
        {
            ::QSourceLocation*sipRes;

            sipRes = new ::QSourceLocation(sipCpp->sourceLocation(*a0));

            return sipConvertFromNewType(sipRes, sipType_QSourceLocation, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractXmlNodeModel, sipName_sourceLocation, doc_QAbstractXmlNodeModel_sourceLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractXmlNodeModel_nextFromSimpleAxis, "nextFromSimpleAxis(self, axis: QAbstractXmlNodeModel.SimpleAxis, origin: QXmlNodeModelIndex) -> QXmlNodeModelIndex");

extern "C" {static PyObject *meth_QAbstractXmlNodeModel_nextFromSimpleAxis(PyObject *, PyObject *);}
static PyObject *meth_QAbstractXmlNodeModel_nextFromSimpleAxis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QAbstractXmlNodeModel::SimpleAxis a0;
        const ::QXmlNodeModelIndex* a1;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pEJ9", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, sipType_QAbstractXmlNodeModel_SimpleAxis, &a0, sipType_QXmlNodeModelIndex, &a1))
        {
            ::QXmlNodeModelIndex*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractXmlNodeModel, sipName_nextFromSimpleAxis);
                return SIP_NULLPTR;
            }

            sipRes = new ::QXmlNodeModelIndex(sipCpp->nextFromSimpleAxis(a0, *a1));

            return sipConvertFromNewType(sipRes, sipType_QXmlNodeModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractXmlNodeModel, sipName_nextFromSimpleAxis, doc_QAbstractXmlNodeModel_nextFromSimpleAxis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractXmlNodeModel_attributes, "attributes(self, element: QXmlNodeModelIndex) -> list[QXmlNodeModelIndex]");

extern "C" {static PyObject *meth_QAbstractXmlNodeModel_attributes(PyObject *, PyObject *);}
static PyObject *meth_QAbstractXmlNodeModel_attributes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QXmlNodeModelIndex* a0;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, sipType_QXmlNodeModelIndex, &a0))
        {
            QVector< ::QXmlNodeModelIndex>*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractXmlNodeModel, sipName_attributes);
                return SIP_NULLPTR;
            }

            sipRes = new QVector< ::QXmlNodeModelIndex>(sipCpp->attributes(*a0));

            return sipConvertFromNewType(sipRes, sipType_QVector_0100QXmlNodeModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractXmlNodeModel, sipName_attributes, doc_QAbstractXmlNodeModel_attributes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractXmlNodeModel_createIndex, "createIndex(self, data: int) -> QXmlNodeModelIndex\n"
"createIndex(self, data: int, additionalData: int) -> QXmlNodeModelIndex\n"
"createIndex(self, pointer: Any, additionalData: int = 0) -> QXmlNodeModelIndex");

extern "C" {static PyObject *meth_QAbstractXmlNodeModel_createIndex(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QAbstractXmlNodeModel_createIndex(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qint64 a0;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "pn", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, &a0))
        {
            ::QXmlNodeModelIndex*sipRes;

            sipRes = new ::QXmlNodeModelIndex(sipCpp->createIndex(a0));

            return sipConvertFromNewType(sipRes, sipType_QXmlNodeModelIndex, SIP_NULLPTR);
        }
    }

    {
        ::qint64 a0;
        ::qint64 a1;
        const ::QAbstractXmlNodeModel *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "pnn", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, &a0, &a1))
        {
            ::QXmlNodeModelIndex*sipRes;

            sipRes = new ::QXmlNodeModelIndex(sipCpp->createIndex(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QXmlNodeModelIndex, SIP_NULLPTR);
        }
    }

    {
        PyObject * a0;
        ::qint64 a1 = 0;
        const ::QAbstractXmlNodeModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_additionalData,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "pP0|n", &sipSelf, sipType_QAbstractXmlNodeModel, &sipCpp, &a0, &a1))
        {
            ::QXmlNodeModelIndex*sipRes;

            sipRes = new ::QXmlNodeModelIndex(sipCpp->createIndex(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QXmlNodeModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractXmlNodeModel, sipName_createIndex, doc_QAbstractXmlNodeModel_createIndex);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAbstractXmlNodeModel(void *, int);}
static void release_QAbstractXmlNodeModel(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQAbstractXmlNodeModel *>(sipCppV);
    else
        delete reinterpret_cast< ::QAbstractXmlNodeModel *>(sipCppV);
}


extern "C" {static void dealloc_QAbstractXmlNodeModel(sipSimpleWrapper *);}
static void dealloc_QAbstractXmlNodeModel(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAbstractXmlNodeModel *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAbstractXmlNodeModel(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAbstractXmlNodeModel(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAbstractXmlNodeModel(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQAbstractXmlNodeModel *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQAbstractXmlNodeModel();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QAbstractXmlNodeModel[] = {
    {sipName_attributes, meth_QAbstractXmlNodeModel_attributes, METH_VARARGS, doc_QAbstractXmlNodeModel_attributes},
    {sipName_baseUri, meth_QAbstractXmlNodeModel_baseUri, METH_VARARGS, doc_QAbstractXmlNodeModel_baseUri},
    {sipName_compareOrder, meth_QAbstractXmlNodeModel_compareOrder, METH_VARARGS, doc_QAbstractXmlNodeModel_compareOrder},
    {sipName_createIndex, SIP_MLMETH_CAST(meth_QAbstractXmlNodeModel_createIndex), METH_VARARGS|METH_KEYWORDS, doc_QAbstractXmlNodeModel_createIndex},
    {sipName_documentUri, meth_QAbstractXmlNodeModel_documentUri, METH_VARARGS, doc_QAbstractXmlNodeModel_documentUri},
    {sipName_elementById, meth_QAbstractXmlNodeModel_elementById, METH_VARARGS, doc_QAbstractXmlNodeModel_elementById},
    {sipName_kind, meth_QAbstractXmlNodeModel_kind, METH_VARARGS, doc_QAbstractXmlNodeModel_kind},
    {sipName_name, meth_QAbstractXmlNodeModel_name, METH_VARARGS, doc_QAbstractXmlNodeModel_name},
    {sipName_namespaceBindings, meth_QAbstractXmlNodeModel_namespaceBindings, METH_VARARGS, doc_QAbstractXmlNodeModel_namespaceBindings},
    {sipName_nextFromSimpleAxis, meth_QAbstractXmlNodeModel_nextFromSimpleAxis, METH_VARARGS, doc_QAbstractXmlNodeModel_nextFromSimpleAxis},
    {sipName_nodesByIdref, meth_QAbstractXmlNodeModel_nodesByIdref, METH_VARARGS, doc_QAbstractXmlNodeModel_nodesByIdref},
    {sipName_root, meth_QAbstractXmlNodeModel_root, METH_VARARGS, doc_QAbstractXmlNodeModel_root},
    {sipName_sourceLocation, meth_QAbstractXmlNodeModel_sourceLocation, METH_VARARGS, doc_QAbstractXmlNodeModel_sourceLocation},
    {sipName_stringValue, meth_QAbstractXmlNodeModel_stringValue, METH_VARARGS, doc_QAbstractXmlNodeModel_stringValue},
    {sipName_typedValue, meth_QAbstractXmlNodeModel_typedValue, METH_VARARGS, doc_QAbstractXmlNodeModel_typedValue}
};

static sipEnumMemberDef enummembers_QAbstractXmlNodeModel[] = {
    {sipName_FirstChild, static_cast<int>(::QAbstractXmlNodeModel::FirstChild), 3},
    {sipName_NextSibling, static_cast<int>(::QAbstractXmlNodeModel::NextSibling), 3},
    {sipName_Parent, static_cast<int>(::QAbstractXmlNodeModel::Parent), 3},
    {sipName_PreviousSibling, static_cast<int>(::QAbstractXmlNodeModel::PreviousSibling), 3},
};

PyDoc_STRVAR(doc_QAbstractXmlNodeModel, "\1QAbstractXmlNodeModel()");


static pyqt5ClassPluginDef plugin_QAbstractXmlNodeModel = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtXmlPatterns_QAbstractXmlNodeModel = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAbstractXmlNodeModel,
        SIP_NULLPTR,
        &plugin_QAbstractXmlNodeModel,
    },
    {
        sipNameNr_QAbstractXmlNodeModel,
        {0, 0, 1},
        15, methods_QAbstractXmlNodeModel,
        4, enummembers_QAbstractXmlNodeModel,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAbstractXmlNodeModel,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QAbstractXmlNodeModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAbstractXmlNodeModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QAbstractXmlNodeModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QAbstractXmlNodeModel),
};
