/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKit.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebsettings.sip"
#include <qwebsettings.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebSettings.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebSettings.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebSettings.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebSettings.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebSettings.cpp"


PyDoc_STRVAR(doc_QWebSettings_globalSettings, "globalSettings() -> Optional[QWebSettings]");

extern "C" {static PyObject *meth_QWebSettings_globalSettings(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_globalSettings(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QWebSettings*sipRes;

            sipRes = ::QWebSettings::globalSettings();

            return sipConvertFromType(sipRes, sipType_QWebSettings, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_globalSettings, doc_QWebSettings_globalSettings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setFontFamily, "setFontFamily(self, which: QWebSettings.FontFamily, family: Optional[str])");

extern "C" {static PyObject *meth_QWebSettings_setFontFamily(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setFontFamily(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSettings::FontFamily a0;
        const ::QString* a1;
        int a1State = 0;
        ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ1", &sipSelf, sipType_QWebSettings, &sipCpp, sipType_QWebSettings_FontFamily, &a0, sipType_QString, &a1, &a1State))
        {
            sipCpp->setFontFamily(a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setFontFamily, doc_QWebSettings_setFontFamily);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_fontFamily, "fontFamily(self, which: QWebSettings.FontFamily) -> str");

extern "C" {static PyObject *meth_QWebSettings_fontFamily(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_fontFamily(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSettings::FontFamily a0;
        const ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebSettings, &sipCpp, sipType_QWebSettings_FontFamily, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->fontFamily(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_fontFamily, doc_QWebSettings_fontFamily);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_resetFontFamily, "resetFontFamily(self, which: QWebSettings.FontFamily)");

extern "C" {static PyObject *meth_QWebSettings_resetFontFamily(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_resetFontFamily(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSettings::FontFamily a0;
        ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebSettings, &sipCpp, sipType_QWebSettings_FontFamily, &a0))
        {
            sipCpp->resetFontFamily(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_resetFontFamily, doc_QWebSettings_resetFontFamily);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setFontSize, "setFontSize(self, type: QWebSettings.FontSize, size: int)");

extern "C" {static PyObject *meth_QWebSettings_setFontSize(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setFontSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSettings::FontSize a0;
        int a1;
        ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEi", &sipSelf, sipType_QWebSettings, &sipCpp, sipType_QWebSettings_FontSize, &a0, &a1))
        {
            sipCpp->setFontSize(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setFontSize, doc_QWebSettings_setFontSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_fontSize, "fontSize(self, type: QWebSettings.FontSize) -> int");

extern "C" {static PyObject *meth_QWebSettings_fontSize(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_fontSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSettings::FontSize a0;
        const ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebSettings, &sipCpp, sipType_QWebSettings_FontSize, &a0))
        {
            int sipRes;

            sipRes = sipCpp->fontSize(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_fontSize, doc_QWebSettings_fontSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_resetFontSize, "resetFontSize(self, type: QWebSettings.FontSize)");

extern "C" {static PyObject *meth_QWebSettings_resetFontSize(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_resetFontSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSettings::FontSize a0;
        ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebSettings, &sipCpp, sipType_QWebSettings_FontSize, &a0))
        {
            sipCpp->resetFontSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_resetFontSize, doc_QWebSettings_resetFontSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setAttribute, "setAttribute(self, attr: QWebSettings.WebAttribute, on: bool)");

extern "C" {static PyObject *meth_QWebSettings_setAttribute(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSettings::WebAttribute a0;
        bool a1;
        ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEb", &sipSelf, sipType_QWebSettings, &sipCpp, sipType_QWebSettings_WebAttribute, &a0, &a1))
        {
            sipCpp->setAttribute(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setAttribute, doc_QWebSettings_setAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_testAttribute, "testAttribute(self, attr: QWebSettings.WebAttribute) -> bool");

extern "C" {static PyObject *meth_QWebSettings_testAttribute(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_testAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSettings::WebAttribute a0;
        const ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebSettings, &sipCpp, sipType_QWebSettings_WebAttribute, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->testAttribute(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_testAttribute, doc_QWebSettings_testAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_resetAttribute, "resetAttribute(self, attr: QWebSettings.WebAttribute)");

extern "C" {static PyObject *meth_QWebSettings_resetAttribute(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_resetAttribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSettings::WebAttribute a0;
        ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebSettings, &sipCpp, sipType_QWebSettings_WebAttribute, &a0))
        {
            sipCpp->resetAttribute(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_resetAttribute, doc_QWebSettings_resetAttribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setUserStyleSheetUrl, "setUserStyleSheetUrl(self, location: QUrl)");

extern "C" {static PyObject *meth_QWebSettings_setUserStyleSheetUrl(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setUserStyleSheetUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebSettings, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setUserStyleSheetUrl(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setUserStyleSheetUrl, doc_QWebSettings_setUserStyleSheetUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_userStyleSheetUrl, "userStyleSheetUrl(self) -> QUrl");

extern "C" {static PyObject *meth_QWebSettings_userStyleSheetUrl(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_userStyleSheetUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSettings, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->userStyleSheetUrl());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_userStyleSheetUrl, doc_QWebSettings_userStyleSheetUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setIconDatabasePath, "setIconDatabasePath(location: Optional[str])");

extern "C" {static PyObject *meth_QWebSettings_setIconDatabasePath(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setIconDatabasePath(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString, &a0, &a0State))
        {
            ::QWebSettings::setIconDatabasePath(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setIconDatabasePath, doc_QWebSettings_setIconDatabasePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_iconDatabasePath, "iconDatabasePath() -> str");

extern "C" {static PyObject *meth_QWebSettings_iconDatabasePath(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_iconDatabasePath(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QWebSettings::iconDatabasePath());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_iconDatabasePath, doc_QWebSettings_iconDatabasePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_clearIconDatabase, "clearIconDatabase()");

extern "C" {static PyObject *meth_QWebSettings_clearIconDatabase(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_clearIconDatabase(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QWebSettings::clearIconDatabase();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_clearIconDatabase, doc_QWebSettings_clearIconDatabase);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_iconForUrl, "iconForUrl(url: QUrl) -> QIcon");

extern "C" {static PyObject *meth_QWebSettings_iconForUrl(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_iconForUrl(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QUrl, &a0))
        {
            ::QIcon*sipRes;

            sipRes = new ::QIcon(::QWebSettings::iconForUrl(*a0));

            return sipConvertFromNewType(sipRes, sipType_QIcon, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_iconForUrl, doc_QWebSettings_iconForUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setWebGraphic, "setWebGraphic(type: QWebSettings.WebGraphic, graphic: QPixmap)");

extern "C" {static PyObject *meth_QWebSettings_setWebGraphic(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setWebGraphic(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSettings::WebGraphic a0;
        const ::QPixmap* a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "EJ9", sipType_QWebSettings_WebGraphic, &a0, sipType_QPixmap, &a1))
        {
            ::QWebSettings::setWebGraphic(a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setWebGraphic, doc_QWebSettings_setWebGraphic);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_webGraphic, "webGraphic(type: QWebSettings.WebGraphic) -> QPixmap");

extern "C" {static PyObject *meth_QWebSettings_webGraphic(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_webGraphic(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSettings::WebGraphic a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "E", sipType_QWebSettings_WebGraphic, &a0))
        {
            ::QPixmap*sipRes;

            sipRes = new ::QPixmap(::QWebSettings::webGraphic(a0));

            return sipConvertFromNewType(sipRes, sipType_QPixmap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_webGraphic, doc_QWebSettings_webGraphic);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setMaximumPagesInCache, "setMaximumPagesInCache(pages: int)");

extern "C" {static PyObject *meth_QWebSettings_setMaximumPagesInCache(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setMaximumPagesInCache(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "i", &a0))
        {
            ::QWebSettings::setMaximumPagesInCache(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setMaximumPagesInCache, doc_QWebSettings_setMaximumPagesInCache);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_maximumPagesInCache, "maximumPagesInCache() -> int");

extern "C" {static PyObject *meth_QWebSettings_maximumPagesInCache(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_maximumPagesInCache(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            int sipRes;

            sipRes = ::QWebSettings::maximumPagesInCache();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_maximumPagesInCache, doc_QWebSettings_maximumPagesInCache);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setObjectCacheCapacities, "setObjectCacheCapacities(cacheMinDeadCapacity: int, cacheMaxDead: int, totalCapacity: int)");

extern "C" {static PyObject *meth_QWebSettings_setObjectCacheCapacities(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setObjectCacheCapacities(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;

        if (sipParseArgs(&sipParseErr, sipArgs, "iii", &a0, &a1, &a2))
        {
            ::QWebSettings::setObjectCacheCapacities(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setObjectCacheCapacities, doc_QWebSettings_setObjectCacheCapacities);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setOfflineStoragePath, "setOfflineStoragePath(path: Optional[str])");

extern "C" {static PyObject *meth_QWebSettings_setOfflineStoragePath(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setOfflineStoragePath(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString, &a0, &a0State))
        {
            ::QWebSettings::setOfflineStoragePath(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setOfflineStoragePath, doc_QWebSettings_setOfflineStoragePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_offlineStoragePath, "offlineStoragePath() -> str");

extern "C" {static PyObject *meth_QWebSettings_offlineStoragePath(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_offlineStoragePath(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QWebSettings::offlineStoragePath());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_offlineStoragePath, doc_QWebSettings_offlineStoragePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setOfflineStorageDefaultQuota, "setOfflineStorageDefaultQuota(maximumSize: int)");

extern "C" {static PyObject *meth_QWebSettings_setOfflineStorageDefaultQuota(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setOfflineStorageDefaultQuota(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qint64 a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "n", &a0))
        {
            ::QWebSettings::setOfflineStorageDefaultQuota(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setOfflineStorageDefaultQuota, doc_QWebSettings_setOfflineStorageDefaultQuota);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_offlineStorageDefaultQuota, "offlineStorageDefaultQuota() -> int");

extern "C" {static PyObject *meth_QWebSettings_offlineStorageDefaultQuota(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_offlineStorageDefaultQuota(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::qint64 sipRes;

            sipRes = ::QWebSettings::offlineStorageDefaultQuota();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_offlineStorageDefaultQuota, doc_QWebSettings_offlineStorageDefaultQuota);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setDefaultTextEncoding, "setDefaultTextEncoding(self, encoding: Optional[str])");

extern "C" {static PyObject *meth_QWebSettings_setDefaultTextEncoding(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setDefaultTextEncoding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebSettings, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setDefaultTextEncoding(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setDefaultTextEncoding, doc_QWebSettings_setDefaultTextEncoding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_defaultTextEncoding, "defaultTextEncoding(self) -> str");

extern "C" {static PyObject *meth_QWebSettings_defaultTextEncoding(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_defaultTextEncoding(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSettings, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->defaultTextEncoding());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_defaultTextEncoding, doc_QWebSettings_defaultTextEncoding);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setOfflineWebApplicationCachePath, "setOfflineWebApplicationCachePath(path: Optional[str])");

extern "C" {static PyObject *meth_QWebSettings_setOfflineWebApplicationCachePath(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setOfflineWebApplicationCachePath(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString, &a0, &a0State))
        {
            ::QWebSettings::setOfflineWebApplicationCachePath(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setOfflineWebApplicationCachePath, doc_QWebSettings_setOfflineWebApplicationCachePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_offlineWebApplicationCachePath, "offlineWebApplicationCachePath() -> str");

extern "C" {static PyObject *meth_QWebSettings_offlineWebApplicationCachePath(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_offlineWebApplicationCachePath(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QWebSettings::offlineWebApplicationCachePath());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_offlineWebApplicationCachePath, doc_QWebSettings_offlineWebApplicationCachePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setOfflineWebApplicationCacheQuota, "setOfflineWebApplicationCacheQuota(maximumSize: int)");

extern "C" {static PyObject *meth_QWebSettings_setOfflineWebApplicationCacheQuota(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setOfflineWebApplicationCacheQuota(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qint64 a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "n", &a0))
        {
            ::QWebSettings::setOfflineWebApplicationCacheQuota(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setOfflineWebApplicationCacheQuota, doc_QWebSettings_setOfflineWebApplicationCacheQuota);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_offlineWebApplicationCacheQuota, "offlineWebApplicationCacheQuota() -> int");

extern "C" {static PyObject *meth_QWebSettings_offlineWebApplicationCacheQuota(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_offlineWebApplicationCacheQuota(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::qint64 sipRes;

            sipRes = ::QWebSettings::offlineWebApplicationCacheQuota();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_offlineWebApplicationCacheQuota, doc_QWebSettings_offlineWebApplicationCacheQuota);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setLocalStoragePath, "setLocalStoragePath(self, path: Optional[str])");

extern "C" {static PyObject *meth_QWebSettings_setLocalStoragePath(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setLocalStoragePath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebSettings, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setLocalStoragePath(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setLocalStoragePath, doc_QWebSettings_setLocalStoragePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_localStoragePath, "localStoragePath(self) -> str");

extern "C" {static PyObject *meth_QWebSettings_localStoragePath(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_localStoragePath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSettings, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->localStoragePath());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_localStoragePath, doc_QWebSettings_localStoragePath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_clearMemoryCaches, "clearMemoryCaches()");

extern "C" {static PyObject *meth_QWebSettings_clearMemoryCaches(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_clearMemoryCaches(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QWebSettings::clearMemoryCaches();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_clearMemoryCaches, doc_QWebSettings_clearMemoryCaches);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_enablePersistentStorage, "enablePersistentStorage(path: Optional[str] = '')");

extern "C" {static PyObject *meth_QWebSettings_enablePersistentStorage(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_enablePersistentStorage(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString& a0def = QString();
        const ::QString* a0 = &a0def;
        int a0State = 0;

        static const char *sipKwdList[] = {
            sipName_path,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "|J1", sipType_QString, &a0, &a0State))
        {
            ::QWebSettings::enablePersistentStorage(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_enablePersistentStorage, doc_QWebSettings_enablePersistentStorage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setThirdPartyCookiePolicy, "setThirdPartyCookiePolicy(self, a0: QWebSettings.ThirdPartyCookiePolicy)");

extern "C" {static PyObject *meth_QWebSettings_setThirdPartyCookiePolicy(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setThirdPartyCookiePolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebSettings::ThirdPartyCookiePolicy a0;
        ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebSettings, &sipCpp, sipType_QWebSettings_ThirdPartyCookiePolicy, &a0))
        {
            sipCpp->setThirdPartyCookiePolicy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setThirdPartyCookiePolicy, doc_QWebSettings_setThirdPartyCookiePolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_thirdPartyCookiePolicy, "thirdPartyCookiePolicy(self) -> QWebSettings.ThirdPartyCookiePolicy");

extern "C" {static PyObject *meth_QWebSettings_thirdPartyCookiePolicy(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_thirdPartyCookiePolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSettings, &sipCpp))
        {
            ::QWebSettings::ThirdPartyCookiePolicy sipRes;

            sipRes = sipCpp->thirdPartyCookiePolicy();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QWebSettings_ThirdPartyCookiePolicy);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_thirdPartyCookiePolicy, doc_QWebSettings_thirdPartyCookiePolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_setCSSMediaType, "setCSSMediaType(self, a0: Optional[str])");

extern "C" {static PyObject *meth_QWebSettings_setCSSMediaType(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_setCSSMediaType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebSettings, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCSSMediaType(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_setCSSMediaType, doc_QWebSettings_setCSSMediaType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebSettings_cssMediaType, "cssMediaType(self) -> str");

extern "C" {static PyObject *meth_QWebSettings_cssMediaType(PyObject *, PyObject *);}
static PyObject *meth_QWebSettings_cssMediaType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebSettings *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebSettings, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->cssMediaType());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebSettings, sipName_cssMediaType, doc_QWebSettings_cssMediaType);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebSettings(void *, int);}
static void release_QWebSettings(void *, int)
{
}


static PyMethodDef methods_QWebSettings[] = {
    {sipName_clearIconDatabase, meth_QWebSettings_clearIconDatabase, METH_VARARGS, doc_QWebSettings_clearIconDatabase},
    {sipName_clearMemoryCaches, meth_QWebSettings_clearMemoryCaches, METH_VARARGS, doc_QWebSettings_clearMemoryCaches},
    {sipName_cssMediaType, meth_QWebSettings_cssMediaType, METH_VARARGS, doc_QWebSettings_cssMediaType},
    {sipName_defaultTextEncoding, meth_QWebSettings_defaultTextEncoding, METH_VARARGS, doc_QWebSettings_defaultTextEncoding},
    {sipName_enablePersistentStorage, SIP_MLMETH_CAST(meth_QWebSettings_enablePersistentStorage), METH_VARARGS|METH_KEYWORDS, doc_QWebSettings_enablePersistentStorage},
    {sipName_fontFamily, meth_QWebSettings_fontFamily, METH_VARARGS, doc_QWebSettings_fontFamily},
    {sipName_fontSize, meth_QWebSettings_fontSize, METH_VARARGS, doc_QWebSettings_fontSize},
    {sipName_globalSettings, meth_QWebSettings_globalSettings, METH_VARARGS, doc_QWebSettings_globalSettings},
    {sipName_iconDatabasePath, meth_QWebSettings_iconDatabasePath, METH_VARARGS, doc_QWebSettings_iconDatabasePath},
    {sipName_iconForUrl, meth_QWebSettings_iconForUrl, METH_VARARGS, doc_QWebSettings_iconForUrl},
    {sipName_localStoragePath, meth_QWebSettings_localStoragePath, METH_VARARGS, doc_QWebSettings_localStoragePath},
    {sipName_maximumPagesInCache, meth_QWebSettings_maximumPagesInCache, METH_VARARGS, doc_QWebSettings_maximumPagesInCache},
    {sipName_offlineStorageDefaultQuota, meth_QWebSettings_offlineStorageDefaultQuota, METH_VARARGS, doc_QWebSettings_offlineStorageDefaultQuota},
    {sipName_offlineStoragePath, meth_QWebSettings_offlineStoragePath, METH_VARARGS, doc_QWebSettings_offlineStoragePath},
    {sipName_offlineWebApplicationCachePath, meth_QWebSettings_offlineWebApplicationCachePath, METH_VARARGS, doc_QWebSettings_offlineWebApplicationCachePath},
    {sipName_offlineWebApplicationCacheQuota, meth_QWebSettings_offlineWebApplicationCacheQuota, METH_VARARGS, doc_QWebSettings_offlineWebApplicationCacheQuota},
    {sipName_resetAttribute, meth_QWebSettings_resetAttribute, METH_VARARGS, doc_QWebSettings_resetAttribute},
    {sipName_resetFontFamily, meth_QWebSettings_resetFontFamily, METH_VARARGS, doc_QWebSettings_resetFontFamily},
    {sipName_resetFontSize, meth_QWebSettings_resetFontSize, METH_VARARGS, doc_QWebSettings_resetFontSize},
    {sipName_setAttribute, meth_QWebSettings_setAttribute, METH_VARARGS, doc_QWebSettings_setAttribute},
    {sipName_setCSSMediaType, meth_QWebSettings_setCSSMediaType, METH_VARARGS, doc_QWebSettings_setCSSMediaType},
    {sipName_setDefaultTextEncoding, meth_QWebSettings_setDefaultTextEncoding, METH_VARARGS, doc_QWebSettings_setDefaultTextEncoding},
    {sipName_setFontFamily, meth_QWebSettings_setFontFamily, METH_VARARGS, doc_QWebSettings_setFontFamily},
    {sipName_setFontSize, meth_QWebSettings_setFontSize, METH_VARARGS, doc_QWebSettings_setFontSize},
    {sipName_setIconDatabasePath, meth_QWebSettings_setIconDatabasePath, METH_VARARGS, doc_QWebSettings_setIconDatabasePath},
    {sipName_setLocalStoragePath, meth_QWebSettings_setLocalStoragePath, METH_VARARGS, doc_QWebSettings_setLocalStoragePath},
    {sipName_setMaximumPagesInCache, meth_QWebSettings_setMaximumPagesInCache, METH_VARARGS, doc_QWebSettings_setMaximumPagesInCache},
    {sipName_setObjectCacheCapacities, meth_QWebSettings_setObjectCacheCapacities, METH_VARARGS, doc_QWebSettings_setObjectCacheCapacities},
    {sipName_setOfflineStorageDefaultQuota, meth_QWebSettings_setOfflineStorageDefaultQuota, METH_VARARGS, doc_QWebSettings_setOfflineStorageDefaultQuota},
    {sipName_setOfflineStoragePath, meth_QWebSettings_setOfflineStoragePath, METH_VARARGS, doc_QWebSettings_setOfflineStoragePath},
    {sipName_setOfflineWebApplicationCachePath, meth_QWebSettings_setOfflineWebApplicationCachePath, METH_VARARGS, doc_QWebSettings_setOfflineWebApplicationCachePath},
    {sipName_setOfflineWebApplicationCacheQuota, meth_QWebSettings_setOfflineWebApplicationCacheQuota, METH_VARARGS, doc_QWebSettings_setOfflineWebApplicationCacheQuota},
    {sipName_setThirdPartyCookiePolicy, meth_QWebSettings_setThirdPartyCookiePolicy, METH_VARARGS, doc_QWebSettings_setThirdPartyCookiePolicy},
    {sipName_setUserStyleSheetUrl, meth_QWebSettings_setUserStyleSheetUrl, METH_VARARGS, doc_QWebSettings_setUserStyleSheetUrl},
    {sipName_setWebGraphic, meth_QWebSettings_setWebGraphic, METH_VARARGS, doc_QWebSettings_setWebGraphic},
    {sipName_testAttribute, meth_QWebSettings_testAttribute, METH_VARARGS, doc_QWebSettings_testAttribute},
    {sipName_thirdPartyCookiePolicy, meth_QWebSettings_thirdPartyCookiePolicy, METH_VARARGS, doc_QWebSettings_thirdPartyCookiePolicy},
    {sipName_userStyleSheetUrl, meth_QWebSettings_userStyleSheetUrl, METH_VARARGS, doc_QWebSettings_userStyleSheetUrl},
    {sipName_webGraphic, meth_QWebSettings_webGraphic, METH_VARARGS, doc_QWebSettings_webGraphic}
};

static sipEnumMemberDef enummembers_QWebSettings[] = {
    {sipName_Accelerated2dCanvasEnabled, static_cast<int>(::QWebSettings::Accelerated2dCanvasEnabled), 26},
    {sipName_AcceleratedCompositingEnabled, static_cast<int>(::QWebSettings::AcceleratedCompositingEnabled), 26},
    {sipName_AllowThirdPartyWithExistingCookies, static_cast<int>(::QWebSettings::AllowThirdPartyWithExistingCookies), 25},
    {sipName_AlwaysAllowThirdPartyCookies, static_cast<int>(::QWebSettings::AlwaysAllowThirdPartyCookies), 25},
    {sipName_AlwaysBlockThirdPartyCookies, static_cast<int>(::QWebSettings::AlwaysBlockThirdPartyCookies), 25},
    {sipName_AutoLoadImages, static_cast<int>(::QWebSettings::AutoLoadImages), 26},
    {sipName_CSSGridLayoutEnabled, static_cast<int>(::QWebSettings::CSSGridLayoutEnabled), 26},
    {sipName_CSSRegionsEnabled, static_cast<int>(::QWebSettings::CSSRegionsEnabled), 26},
    {sipName_CaretBrowsingEnabled, static_cast<int>(::QWebSettings::CaretBrowsingEnabled), 26},
    {sipName_CursiveFont, static_cast<int>(::QWebSettings::CursiveFont), 23},
    {sipName_DefaultFixedFontSize, static_cast<int>(::QWebSettings::DefaultFixedFontSize), 24},
    {sipName_DefaultFontSize, static_cast<int>(::QWebSettings::DefaultFontSize), 24},
    {sipName_DefaultFrameIconGraphic, static_cast<int>(::QWebSettings::DefaultFrameIconGraphic), 27},
    {sipName_DeveloperExtrasEnabled, static_cast<int>(::QWebSettings::DeveloperExtrasEnabled), 26},
    {sipName_DnsPrefetchEnabled, static_cast<int>(::QWebSettings::DnsPrefetchEnabled), 26},
    {sipName_FantasyFont, static_cast<int>(::QWebSettings::FantasyFont), 23},
    {sipName_FixedFont, static_cast<int>(::QWebSettings::FixedFont), 23},
    {sipName_FrameFlatteningEnabled, static_cast<int>(::QWebSettings::FrameFlatteningEnabled), 26},
    {sipName_HyperlinkAuditingEnabled, static_cast<int>(::QWebSettings::HyperlinkAuditingEnabled), 26},
    {sipName_InputSpeechButtonGraphic, static_cast<int>(::QWebSettings::InputSpeechButtonGraphic), 27},
    {sipName_JavaEnabled, static_cast<int>(::QWebSettings::JavaEnabled), 26},
    {sipName_JavascriptCanAccessClipboard, static_cast<int>(::QWebSettings::JavascriptCanAccessClipboard), 26},
    {sipName_JavascriptCanCloseWindows, static_cast<int>(::QWebSettings::JavascriptCanCloseWindows), 26},
    {sipName_JavascriptCanOpenWindows, static_cast<int>(::QWebSettings::JavascriptCanOpenWindows), 26},
    {sipName_JavascriptEnabled, static_cast<int>(::QWebSettings::JavascriptEnabled), 26},
    {sipName_LinksIncludedInFocusChain, static_cast<int>(::QWebSettings::LinksIncludedInFocusChain), 26},
    {sipName_LocalContentCanAccessFileUrls, static_cast<int>(::QWebSettings::LocalContentCanAccessFileUrls), 26},
    {sipName_LocalContentCanAccessRemoteUrls, static_cast<int>(::QWebSettings::LocalContentCanAccessRemoteUrls), 26},
    {sipName_LocalStorageDatabaseEnabled, static_cast<int>(::QWebSettings::LocalStorageDatabaseEnabled), 26},
    {sipName_LocalStorageEnabled, static_cast<int>(::QWebSettings::LocalStorageEnabled), 26},
    {sipName_MinimumFontSize, static_cast<int>(::QWebSettings::MinimumFontSize), 24},
    {sipName_MinimumLogicalFontSize, static_cast<int>(::QWebSettings::MinimumLogicalFontSize), 24},
    {sipName_MissingImageGraphic, static_cast<int>(::QWebSettings::MissingImageGraphic), 27},
    {sipName_MissingPluginGraphic, static_cast<int>(::QWebSettings::MissingPluginGraphic), 27},
    {sipName_NotificationsEnabled, static_cast<int>(::QWebSettings::NotificationsEnabled), 26},
    {sipName_OfflineStorageDatabaseEnabled, static_cast<int>(::QWebSettings::OfflineStorageDatabaseEnabled), 26},
    {sipName_OfflineWebApplicationCacheEnabled, static_cast<int>(::QWebSettings::OfflineWebApplicationCacheEnabled), 26},
    {sipName_PluginsEnabled, static_cast<int>(::QWebSettings::PluginsEnabled), 26},
    {sipName_PrintElementBackgrounds, static_cast<int>(::QWebSettings::PrintElementBackgrounds), 26},
    {sipName_PrivateBrowsingEnabled, static_cast<int>(::QWebSettings::PrivateBrowsingEnabled), 26},
    {sipName_SansSerifFont, static_cast<int>(::QWebSettings::SansSerifFont), 23},
    {sipName_ScrollAnimatorEnabled, static_cast<int>(::QWebSettings::ScrollAnimatorEnabled), 26},
    {sipName_SearchCancelButtonGraphic, static_cast<int>(::QWebSettings::SearchCancelButtonGraphic), 27},
    {sipName_SearchCancelButtonPressedGraphic, static_cast<int>(::QWebSettings::SearchCancelButtonPressedGraphic), 27},
    {sipName_SerifFont, static_cast<int>(::QWebSettings::SerifFont), 23},
    {sipName_SiteSpecificQuirksEnabled, static_cast<int>(::QWebSettings::SiteSpecificQuirksEnabled), 26},
    {sipName_SpatialNavigationEnabled, static_cast<int>(::QWebSettings::SpatialNavigationEnabled), 26},
    {sipName_StandardFont, static_cast<int>(::QWebSettings::StandardFont), 23},
    {sipName_TextAreaSizeGripCornerGraphic, static_cast<int>(::QWebSettings::TextAreaSizeGripCornerGraphic), 27},
    {sipName_TiledBackingStoreEnabled, static_cast<int>(::QWebSettings::TiledBackingStoreEnabled), 26},
    {sipName_WebAudioEnabled, static_cast<int>(::QWebSettings::WebAudioEnabled), 26},
    {sipName_WebGLEnabled, static_cast<int>(::QWebSettings::WebGLEnabled), 26},
    {sipName_XSSAuditingEnabled, static_cast<int>(::QWebSettings::XSSAuditingEnabled), 26},
    {sipName_ZoomTextOnly, static_cast<int>(::QWebSettings::ZoomTextOnly), 26},
};


static pyqt5ClassPluginDef plugin_QWebSettings = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKit_QWebSettings = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebSettings,
        SIP_NULLPTR,
        &plugin_QWebSettings,
    },
    {
        sipNameNr_QWebSettings,
        {0, 0, 1},
        39, methods_QWebSettings,
        54, enummembers_QWebSettings,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QWebSettings,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
