/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetwork.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qlocalserver.sip"
#include <qlocalserver.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 166 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qlocalserver.sip"
#include <qlocalserver.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qabstractsocket.sip"
#include <qabstractsocket.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qlocalsocket.sip"
#include <qlocalsocket.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtNetwork/sipQtNetworkQLocalServer.cpp"


class sipQLocalServer : public ::QLocalServer
{
public:
    sipQLocalServer(::QObject*);
    virtual ~sipQLocalServer();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void incomingConnection(::quintptr) SIP_OVERRIDE;
    ::QLocalSocket* nextPendingConnection() SIP_OVERRIDE;
    bool hasPendingConnections() const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQLocalServer(const sipQLocalServer &);
    sipQLocalServer &operator = (const sipQLocalServer &);

    char sipPyMethods[10];
};

sipQLocalServer::sipQLocalServer(::QObject*a0): ::QLocalServer(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQLocalServer::~sipQLocalServer()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQLocalServer::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtNetwork_qt_metaobject(sipPySelf, sipType_QLocalServer);

    return ::QLocalServer::metaObject();
}

int sipQLocalServer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QLocalServer::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtNetwork_qt_metacall(sipPySelf, sipType_QLocalServer, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQLocalServer::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtNetwork_qt_metacast(sipPySelf, sipType_QLocalServer, _clname, &sipCpp) ? sipCpp : ::QLocalServer::qt_metacast(_clname));
}

void sipQLocalServer::incomingConnection(::quintptr a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_incomingConnection);

    if (!sipMeth)
    {
        ::QLocalServer::incomingConnection(a0);
        return;
    }

    extern void sipVH_QtNetwork_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::quintptr);

    sipVH_QtNetwork_29(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QLocalSocket* sipQLocalServer::nextPendingConnection()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_nextPendingConnection);

    if (!sipMeth)
        return ::QLocalServer::nextPendingConnection();

    extern ::QLocalSocket* sipVH_QtNetwork_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_28(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQLocalServer::hasPendingConnections() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasPendingConnections);

    if (!sipMeth)
        return ::QLocalServer::hasPendingConnections();

    extern bool sipVH_QtNetwork_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetwork_18(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQLocalServer::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QLocalServer::event(a0);

    extern bool sipVH_QtNetwork_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtNetwork_5(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQLocalServer::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QLocalServer::eventFilter(a0, a1);

    extern bool sipVH_QtNetwork_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtNetwork_4(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQLocalServer::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QLocalServer::timerEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtNetwork_3(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLocalServer::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QLocalServer::childEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtNetwork_2(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLocalServer::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QLocalServer::customEvent(a0);
        return;
    }

    extern void sipVH_QtNetwork_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtNetwork_1(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLocalServer::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QLocalServer::connectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLocalServer::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QLocalServer::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtNetwork_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtNetwork_0(sipGILState, sipImportedVirtErrorHandlers_QtNetwork_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QLocalServer_close, "close(self)");

extern "C" {static PyObject *meth_QLocalServer_close(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_close(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocalServer, &sipCpp))
        {
            sipCpp->close();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_close, doc_QLocalServer_close);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QLocalServer_errorString(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocalServer, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_errorString, doc_QLocalServer_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_hasPendingConnections, "hasPendingConnections(self) -> bool");

extern "C" {static PyObject *meth_QLocalServer_hasPendingConnections(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_hasPendingConnections(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocalServer, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QLocalServer::hasPendingConnections() : sipCpp->hasPendingConnections());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_hasPendingConnections, doc_QLocalServer_hasPendingConnections);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_isListening, "isListening(self) -> bool");

extern "C" {static PyObject *meth_QLocalServer_isListening(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_isListening(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocalServer, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isListening();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_isListening, doc_QLocalServer_isListening);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_listen, "listen(self, name: Optional[str]) -> bool\n"
"listen(self, socketDescriptor: PyQt5.sip.voidptr) -> bool");

extern "C" {static PyObject *meth_QLocalServer_listen(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_listen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLocalServer, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->listen(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::qintptr* a0;
        int a0State = 0;
        ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLocalServer, &sipCpp, sipType_qintptr, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->listen(*a0);
            sipReleaseType(a0, sipType_qintptr, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_listen, doc_QLocalServer_listen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_maxPendingConnections, "maxPendingConnections(self) -> int");

extern "C" {static PyObject *meth_QLocalServer_maxPendingConnections(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_maxPendingConnections(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocalServer, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxPendingConnections();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_maxPendingConnections, doc_QLocalServer_maxPendingConnections);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_nextPendingConnection, "nextPendingConnection(self) -> Optional[QLocalSocket]");

extern "C" {static PyObject *meth_QLocalServer_nextPendingConnection(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_nextPendingConnection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocalServer, &sipCpp))
        {
            ::QLocalSocket*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QLocalServer::nextPendingConnection() : sipCpp->nextPendingConnection());

            return sipConvertFromType(sipRes, sipType_QLocalSocket, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_nextPendingConnection, doc_QLocalServer_nextPendingConnection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_serverName, "serverName(self) -> str");

extern "C" {static PyObject *meth_QLocalServer_serverName(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_serverName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocalServer, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->serverName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_serverName, doc_QLocalServer_serverName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_fullServerName, "fullServerName(self) -> str");

extern "C" {static PyObject *meth_QLocalServer_fullServerName(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_fullServerName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocalServer, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->fullServerName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_fullServerName, doc_QLocalServer_fullServerName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_serverError, "serverError(self) -> QAbstractSocket.SocketError");

extern "C" {static PyObject *meth_QLocalServer_serverError(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_serverError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocalServer, &sipCpp))
        {
            ::QAbstractSocket::SocketError sipRes;

            sipRes = sipCpp->serverError();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAbstractSocket_SocketError);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_serverError, doc_QLocalServer_serverError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_setMaxPendingConnections, "setMaxPendingConnections(self, numConnections: int)");

extern "C" {static PyObject *meth_QLocalServer_setMaxPendingConnections(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_setMaxPendingConnections(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QLocalServer, &sipCpp, &a0))
        {
            sipCpp->setMaxPendingConnections(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_setMaxPendingConnections, doc_QLocalServer_setMaxPendingConnections);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_waitForNewConnection, "waitForNewConnection(self, msecs: int = 0) -> (bool, Optional[bool])");

extern "C" {static PyObject *meth_QLocalServer_waitForNewConnection(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_waitForNewConnection(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = 0;
        bool a1;
        ::QLocalServer *sipCpp;

        static const char *sipKwdList[] = {
            sipName_msecs,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QLocalServer, &sipCpp, &a0))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->waitForNewConnection(a0, &a1);
            Py_END_ALLOW_THREADS

            return sipBuildResult(0, "(bb)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_waitForNewConnection, doc_QLocalServer_waitForNewConnection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_removeServer, "removeServer(name: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QLocalServer_removeServer(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_removeServer(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = ::QLocalServer::removeServer(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_removeServer, doc_QLocalServer_removeServer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_incomingConnection, "incomingConnection(self, socketDescriptor: PyQt5.sip.voidptr)");

extern "C" {static PyObject *meth_QLocalServer_incomingConnection(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_incomingConnection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::quintptr* a0;
        int a0State = 0;
        ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QLocalServer, &sipCpp, sipType_quintptr, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QLocalServer::incomingConnection(*a0) : sipCpp->incomingConnection(*a0));
            sipReleaseType(a0, sipType_quintptr, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_incomingConnection, doc_QLocalServer_incomingConnection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_setSocketOptions, "setSocketOptions(self, options: Union[QLocalServer.SocketOptions, QLocalServer.SocketOption])");

extern "C" {static PyObject *meth_QLocalServer_setSocketOptions(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_setSocketOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocalServer::SocketOptions* a0;
        int a0State = 0;
        ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLocalServer, &sipCpp, sipType_QLocalServer_SocketOptions, &a0, &a0State))
        {
            sipCpp->setSocketOptions(*a0);
            sipReleaseType(a0, sipType_QLocalServer_SocketOptions, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_setSocketOptions, doc_QLocalServer_setSocketOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_socketOptions, "socketOptions(self) -> QLocalServer.SocketOptions");

extern "C" {static PyObject *meth_QLocalServer_socketOptions(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_socketOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocalServer, &sipCpp))
        {
            ::QLocalServer::SocketOptions*sipRes;

            sipRes = new ::QLocalServer::SocketOptions(sipCpp->socketOptions());

            return sipConvertFromNewType(sipRes, sipType_QLocalServer_SocketOptions, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_socketOptions, doc_QLocalServer_socketOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocalServer_socketDescriptor, "socketDescriptor(self) -> PyQt5.sip.voidptr");

extern "C" {static PyObject *meth_QLocalServer_socketDescriptor(PyObject *, PyObject *);}
static PyObject *meth_QLocalServer_socketDescriptor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocalServer *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocalServer, &sipCpp))
        {
            ::qintptr*sipRes;

            sipRes = new ::qintptr(sipCpp->socketDescriptor());

            return sipConvertFromNewType(sipRes, sipType_qintptr, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocalServer, sipName_socketDescriptor, doc_QLocalServer_socketDescriptor);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QLocalServer(void *, const sipTypeDef *);}
static void *cast_QLocalServer(void *sipCppV, const sipTypeDef *targetType)
{
    ::QLocalServer *sipCpp = reinterpret_cast< ::QLocalServer *>(sipCppV);

    if (targetType == sipType_QLocalServer)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QLocalServer(void *, int);}
static void release_QLocalServer(void *sipCppV, int)
{
    ::QLocalServer *sipCpp = reinterpret_cast< ::QLocalServer *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QLocalServer(Py_ssize_t);}
static void *array_QLocalServer(Py_ssize_t sipNrElem)
{
    return new ::QLocalServer[sipNrElem];
}


extern "C" {static void array_delete_QLocalServer(void *);}
static void array_delete_QLocalServer(void *sipCpp)
{
    delete[] reinterpret_cast< ::QLocalServer *>(sipCpp);
}


extern "C" {static void dealloc_QLocalServer(sipSimpleWrapper *);}
static void dealloc_QLocalServer(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQLocalServer *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QLocalServer(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QLocalServer(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QLocalServer(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQLocalServer *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQLocalServer(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QLocalServer[] = {{12, 0, 1}};


static PyMethodDef methods_QLocalServer[] = {
    {sipName_close, meth_QLocalServer_close, METH_VARARGS, doc_QLocalServer_close},
    {sipName_errorString, meth_QLocalServer_errorString, METH_VARARGS, doc_QLocalServer_errorString},
    {sipName_fullServerName, meth_QLocalServer_fullServerName, METH_VARARGS, doc_QLocalServer_fullServerName},
    {sipName_hasPendingConnections, meth_QLocalServer_hasPendingConnections, METH_VARARGS, doc_QLocalServer_hasPendingConnections},
    {sipName_incomingConnection, meth_QLocalServer_incomingConnection, METH_VARARGS, doc_QLocalServer_incomingConnection},
    {sipName_isListening, meth_QLocalServer_isListening, METH_VARARGS, doc_QLocalServer_isListening},
    {sipName_listen, meth_QLocalServer_listen, METH_VARARGS, doc_QLocalServer_listen},
    {sipName_maxPendingConnections, meth_QLocalServer_maxPendingConnections, METH_VARARGS, doc_QLocalServer_maxPendingConnections},
    {sipName_nextPendingConnection, meth_QLocalServer_nextPendingConnection, METH_VARARGS, doc_QLocalServer_nextPendingConnection},
    {sipName_removeServer, meth_QLocalServer_removeServer, METH_VARARGS, doc_QLocalServer_removeServer},
    {sipName_serverError, meth_QLocalServer_serverError, METH_VARARGS, doc_QLocalServer_serverError},
    {sipName_serverName, meth_QLocalServer_serverName, METH_VARARGS, doc_QLocalServer_serverName},
    {sipName_setMaxPendingConnections, meth_QLocalServer_setMaxPendingConnections, METH_VARARGS, doc_QLocalServer_setMaxPendingConnections},
    {sipName_setSocketOptions, meth_QLocalServer_setSocketOptions, METH_VARARGS, doc_QLocalServer_setSocketOptions},
    {sipName_socketDescriptor, meth_QLocalServer_socketDescriptor, METH_VARARGS, doc_QLocalServer_socketDescriptor},
    {sipName_socketOptions, meth_QLocalServer_socketOptions, METH_VARARGS, doc_QLocalServer_socketOptions},
    {sipName_waitForNewConnection, SIP_MLMETH_CAST(meth_QLocalServer_waitForNewConnection), METH_VARARGS|METH_KEYWORDS, doc_QLocalServer_waitForNewConnection}
};

static sipEnumMemberDef enummembers_QLocalServer[] = {
    {sipName_GroupAccessOption, static_cast<int>(::QLocalServer::GroupAccessOption), 51},
    {sipName_OtherAccessOption, static_cast<int>(::QLocalServer::OtherAccessOption), 51},
    {sipName_UserAccessOption, static_cast<int>(::QLocalServer::UserAccessOption), 51},
    {sipName_WorldAccessOption, static_cast<int>(::QLocalServer::WorldAccessOption), 51},
};

PyDoc_STRVAR(doc_QLocalServer, "\1QLocalServer(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QLocalServer[] = {
    {"newConnection()", "\1newConnection(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QLocalServer = {
    &::QLocalServer::staticMetaObject,
    0,
    signals_QLocalServer,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNetwork_QLocalServer = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QLocalServer,
        SIP_NULLPTR,
        &plugin_QLocalServer,
    },
    {
        sipNameNr_QLocalServer,
        {0, 0, 1},
        17, methods_QLocalServer,
        4, enummembers_QLocalServer,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QLocalServer,
    -1,
    -1,
    supers_QLocalServer,
    SIP_NULLPTR,
    init_type_QLocalServer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QLocalServer,
    SIP_NULLPTR,
    array_QLocalServer,
    SIP_NULLPTR,
    release_QLocalServer,
    cast_QLocalServer,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QLocalServer,
    sizeof (::QLocalServer),
};
