/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtOpenGLAPI_H
#define _QtOpenGLAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_OpenGL_ES_CommonLite_Version_1_0 0
#define sipName_OpenGL_ES_CommonLite_Version_1_0 &sipStrings_QtOpenGL[0]
#define sipNameNr_OpenGL_ES_CommonLite_Version_1_1 33
#define sipName_OpenGL_ES_CommonLite_Version_1_1 &sipStrings_QtOpenGL[33]
#define sipNameNr_QGLFormat__OpenGLContextProfile 66
#define sipName_QGLFormat__OpenGLContextProfile &sipStrings_QtOpenGL[66]
#define sipNameNr_QGLFormat__OpenGLVersionFlags 98
#define sipName_QGLFormat__OpenGLVersionFlags &sipStrings_QtOpenGL[98]
#define sipNameNr_OpenGL_ES_Common_Version_1_0 128
#define sipName_OpenGL_ES_Common_Version_1_0 &sipStrings_QtOpenGL[128]
#define sipNameNr_OpenGL_ES_Common_Version_1_1 157
#define sipName_OpenGL_ES_Common_Version_1_1 &sipStrings_QtOpenGL[157]
#define sipNameNr_PremultipliedAlphaBindOption 186
#define sipName_PremultipliedAlphaBindOption &sipStrings_QtOpenGL[186]
#define sipNameNr_QGLFormat__OpenGLVersionFlag 215
#define sipName_QGLFormat__OpenGLVersionFlag &sipStrings_QtOpenGL[215]
#define sipNameNr_LinearFilteringBindOption 244
#define sipName_LinearFilteringBindOption &sipStrings_QtOpenGL[244]
#define sipNameNr_QGLContext__BindOptions 270
#define sipName_QGLContext__BindOptions &sipStrings_QtOpenGL[270]
#define sipNameNr_overlayTransparentColor 294
#define sipName_overlayTransparentColor &sipStrings_QtOpenGL[294]
#define sipNameNr_setDefaultOverlayFormat 318
#define sipName_setDefaultOverlayFormat &sipStrings_QtOpenGL[318]
#define sipNameNr_QGLContext__BindOption 342
#define sipName_QGLContext__BindOption &sipStrings_QtOpenGL[342]
#define sipNameNr_NoDeprecatedFunctions 365
#define sipName_NoDeprecatedFunctions &sipStrings_QtOpenGL[365]
#define sipNameNr_OpenGL_ES_Version_2_0 387
#define sipName_OpenGL_ES_Version_2_0 &sipStrings_QtOpenGL[387]
#define sipNameNr_mouseDoubleClickEvent 409
#define sipName_mouseDoubleClickEvent &sipStrings_QtOpenGL[409]
#define sipNameNr_CompatibilityProfile 431
#define sipName_CompatibilityProfile &sipStrings_QtOpenGL[431]
#define sipNameNr_OpenGLContextProfile 77
#define sipName_OpenGLContextProfile &sipStrings_QtOpenGL[77]
#define sipNameNr_defaultOverlayFormat 452
#define sipName_defaultOverlayFormat &sipStrings_QtOpenGL[452]
#define sipNameNr_setStencilBufferSize 473
#define sipName_setStencilBufferSize &sipStrings_QtOpenGL[473]
#define sipNameNr_setTextureCacheLimit 494
#define sipName_setTextureCacheLimit &sipStrings_QtOpenGL[494]
#define sipNameNr_DeprecatedFunctions 367
#define sipName_DeprecatedFunctions &sipStrings_QtOpenGL[367]
#define sipNameNr_InvertedYBindOption 515
#define sipName_InvertedYBindOption &sipStrings_QtOpenGL[515]
#define sipNameNr_OpenGL_Version_None 535
#define sipName_OpenGL_Version_None &sipStrings_QtOpenGL[535]
#define sipNameNr_initializeOverlayGL 555
#define sipName_initializeOverlayGL &sipStrings_QtOpenGL[555]
#define sipNameNr_OpenGLVersionFlags 109
#define sipName_OpenGLVersionFlags &sipStrings_QtOpenGL[109]
#define sipNameNr_OpenGL_Version_1_1 575
#define sipName_OpenGL_Version_1_1 &sipStrings_QtOpenGL[575]
#define sipNameNr_OpenGL_Version_1_2 594
#define sipName_OpenGL_Version_1_2 &sipStrings_QtOpenGL[594]
#define sipNameNr_OpenGL_Version_1_3 613
#define sipName_OpenGL_Version_1_3 &sipStrings_QtOpenGL[613]
#define sipNameNr_OpenGL_Version_1_4 632
#define sipName_OpenGL_Version_1_4 &sipStrings_QtOpenGL[632]
#define sipNameNr_OpenGL_Version_1_5 651
#define sipName_OpenGL_Version_1_5 &sipStrings_QtOpenGL[651]
#define sipNameNr_OpenGL_Version_2_0 670
#define sipName_OpenGL_Version_2_0 &sipStrings_QtOpenGL[670]
#define sipNameNr_OpenGL_Version_2_1 689
#define sipName_OpenGL_Version_2_1 &sipStrings_QtOpenGL[689]
#define sipNameNr_OpenGL_Version_3_0 708
#define sipName_OpenGL_Version_3_0 &sipStrings_QtOpenGL[708]
#define sipNameNr_OpenGL_Version_3_1 727
#define sipName_OpenGL_Version_3_1 &sipStrings_QtOpenGL[727]
#define sipNameNr_OpenGL_Version_3_2 746
#define sipName_OpenGL_Version_3_2 &sipStrings_QtOpenGL[746]
#define sipNameNr_OpenGL_Version_3_3 765
#define sipName_OpenGL_Version_3_3 &sipStrings_QtOpenGL[765]
#define sipNameNr_OpenGL_Version_4_0 784
#define sipName_OpenGL_Version_4_0 &sipStrings_QtOpenGL[784]
#define sipNameNr_OpenGL_Version_4_1 803
#define sipName_OpenGL_Version_4_1 &sipStrings_QtOpenGL[803]
#define sipNameNr_OpenGL_Version_4_2 822
#define sipName_OpenGL_Version_4_2 &sipStrings_QtOpenGL[822]
#define sipNameNr_OpenGL_Version_4_3 841
#define sipName_OpenGL_Version_4_3 &sipStrings_QtOpenGL[841]
#define sipNameNr_QGL__FormatOptions 860
#define sipName_QGL__FormatOptions &sipStrings_QtOpenGL[860]
#define sipNameNr_focusNextPrevChild 879
#define sipName_focusNextPrevChild &sipStrings_QtOpenGL[879]
#define sipNameNr_makeOverlayCurrent 898
#define sipName_makeOverlayCurrent &sipStrings_QtOpenGL[898]
#define sipNameNr_openGLVersionFlags 917
#define sipName_openGLVersionFlags &sipStrings_QtOpenGL[917]
#define sipNameNr_setAccumBufferSize 936
#define sipName_setAccumBufferSize &sipStrings_QtOpenGL[936]
#define sipNameNr_setAlphaBufferSize 955
#define sipName_setAlphaBufferSize &sipStrings_QtOpenGL[955]
#define sipNameNr_setDepthBufferSize 974
#define sipName_setDepthBufferSize &sipStrings_QtOpenGL[974]
#define sipNameNr_setDirectRendering 993
#define sipName_setDirectRendering &sipStrings_QtOpenGL[993]
#define sipNameNr_setGreenBufferSize 1012
#define sipName_setGreenBufferSize &sipStrings_QtOpenGL[1012]
#define sipNameNr_DefaultBindOption 1031
#define sipName_DefaultBindOption &sipStrings_QtOpenGL[1031]
#define sipNameNr_IndirectRendering 1049
#define sipName_IndirectRendering &sipStrings_QtOpenGL[1049]
#define sipNameNr_OpenGLVersionFlag 226
#define sipName_OpenGLVersionFlag &sipStrings_QtOpenGL[226]
#define sipNameNr_QGL__FormatOption 1067
#define sipName_QGL__FormatOption &sipStrings_QtOpenGL[1067]
#define sipNameNr_convertToGLFormat 1085
#define sipName_convertToGLFormat &sipStrings_QtOpenGL[1085]
#define sipNameNr_hasHeightForWidth 1103
#define sipName_hasHeightForWidth &sipStrings_QtOpenGL[1103]
#define sipNameNr_hasOpenGLOverlays 1121
#define sipName_hasOpenGLOverlays &sipStrings_QtOpenGL[1121]
#define sipNameNr_mouseReleaseEvent 1139
#define sipName_mouseReleaseEvent &sipStrings_QtOpenGL[1139]
#define sipNameNr_setAutoBufferSwap 1157
#define sipName_setAutoBufferSwap &sipStrings_QtOpenGL[1157]
#define sipNameNr_setBlueBufferSize 1175
#define sipName_setBlueBufferSize &sipStrings_QtOpenGL[1175]
#define sipNameNr_sip_simplewrapper 1193
#define sipName_sip_simplewrapper &sipStrings_QtOpenGL[1193]
#define sipNameNr_stencilBufferSize 1211
#define sipName_stencilBufferSize &sipStrings_QtOpenGL[1211]
#define sipNameNr_textureCacheLimit 1229
#define sipName_textureCacheLimit &sipStrings_QtOpenGL[1229]
#define sipNameNr_MipmapBindOption 1247
#define sipName_MipmapBindOption &sipStrings_QtOpenGL[1247]
#define sipNameNr_contextMenuEvent 1264
#define sipName_contextMenuEvent &sipStrings_QtOpenGL[1264]
#define sipNameNr_deleteOldContext 1281
#define sipName_deleteOldContext &sipStrings_QtOpenGL[1281]
#define sipNameNr_disconnectNotify 1298
#define sipName_disconnectNotify &sipStrings_QtOpenGL[1298]
#define sipNameNr_inputMethodEvent 1315
#define sipName_inputMethodEvent &sipStrings_QtOpenGL[1315]
#define sipNameNr_inputMethodQuery 1332
#define sipName_inputMethodQuery &sipStrings_QtOpenGL[1332]
#define sipNameNr_setDefaultFormat 1349
#define sipName_setDefaultFormat &sipStrings_QtOpenGL[1349]
#define sipNameNr_setRedBufferSize 1366
#define sipName_setRedBufferSize &sipStrings_QtOpenGL[1366]
#define sipNameNr_setSampleBuffers 1383
#define sipName_setSampleBuffers &sipStrings_QtOpenGL[1383]
#define sipNameNr_setWindowCreated 1400
#define sipName_setWindowCreated &sipStrings_QtOpenGL[1400]
#define sipNameNr_DirectRendering 996
#define sipName_DirectRendering &sipStrings_QtOpenGL[996]
#define sipNameNr_NoSampleBuffers 1417
#define sipName_NoSampleBuffers &sipStrings_QtOpenGL[1417]
#define sipNameNr_NoStencilBuffer 1433
#define sipName_NoStencilBuffer &sipStrings_QtOpenGL[1433]
#define sipNameNr_NoStereoBuffers 1449
#define sipName_NoStereoBuffers &sipStrings_QtOpenGL[1449]
#define sipNameNr_accumBufferSize 1465
#define sipName_accumBufferSize &sipStrings_QtOpenGL[1465]
#define sipNameNr_alphaBufferSize 1481
#define sipName_alphaBufferSize &sipStrings_QtOpenGL[1481]
#define sipNameNr_depthBufferSize 1497
#define sipName_depthBufferSize &sipStrings_QtOpenGL[1497]
#define sipNameNr_directRendering 1051
#define sipName_directRendering &sipStrings_QtOpenGL[1051]
#define sipNameNr_grabFrameBuffer 1513
#define sipName_grabFrameBuffer &sipStrings_QtOpenGL[1513]
#define sipNameNr_greenBufferSize 1529
#define sipName_greenBufferSize &sipStrings_QtOpenGL[1529]
#define sipNameNr_keyReleaseEvent 1545
#define sipName_keyReleaseEvent &sipStrings_QtOpenGL[1545]
#define sipNameNr_minimumSizeHint 1561
#define sipName_minimumSizeHint &sipStrings_QtOpenGL[1561]
#define sipNameNr_mousePressEvent 1577
#define sipName_mousePressEvent &sipStrings_QtOpenGL[1577]
#define sipNameNr_requestedFormat 1593
#define sipName_requestedFormat &sipStrings_QtOpenGL[1593]
#define sipNameNr_resizeOverlayGL 1609
#define sipName_resizeOverlayGL &sipStrings_QtOpenGL[1609]
#define sipNameNr_setDoubleBuffer 1625
#define sipName_setDoubleBuffer &sipStrings_QtOpenGL[1625]
#define sipNameNr_setSwapInterval 1641
#define sipName_setSwapInterval &sipStrings_QtOpenGL[1641]
#define sipNameNr_updateOverlayGL 1657
#define sipName_updateOverlayGL &sipStrings_QtOpenGL[1657]
#define sipNameNr_NoAlphaChannel 1673
#define sipName_NoAlphaChannel &sipStrings_QtOpenGL[1673]
#define sipNameNr_PyQt5_QtOpenGL 1688
#define sipName_PyQt5_QtOpenGL &sipStrings_QtOpenGL[1688]
#define sipNameNr_autoBufferSwap 1703
#define sipName_autoBufferSwap &sipStrings_QtOpenGL[1703]
#define sipNameNr_blueBufferSize 1718
#define sipName_blueBufferSize &sipStrings_QtOpenGL[1718]
#define sipNameNr_currentContext 1733
#define sipName_currentContext &sipStrings_QtOpenGL[1733]
#define sipNameNr_deviceIsPixmap 1748
#define sipName_deviceIsPixmap &sipStrings_QtOpenGL[1748]
#define sipNameNr_dragEnterEvent 1763
#define sipName_dragEnterEvent &sipStrings_QtOpenGL[1763]
#define sipNameNr_dragLeaveEvent 1778
#define sipName_dragLeaveEvent &sipStrings_QtOpenGL[1778]
#define sipNameNr_getProcAddress 1793
#define sipName_getProcAddress &sipStrings_QtOpenGL[1793]
#define sipNameNr_heightForWidth 1808
#define sipName_heightForWidth &sipStrings_QtOpenGL[1808]
#define sipNameNr_mouseMoveEvent 1823
#define sipName_mouseMoveEvent &sipStrings_QtOpenGL[1823]
#define sipNameNr_overlayContext 1838
#define sipName_overlayContext &sipStrings_QtOpenGL[1838]
#define sipNameNr_paintOverlayGL 1853
#define sipName_paintOverlayGL &sipStrings_QtOpenGL[1853]
#define sipNameNr_setInitialized 1868
#define sipName_setInitialized &sipStrings_QtOpenGL[1868]
#define sipNameNr_FormatOptions 865
#define sipName_FormatOptions &sipStrings_QtOpenGL[865]
#define sipNameNr_NoAccumBuffer 1883
#define sipName_NoAccumBuffer &sipStrings_QtOpenGL[1883]
#define sipNameNr_NoDepthBuffer 1897
#define sipName_NoDepthBuffer &sipStrings_QtOpenGL[1897]
#define sipNameNr_SampleBuffers 1386
#define sipName_SampleBuffers &sipStrings_QtOpenGL[1386]
#define sipNameNr_StencilBuffer 1435
#define sipName_StencilBuffer &sipStrings_QtOpenGL[1435]
#define sipNameNr_StereoBuffers 1451
#define sipName_StereoBuffers &sipStrings_QtOpenGL[1451]
#define sipNameNr_chooseContext 1911
#define sipName_chooseContext &sipStrings_QtOpenGL[1911]
#define sipNameNr_connectNotify 1301
#define sipName_connectNotify &sipStrings_QtOpenGL[1301]
#define sipNameNr_defaultFormat 1925
#define sipName_defaultFormat &sipStrings_QtOpenGL[1925]
#define sipNameNr_deleteTexture 1939
#define sipName_deleteTexture &sipStrings_QtOpenGL[1939]
#define sipNameNr_dragMoveEvent 1953
#define sipName_dragMoveEvent &sipStrings_QtOpenGL[1953]
#define sipNameNr_focusOutEvent 1967
#define sipName_focusOutEvent &sipStrings_QtOpenGL[1967]
#define sipNameNr_keyPressEvent 1981
#define sipName_keyPressEvent &sipStrings_QtOpenGL[1981]
#define sipNameNr_qglClearColor 1995
#define sipName_qglClearColor &sipStrings_QtOpenGL[1995]
#define sipNameNr_redBufferSize 2009
#define sipName_redBufferSize &sipStrings_QtOpenGL[2009]
#define sipNameNr_sampleBuffers 2023
#define sipName_sampleBuffers &sipStrings_QtOpenGL[2023]
#define sipNameNr_sharedPainter 2037
#define sipName_sharedPainter &sipStrings_QtOpenGL[2037]
#define sipNameNr_textureTarget 2051
#define sipName_textureTarget &sipStrings_QtOpenGL[2051]
#define sipNameNr_windowCreated 2065
#define sipName_windowCreated &sipStrings_QtOpenGL[2065]
#define sipNameNr_AlphaChannel 1675
#define sipName_AlphaChannel &sipStrings_QtOpenGL[1675]
#define sipNameNr_DoubleBuffer 1628
#define sipName_DoubleBuffer &sipStrings_QtOpenGL[1628]
#define sipNameNr_FormatOption 1072
#define sipName_FormatOption &sipStrings_QtOpenGL[1072]
#define sipNameNr_NoBindOption 2079
#define sipName_NoBindOption &sipStrings_QtOpenGL[2079]
#define sipNameNr_SingleBuffer 2092
#define sipName_SingleBuffer &sipStrings_QtOpenGL[2092]
#define sipNameNr_doubleBuffer 2105
#define sipName_doubleBuffer &sipStrings_QtOpenGL[2105]
#define sipNameNr_focusInEvent 2118
#define sipName_focusInEvent &sipStrings_QtOpenGL[2118]
#define sipNameNr_initializeGL 2131
#define sipName_initializeGL &sipStrings_QtOpenGL[2131]
#define sipNameNr_majorVersion 2144
#define sipName_majorVersion &sipStrings_QtOpenGL[2144]
#define sipNameNr_minorVersion 2157
#define sipName_minorVersion &sipStrings_QtOpenGL[2157]
#define sipNameNr_moveToThread 2170
#define sipName_moveToThread &sipStrings_QtOpenGL[2170]
#define sipNameNr_renderPixmap 2183
#define sipName_renderPixmap &sipStrings_QtOpenGL[2183]
#define sipNameNr_shareContext 2196
#define sipName_shareContext &sipStrings_QtOpenGL[2196]
#define sipNameNr_swapInterval 2209
#define sipName_swapInterval &sipStrings_QtOpenGL[2209]
#define sipNameNr_AccumBuffer 1885
#define sipName_AccumBuffer &sipStrings_QtOpenGL[1885]
#define sipNameNr_BindOptions 282
#define sipName_BindOptions &sipStrings_QtOpenGL[282]
#define sipNameNr_CoreProfile 2222
#define sipName_CoreProfile &sipStrings_QtOpenGL[2222]
#define sipNameNr_DepthBuffer 1899
#define sipName_DepthBuffer &sipStrings_QtOpenGL[1899]
#define sipNameNr_actionEvent 2234
#define sipName_actionEvent &sipStrings_QtOpenGL[2234]
#define sipNameNr_bindTexture 2246
#define sipName_bindTexture &sipStrings_QtOpenGL[2246]
#define sipNameNr_changeEvent 2258
#define sipName_changeEvent &sipStrings_QtOpenGL[2258]
#define sipNameNr_customEvent 2270
#define sipName_customEvent &sipStrings_QtOpenGL[2270]
#define sipNameNr_doneCurrent 2282
#define sipName_doneCurrent &sipStrings_QtOpenGL[2282]
#define sipNameNr_drawTexture 2294
#define sipName_drawTexture &sipStrings_QtOpenGL[2294]
#define sipNameNr_eventFilter 2306
#define sipName_eventFilter &sipStrings_QtOpenGL[2306]
#define sipNameNr_initPainter 2318
#define sipName_initPainter &sipStrings_QtOpenGL[2318]
#define sipNameNr_initialized 2330
#define sipName_initialized &sipStrings_QtOpenGL[2330]
#define sipNameNr_makeCurrent 2342
#define sipName_makeCurrent &sipStrings_QtOpenGL[2342]
#define sipNameNr_nativeEvent 2354
#define sipName_nativeEvent &sipStrings_QtOpenGL[2354]
#define sipNameNr_paintEngine 2366
#define sipName_paintEngine &sipStrings_QtOpenGL[2366]
#define sipNameNr_resizeEvent 2378
#define sipName_resizeEvent &sipStrings_QtOpenGL[2378]
#define sipNameNr_shareWidget 2390
#define sipName_shareWidget &sipStrings_QtOpenGL[2390]
#define sipNameNr_swapBuffers 2402
#define sipName_swapBuffers &sipStrings_QtOpenGL[2402]
#define sipNameNr_tabletEvent 2414
#define sipName_tabletEvent &sipStrings_QtOpenGL[2414]
#define sipNameNr_BindOption 204
#define sipName_BindOption &sipStrings_QtOpenGL[204]
#define sipNameNr_ColorIndex 2426
#define sipName_ColorIndex &sipStrings_QtOpenGL[2426]
#define sipNameNr_HasOverlay 2437
#define sipName_HasOverlay &sipStrings_QtOpenGL[2437]
#define sipNameNr_QGLContext 2448
#define sipName_QGLContext &sipStrings_QtOpenGL[2448]
#define sipNameNr___invert__ 2459
#define sipName___invert__ &sipStrings_QtOpenGL[2459]
#define sipNameNr_areSharing 2470
#define sipName_areSharing &sipStrings_QtOpenGL[2470]
#define sipNameNr_childEvent 2481
#define sipName_childEvent &sipStrings_QtOpenGL[2481]
#define sipNameNr_closeEvent 2492
#define sipName_closeEvent &sipStrings_QtOpenGL[2492]
#define sipNameNr_enterEvent 2503
#define sipName_enterEvent &sipStrings_QtOpenGL[2503]
#define sipNameNr_hasOverlay 2514
#define sipName_hasOverlay &sipStrings_QtOpenGL[2514]
#define sipNameNr_leaveEvent 2525
#define sipName_leaveEvent &sipStrings_QtOpenGL[2525]
#define sipNameNr_paintEvent 2536
#define sipName_paintEvent &sipStrings_QtOpenGL[2536]
#define sipNameNr_renderText 2547
#define sipName_renderText &sipStrings_QtOpenGL[2547]
#define sipNameNr_setContext 2558
#define sipName_setContext &sipStrings_QtOpenGL[2558]
#define sipNameNr_setOverlay 2569
#define sipName_setOverlay &sipStrings_QtOpenGL[2569]
#define sipNameNr_setProfile 2580
#define sipName_setProfile &sipStrings_QtOpenGL[2580]
#define sipNameNr_setSamples 2591
#define sipName_setSamples &sipStrings_QtOpenGL[2591]
#define sipNameNr_setStencil 2602
#define sipName_setStencil &sipStrings_QtOpenGL[2602]
#define sipNameNr_setVersion 2613
#define sipName_setVersion &sipStrings_QtOpenGL[2613]
#define sipNameNr_setVisible 2624
#define sipName_setVisible &sipStrings_QtOpenGL[2624]
#define sipNameNr_testOption 2635
#define sipName_testOption &sipStrings_QtOpenGL[2635]
#define sipNameNr_timerEvent 2646
#define sipName_timerEvent &sipStrings_QtOpenGL[2646]
#define sipNameNr_useContext 2657
#define sipName_useContext &sipStrings_QtOpenGL[2657]
#define sipNameNr_wheelEvent 2668
#define sipName_wheelEvent &sipStrings_QtOpenGL[2668]
#define sipNameNr_NoOverlay 2679
#define sipName_NoOverlay &sipStrings_QtOpenGL[2679]
#define sipNameNr_NoProfile 2689
#define sipName_NoProfile &sipStrings_QtOpenGL[2689]
#define sipNameNr_QGLFormat 2699
#define sipName_QGLFormat &sipStrings_QtOpenGL[2699]
#define sipNameNr_QGLWidget 2709
#define sipName_QGLWidget &sipStrings_QtOpenGL[2709]
#define sipNameNr___index__ 2719
#define sipName___index__ &sipStrings_QtOpenGL[2719]
#define sipNameNr_dropEvent 2729
#define sipName_dropEvent &sipStrings_QtOpenGL[2729]
#define sipNameNr_hasOpenGL 2739
#define sipName_hasOpenGL &sipStrings_QtOpenGL[2739]
#define sipNameNr_hideEvent 2749
#define sipName_hideEvent &sipStrings_QtOpenGL[2749]
#define sipNameNr_isSharing 2759
#define sipName_isSharing &sipStrings_QtOpenGL[2759]
#define sipNameNr_moveEvent 2769
#define sipName_moveEvent &sipStrings_QtOpenGL[2769]
#define sipNameNr_setFormat 2779
#define sipName_setFormat &sipStrings_QtOpenGL[2779]
#define sipNameNr_setOption 2789
#define sipName_setOption &sipStrings_QtOpenGL[2789]
#define sipNameNr_setStereo 2799
#define sipName_setStereo &sipStrings_QtOpenGL[2799]
#define sipNameNr_showEvent 2809
#define sipName_showEvent &sipStrings_QtOpenGL[2809]
#define sipNameNr_withAlpha 2819
#define sipName_withAlpha &sipStrings_QtOpenGL[2819]
#define sipNameNr___bool__ 2829
#define sipName___bool__ &sipStrings_QtOpenGL[2829]
#define sipNameNr___hash__ 2838
#define sipName___hash__ &sipStrings_QtOpenGL[2838]
#define sipNameNr___iand__ 2847
#define sipName___iand__ &sipStrings_QtOpenGL[2847]
#define sipNameNr___ixor__ 2856
#define sipName___ixor__ &sipStrings_QtOpenGL[2856]
#define sipNameNr_qglColor 2865
#define sipName_qglColor &sipStrings_QtOpenGL[2865]
#define sipNameNr_resizeGL 2874
#define sipName_resizeGL &sipStrings_QtOpenGL[2874]
#define sipNameNr_setAccum 2883
#define sipName_setAccum &sipStrings_QtOpenGL[2883]
#define sipNameNr_setAlpha 2892
#define sipName_setAlpha &sipStrings_QtOpenGL[2892]
#define sipNameNr_setDepth 2901
#define sipName_setDepth &sipStrings_QtOpenGL[2901]
#define sipNameNr_setPlane 2910
#define sipName_setPlane &sipStrings_QtOpenGL[2910]
#define sipNameNr_sizeHint 2919
#define sipName_sizeHint &sipStrings_QtOpenGL[2919]
#define sipNameNr_updateGL 2928
#define sipName_updateGL &sipStrings_QtOpenGL[2928]
#define sipNameNr___and__ 2937
#define sipName___and__ &sipStrings_QtOpenGL[2937]
#define sipNameNr___int__ 2945
#define sipName___int__ &sipStrings_QtOpenGL[2945]
#define sipNameNr___ior__ 2953
#define sipName___ior__ &sipStrings_QtOpenGL[2953]
#define sipNameNr___xor__ 2961
#define sipName___xor__ &sipStrings_QtOpenGL[2961]
#define sipNameNr_context 2969
#define sipName_context &sipStrings_QtOpenGL[2969]
#define sipNameNr_devType 2977
#define sipName_devType &sipStrings_QtOpenGL[2977]
#define sipNameNr_isValid 2985
#define sipName_isValid &sipStrings_QtOpenGL[2985]
#define sipNameNr_paintGL 2993
#define sipName_paintGL &sipStrings_QtOpenGL[2993]
#define sipNameNr_profile 3001
#define sipName_profile &sipStrings_QtOpenGL[3001]
#define sipNameNr_samples 3009
#define sipName_samples &sipStrings_QtOpenGL[3009]
#define sipNameNr_setRgba 3017
#define sipName_setRgba &sipStrings_QtOpenGL[3017]
#define sipNameNr_stencil 3025
#define sipName_stencil &sipStrings_QtOpenGL[3025]
#define sipNameNr___eq__ 3033
#define sipName___eq__ &sipStrings_QtOpenGL[3033]
#define sipNameNr___ne__ 3040
#define sipName___ne__ &sipStrings_QtOpenGL[3040]
#define sipNameNr___or__ 3047
#define sipName___or__ &sipStrings_QtOpenGL[3047]
#define sipNameNr_create 3054
#define sipName_create &sipStrings_QtOpenGL[3054]
#define sipNameNr_device 3061
#define sipName_device &sipStrings_QtOpenGL[3061]
#define sipNameNr_format 3068
#define sipName_format &sipStrings_QtOpenGL[3068]
#define sipNameNr_glDraw 3075
#define sipName_glDraw &sipStrings_QtOpenGL[3075]
#define sipNameNr_glInit 3082
#define sipName_glInit &sipStrings_QtOpenGL[3082]
#define sipNameNr_height 3089
#define sipName_height &sipStrings_QtOpenGL[3089]
#define sipNameNr_metric 3096
#define sipName_metric &sipStrings_QtOpenGL[3096]
#define sipNameNr_parent 3103
#define sipName_parent &sipStrings_QtOpenGL[3103]
#define sipNameNr_stereo 3110
#define sipName_stereo &sipStrings_QtOpenGL[3110]
#define sipNameNr_target 3117
#define sipName_target &sipStrings_QtOpenGL[3117]
#define sipNameNr_accum 3124
#define sipName_accum &sipStrings_QtOpenGL[3124]
#define sipNameNr_alpha 3130
#define sipName_alpha &sipStrings_QtOpenGL[3130]
#define sipNameNr_depth 3136
#define sipName_depth &sipStrings_QtOpenGL[3136]
#define sipNameNr_event 3142
#define sipName_event &sipStrings_QtOpenGL[3142]
#define sipNameNr_flags 3148
#define sipName_flags &sipStrings_QtOpenGL[3148]
#define sipNameNr_plane 3154
#define sipName_plane &sipStrings_QtOpenGL[3154]
#define sipNameNr_reset 3160
#define sipName_reset &sipStrings_QtOpenGL[3160]
#define sipNameNr_width 3166
#define sipName_width &sipStrings_QtOpenGL[3166]
#define sipNameNr_Rgba 3020
#define sipName_Rgba &sipStrings_QtOpenGL[3020]
#define sipNameNr_font 3172
#define sipName_font &sipStrings_QtOpenGL[3172]
#define sipNameNr_rgba 3177
#define sipName_rgba &sipStrings_QtOpenGL[3177]
#define sipNameNr_QGL 3182
#define sipName_QGL &sipStrings_QtOpenGL[3182]

#define sipMalloc                   sipAPI_QtOpenGL->api_malloc
#define sipFree                     sipAPI_QtOpenGL->api_free
#define sipBuildResult              sipAPI_QtOpenGL->api_build_result
#define sipCallMethod               sipAPI_QtOpenGL->api_call_method
#define sipCallProcedureMethod      sipAPI_QtOpenGL->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtOpenGL->api_call_error_handler
#define sipParseResultEx            sipAPI_QtOpenGL->api_parse_result_ex
#define sipParseResult              sipAPI_QtOpenGL->api_parse_result
#define sipParseArgs                sipAPI_QtOpenGL->api_parse_args
#define sipParseKwdArgs             sipAPI_QtOpenGL->api_parse_kwd_args
#define sipParsePair                sipAPI_QtOpenGL->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtOpenGL->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtOpenGL->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtOpenGL->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtOpenGL->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtOpenGL->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtOpenGL->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtOpenGL->api_add_exception
#define sipNoFunction               sipAPI_QtOpenGL->api_no_function
#define sipNoMethod                 sipAPI_QtOpenGL->api_no_method
#define sipAbstractMethod           sipAPI_QtOpenGL->api_abstract_method
#define sipBadClass                 sipAPI_QtOpenGL->api_bad_class
#define sipBadCatcherResult         sipAPI_QtOpenGL->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtOpenGL->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtOpenGL->api_bad_operator_arg
#define sipTrace                    sipAPI_QtOpenGL->api_trace
#define sipTransferBack             sipAPI_QtOpenGL->api_transfer_back
#define sipTransferTo               sipAPI_QtOpenGL->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtOpenGL->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtOpenGL->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtOpenGL->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtOpenGL->api_voidptr_type
#define sipGetPyObject              sipAPI_QtOpenGL->api_get_pyobject
#define sipGetAddress               sipAPI_QtOpenGL->api_get_address
#define sipGetMixinAddress          sipAPI_QtOpenGL->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtOpenGL->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtOpenGL->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtOpenGL->api_call_hook
#define sipEndThread                sipAPI_QtOpenGL->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtOpenGL->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtOpenGL->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtOpenGL->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtOpenGL->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtOpenGL->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtOpenGL->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtOpenGL->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtOpenGL->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtOpenGL->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtOpenGL->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtOpenGL->api_convert_to_bool
#define sipReleaseType              sipAPI_QtOpenGL->api_release_type
#define sipConvertFromType          sipAPI_QtOpenGL->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtOpenGL->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtOpenGL->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtOpenGL->api_convert_from_enum
#define sipGetState                 sipAPI_QtOpenGL->api_get_state
#define sipExportSymbol             sipAPI_QtOpenGL->api_export_symbol
#define sipImportSymbol             sipAPI_QtOpenGL->api_import_symbol
#define sipFindType                 sipAPI_QtOpenGL->api_find_type
#define sipBytes_AsChar             sipAPI_QtOpenGL->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtOpenGL->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtOpenGL->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtOpenGL->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtOpenGL->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtOpenGL->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtOpenGL->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtOpenGL->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtOpenGL->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtOpenGL->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtOpenGL->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtOpenGL->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtOpenGL->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtOpenGL->api_get_reference
#define sipKeepReference            sipAPI_QtOpenGL->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtOpenGL->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtOpenGL->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtOpenGL->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtOpenGL->api_type_scope
#define sipResolveTypedef           sipAPI_QtOpenGL->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtOpenGL->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtOpenGL->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtOpenGL->api_init_mixin
#define sipExportModule             sipAPI_QtOpenGL->api_export_module
#define sipInitModule               sipAPI_QtOpenGL->api_init_module
#define sipGetInterpreter           sipAPI_QtOpenGL->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtOpenGL->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtOpenGL->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtOpenGL->api_py_type_dict
#define sipPyTypeName               sipAPI_QtOpenGL->api_py_type_name
#define sipGetCFunction             sipAPI_QtOpenGL->api_get_c_function
#define sipGetMethod                sipAPI_QtOpenGL->api_get_method
#define sipFromMethod               sipAPI_QtOpenGL->api_from_method
#define sipGetDate                  sipAPI_QtOpenGL->api_get_date
#define sipFromDate                 sipAPI_QtOpenGL->api_from_date
#define sipGetDateTime              sipAPI_QtOpenGL->api_get_datetime
#define sipFromDateTime             sipAPI_QtOpenGL->api_from_datetime
#define sipGetTime                  sipAPI_QtOpenGL->api_get_time
#define sipFromTime                 sipAPI_QtOpenGL->api_from_time
#define sipIsUserType               sipAPI_QtOpenGL->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtOpenGL->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtOpenGL->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtOpenGL->api_unicode_write
#define sipUnicodeData              sipAPI_QtOpenGL->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtOpenGL->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtOpenGL->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtOpenGL->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtOpenGL->api_is_derived_class
#define sipGetUserObject            sipAPI_QtOpenGL->api_get_user_object
#define sipSetUserObject            sipAPI_QtOpenGL->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtOpenGL->api_register_event_handler
#define sipConvertToArray           sipAPI_QtOpenGL->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtOpenGL->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtOpenGL->api_enable_gc
#define sipPrintObject              sipAPI_QtOpenGL->api_print_object
#define sipLong_AsChar              sipAPI_QtOpenGL->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtOpenGL->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtOpenGL->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtOpenGL->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtOpenGL->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtOpenGL->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtOpenGL->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtOpenGL->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtOpenGL->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtOpenGL->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtOpenGL->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtOpenGL->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtOpenGL->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtOpenGL->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtOpenGL->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtOpenGL->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtOpenGL->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtOpenGL->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtOpenGL->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtOpenGL->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtOpenGL->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtOpenGL->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtOpenGL->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtOpenGL->api_connect_rx
#define sipConvertRx                sipAPI_QtOpenGL->api_convert_rx
#define sipDisconnectRx             sipAPI_QtOpenGL->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtOpenGL->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtOpenGL->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtOpenGL->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtOpenGL->api_same_slot
#define sipSaveSlot                 sipAPI_QtOpenGL->api_save_slot
#define sipVisitSlot                sipAPI_QtOpenGL->api_visit_slot
#define sipIsPyMethod               sipAPI_QtOpenGL->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtOpenGL[];

#define sipType_QGL sipExportedTypes_QtOpenGL[0]

#define sipType_QGL_FormatOption sipExportedTypes_QtOpenGL[1]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QGL;

#define sipType_QGL_FormatOptions sipExportedTypes_QtOpenGL[2]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QGL_FormatOptions;

#define sipType_QGLFormat sipExportedTypes_QtOpenGL[6]

#define sipType_QGLFormat_OpenGLContextProfile sipExportedTypes_QtOpenGL[7]

#define sipType_QGLFormat_OpenGLVersionFlag sipExportedTypes_QtOpenGL[8]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QGLFormat;

#define sipType_QGLFormat_OpenGLVersionFlags sipExportedTypes_QtOpenGL[9]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QGLFormat_OpenGLVersionFlags;

#define sipType_QGLContext sipExportedTypes_QtOpenGL[3]

#define sipType_QGLContext_BindOption sipExportedTypes_QtOpenGL[4]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QGLContext;

#define sipType_QGLContext_BindOptions sipExportedTypes_QtOpenGL[5]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QGLContext_BindOptions;

#define sipType_QGLWidget sipExportedTypes_QtOpenGL[10]

extern sipClassTypeDef sipTypeDef_QtOpenGL_QGLWidget;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtOpenGL;
extern sipExportedModuleDef sipModuleAPI_QtOpenGL;
extern sipTypeDef *sipExportedTypes_QtOpenGL[];

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtOpenGL_QtCore[12].it_td

#define sipType_Qt_WindowFlags sipImportedTypes_QtOpenGL_QtCore[13].it_td

#define sipType_QObject sipImportedTypes_QtOpenGL_QtCore[4].it_td

#define sipType_QByteArray sipImportedTypes_QtOpenGL_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtOpenGL_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtOpenGL_QtCore[10].it_td

#define sipType_QChildEvent sipImportedTypes_QtOpenGL_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtOpenGL_QtCore[3].it_td

#define sipType_QPointF sipImportedTypes_QtOpenGL_QtCore[5].it_td

#define sipType_QRectF sipImportedTypes_QtOpenGL_QtCore[6].it_td

#define sipType_QSize sipImportedTypes_QtOpenGL_QtCore[7].it_td

#define sipType_QThread sipImportedTypes_QtOpenGL_QtCore[9].it_td

#define sipType_QVariant sipImportedTypes_QtOpenGL_QtCore[11].it_td

#define sipType_QString sipImportedTypes_QtOpenGL_QtCore[8].it_td
extern sipImportedTypeDef sipImportedTypes_QtOpenGL_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtOpenGL_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtOpenGL_QtGui[16].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtOpenGL_QtGui[17].it_td

#define sipType_QPixmap sipImportedTypes_QtOpenGL_QtGui[21].it_td

#define sipType_QColor sipImportedTypes_QtOpenGL_QtGui[2].it_td

#define sipType_QMouseEvent sipImportedTypes_QtOpenGL_QtGui[14].it_td

#define sipType_QWheelEvent sipImportedTypes_QtOpenGL_QtGui[25].it_td

#define sipType_QTabletEvent sipImportedTypes_QtOpenGL_QtGui[24].it_td

#define sipType_QKeyEvent sipImportedTypes_QtOpenGL_QtGui[13].it_td

#define sipType_QFocusEvent sipImportedTypes_QtOpenGL_QtGui[8].it_td

#define sipType_QPaintEvent sipImportedTypes_QtOpenGL_QtGui[19].it_td

#define sipType_QMoveEvent sipImportedTypes_QtOpenGL_QtGui[15].it_td

#define sipType_QResizeEvent sipImportedTypes_QtOpenGL_QtGui[22].it_td

#define sipType_QCloseEvent sipImportedTypes_QtOpenGL_QtGui[1].it_td

#define sipType_QShowEvent sipImportedTypes_QtOpenGL_QtGui[23].it_td

#define sipType_QHideEvent sipImportedTypes_QtOpenGL_QtGui[10].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtOpenGL_QtGui[3].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtOpenGL_QtGui[12].it_td

#define sipType_QDropEvent sipImportedTypes_QtOpenGL_QtGui[7].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtOpenGL_QtGui[6].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtOpenGL_QtGui[4].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtOpenGL_QtGui[5].it_td

#define sipType_QActionEvent sipImportedTypes_QtOpenGL_QtGui[0].it_td

#define sipType_QFont sipImportedTypes_QtOpenGL_QtGui[9].it_td

#define sipType_QImage sipImportedTypes_QtOpenGL_QtGui[11].it_td

#define sipType_QPainter sipImportedTypes_QtOpenGL_QtGui[20].it_td

#define sipType_QPaintEngine sipImportedTypes_QtOpenGL_QtGui[18].it_td
extern sipImportedTypeDef sipImportedTypes_QtOpenGL_QtGui[];

#define sipType_QWidget sipImportedTypes_QtOpenGL_QtWidgets[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtOpenGL_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtOpenGL_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtOpenGL_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtOpenGL_qt_metacast;

#endif
