/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceimage.sip"
#include <qplaceimage.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceImage.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecontent.sip"
#include <qplacecontent.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceImage.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceImage.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceImage.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceuser.sip"
#include <qplaceuser.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceImage.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesupplier.sip"
#include <qplacesupplier.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceImage.cpp"


class sipQPlaceImage : public ::QPlaceImage
{
public:
    sipQPlaceImage();
    sipQPlaceImage(const ::QPlaceContent&);
    sipQPlaceImage(const ::QPlaceImage&);
    ~sipQPlaceImage();

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPlaceImage(const sipQPlaceImage &);
    sipQPlaceImage &operator = (const sipQPlaceImage &);
};

sipQPlaceImage::sipQPlaceImage(): ::QPlaceImage(), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceImage::sipQPlaceImage(const ::QPlaceContent& a0): ::QPlaceImage(a0), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceImage::sipQPlaceImage(const ::QPlaceImage& a0): ::QPlaceImage(a0), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceImage::~sipQPlaceImage()
{
    sipInstanceDestroyedEx(&sipPySelf);
}


PyDoc_STRVAR(doc_QPlaceImage_url, "url(self) -> QUrl");

extern "C" {static PyObject *meth_QPlaceImage_url(PyObject *, PyObject *);}
static PyObject *meth_QPlaceImage_url(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceImage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceImage, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->url());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceImage, sipName_url, doc_QPlaceImage_url);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceImage_setUrl, "setUrl(self, url: QUrl)");

extern "C" {static PyObject *meth_QPlaceImage_setUrl(PyObject *, PyObject *);}
static PyObject *meth_QPlaceImage_setUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QPlaceImage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceImage, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setUrl(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceImage, sipName_setUrl, doc_QPlaceImage_setUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceImage_imageId, "imageId(self) -> str");

extern "C" {static PyObject *meth_QPlaceImage_imageId(PyObject *, PyObject *);}
static PyObject *meth_QPlaceImage_imageId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceImage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceImage, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->imageId());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceImage, sipName_imageId, doc_QPlaceImage_imageId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceImage_setImageId, "setImageId(self, identifier: Optional[str])");

extern "C" {static PyObject *meth_QPlaceImage_setImageId(PyObject *, PyObject *);}
static PyObject *meth_QPlaceImage_setImageId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceImage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceImage, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setImageId(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceImage, sipName_setImageId, doc_QPlaceImage_setImageId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceImage_mimeType, "mimeType(self) -> str");

extern "C" {static PyObject *meth_QPlaceImage_mimeType(PyObject *, PyObject *);}
static PyObject *meth_QPlaceImage_mimeType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceImage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceImage, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->mimeType());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceImage, sipName_mimeType, doc_QPlaceImage_mimeType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceImage_setMimeType, "setMimeType(self, data: Optional[str])");

extern "C" {static PyObject *meth_QPlaceImage_setMimeType(PyObject *, PyObject *);}
static PyObject *meth_QPlaceImage_setMimeType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceImage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceImage, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setMimeType(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceImage, sipName_setMimeType, doc_QPlaceImage_setMimeType);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPlaceImage(void *, const sipTypeDef *);}
static void *cast_QPlaceImage(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPlaceImage *sipCpp = reinterpret_cast< ::QPlaceImage *>(sipCppV);

    if (targetType == sipType_QPlaceImage)
        return sipCppV;

    if (targetType == sipType_QPlaceContent)
        return static_cast< ::QPlaceContent *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPlaceImage(void *, int);}
static void release_QPlaceImage(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQPlaceImage *>(sipCppV);
    else
        delete reinterpret_cast< ::QPlaceImage *>(sipCppV);
}


extern "C" {static void *array_QPlaceImage(Py_ssize_t);}
static void *array_QPlaceImage(Py_ssize_t sipNrElem)
{
    return new ::QPlaceImage[sipNrElem];
}


extern "C" {static void array_delete_QPlaceImage(void *);}
static void array_delete_QPlaceImage(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPlaceImage *>(sipCpp);
}


extern "C" {static void assign_QPlaceImage(void *, Py_ssize_t, void *);}
static void assign_QPlaceImage(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPlaceImage *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPlaceImage *>(sipSrc);
}


extern "C" {static void *copy_QPlaceImage(const void *, Py_ssize_t);}
static void *copy_QPlaceImage(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPlaceImage(reinterpret_cast<const ::QPlaceImage *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPlaceImage(sipSimpleWrapper *);}
static void dealloc_QPlaceImage(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPlaceImage *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPlaceImage(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPlaceImage(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPlaceImage(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQPlaceImage *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQPlaceImage();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QPlaceContent* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPlaceContent, &a0))
        {
            sipCpp = new sipQPlaceImage(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QPlaceImage* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPlaceImage, &a0))
        {
            sipCpp = new sipQPlaceImage(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPlaceImage[] = {{57, 255, 1}};


static PyMethodDef methods_QPlaceImage[] = {
    {sipName_imageId, meth_QPlaceImage_imageId, METH_VARARGS, doc_QPlaceImage_imageId},
    {sipName_mimeType, meth_QPlaceImage_mimeType, METH_VARARGS, doc_QPlaceImage_mimeType},
    {sipName_setImageId, meth_QPlaceImage_setImageId, METH_VARARGS, doc_QPlaceImage_setImageId},
    {sipName_setMimeType, meth_QPlaceImage_setMimeType, METH_VARARGS, doc_QPlaceImage_setMimeType},
    {sipName_setUrl, meth_QPlaceImage_setUrl, METH_VARARGS, doc_QPlaceImage_setUrl},
    {sipName_url, meth_QPlaceImage_url, METH_VARARGS, doc_QPlaceImage_url}
};

PyDoc_STRVAR(doc_QPlaceImage, "\1QPlaceImage()\n"
"QPlaceImage(other: QPlaceContent)\n"
"QPlaceImage(a0: QPlaceImage)");


static pyqt5ClassPluginDef plugin_QPlaceImage = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QPlaceImage = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPlaceImage,
        SIP_NULLPTR,
        &plugin_QPlaceImage,
    },
    {
        sipNameNr_QPlaceImage,
        {0, 0, 1},
        6, methods_QPlaceImage,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPlaceImage,
    -1,
    -1,
    supers_QPlaceImage,
    SIP_NULLPTR,
    init_type_QPlaceImage,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPlaceImage,
    assign_QPlaceImage,
    array_QPlaceImage,
    copy_QPlaceImage,
    release_QPlaceImage,
    cast_QPlaceImage,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPlaceImage,
    sizeof (::QPlaceImage),
};
