/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimediaWidgets.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimediaWidgets/qgraphicsvideoitem.sip"
#include <qgraphicsvideoitem.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qabstractvideosurface.sip"
#include <qabstractvideosurface.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaobject.sip"
#include <qmediaobject.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 103 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 1031 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicstransform.sip"
#include <qgraphicstransform.h>
#line 122 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 125 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 607 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 128 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 131 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qtransform.sip"
#include <qtransform.h>
#line 134 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 137 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 140 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 143 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicswidget.sip"
#include <qgraphicswidget.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 88 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 152 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 363 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 155 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 509 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 158 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 161 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 384 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 199 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 167 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 139 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 170 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 329 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpolygon.sip"
#include <qpolygon.h>
#line 173 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 176 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 179 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 182 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 578 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 185 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsscene.sip"
#include <qgraphicsscene.h>
#line 188 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimediaWidgets/sipQtMultimediaWidgetsQGraphicsVideoItem.cpp"


class sipQGraphicsVideoItem : public ::QGraphicsVideoItem
{
public:
    sipQGraphicsVideoItem(::QGraphicsItem*);
    virtual ~sipQGraphicsVideoItem();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QMediaObject* mediaObject() const SIP_OVERRIDE;
    bool setMediaObject(::QMediaObject*) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void wheelEvent(::QGraphicsSceneWheelEvent*) SIP_OVERRIDE;
    bool sceneEventFilter(::QGraphicsItem*, ::QEvent*) SIP_OVERRIDE;
    bool sceneEvent(::QEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QGraphicsSceneMouseEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    ::QVariant itemChange(::QGraphicsItem::GraphicsItemChange, const ::QVariant&) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    void hoverMoveEvent(::QGraphicsSceneHoverEvent*) SIP_OVERRIDE;
    void hoverLeaveEvent(::QGraphicsSceneHoverEvent*) SIP_OVERRIDE;
    void hoverEnterEvent(::QGraphicsSceneHoverEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void dropEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QGraphicsSceneDragDropEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QGraphicsSceneContextMenuEvent*) SIP_OVERRIDE;
    int type() const SIP_OVERRIDE;
    void paint(::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*) SIP_OVERRIDE;
    ::QPainterPath opaqueArea() const SIP_OVERRIDE;
    bool isObscuredBy(const ::QGraphicsItem*) const SIP_OVERRIDE;
    bool collidesWithPath(const ::QPainterPath&, ::Qt::ItemSelectionMode) const SIP_OVERRIDE;
    bool collidesWithItem(const ::QGraphicsItem*, ::Qt::ItemSelectionMode) const SIP_OVERRIDE;
    bool contains(const ::QPointF&) const SIP_OVERRIDE;
    ::QPainterPath shape() const SIP_OVERRIDE;
    ::QRectF boundingRect() const SIP_OVERRIDE;
    void advance(int) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQGraphicsVideoItem(const sipQGraphicsVideoItem &);
    sipQGraphicsVideoItem &operator = (const sipQGraphicsVideoItem &);

    char sipPyMethods[41];
};

sipQGraphicsVideoItem::sipQGraphicsVideoItem(::QGraphicsItem*a0): ::QGraphicsVideoItem(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGraphicsVideoItem::~sipQGraphicsVideoItem()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQGraphicsVideoItem::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimediaWidgets_qt_metaobject(sipPySelf, sipType_QGraphicsVideoItem);

    return ::QGraphicsVideoItem::metaObject();
}

int sipQGraphicsVideoItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QGraphicsVideoItem::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimediaWidgets_qt_metacall(sipPySelf, sipType_QGraphicsVideoItem, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQGraphicsVideoItem::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimediaWidgets_qt_metacast(sipPySelf, sipType_QGraphicsVideoItem, _clname, &sipCpp) ? sipCpp : ::QGraphicsVideoItem::qt_metacast(_clname));
}

::QMediaObject* sipQGraphicsVideoItem::mediaObject() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_mediaObject);

    if (!sipMeth)
        return ::QGraphicsVideoItem::mediaObject();

    extern ::QMediaObject* sipVH_QtMultimediaWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimediaWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQGraphicsVideoItem::setMediaObject(::QMediaObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_setMediaObject);

    if (!sipMeth)
        return ::QGraphicsVideoItem::setMediaObject(a0);

    extern bool sipVH_QtMultimediaWidgets_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMediaObject*);

    return sipVH_QtMultimediaWidgets_36(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimediaWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimediaWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimediaWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimediaWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimediaWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsVideoItem::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QGraphicsVideoItem::eventFilter(a0, a1);

    extern bool sipVH_QtMultimediaWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimediaWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGraphicsVideoItem::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QGraphicsVideoItem::event(a0);

    extern bool sipVH_QtMultimediaWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimediaWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::wheelEvent(::QGraphicsSceneWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_52(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneWheelEvent*);

    sipVH_QtMultimediaWidgets_52(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsVideoItem::sceneEventFilter(::QGraphicsItem*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_sceneEventFilter);

    if (!sipMeth)
        return ::QGraphicsVideoItem::sceneEventFilter(a0, a1);

    extern bool sipVH_QtMultimediaWidgets_51(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsItem*, ::QEvent*);

    return sipVH_QtMultimediaWidgets_51(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGraphicsVideoItem::sceneEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_sceneEvent);

    if (!sipMeth)
        return ::QGraphicsVideoItem::sceneEvent(a0);

    extern bool sipVH_QtMultimediaWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimediaWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::mouseReleaseEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_50(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtMultimediaWidgets_50(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::mousePressEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_50(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtMultimediaWidgets_50(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::mouseMoveEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_50(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtMultimediaWidgets_50(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::mouseDoubleClickEvent(::QGraphicsSceneMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_50(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneMouseEvent*);

    sipVH_QtMultimediaWidgets_50(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtMultimediaWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtMultimediaWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQGraphicsVideoItem::itemChange(::QGraphicsItem::GraphicsItemChange a0, const ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_itemChange);

    if (!sipMeth)
        return ::QGraphicsVideoItem::itemChange(a0, a1);

    extern ::QVariant sipVH_QtMultimediaWidgets_49(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsItem::GraphicsItemChange, const ::QVariant&);

    return sipVH_QtMultimediaWidgets_49(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QVariant sipQGraphicsVideoItem::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[19]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QGraphicsVideoItem::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtMultimediaWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtMultimediaWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtMultimediaWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::hoverMoveEvent(::QGraphicsSceneHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_hoverMoveEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::hoverMoveEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneHoverEvent*);

    sipVH_QtMultimediaWidgets_48(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::hoverLeaveEvent(::QGraphicsSceneHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_hoverLeaveEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::hoverLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneHoverEvent*);

    sipVH_QtMultimediaWidgets_48(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::hoverEnterEvent(::QGraphicsSceneHoverEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_hoverEnterEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::hoverEnterEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneHoverEvent*);

    sipVH_QtMultimediaWidgets_48(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtMultimediaWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtMultimediaWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::dropEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::dropEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtMultimediaWidgets_47(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::dragMoveEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtMultimediaWidgets_47(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::dragLeaveEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtMultimediaWidgets_47(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::dragEnterEvent(::QGraphicsSceneDragDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneDragDropEvent*);

    sipVH_QtMultimediaWidgets_47(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsVideoItem::contextMenuEvent(::QGraphicsSceneContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_46(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsSceneContextMenuEvent*);

    sipVH_QtMultimediaWidgets_46(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQGraphicsVideoItem::type() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[31]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_type);

    if (!sipMeth)
        return ::QGraphicsVideoItem::type();

    extern int sipVH_QtMultimediaWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimediaWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQGraphicsVideoItem::paint(::QPainter*a0, const ::QStyleOptionGraphicsItem*a1, ::QWidget*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_paint);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::paint(a0, a1, a2);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_45(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QStyleOptionGraphicsItem*, ::QWidget*);

    sipVH_QtMultimediaWidgets_45(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPainterPath sipQGraphicsVideoItem::opaqueArea() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[33]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_opaqueArea);

    if (!sipMeth)
        return ::QGraphicsVideoItem::opaqueArea();

    extern ::QPainterPath sipVH_QtMultimediaWidgets_40(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimediaWidgets_40(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQGraphicsVideoItem::isObscuredBy(const ::QGraphicsItem*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[34]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isObscuredBy);

    if (!sipMeth)
        return ::QGraphicsVideoItem::isObscuredBy(a0);

    extern bool sipVH_QtMultimediaWidgets_44(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGraphicsItem*);

    return sipVH_QtMultimediaWidgets_44(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsVideoItem::collidesWithPath(const ::QPainterPath& a0, ::Qt::ItemSelectionMode a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[35]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_collidesWithPath);

    if (!sipMeth)
        return ::QGraphicsVideoItem::collidesWithPath(a0, a1);

    extern bool sipVH_QtMultimediaWidgets_43(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPainterPath&, ::Qt::ItemSelectionMode);

    return sipVH_QtMultimediaWidgets_43(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGraphicsVideoItem::collidesWithItem(const ::QGraphicsItem*a0, ::Qt::ItemSelectionMode a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[36]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_collidesWithItem);

    if (!sipMeth)
        return ::QGraphicsVideoItem::collidesWithItem(a0, a1);

    extern bool sipVH_QtMultimediaWidgets_42(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGraphicsItem*, ::Qt::ItemSelectionMode);

    return sipVH_QtMultimediaWidgets_42(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGraphicsVideoItem::contains(const ::QPointF& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[37]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_contains);

    if (!sipMeth)
        return ::QGraphicsVideoItem::contains(a0);

    extern bool sipVH_QtMultimediaWidgets_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPointF&);

    return sipVH_QtMultimediaWidgets_41(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPainterPath sipQGraphicsVideoItem::shape() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[38]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_shape);

    if (!sipMeth)
        return ::QGraphicsVideoItem::shape();

    extern ::QPainterPath sipVH_QtMultimediaWidgets_40(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimediaWidgets_40(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QRectF sipQGraphicsVideoItem::boundingRect() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[39]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_boundingRect);

    if (!sipMeth)
        return ::QGraphicsVideoItem::boundingRect();

    extern ::QRectF sipVH_QtMultimediaWidgets_39(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimediaWidgets_39(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQGraphicsVideoItem::advance(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_advance);

    if (!sipMeth)
    {
        ::QGraphicsVideoItem::advance(a0);
        return;
    }

    extern void sipVH_QtMultimediaWidgets_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtMultimediaWidgets_38(sipGILState, sipImportedVirtErrorHandlers_QtMultimediaWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QGraphicsVideoItem_mediaObject, "mediaObject(self) -> Optional[QMediaObject]");

extern "C" {static PyObject *meth_QGraphicsVideoItem_mediaObject(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsVideoItem_mediaObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QGraphicsVideoItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsVideoItem, &sipCpp))
        {
            ::QMediaObject*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGraphicsVideoItem::mediaObject() : sipCpp->mediaObject());

            return sipConvertFromType(sipRes, sipType_QMediaObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsVideoItem, sipName_mediaObject, doc_QGraphicsVideoItem_mediaObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsVideoItem_aspectRatioMode, "aspectRatioMode(self) -> Qt.AspectRatioMode");

extern "C" {static PyObject *meth_QGraphicsVideoItem_aspectRatioMode(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsVideoItem_aspectRatioMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsVideoItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsVideoItem, &sipCpp))
        {
            ::Qt::AspectRatioMode sipRes;

            sipRes = sipCpp->aspectRatioMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_AspectRatioMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsVideoItem, sipName_aspectRatioMode, doc_QGraphicsVideoItem_aspectRatioMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsVideoItem_setAspectRatioMode, "setAspectRatioMode(self, mode: Qt.AspectRatioMode)");

extern "C" {static PyObject *meth_QGraphicsVideoItem_setAspectRatioMode(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsVideoItem_setAspectRatioMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::AspectRatioMode a0;
        ::QGraphicsVideoItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGraphicsVideoItem, &sipCpp, sipType_Qt_AspectRatioMode, &a0))
        {
            sipCpp->setAspectRatioMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsVideoItem, sipName_setAspectRatioMode, doc_QGraphicsVideoItem_setAspectRatioMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsVideoItem_offset, "offset(self) -> QPointF");

extern "C" {static PyObject *meth_QGraphicsVideoItem_offset(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsVideoItem_offset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsVideoItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsVideoItem, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->offset());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsVideoItem, sipName_offset, doc_QGraphicsVideoItem_offset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsVideoItem_setOffset, "setOffset(self, offset: Union[QPointF, QPoint])");

extern "C" {static PyObject *meth_QGraphicsVideoItem_setOffset(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsVideoItem_setOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        int a0State = 0;
        ::QGraphicsVideoItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGraphicsVideoItem, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
            sipCpp->setOffset(*a0);
            sipReleaseType(const_cast< ::QPointF *>(a0), sipType_QPointF, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsVideoItem, sipName_setOffset, doc_QGraphicsVideoItem_setOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsVideoItem_size, "size(self) -> QSizeF");

extern "C" {static PyObject *meth_QGraphicsVideoItem_size(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsVideoItem_size(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsVideoItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsVideoItem, &sipCpp))
        {
            ::QSizeF*sipRes;

            sipRes = new ::QSizeF(sipCpp->size());

            return sipConvertFromNewType(sipRes, sipType_QSizeF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsVideoItem, sipName_size, doc_QGraphicsVideoItem_size);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsVideoItem_setSize, "setSize(self, size: QSizeF)");

extern "C" {static PyObject *meth_QGraphicsVideoItem_setSize(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsVideoItem_setSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSizeF* a0;
        ::QGraphicsVideoItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGraphicsVideoItem, &sipCpp, sipType_QSizeF, &a0))
        {
            sipCpp->setSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsVideoItem, sipName_setSize, doc_QGraphicsVideoItem_setSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsVideoItem_nativeSize, "nativeSize(self) -> QSizeF");

extern "C" {static PyObject *meth_QGraphicsVideoItem_nativeSize(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsVideoItem_nativeSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsVideoItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsVideoItem, &sipCpp))
        {
            ::QSizeF*sipRes;

            sipRes = new ::QSizeF(sipCpp->nativeSize());

            return sipConvertFromNewType(sipRes, sipType_QSizeF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsVideoItem, sipName_nativeSize, doc_QGraphicsVideoItem_nativeSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsVideoItem_boundingRect, "boundingRect(self) -> QRectF");

extern "C" {static PyObject *meth_QGraphicsVideoItem_boundingRect(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsVideoItem_boundingRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QGraphicsVideoItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsVideoItem, &sipCpp))
        {
            ::QRectF*sipRes;

            sipRes = new ::QRectF((sipSelfWasArg ? sipCpp->::QGraphicsVideoItem::boundingRect() : sipCpp->boundingRect()));

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsVideoItem, sipName_boundingRect, doc_QGraphicsVideoItem_boundingRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsVideoItem_paint, "paint(self, painter: Optional[QPainter], option: Optional[QStyleOptionGraphicsItem], widget: Optional[QWidget] = None)");

extern "C" {static PyObject *meth_QGraphicsVideoItem_paint(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QGraphicsVideoItem_paint(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPainter* a0;
        const ::QStyleOptionGraphicsItem* a1;
        ::QWidget* a2 = 0;
        ::QGraphicsVideoItem *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8J8|J8", &sipSelf, sipType_QGraphicsVideoItem, &sipCpp, sipType_QPainter, &a0, sipType_QStyleOptionGraphicsItem, &a1, sipType_QWidget, &a2))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsVideoItem::paint(a0, a1, a2) : sipCpp->paint(a0, a1, a2));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsVideoItem, sipName_paint, doc_QGraphicsVideoItem_paint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsVideoItem_timerEvent, "timerEvent(self, event: Optional[QTimerEvent])");

extern "C" {static PyObject *meth_QGraphicsVideoItem_timerEvent(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsVideoItem_timerEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QTimerEvent* a0;
        ::QGraphicsVideoItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsVideoItem, &sipCpp, sipType_QTimerEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsVideoItem::timerEvent(a0) : sipCpp->timerEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsVideoItem, sipName_timerEvent, doc_QGraphicsVideoItem_timerEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsVideoItem_itemChange, "itemChange(self, change: QGraphicsItem.GraphicsItemChange, value: Any) -> Any");

extern "C" {static PyObject *meth_QGraphicsVideoItem_itemChange(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsVideoItem_itemChange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGraphicsItem::GraphicsItemChange a0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QGraphicsVideoItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pEJ1", &sipSelf, sipType_QGraphicsVideoItem, &sipCpp, sipType_QGraphicsItem_GraphicsItemChange, &a0, sipType_QVariant, &a1, &a1State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QGraphicsVideoItem::itemChange(a0, *a1) : sipCpp->itemChange(a0, *a1)));
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsVideoItem, sipName_itemChange, doc_QGraphicsVideoItem_itemChange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsVideoItem_setMediaObject, "setMediaObject(self, object: Optional[QMediaObject]) -> bool");

extern "C" {static PyObject *meth_QGraphicsVideoItem_setMediaObject(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsVideoItem_setMediaObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMediaObject* a0;
        ::QGraphicsVideoItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsVideoItem, &sipCpp, sipType_QMediaObject, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGraphicsVideoItem::setMediaObject(a0) : sipCpp->setMediaObject(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsVideoItem, sipName_setMediaObject, doc_QGraphicsVideoItem_setMediaObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsVideoItem_videoSurface, "videoSurface(self) -> Optional[QAbstractVideoSurface]");

extern "C" {static PyObject *meth_QGraphicsVideoItem_videoSurface(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsVideoItem_videoSurface(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsVideoItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsVideoItem, &sipCpp))
        {
            ::QAbstractVideoSurface*sipRes;

            sipRes = sipCpp->videoSurface();

            return sipConvertFromType(sipRes, sipType_QAbstractVideoSurface, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsVideoItem, sipName_videoSurface, doc_QGraphicsVideoItem_videoSurface);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGraphicsVideoItem(void *, const sipTypeDef *);}
static void *cast_QGraphicsVideoItem(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGraphicsVideoItem *sipCpp = reinterpret_cast< ::QGraphicsVideoItem *>(sipCppV);

    if (targetType == sipType_QGraphicsVideoItem)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QGraphicsObject)->ctd_cast(static_cast< ::QGraphicsObject *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    if (targetType == sipType_QMediaBindableInterface)
        return static_cast< ::QMediaBindableInterface *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGraphicsVideoItem(void *, int);}
static void release_QGraphicsVideoItem(void *sipCppV, int)
{
    ::QGraphicsVideoItem *sipCpp = reinterpret_cast< ::QGraphicsVideoItem *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QGraphicsVideoItem(Py_ssize_t);}
static void *array_QGraphicsVideoItem(Py_ssize_t sipNrElem)
{
    return new ::QGraphicsVideoItem[sipNrElem];
}


extern "C" {static void array_delete_QGraphicsVideoItem(void *);}
static void array_delete_QGraphicsVideoItem(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGraphicsVideoItem *>(sipCpp);
}


extern "C" {static void dealloc_QGraphicsVideoItem(sipSimpleWrapper *);}
static void dealloc_QGraphicsVideoItem(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQGraphicsVideoItem *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGraphicsVideoItem(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QGraphicsVideoItem(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGraphicsVideoItem(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQGraphicsVideoItem *sipCpp = SIP_NULLPTR;

    {
        ::QGraphicsItem* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QGraphicsItem, &a0, sipOwner))
        {
            sipCpp = new sipQGraphicsVideoItem(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGraphicsVideoItem[] = {{2, 4, 0}, {1, 3, 1}};


static PyMethodDef methods_QGraphicsVideoItem[] = {
    {sipName_aspectRatioMode, meth_QGraphicsVideoItem_aspectRatioMode, METH_VARARGS, doc_QGraphicsVideoItem_aspectRatioMode},
    {sipName_boundingRect, meth_QGraphicsVideoItem_boundingRect, METH_VARARGS, doc_QGraphicsVideoItem_boundingRect},
    {sipName_itemChange, meth_QGraphicsVideoItem_itemChange, METH_VARARGS, doc_QGraphicsVideoItem_itemChange},
    {sipName_mediaObject, meth_QGraphicsVideoItem_mediaObject, METH_VARARGS, doc_QGraphicsVideoItem_mediaObject},
    {sipName_nativeSize, meth_QGraphicsVideoItem_nativeSize, METH_VARARGS, doc_QGraphicsVideoItem_nativeSize},
    {sipName_offset, meth_QGraphicsVideoItem_offset, METH_VARARGS, doc_QGraphicsVideoItem_offset},
    {sipName_paint, SIP_MLMETH_CAST(meth_QGraphicsVideoItem_paint), METH_VARARGS|METH_KEYWORDS, doc_QGraphicsVideoItem_paint},
    {sipName_setAspectRatioMode, meth_QGraphicsVideoItem_setAspectRatioMode, METH_VARARGS, doc_QGraphicsVideoItem_setAspectRatioMode},
    {sipName_setMediaObject, meth_QGraphicsVideoItem_setMediaObject, METH_VARARGS, doc_QGraphicsVideoItem_setMediaObject},
    {sipName_setOffset, meth_QGraphicsVideoItem_setOffset, METH_VARARGS, doc_QGraphicsVideoItem_setOffset},
    {sipName_setSize, meth_QGraphicsVideoItem_setSize, METH_VARARGS, doc_QGraphicsVideoItem_setSize},
    {sipName_size, meth_QGraphicsVideoItem_size, METH_VARARGS, doc_QGraphicsVideoItem_size},
    {sipName_timerEvent, meth_QGraphicsVideoItem_timerEvent, METH_VARARGS, doc_QGraphicsVideoItem_timerEvent},
    {sipName_videoSurface, meth_QGraphicsVideoItem_videoSurface, METH_VARARGS, doc_QGraphicsVideoItem_videoSurface}
};

PyDoc_STRVAR(doc_QGraphicsVideoItem, "\1QGraphicsVideoItem(parent: Optional[QGraphicsItem] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QGraphicsVideoItem[] = {
    {"nativeSizeChanged(QSizeF)", "\1nativeSizeChanged(self, size: QSizeF)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QGraphicsVideoItem = {
    &::QGraphicsVideoItem::staticMetaObject,
    0,
    signals_QGraphicsVideoItem,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimediaWidgets_QGraphicsVideoItem = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGraphicsVideoItem,
        SIP_NULLPTR,
        &plugin_QGraphicsVideoItem,
    },
    {
        sipNameNr_QGraphicsVideoItem,
        {0, 0, 1},
        14, methods_QGraphicsVideoItem,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGraphicsVideoItem,
    -1,
    -1,
    supers_QGraphicsVideoItem,
    SIP_NULLPTR,
    init_type_QGraphicsVideoItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGraphicsVideoItem,
    SIP_NULLPTR,
    array_QGraphicsVideoItem,
    SIP_NULLPTR,
    release_QGraphicsVideoItem,
    cast_QGraphicsVideoItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGraphicsVideoItem,
    sizeof (::QGraphicsVideoItem),
};
