/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtSvg.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSvg/qsvggenerator.sip"
#include <qsvggenerator.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSvg/sipQtSvgQSvgGenerator.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSvg/sipQtSvgQSvgGenerator.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSvg/sipQtSvgQSvgGenerator.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSvg/sipQtSvgQSvgGenerator.cpp"
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSvg/sipQtSvgQSvgGenerator.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSvg/sipQtSvgQSvgGenerator.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSvg/sipQtSvgQSvgGenerator.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSvg/sipQtSvgQSvgGenerator.cpp"


class sipQSvgGenerator : public ::QSvgGenerator
{
public:
    sipQSvgGenerator();
    virtual ~sipQSvgGenerator();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSvgGenerator(const sipQSvgGenerator &);
    sipQSvgGenerator &operator = (const sipQSvgGenerator &);

    char sipPyMethods[2];
};

sipQSvgGenerator::sipQSvgGenerator(): ::QSvgGenerator(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSvgGenerator::~sipQSvgGenerator()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

::QPaintEngine* sipQSvgGenerator::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QSvgGenerator::paintEngine();

    extern ::QPaintEngine* sipVH_QtSvg_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSvg_27(sipGILState, sipImportedVirtErrorHandlers_QtSvg_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQSvgGenerator::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QSvgGenerator::metric(a0);

    extern int sipVH_QtSvg_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtSvg_26(sipGILState, sipImportedVirtErrorHandlers_QtSvg_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QSvgGenerator_size, "size(self) -> QSize");

extern "C" {static PyObject *meth_QSvgGenerator_size(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_size(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgGenerator, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->size());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_size, doc_QSvgGenerator_size);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_setSize, "setSize(self, size: QSize)");

extern "C" {static PyObject *meth_QSvgGenerator_setSize(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_setSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSvgGenerator, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_setSize, doc_QSvgGenerator_setSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_fileName, "fileName(self) -> str");

extern "C" {static PyObject *meth_QSvgGenerator_fileName(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_fileName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgGenerator, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->fileName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_fileName, doc_QSvgGenerator_fileName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_setFileName, "setFileName(self, fileName: Optional[str])");

extern "C" {static PyObject *meth_QSvgGenerator_setFileName(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_setFileName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSvgGenerator, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setFileName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_setFileName, doc_QSvgGenerator_setFileName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_outputDevice, "outputDevice(self) -> Optional[QIODevice]");

extern "C" {static PyObject *meth_QSvgGenerator_outputDevice(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_outputDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgGenerator, &sipCpp))
        {
            ::QIODevice*sipRes;

            sipRes = sipCpp->outputDevice();

            return sipConvertFromType(sipRes, sipType_QIODevice, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_outputDevice, doc_QSvgGenerator_outputDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_setOutputDevice, "setOutputDevice(self, outputDevice: Optional[QIODevice])");

extern "C" {static PyObject *meth_QSvgGenerator_setOutputDevice(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_setOutputDevice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QIODevice* a0;
        ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QSvgGenerator, &sipCpp, sipType_QIODevice, &a0))
        {
            sipCpp->setOutputDevice(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_setOutputDevice, doc_QSvgGenerator_setOutputDevice);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_resolution, "resolution(self) -> int");

extern "C" {static PyObject *meth_QSvgGenerator_resolution(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_resolution(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgGenerator, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->resolution();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_resolution, doc_QSvgGenerator_resolution);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_setResolution, "setResolution(self, resolution: int)");

extern "C" {static PyObject *meth_QSvgGenerator_setResolution(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_setResolution(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSvgGenerator, &sipCpp, &a0))
        {
            sipCpp->setResolution(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_setResolution, doc_QSvgGenerator_setResolution);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_title, "title(self) -> str");

extern "C" {static PyObject *meth_QSvgGenerator_title(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_title(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgGenerator, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->title());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_title, doc_QSvgGenerator_title);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_setTitle, "setTitle(self, title: Optional[str])");

extern "C" {static PyObject *meth_QSvgGenerator_setTitle(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_setTitle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSvgGenerator, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTitle(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_setTitle, doc_QSvgGenerator_setTitle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_description, "description(self) -> str");

extern "C" {static PyObject *meth_QSvgGenerator_description(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_description(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgGenerator, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->description());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_description, doc_QSvgGenerator_description);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_setDescription, "setDescription(self, description: Optional[str])");

extern "C" {static PyObject *meth_QSvgGenerator_setDescription(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_setDescription(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSvgGenerator, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setDescription(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_setDescription, doc_QSvgGenerator_setDescription);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_viewBox, "viewBox(self) -> QRect");

extern "C" {static PyObject *meth_QSvgGenerator_viewBox(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_viewBox(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgGenerator, &sipCpp))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect(sipCpp->viewBox());

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_viewBox, doc_QSvgGenerator_viewBox);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_viewBoxF, "viewBoxF(self) -> QRectF");

extern "C" {static PyObject *meth_QSvgGenerator_viewBoxF(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_viewBoxF(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSvgGenerator, &sipCpp))
        {
            ::QRectF*sipRes;

            sipRes = new ::QRectF(sipCpp->viewBoxF());

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_viewBoxF, doc_QSvgGenerator_viewBoxF);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_setViewBox, "setViewBox(self, viewBox: QRect)\n"
"setViewBox(self, viewBox: QRectF)");

extern "C" {static PyObject *meth_QSvgGenerator_setViewBox(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_setViewBox(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRect* a0;
        ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSvgGenerator, &sipCpp, sipType_QRect, &a0))
        {
            sipCpp->setViewBox(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QRectF* a0;
        ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSvgGenerator, &sipCpp, sipType_QRectF, &a0))
        {
            sipCpp->setViewBox(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_setViewBox, doc_QSvgGenerator_setViewBox);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_paintEngine, "paintEngine(self) -> Optional[QPaintEngine]");

extern "C" {static PyObject *meth_QSvgGenerator_paintEngine(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_paintEngine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QSvgGenerator, &sipCpp))
        {
            ::QPaintEngine*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSvgGenerator::paintEngine() : sipCpp->paintEngine());

            return sipConvertFromType(sipRes, sipType_QPaintEngine, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_paintEngine, doc_QSvgGenerator_paintEngine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSvgGenerator_metric, "metric(self, metric: QPaintDevice.PaintDeviceMetric) -> int");

extern "C" {static PyObject *meth_QSvgGenerator_metric(PyObject *, PyObject *);}
static PyObject *meth_QSvgGenerator_metric(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintDevice::PaintDeviceMetric a0;
        const ::QSvgGenerator *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QSvgGenerator, &sipCpp, sipType_QPaintDevice_PaintDeviceMetric, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSvgGenerator::metric(a0) : sipCpp->metric(a0));

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSvgGenerator, sipName_metric, doc_QSvgGenerator_metric);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSvgGenerator(void *, const sipTypeDef *);}
static void *cast_QSvgGenerator(void *sipCppV, const sipTypeDef *targetType)
{
    ::QSvgGenerator *sipCpp = reinterpret_cast< ::QSvgGenerator *>(sipCppV);

    if (targetType == sipType_QSvgGenerator)
        return sipCppV;

    if (targetType == sipType_QPaintDevice)
        return static_cast< ::QPaintDevice *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSvgGenerator(void *, int);}
static void release_QSvgGenerator(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQSvgGenerator *>(sipCppV);
    else
        delete reinterpret_cast< ::QSvgGenerator *>(sipCppV);
}


extern "C" {static void *array_QSvgGenerator(Py_ssize_t);}
static void *array_QSvgGenerator(Py_ssize_t sipNrElem)
{
    return new ::QSvgGenerator[sipNrElem];
}


extern "C" {static void array_delete_QSvgGenerator(void *);}
static void array_delete_QSvgGenerator(void *sipCpp)
{
    delete[] reinterpret_cast< ::QSvgGenerator *>(sipCpp);
}


extern "C" {static void dealloc_QSvgGenerator(sipSimpleWrapper *);}
static void dealloc_QSvgGenerator(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSvgGenerator *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSvgGenerator(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSvgGenerator(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSvgGenerator(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQSvgGenerator *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQSvgGenerator();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSvgGenerator[] = {{13, 1, 1}};


static PyMethodDef methods_QSvgGenerator[] = {
    {sipName_description, meth_QSvgGenerator_description, METH_VARARGS, doc_QSvgGenerator_description},
    {sipName_fileName, meth_QSvgGenerator_fileName, METH_VARARGS, doc_QSvgGenerator_fileName},
    {sipName_metric, meth_QSvgGenerator_metric, METH_VARARGS, doc_QSvgGenerator_metric},
    {sipName_outputDevice, meth_QSvgGenerator_outputDevice, METH_VARARGS, doc_QSvgGenerator_outputDevice},
    {sipName_paintEngine, meth_QSvgGenerator_paintEngine, METH_VARARGS, doc_QSvgGenerator_paintEngine},
    {sipName_resolution, meth_QSvgGenerator_resolution, METH_VARARGS, doc_QSvgGenerator_resolution},
    {sipName_setDescription, meth_QSvgGenerator_setDescription, METH_VARARGS, doc_QSvgGenerator_setDescription},
    {sipName_setFileName, meth_QSvgGenerator_setFileName, METH_VARARGS, doc_QSvgGenerator_setFileName},
    {sipName_setOutputDevice, meth_QSvgGenerator_setOutputDevice, METH_VARARGS, doc_QSvgGenerator_setOutputDevice},
    {sipName_setResolution, meth_QSvgGenerator_setResolution, METH_VARARGS, doc_QSvgGenerator_setResolution},
    {sipName_setSize, meth_QSvgGenerator_setSize, METH_VARARGS, doc_QSvgGenerator_setSize},
    {sipName_setTitle, meth_QSvgGenerator_setTitle, METH_VARARGS, doc_QSvgGenerator_setTitle},
    {sipName_setViewBox, meth_QSvgGenerator_setViewBox, METH_VARARGS, doc_QSvgGenerator_setViewBox},
    {sipName_size, meth_QSvgGenerator_size, METH_VARARGS, doc_QSvgGenerator_size},
    {sipName_title, meth_QSvgGenerator_title, METH_VARARGS, doc_QSvgGenerator_title},
    {sipName_viewBox, meth_QSvgGenerator_viewBox, METH_VARARGS, doc_QSvgGenerator_viewBox},
    {sipName_viewBoxF, meth_QSvgGenerator_viewBoxF, METH_VARARGS, doc_QSvgGenerator_viewBoxF}
};

PyDoc_STRVAR(doc_QSvgGenerator, "\1QSvgGenerator()");


static pyqt5ClassPluginDef plugin_QSvgGenerator = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtSvg_QSvgGenerator = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSvgGenerator,
        SIP_NULLPTR,
        &plugin_QSvgGenerator,
    },
    {
        sipNameNr_QSvgGenerator,
        {0, 0, 1},
        17, methods_QSvgGenerator,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSvgGenerator,
    -1,
    -1,
    supers_QSvgGenerator,
    SIP_NULLPTR,
    init_type_QSvgGenerator,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSvgGenerator,
    SIP_NULLPTR,
    array_QSvgGenerator,
    SIP_NULLPTR,
    release_QSvgGenerator,
    cast_QSvgGenerator,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QSvgGenerator,
    sizeof (::QSvgGenerator),
};
