/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpropertyanimation.sip"
#include <qpropertyanimation.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qeasingcurve.sip"
#include <qeasingcurve.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 253 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#include <qpair.h>
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qanimationgroup.sip"
#include <qanimationgroup.h>
#line 55 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQPropertyAnimation.cpp"


class sipQPropertyAnimation : public ::QPropertyAnimation
{
public:
    sipQPropertyAnimation(::QObject*);
    sipQPropertyAnimation(::QObject*, const ::QByteArray&, ::QObject*);
    virtual ~sipQPropertyAnimation();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void updateDirection(::QAbstractAnimation::Direction) SIP_OVERRIDE;
    void updateState(::QAbstractAnimation::State, ::QAbstractAnimation::State) SIP_OVERRIDE;
    void updateCurrentTime(int) SIP_OVERRIDE;
    int duration() const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void updateCurrentValue(const ::QVariant&) SIP_OVERRIDE;
    ::QVariant interpolated(const ::QVariant&, const ::QVariant&, ::qreal) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPropertyAnimation(const sipQPropertyAnimation &);
    sipQPropertyAnimation &operator = (const sipQPropertyAnimation &);

    char sipPyMethods[13];
};

sipQPropertyAnimation::sipQPropertyAnimation(::QObject*a0): ::QPropertyAnimation(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQPropertyAnimation::sipQPropertyAnimation(::QObject*a0, const ::QByteArray& a1, ::QObject*a2): ::QPropertyAnimation(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQPropertyAnimation::~sipQPropertyAnimation()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQPropertyAnimation::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtCore_qt_metaobject(sipPySelf, sipType_QPropertyAnimation);

    return ::QPropertyAnimation::metaObject();
}

int sipQPropertyAnimation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QPropertyAnimation::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtCore_qt_metacall(sipPySelf, sipType_QPropertyAnimation, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQPropertyAnimation::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtCore_qt_metacast(sipPySelf, sipType_QPropertyAnimation, _clname, &sipCpp) ? sipCpp : ::QPropertyAnimation::qt_metacast(_clname));
}

void sipQPropertyAnimation::updateDirection(::QAbstractAnimation::Direction a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_updateDirection);

    if (!sipMeth)
    {
        ::QPropertyAnimation::updateDirection(a0);
        return;
    }

    extern void sipVH_QtCore_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QAbstractAnimation::Direction);

    sipVH_QtCore_9(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQPropertyAnimation::updateState(::QAbstractAnimation::State a0, ::QAbstractAnimation::State a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_updateState);

    if (!sipMeth)
    {
        ::QPropertyAnimation::updateState(a0, a1);
        return;
    }

    extern void sipVH_QtCore_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QAbstractAnimation::State, ::QAbstractAnimation::State);

    sipVH_QtCore_8(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1);
}

void sipQPropertyAnimation::updateCurrentTime(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_updateCurrentTime);

    if (!sipMeth)
    {
        ::QPropertyAnimation::updateCurrentTime(a0);
        return;
    }

    extern void sipVH_QtCore_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtCore_7(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

int sipQPropertyAnimation::duration() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_duration);

    if (!sipMeth)
        return ::QPropertyAnimation::duration();

    extern int sipVH_QtCore_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_6(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth);
}

bool sipQPropertyAnimation::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QPropertyAnimation::event(a0);

    extern bool sipVH_QtCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtCore_0(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQPropertyAnimation::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QPropertyAnimation::eventFilter(a0, a1);

    extern bool sipVH_QtCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtCore_1(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1);
}

void sipQPropertyAnimation::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QPropertyAnimation::timerEvent(a0);
        return;
    }

    extern void sipVH_QtCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtCore_2(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQPropertyAnimation::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QPropertyAnimation::childEvent(a0);
        return;
    }

    extern void sipVH_QtCore_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtCore_3(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQPropertyAnimation::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QPropertyAnimation::customEvent(a0);
        return;
    }

    extern void sipVH_QtCore_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtCore_4(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQPropertyAnimation::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QPropertyAnimation::connectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQPropertyAnimation::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QPropertyAnimation::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQPropertyAnimation::updateCurrentValue(const ::QVariant& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_updateCurrentValue);

    if (!sipMeth)
    {
        ::QPropertyAnimation::updateCurrentValue(a0);
        return;
    }

    extern void sipVH_QtCore_57(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QVariant&);

    sipVH_QtCore_57(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

::QVariant sipQPropertyAnimation::interpolated(const ::QVariant& a0, const ::QVariant& a1, ::qreal a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_interpolated);

    if (!sipMeth)
        return ::QPropertyAnimation::interpolated(a0, a1, a2);

    extern ::QVariant sipVH_QtCore_58(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QVariant&, const ::QVariant&, ::qreal);

    return sipVH_QtCore_58(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}


PyDoc_STRVAR(doc_QPropertyAnimation_targetObject, "targetObject(self) -> Optional[QObject]");

extern "C" {static PyObject *meth_QPropertyAnimation_targetObject(PyObject *, PyObject *);}
static PyObject *meth_QPropertyAnimation_targetObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPropertyAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPropertyAnimation, &sipCpp))
        {
            ::QObject*sipRes;

            sipRes = sipCpp->targetObject();

            return sipConvertFromType(sipRes, sipType_QObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPropertyAnimation, sipName_targetObject, doc_QPropertyAnimation_targetObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPropertyAnimation_setTargetObject, "setTargetObject(self, target: Optional[QObject])");

extern "C" {static PyObject *meth_QPropertyAnimation_setTargetObject(PyObject *, PyObject *);}
static PyObject *meth_QPropertyAnimation_setTargetObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QObject* a0;
        PyObject *a0Keep;
        ::QPropertyAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QPropertyAnimation, &sipCpp, &a0Keep, sipType_QObject, &a0))
        {
            sipCpp->setTargetObject(a0);

            sipKeepReference(sipSelf, 0, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPropertyAnimation, sipName_setTargetObject, doc_QPropertyAnimation_setTargetObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPropertyAnimation_propertyName, "propertyName(self) -> QByteArray");

extern "C" {static PyObject *meth_QPropertyAnimation_propertyName(PyObject *, PyObject *);}
static PyObject *meth_QPropertyAnimation_propertyName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPropertyAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPropertyAnimation, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->propertyName());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPropertyAnimation, sipName_propertyName, doc_QPropertyAnimation_propertyName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPropertyAnimation_setPropertyName, "setPropertyName(self, propertyName: Union[QByteArray, bytes, bytearray])");

extern "C" {static PyObject *meth_QPropertyAnimation_setPropertyName(PyObject *, PyObject *);}
static PyObject *meth_QPropertyAnimation_setPropertyName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QPropertyAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPropertyAnimation, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            sipCpp->setPropertyName(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPropertyAnimation, sipName_setPropertyName, doc_QPropertyAnimation_setPropertyName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPropertyAnimation_event, "event(self, event: Optional[QEvent]) -> bool");

extern "C" {static PyObject *meth_QPropertyAnimation_event(PyObject *, PyObject *);}
static PyObject *meth_QPropertyAnimation_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QPropertyAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QPropertyAnimation, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPropertyAnimation::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPropertyAnimation, sipName_event, doc_QPropertyAnimation_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPropertyAnimation_updateCurrentValue, "updateCurrentValue(self, value: Any)");

extern "C" {static PyObject *meth_QPropertyAnimation_updateCurrentValue(PyObject *, PyObject *);}
static PyObject *meth_QPropertyAnimation_updateCurrentValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QVariant* a0;
        int a0State = 0;
        ::QPropertyAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QPropertyAnimation, &sipCpp, sipType_QVariant, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QPropertyAnimation::updateCurrentValue(*a0) : sipCpp->updateCurrentValue(*a0));
            sipReleaseType(const_cast< ::QVariant *>(a0), sipType_QVariant, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPropertyAnimation, sipName_updateCurrentValue, doc_QPropertyAnimation_updateCurrentValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPropertyAnimation_updateState, "updateState(self, newState: QAbstractAnimation.State, oldState: QAbstractAnimation.State)");

extern "C" {static PyObject *meth_QPropertyAnimation_updateState(PyObject *, PyObject *);}
static PyObject *meth_QPropertyAnimation_updateState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QAbstractAnimation::State a0;
        ::QAbstractAnimation::State a1;
        ::QPropertyAnimation *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pEE", &sipSelf, sipType_QPropertyAnimation, &sipCpp, sipType_QAbstractAnimation_State, &a0, sipType_QAbstractAnimation_State, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QPropertyAnimation::updateState(a0, a1) : sipCpp->updateState(a0, a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPropertyAnimation, sipName_updateState, doc_QPropertyAnimation_updateState);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPropertyAnimation(void *, const sipTypeDef *);}
static void *cast_QPropertyAnimation(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPropertyAnimation *sipCpp = reinterpret_cast< ::QPropertyAnimation *>(sipCppV);

    if (targetType == sipType_QPropertyAnimation)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QVariantAnimation)->ctd_cast(static_cast< ::QVariantAnimation *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPropertyAnimation(void *, int);}
static void release_QPropertyAnimation(void *sipCppV, int)
{
    ::QPropertyAnimation *sipCpp = reinterpret_cast< ::QPropertyAnimation *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QPropertyAnimation(Py_ssize_t);}
static void *array_QPropertyAnimation(Py_ssize_t sipNrElem)
{
    return new ::QPropertyAnimation[sipNrElem];
}


extern "C" {static void array_delete_QPropertyAnimation(void *);}
static void array_delete_QPropertyAnimation(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPropertyAnimation *>(sipCpp);
}


extern "C" {static void dealloc_QPropertyAnimation(sipSimpleWrapper *);}
static void dealloc_QPropertyAnimation(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPropertyAnimation *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPropertyAnimation(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPropertyAnimation(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPropertyAnimation(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQPropertyAnimation *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQPropertyAnimation(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QObject* a0;
        PyObject *a0Keep;
        const ::QByteArray* a1;
        int a1State = 0;
        ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8J1|JH", &a0Keep, sipType_QObject, &a0, sipType_QByteArray, &a1, &a1State, sipType_QObject, &a2, sipOwner))
        {
            sipCpp = new sipQPropertyAnimation(a0, *a1, a2);

            sipKeepReference((PyObject *)sipSelf, 0, a0Keep);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPropertyAnimation[] = {{325, 255, 1}};


static PyMethodDef methods_QPropertyAnimation[] = {
    {sipName_event, meth_QPropertyAnimation_event, METH_VARARGS, doc_QPropertyAnimation_event},
    {sipName_propertyName, meth_QPropertyAnimation_propertyName, METH_VARARGS, doc_QPropertyAnimation_propertyName},
    {sipName_setPropertyName, meth_QPropertyAnimation_setPropertyName, METH_VARARGS, doc_QPropertyAnimation_setPropertyName},
    {sipName_setTargetObject, meth_QPropertyAnimation_setTargetObject, METH_VARARGS, doc_QPropertyAnimation_setTargetObject},
    {sipName_targetObject, meth_QPropertyAnimation_targetObject, METH_VARARGS, doc_QPropertyAnimation_targetObject},
    {sipName_updateCurrentValue, meth_QPropertyAnimation_updateCurrentValue, METH_VARARGS, doc_QPropertyAnimation_updateCurrentValue},
    {sipName_updateState, meth_QPropertyAnimation_updateState, METH_VARARGS, doc_QPropertyAnimation_updateState}
};

PyDoc_STRVAR(doc_QPropertyAnimation, "\1QPropertyAnimation(parent: Optional[QObject] = None)\n"
"QPropertyAnimation(target: Optional[QObject], propertyName: Union[QByteArray, bytes, bytearray], parent: Optional[QObject] = None)");


static pyqt5ClassPluginDef plugin_QPropertyAnimation = {
    &::QPropertyAnimation::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QPropertyAnimation = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPropertyAnimation,
        SIP_NULLPTR,
        &plugin_QPropertyAnimation,
    },
    {
        sipNameNr_QPropertyAnimation,
        {0, 0, 1},
        7, methods_QPropertyAnimation,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPropertyAnimation,
    -1,
    -1,
    supers_QPropertyAnimation,
    SIP_NULLPTR,
    init_type_QPropertyAnimation,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPropertyAnimation,
    SIP_NULLPTR,
    array_QPropertyAnimation,
    SIP_NULLPTR,
    release_QPropertyAnimation,
    cast_QPropertyAnimation,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPropertyAnimation,
    sizeof (::QPropertyAnimation),
};
