/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtWebKitAPI_H
#define _QtWebKitAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QWebSecurityOrigin__SubdomainSetting 0
#define sipName_QWebSecurityOrigin__SubdomainSetting &sipStrings_QtWebKit[0]
#define sipNameNr_QWebSettings__ThirdPartyCookiePolicy 37
#define sipName_QWebSettings__ThirdPartyCookiePolicy &sipStrings_QtWebKit[37]
#define sipNameNr_AllowThirdPartyWithExistingCookies 74
#define sipName_AllowThirdPartyWithExistingCookies &sipStrings_QtWebKit[74]
#define sipNameNr_109 109
#define sipName_109 &sipStrings_QtWebKit[109]
#define sipNameNr_QWebPluginFactory__ExtensionOption 144
#define sipName_QWebPluginFactory__ExtensionOption &sipStrings_QtWebKit[144]
#define sipNameNr_QWebPluginFactory__ExtensionReturn 179
#define sipName_QWebPluginFactory__ExtensionReturn &sipStrings_QtWebKit[179]
#define sipNameNr_setOfflineWebApplicationCacheQuota 214
#define sipName_setOfflineWebApplicationCacheQuota &sipStrings_QtWebKit[214]
#define sipNameNr_OfflineWebApplicationCacheEnabled 249
#define sipName_OfflineWebApplicationCacheEnabled &sipStrings_QtWebKit[249]
#define sipNameNr_QWebElement__StyleResolveStrategy 283
#define sipName_QWebElement__StyleResolveStrategy &sipStrings_QtWebKit[283]
#define sipNameNr_setOfflineWebApplicationCachePath 317
#define sipName_setOfflineWebApplicationCachePath &sipStrings_QtWebKit[317]
#define sipNameNr_351 351
#define sipName_351 &sipStrings_QtWebKit[351]
#define sipNameNr_SearchCancelButtonPressedGraphic 384
#define sipName_SearchCancelButtonPressedGraphic &sipStrings_QtWebKit[384]
#define sipNameNr_LocalContentCanAccessRemoteUrls 417
#define sipName_LocalContentCanAccessRemoteUrls &sipStrings_QtWebKit[417]
#define sipNameNr_offlineWebApplicationCacheQuota 449
#define sipName_offlineWebApplicationCacheQuota &sipStrings_QtWebKit[449]
#define sipNameNr_offlineWebApplicationCachePath 481
#define sipName_offlineWebApplicationCachePath &sipStrings_QtWebKit[481]
#define sipNameNr_AcceleratedCompositingEnabled 512
#define sipName_AcceleratedCompositingEnabled &sipStrings_QtWebKit[512]
#define sipNameNr_LocalContentCanAccessFileUrls 542
#define sipName_LocalContentCanAccessFileUrls &sipStrings_QtWebKit[542]
#define sipNameNr_OfflineStorageDatabaseEnabled 572
#define sipName_OfflineStorageDatabaseEnabled &sipStrings_QtWebKit[572]
#define sipNameNr_TextAreaSizeGripCornerGraphic 602
#define sipName_TextAreaSizeGripCornerGraphic &sipStrings_QtWebKit[602]
#define sipNameNr_setOfflineStorageDefaultQuota 632
#define sipName_setOfflineStorageDefaultQuota &sipStrings_QtWebKit[632]
#define sipNameNr_AlwaysAllowThirdPartyCookies 662
#define sipName_AlwaysAllowThirdPartyCookies &sipStrings_QtWebKit[662]
#define sipNameNr_AlwaysBlockThirdPartyCookies 691
#define sipName_AlwaysBlockThirdPartyCookies &sipStrings_QtWebKit[691]
#define sipNameNr_JavascriptCanAccessClipboard 720
#define sipName_JavascriptCanAccessClipboard &sipStrings_QtWebKit[720]
#define sipNameNr_QWebPluginFactory__Extension 749
#define sipName_QWebPluginFactory__Extension &sipStrings_QtWebKit[749]
#define sipNameNr_LocalStorageDatabaseEnabled 778
#define sipName_LocalStorageDatabaseEnabled &sipStrings_QtWebKit[778]
#define sipNameNr_QWebPluginFactory__MimeType 806
#define sipName_QWebPluginFactory__MimeType &sipStrings_QtWebKit[806]
#define sipNameNr_Accelerated2dCanvasEnabled 834
#define sipName_Accelerated2dCanvasEnabled &sipStrings_QtWebKit[834]
#define sipNameNr_QWebSettings__WebAttribute 861
#define sipName_QWebSettings__WebAttribute &sipStrings_QtWebKit[861]
#define sipNameNr_offlineStorageDefaultQuota 888
#define sipName_offlineStorageDefaultQuota &sipStrings_QtWebKit[888]
#define sipNameNr_removeAccessWhitelistEntry 915
#define sipName_removeAccessWhitelistEntry &sipStrings_QtWebKit[915]
#define sipNameNr_JavascriptCanCloseWindows 942
#define sipName_JavascriptCanCloseWindows &sipStrings_QtWebKit[942]
#define sipNameNr_LinksIncludedInFocusChain 968
#define sipName_LinksIncludedInFocusChain &sipStrings_QtWebKit[968]
#define sipNameNr_994 994
#define sipName_994 &sipStrings_QtWebKit[994]
#define sipNameNr_QWebPluginFactory__Plugin 1020
#define sipName_QWebPluginFactory__Plugin &sipStrings_QtWebKit[1020]
#define sipNameNr_SearchCancelButtonGraphic 1046
#define sipName_SearchCancelButtonGraphic &sipStrings_QtWebKit[1046]
#define sipNameNr_SiteSpecificQuirksEnabled 1072
#define sipName_SiteSpecificQuirksEnabled &sipStrings_QtWebKit[1072]
#define sipNameNr_setThirdPartyCookiePolicy 1098
#define sipName_setThirdPartyCookiePolicy &sipStrings_QtWebKit[1098]
#define sipNameNr_HyperlinkAuditingEnabled 1124
#define sipName_HyperlinkAuditingEnabled &sipStrings_QtWebKit[1124]
#define sipNameNr_InputSpeechButtonGraphic 1149
#define sipName_InputSpeechButtonGraphic &sipStrings_QtWebKit[1149]
#define sipNameNr_JavascriptCanOpenWindows 1174
#define sipName_JavascriptCanOpenWindows &sipStrings_QtWebKit[1174]
#define sipNameNr_QWebSettings__FontFamily 1199
#define sipName_QWebSettings__FontFamily &sipStrings_QtWebKit[1199]
#define sipNameNr_QWebSettings__WebGraphic 1224
#define sipName_QWebSettings__WebGraphic &sipStrings_QtWebKit[1224]
#define sipNameNr_SpatialNavigationEnabled 1249
#define sipName_SpatialNavigationEnabled &sipStrings_QtWebKit[1249]
#define sipNameNr_TiledBackingStoreEnabled 1274
#define sipName_TiledBackingStoreEnabled &sipStrings_QtWebKit[1274]
#define sipNameNr_setApplicationCacheQuota 1299
#define sipName_setApplicationCacheQuota &sipStrings_QtWebKit[1299]
#define sipNameNr_setObjectCacheCapacities 1324
#define sipName_setObjectCacheCapacities &sipStrings_QtWebKit[1324]
#define sipNameNr_DefaultFrameIconGraphic 1349
#define sipName_DefaultFrameIconGraphic &sipStrings_QtWebKit[1349]
#define sipNameNr_PrintElementBackgrounds 1373
#define sipName_PrintElementBackgrounds &sipStrings_QtWebKit[1373]
#define sipNameNr_addAccessWhitelistEntry 1397
#define sipName_addAccessWhitelistEntry &sipStrings_QtWebKit[1397]
#define sipNameNr_enablePersistentStorage 1421
#define sipName_enablePersistentStorage &sipStrings_QtWebKit[1421]
#define sipNameNr_DeveloperExtrasEnabled 1445
#define sipName_DeveloperExtrasEnabled &sipStrings_QtWebKit[1445]
#define sipNameNr_FrameFlatteningEnabled 1468
#define sipName_FrameFlatteningEnabled &sipStrings_QtWebKit[1468]
#define sipNameNr_MinimumLogicalFontSize 1491
#define sipName_MinimumLogicalFontSize &sipStrings_QtWebKit[1491]
#define sipNameNr_PrivateBrowsingEnabled 1514
#define sipName_PrivateBrowsingEnabled &sipStrings_QtWebKit[1514]
#define sipNameNr_1537 1537
#define sipName_1537 &sipStrings_QtWebKit[1537]
#define sipNameNr_QWebSettings__FontSize 1560
#define sipName_QWebSettings__FontSize &sipStrings_QtWebKit[1560]
#define sipNameNr_ThirdPartyCookiePolicy 51
#define sipName_ThirdPartyCookiePolicy &sipStrings_QtWebKit[51]
#define sipNameNr_setDefaultTextEncoding 1583
#define sipName_setDefaultTextEncoding &sipStrings_QtWebKit[1583]
#define sipNameNr_setMaximumPagesInCache 1606
#define sipName_setMaximumPagesInCache &sipStrings_QtWebKit[1606]
#define sipNameNr_thirdPartyCookiePolicy 1629
#define sipName_thirdPartyCookiePolicy &sipStrings_QtWebKit[1629]
#define sipNameNr_QWebElementCollection 1652
#define sipName_QWebElementCollection &sipStrings_QtWebKit[1652]
#define sipNameNr_ScrollAnimatorEnabled 1674
#define sipName_ScrollAnimatorEnabled &sipStrings_QtWebKit[1674]
#define sipNameNr_setOfflineStoragePath 1696
#define sipName_setOfflineStoragePath &sipStrings_QtWebKit[1696]
#define sipNameNr_CSSGridLayoutEnabled 1718
#define sipName_CSSGridLayoutEnabled &sipStrings_QtWebKit[1718]
#define sipNameNr_CaretBrowsingEnabled 1739
#define sipName_CaretBrowsingEnabled &sipStrings_QtWebKit[1739]
#define sipNameNr_DefaultFixedFontSize 1760
#define sipName_DefaultFixedFontSize &sipStrings_QtWebKit[1760]
#define sipNameNr_MissingPluginGraphic 1781
#define sipName_MissingPluginGraphic &sipStrings_QtWebKit[1781]
#define sipNameNr_NotificationsEnabled 1802
#define sipName_NotificationsEnabled &sipStrings_QtWebKit[1802]
#define sipNameNr_QWebHistoryInterface 1823
#define sipName_QWebHistoryInterface &sipStrings_QtWebKit[1823]
#define sipNameNr_StyleResolveStrategy 296
#define sipName_StyleResolveStrategy &sipStrings_QtWebKit[296]
#define sipNameNr_setUserStyleSheetUrl 1844
#define sipName_setUserStyleSheetUrl &sipStrings_QtWebKit[1844]
#define sipNameNr_LocalStorageEnabled 1865
#define sipName_LocalStorageEnabled &sipStrings_QtWebKit[1865]
#define sipNameNr_MissingImageGraphic 1885
#define sipName_MissingImageGraphic &sipStrings_QtWebKit[1885]
#define sipNameNr_1905 1905
#define sipName_1905 &sipStrings_QtWebKit[1905]
#define sipNameNr_defaultTextEncoding 1925
#define sipName_defaultTextEncoding &sipStrings_QtWebKit[1925]
#define sipNameNr_encloseContentsWith 1945
#define sipName_encloseContentsWith &sipStrings_QtWebKit[1945]
#define sipNameNr_maximumPagesInCache 1965
#define sipName_maximumPagesInCache &sipStrings_QtWebKit[1965]
#define sipNameNr_qWebKitMajorVersion 1985
#define sipName_qWebKitMajorVersion &sipStrings_QtWebKit[1985]
#define sipNameNr_qWebKitMinorVersion 2005
#define sipName_qWebKitMinorVersion &sipStrings_QtWebKit[2005]
#define sipNameNr_setDefaultInterface 2025
#define sipName_setDefaultInterface &sipStrings_QtWebKit[2025]
#define sipNameNr_setIconDatabasePath 2045
#define sipName_setIconDatabasePath &sipStrings_QtWebKit[2045]
#define sipNameNr_setLocalStoragePath 2065
#define sipName_setLocalStoragePath &sipStrings_QtWebKit[2065]
#define sipNameNr_setMaximumItemCount 2085
#define sipName_setMaximumItemCount &sipStrings_QtWebKit[2085]
#define sipNameNr_DisallowSubdomains 2105
#define sipName_DisallowSubdomains &sipStrings_QtWebKit[2105]
#define sipNameNr_DnsPrefetchEnabled 2124
#define sipName_DnsPrefetchEnabled &sipStrings_QtWebKit[2124]
#define sipNameNr_2143 2143
#define sipName_2143 &sipStrings_QtWebKit[2143]
#define sipNameNr_QWebSecurityOrigin 2162
#define sipName_QWebSecurityOrigin &sipStrings_QtWebKit[2162]
#define sipNameNr_XSSAuditingEnabled 2181
#define sipName_XSSAuditingEnabled &sipStrings_QtWebKit[2181]
#define sipNameNr_evaluateJavaScript 2200
#define sipName_evaluateJavaScript &sipStrings_QtWebKit[2200]
#define sipNameNr_offlineStoragePath 2219
#define sipName_offlineStoragePath &sipStrings_QtWebKit[2219]
#define sipNameNr_removeAllDatabases 2238
#define sipName_removeAllDatabases &sipStrings_QtWebKit[2238]
#define sipNameNr_removeFromDocument 2257
#define sipName_removeFromDocument &sipStrings_QtWebKit[2257]
#define sipNameNr_CSSRegionsEnabled 2276
#define sipName_CSSRegionsEnabled &sipStrings_QtWebKit[2276]
#define sipNameNr_JavascriptEnabled 2294
#define sipName_JavascriptEnabled &sipStrings_QtWebKit[2294]
#define sipNameNr_QWebPluginFactory 2312
#define sipName_QWebPluginFactory &sipStrings_QtWebKit[2312]
#define sipNameNr_clearIconDatabase 2330
#define sipName_clearIconDatabase &sipStrings_QtWebKit[2330]
#define sipNameNr_clearMemoryCaches 2348
#define sipName_clearMemoryCaches &sipStrings_QtWebKit[2348]
#define sipNameNr_removeAllChildren 2366
#define sipName_removeAllChildren &sipStrings_QtWebKit[2366]
#define sipNameNr_removeAttributeNS 2384
#define sipName_removeAttributeNS &sipStrings_QtWebKit[2384]
#define sipNameNr_removeLocalScheme 2402
#define sipName_removeLocalScheme &sipStrings_QtWebKit[2402]
#define sipNameNr_sip_simplewrapper 2420
#define sipName_sip_simplewrapper &sipStrings_QtWebKit[2420]
#define sipNameNr_supportsExtension 2438
#define sipName_supportsExtension &sipStrings_QtWebKit[2438]
#define sipNameNr_userStyleSheetUrl 2456
#define sipName_userStyleSheetUrl &sipStrings_QtWebKit[2456]
#define sipNameNr_SubdomainSetting 20
#define sipName_SubdomainSetting &sipStrings_QtWebKit[20]
#define sipNameNr_currentItemIndex 2474
#define sipName_currentItemIndex &sipStrings_QtWebKit[2474]
#define sipNameNr_defaultInterface 2491
#define sipName_defaultInterface &sipStrings_QtWebKit[2491]
#define sipNameNr_disconnectNotify 2508
#define sipName_disconnectNotify &sipStrings_QtWebKit[2508]
#define sipNameNr_iconDatabasePath 2525
#define sipName_iconDatabasePath &sipStrings_QtWebKit[2525]
#define sipNameNr_localStoragePath 2542
#define sipName_localStoragePath &sipStrings_QtWebKit[2542]
#define sipNameNr_maximumItemCount 2559
#define sipName_maximumItemCount &sipStrings_QtWebKit[2559]
#define sipNameNr_setDatabaseQuota 2576
#define sipName_setDatabaseQuota &sipStrings_QtWebKit[2576]
#define sipNameNr_setStyleProperty 2593
#define sipName_setStyleProperty &sipStrings_QtWebKit[2593]
#define sipNameNr_takeFromDocument 2610
#define sipName_takeFromDocument &sipStrings_QtWebKit[2610]
#define sipNameNr_AllowSubdomains 2627
#define sipName_AllowSubdomains &sipStrings_QtWebKit[2627]
#define sipNameNr_DefaultFontSize 2643
#define sipName_DefaultFontSize &sipStrings_QtWebKit[2643]
#define sipNameNr_ExtensionOption 163
#define sipName_ExtensionOption &sipStrings_QtWebKit[163]
#define sipNameNr_ExtensionReturn 198
#define sipName_ExtensionReturn &sipStrings_QtWebKit[198]
#define sipNameNr_MinimumFontSize 2659
#define sipName_MinimumFontSize &sipStrings_QtWebKit[2659]
#define sipNameNr_QWebHistoryItem 2675
#define sipName_QWebHistoryItem &sipStrings_QtWebKit[2675]
#define sipNameNr_WebAudioEnabled 2691
#define sipName_WebAudioEnabled &sipStrings_QtWebKit[2691]
#define sipNameNr_addHistoryEntry 2707
#define sipName_addHistoryEntry &sipStrings_QtWebKit[2707]
#define sipNameNr_historyContains 2723
#define sipName_historyContains &sipStrings_QtWebKit[2723]
#define sipNameNr_previousSibling 2739
#define sipName_previousSibling &sipStrings_QtWebKit[2739]
#define sipNameNr_removeAttribute 2755
#define sipName_removeAttribute &sipStrings_QtWebKit[2755]
#define sipNameNr_resetFontFamily 2771
#define sipName_resetFontFamily &sipStrings_QtWebKit[2771]
#define sipNameNr_setCSSMediaType 2787
#define sipName_setCSSMediaType &sipStrings_QtWebKit[2787]
#define sipNameNr_AutoLoadImages 2803
#define sipName_AutoLoadImages &sipStrings_QtWebKit[2803]
#define sipNameNr_PluginsEnabled 2818
#define sipName_PluginsEnabled &sipStrings_QtWebKit[2818]
#define sipNameNr_PyQt5_QtWebKit 2833
#define sipName_PyQt5_QtWebKit &sipStrings_QtWebKit[2833]
#define sipNameNr_addLocalScheme 2848
#define sipName_addLocalScheme &sipStrings_QtWebKit[2848]
#define sipNameNr_attributeNames 2863
#define sipName_attributeNames &sipStrings_QtWebKit[2863]
#define sipNameNr_fileExtensions 2878
#define sipName_fileExtensions &sipStrings_QtWebKit[2878]
#define sipNameNr_globalSettings 2893
#define sipName_globalSettings &sipStrings_QtWebKit[2893]
#define sipNameNr_hasAttributeNS 2908
#define sipName_hasAttributeNS &sipStrings_QtWebKit[2908]
#define sipNameNr_prependOutside 2923
#define sipName_prependOutside &sipStrings_QtWebKit[2923]
#define sipNameNr_qWebKitVersion 2938
#define sipName_qWebKitVersion &sipStrings_QtWebKit[2938]
#define sipNameNr_refreshPlugins 2953
#define sipName_refreshPlugins &sipStrings_QtWebKit[2953]
#define sipNameNr_removeDatabase 2968
#define sipName_removeDatabase &sipStrings_QtWebKit[2968]
#define sipNameNr_resetAttribute 2983
#define sipName_resetAttribute &sipStrings_QtWebKit[2983]
#define sipNameNr_setAttributeNS 2998
#define sipName_setAttributeNS &sipStrings_QtWebKit[2998]
#define sipNameNr_CascadedStyle 3013
#define sipName_CascadedStyle &sipStrings_QtWebKit[3013]
#define sipNameNr_ComputedStyle 3027
#define sipName_ComputedStyle &sipStrings_QtWebKit[3027]
#define sipNameNr_SansSerifFont 3041
#define sipName_SansSerifFont &sipStrings_QtWebKit[3041]
#define sipNameNr_appendOutside 3055
#define sipName_appendOutside &sipStrings_QtWebKit[3055]
#define sipNameNr_connectNotify 2511
#define sipName_connectNotify &sipStrings_QtWebKit[2511]
#define sipNameNr_databaseQuota 3069
#define sipName_databaseQuota &sipStrings_QtWebKit[3069]
#define sipNameNr_databaseUsage 3083
#define sipName_databaseUsage &sipStrings_QtWebKit[3083]
#define sipNameNr_hasAttributes 3097
#define sipName_hasAttributes &sipStrings_QtWebKit[3097]
#define sipNameNr_prependInside 3111
#define sipName_prependInside &sipStrings_QtWebKit[3111]
#define sipNameNr_resetFontSize 3125
#define sipName_resetFontSize &sipStrings_QtWebKit[3125]
#define sipNameNr_setFontFamily 2773
#define sipName_setFontFamily &sipStrings_QtWebKit[2773]
#define sipNameNr_setWebGraphic 3139
#define sipName_setWebGraphic &sipStrings_QtWebKit[3139]
#define sipNameNr_styleProperty 3153
#define sipName_styleProperty &sipStrings_QtWebKit[3153]
#define sipNameNr_testAttribute 3167
#define sipName_testAttribute &sipStrings_QtWebKit[3167]
#define sipNameNr_QWebDatabase 3181
#define sipName_QWebDatabase &sipStrings_QtWebKit[3181]
#define sipNameNr_QWebSettings 3194
#define sipName_QWebSettings &sipStrings_QtWebKit[3194]
#define sipNameNr_StandardFont 3207
#define sipName_StandardFont &sipStrings_QtWebKit[3207]
#define sipNameNr_WebAttribute 875
#define sipName_WebAttribute &sipStrings_QtWebKit[875]
#define sipNameNr_WebGLEnabled 3220
#define sipName_WebGLEnabled &sipStrings_QtWebKit[3220]
#define sipNameNr_ZoomTextOnly 3233
#define sipName_ZoomTextOnly &sipStrings_QtWebKit[3233]
#define sipNameNr_appendInside 3246
#define sipName_appendInside &sipStrings_QtWebKit[3246]
#define sipNameNr_canGoForward 3259
#define sipName_canGoForward &sipStrings_QtWebKit[3259]
#define sipNameNr_cssMediaType 3272
#define sipName_cssMediaType &sipStrings_QtWebKit[3272]
#define sipNameNr_defaultValue 3285
#define sipName_defaultValue &sipStrings_QtWebKit[3285]
#define sipNameNr_expectedSize 3298
#define sipName_expectedSize &sipStrings_QtWebKit[3298]
#define sipNameNr_forwardItems 3311
#define sipName_forwardItems &sipStrings_QtWebKit[3311]
#define sipNameNr_hasAttribute 3324
#define sipName_hasAttribute &sipStrings_QtWebKit[3324]
#define sipNameNr_localSchemes 3337
#define sipName_localSchemes &sipStrings_QtWebKit[3337]
#define sipNameNr_namespaceUri 3350
#define sipName_namespaceUri &sipStrings_QtWebKit[3350]
#define sipNameNr_setAttribute 2985
#define sipName_setAttribute &sipStrings_QtWebKit[2985]
#define sipNameNr_setPlainText 3363
#define sipName_setPlainText &sipStrings_QtWebKit[3363]
#define sipNameNr_CursiveFont 3376
#define sipName_CursiveFont &sipStrings_QtWebKit[3376]
#define sipNameNr_FantasyFont 3388
#define sipName_FantasyFont &sipStrings_QtWebKit[3388]
#define sipNameNr_InlineStyle 3400
#define sipName_InlineStyle &sipStrings_QtWebKit[3400]
#define sipNameNr_JavaEnabled 3412
#define sipName_JavaEnabled &sipStrings_QtWebKit[3412]
#define sipNameNr_QWebElement 3424
#define sipName_QWebElement &sipStrings_QtWebKit[3424]
#define sipNameNr_QWebHistory 3436
#define sipName_QWebHistory &sipStrings_QtWebKit[3436]
#define sipNameNr___getitem__ 3448
#define sipName___getitem__ &sipStrings_QtWebKit[3448]
#define sipNameNr_attributeNS 3460
#define sipName_attributeNS &sipStrings_QtWebKit[3460]
#define sipNameNr_currentItem 3472
#define sipName_currentItem &sipStrings_QtWebKit[3472]
#define sipNameNr_customEvent 3484
#define sipName_customEvent &sipStrings_QtWebKit[3484]
#define sipNameNr_description 3496
#define sipName_description &sipStrings_QtWebKit[3496]
#define sipNameNr_displayName 3508
#define sipName_displayName &sipStrings_QtWebKit[3508]
#define sipNameNr_encloseWith 3520
#define sipName_encloseWith &sipStrings_QtWebKit[3520]
#define sipNameNr_eventFilter 3532
#define sipName_eventFilter &sipStrings_QtWebKit[3532]
#define sipNameNr_forwardItem 3544
#define sipName_forwardItem &sipStrings_QtWebKit[3544]
#define sipNameNr_lastVisited 3556
#define sipName_lastVisited &sipStrings_QtWebKit[3556]
#define sipNameNr_nextSibling 3568
#define sipName_nextSibling &sipStrings_QtWebKit[3568]
#define sipNameNr_originalUrl 3580
#define sipName_originalUrl &sipStrings_QtWebKit[3580]
#define sipNameNr_removeClass 3592
#define sipName_removeClass &sipStrings_QtWebKit[3592]
#define sipNameNr_setFontSize 3127
#define sipName_setFontSize &sipStrings_QtWebKit[3127]
#define sipNameNr_setInnerXml 3604
#define sipName_setInnerXml &sipStrings_QtWebKit[3604]
#define sipNameNr_setOuterXml 3616
#define sipName_setOuterXml &sipStrings_QtWebKit[3616]
#define sipNameNr_setUserData 3628
#define sipName_setUserData &sipStrings_QtWebKit[3628]
#define sipNameNr_toPlainText 3640
#define sipName_toPlainText &sipStrings_QtWebKit[3640]
#define sipNameNr_toggleClass 3652
#define sipName_toggleClass &sipStrings_QtWebKit[3652]
#define sipNameNr_FontFamily 1213
#define sipName_FontFamily &sipStrings_QtWebKit[1213]
#define sipNameNr_WebGraphic 1238
#define sipName_WebGraphic &sipStrings_QtWebKit[1238]
#define sipNameNr___lshift__ 3664
#define sipName___lshift__ &sipStrings_QtWebKit[3664]
#define sipNameNr___rshift__ 3675
#define sipName___rshift__ &sipStrings_QtWebKit[3675]
#define sipNameNr_allOrigins 3686
#define sipName_allOrigins &sipStrings_QtWebKit[3686]
#define sipNameNr_childEvent 3697
#define sipName_childEvent &sipStrings_QtWebKit[3697]
#define sipNameNr_firstChild 3708
#define sipName_firstChild &sipStrings_QtWebKit[3708]
#define sipNameNr_fontFamily 3719
#define sipName_fontFamily &sipStrings_QtWebKit[3719]
#define sipNameNr_iconForUrl 3730
#define sipName_iconForUrl &sipStrings_QtWebKit[3730]
#define sipNameNr_timerEvent 3741
#define sipName_timerEvent &sipStrings_QtWebKit[3741]
#define sipNameNr_toInnerXml 3752
#define sipName_toInnerXml &sipStrings_QtWebKit[3752]
#define sipNameNr_toOuterXml 3763
#define sipName_toOuterXml &sipStrings_QtWebKit[3763]
#define sipNameNr_webGraphic 3774
#define sipName_webGraphic &sipStrings_QtWebKit[3774]
#define sipNameNr_Extension 768
#define sipName_Extension &sipStrings_QtWebKit[768]
#define sipNameNr_FixedFont 3785
#define sipName_FixedFont &sipStrings_QtWebKit[3785]
#define sipNameNr_QWebFrame 3795
#define sipName_QWebFrame &sipStrings_QtWebKit[3795]
#define sipNameNr_SerifFont 3045
#define sipName_SerifFont &sipStrings_QtWebKit[3045]
#define sipNameNr_attribute 3805
#define sipName_attribute &sipStrings_QtWebKit[3805]
#define sipNameNr_backItems 3815
#define sipName_backItems &sipStrings_QtWebKit[3815]
#define sipNameNr_canGoBack 3825
#define sipName_canGoBack &sipStrings_QtWebKit[3825]
#define sipNameNr_databases 3835
#define sipName_databases &sipStrings_QtWebKit[3835]
#define sipNameNr_extension 3845
#define sipName_extension &sipStrings_QtWebKit[3845]
#define sipNameNr_findFirst 3855
#define sipName_findFirst &sipStrings_QtWebKit[3855]
#define sipNameNr_lastChild 3865
#define sipName_lastChild &sipStrings_QtWebKit[3865]
#define sipNameNr_localName 3875
#define sipName_localName &sipStrings_QtWebKit[3875]
#define sipNameNr_mimeTypes 3885
#define sipName_mimeTypes &sipStrings_QtWebKit[3885]
#define sipNameNr_FontSize 1505
#define sipName_FontSize &sipStrings_QtWebKit[1505]
#define sipNameNr_MimeType 825
#define sipName_MimeType &sipStrings_QtWebKit[825]
#define sipNameNr___iadd__ 3895
#define sipName___iadd__ &sipStrings_QtWebKit[3895]
#define sipNameNr_addClass 3904
#define sipName_addClass &sipStrings_QtWebKit[3904]
#define sipNameNr_backItem 3913
#define sipName_backItem &sipStrings_QtWebKit[3913]
#define sipNameNr_document 3922
#define sipName_document &sipStrings_QtWebKit[3922]
#define sipNameNr_fileName 3931
#define sipName_fileName &sipStrings_QtWebKit[3931]
#define sipNameNr_fontSize 3940
#define sipName_fontSize &sipStrings_QtWebKit[3940]
#define sipNameNr_geometry 3949
#define sipName_geometry &sipStrings_QtWebKit[3949]
#define sipNameNr_goToItem 3958
#define sipName_goToItem &sipStrings_QtWebKit[3958]
#define sipNameNr_hasClass 3967
#define sipName_hasClass &sipStrings_QtWebKit[3967]
#define sipNameNr_hasFocus 3976
#define sipName_hasFocus &sipStrings_QtWebKit[3976]
#define sipNameNr_setFocus 3985
#define sipName_setFocus &sipStrings_QtWebKit[3985]
#define sipNameNr_userData 3994
#define sipName_userData &sipStrings_QtWebKit[3994]
#define sipNameNr_webFrame 4003
#define sipName_webFrame &sipStrings_QtWebKit[4003]
#define sipNameNr___add__ 4012
#define sipName___add__ &sipStrings_QtWebKit[4012]
#define sipNameNr___len__ 4020
#define sipName___len__ &sipStrings_QtWebKit[4020]
#define sipNameNr_classes 4028
#define sipName_classes &sipStrings_QtWebKit[4028]
#define sipNameNr_findAll 4036
#define sipName_findAll &sipStrings_QtWebKit[4036]
#define sipNameNr_forward 4044
#define sipName_forward &sipStrings_QtWebKit[4044]
#define sipNameNr_isValid 4052
#define sipName_isValid &sipStrings_QtWebKit[4052]
#define sipNameNr_plugins 4060
#define sipName_plugins &sipStrings_QtWebKit[4060]
#define sipNameNr_replace 4068
#define sipName_replace &sipStrings_QtWebKit[4068]
#define sipNameNr_tagName 4076
#define sipName_tagName &sipStrings_QtWebKit[4076]
#define sipNameNr_Plugin 1039
#define sipName_Plugin &sipStrings_QtWebKit[1039]
#define sipNameNr___eq__ 4084
#define sipName___eq__ &sipStrings_QtWebKit[4084]
#define sipNameNr___ne__ 4091
#define sipName___ne__ &sipStrings_QtWebKit[4091]
#define sipNameNr_append 4098
#define sipName_append &sipStrings_QtWebKit[4098]
#define sipNameNr_create 4105
#define sipName_create &sipStrings_QtWebKit[4105]
#define sipNameNr_isNull 4112
#define sipName_isNull &sipStrings_QtWebKit[4112]
#define sipNameNr_itemAt 4119
#define sipName_itemAt &sipStrings_QtWebKit[4119]
#define sipNameNr_option 4126
#define sipName_option &sipStrings_QtWebKit[4126]
#define sipNameNr_origin 4133
#define sipName_origin &sipStrings_QtWebKit[4133]
#define sipNameNr_output 4140
#define sipName_output &sipStrings_QtWebKit[4140]
#define sipNameNr_parent 4147
#define sipName_parent &sipStrings_QtWebKit[4147]
#define sipNameNr_prefix 4154
#define sipName_prefix &sipStrings_QtWebKit[4154]
#define sipNameNr_render 4161
#define sipName_render &sipStrings_QtWebKit[4161]
#define sipNameNr_scheme 4168
#define sipName_scheme &sipStrings_QtWebKit[4168]
#define sipNameNr_toList 4175
#define sipName_toList &sipStrings_QtWebKit[4175]
#define sipNameNr_clear 4182
#define sipName_clear &sipStrings_QtWebKit[4182]
#define sipNameNr_clone 4188
#define sipName_clone &sipStrings_QtWebKit[4188]
#define sipNameNr_count 4194
#define sipName_count &sipStrings_QtWebKit[4194]
#define sipNameNr_event 4200
#define sipName_event &sipStrings_QtWebKit[4200]
#define sipNameNr_first 4206
#define sipName_first &sipStrings_QtWebKit[4206]
#define sipNameNr_items 4212
#define sipName_items &sipStrings_QtWebKit[4212]
#define sipNameNr_title 4218
#define sipName_title &sipStrings_QtWebKit[4218]
#define sipNameNr_back 4224
#define sipName_back &sipStrings_QtWebKit[4224]
#define sipNameNr_host 4229
#define sipName_host &sipStrings_QtWebKit[4229]
#define sipNameNr_icon 4234
#define sipName_icon &sipStrings_QtWebKit[4234]
#define sipNameNr_last 4239
#define sipName_last &sipStrings_QtWebKit[4239]
#define sipNameNr_name 4244
#define sipName_name &sipStrings_QtWebKit[4244]
#define sipNameNr_path 4249
#define sipName_path &sipStrings_QtWebKit[4249]
#define sipNameNr_port 4254
#define sipName_port &sipStrings_QtWebKit[4254]
#define sipNameNr_size 4259
#define sipName_size &sipStrings_QtWebKit[4259]
#define sipNameNr_url 4264
#define sipName_url &sipStrings_QtWebKit[4264]
#define sipNameNr_at 4268
#define sipName_at &sipStrings_QtWebKit[4268]

#define sipMalloc                   sipAPI_QtWebKit->api_malloc
#define sipFree                     sipAPI_QtWebKit->api_free
#define sipBuildResult              sipAPI_QtWebKit->api_build_result
#define sipCallMethod               sipAPI_QtWebKit->api_call_method
#define sipCallProcedureMethod      sipAPI_QtWebKit->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtWebKit->api_call_error_handler
#define sipParseResultEx            sipAPI_QtWebKit->api_parse_result_ex
#define sipParseResult              sipAPI_QtWebKit->api_parse_result
#define sipParseArgs                sipAPI_QtWebKit->api_parse_args
#define sipParseKwdArgs             sipAPI_QtWebKit->api_parse_kwd_args
#define sipParsePair                sipAPI_QtWebKit->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtWebKit->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtWebKit->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtWebKit->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtWebKit->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtWebKit->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtWebKit->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtWebKit->api_add_exception
#define sipNoFunction               sipAPI_QtWebKit->api_no_function
#define sipNoMethod                 sipAPI_QtWebKit->api_no_method
#define sipAbstractMethod           sipAPI_QtWebKit->api_abstract_method
#define sipBadClass                 sipAPI_QtWebKit->api_bad_class
#define sipBadCatcherResult         sipAPI_QtWebKit->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtWebKit->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtWebKit->api_bad_operator_arg
#define sipTrace                    sipAPI_QtWebKit->api_trace
#define sipTransferBack             sipAPI_QtWebKit->api_transfer_back
#define sipTransferTo               sipAPI_QtWebKit->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtWebKit->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtWebKit->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtWebKit->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtWebKit->api_voidptr_type
#define sipGetPyObject              sipAPI_QtWebKit->api_get_pyobject
#define sipGetAddress               sipAPI_QtWebKit->api_get_address
#define sipGetMixinAddress          sipAPI_QtWebKit->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtWebKit->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtWebKit->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtWebKit->api_call_hook
#define sipEndThread                sipAPI_QtWebKit->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtWebKit->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtWebKit->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtWebKit->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtWebKit->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtWebKit->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtWebKit->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtWebKit->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtWebKit->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtWebKit->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtWebKit->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtWebKit->api_convert_to_bool
#define sipReleaseType              sipAPI_QtWebKit->api_release_type
#define sipConvertFromType          sipAPI_QtWebKit->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtWebKit->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtWebKit->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtWebKit->api_convert_from_enum
#define sipGetState                 sipAPI_QtWebKit->api_get_state
#define sipExportSymbol             sipAPI_QtWebKit->api_export_symbol
#define sipImportSymbol             sipAPI_QtWebKit->api_import_symbol
#define sipFindType                 sipAPI_QtWebKit->api_find_type
#define sipBytes_AsChar             sipAPI_QtWebKit->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtWebKit->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtWebKit->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtWebKit->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtWebKit->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtWebKit->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtWebKit->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtWebKit->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtWebKit->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtWebKit->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtWebKit->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtWebKit->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtWebKit->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtWebKit->api_get_reference
#define sipKeepReference            sipAPI_QtWebKit->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtWebKit->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtWebKit->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtWebKit->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtWebKit->api_type_scope
#define sipResolveTypedef           sipAPI_QtWebKit->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtWebKit->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtWebKit->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtWebKit->api_init_mixin
#define sipExportModule             sipAPI_QtWebKit->api_export_module
#define sipInitModule               sipAPI_QtWebKit->api_init_module
#define sipGetInterpreter           sipAPI_QtWebKit->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtWebKit->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtWebKit->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtWebKit->api_py_type_dict
#define sipPyTypeName               sipAPI_QtWebKit->api_py_type_name
#define sipGetCFunction             sipAPI_QtWebKit->api_get_c_function
#define sipGetMethod                sipAPI_QtWebKit->api_get_method
#define sipFromMethod               sipAPI_QtWebKit->api_from_method
#define sipGetDate                  sipAPI_QtWebKit->api_get_date
#define sipFromDate                 sipAPI_QtWebKit->api_from_date
#define sipGetDateTime              sipAPI_QtWebKit->api_get_datetime
#define sipFromDateTime             sipAPI_QtWebKit->api_from_datetime
#define sipGetTime                  sipAPI_QtWebKit->api_get_time
#define sipFromTime                 sipAPI_QtWebKit->api_from_time
#define sipIsUserType               sipAPI_QtWebKit->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtWebKit->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtWebKit->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtWebKit->api_unicode_write
#define sipUnicodeData              sipAPI_QtWebKit->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtWebKit->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtWebKit->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtWebKit->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtWebKit->api_is_derived_class
#define sipGetUserObject            sipAPI_QtWebKit->api_get_user_object
#define sipSetUserObject            sipAPI_QtWebKit->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtWebKit->api_register_event_handler
#define sipConvertToArray           sipAPI_QtWebKit->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtWebKit->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtWebKit->api_enable_gc
#define sipPrintObject              sipAPI_QtWebKit->api_print_object
#define sipLong_AsChar              sipAPI_QtWebKit->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtWebKit->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtWebKit->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtWebKit->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtWebKit->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtWebKit->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtWebKit->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtWebKit->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtWebKit->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtWebKit->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtWebKit->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtWebKit->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtWebKit->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtWebKit->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtWebKit->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtWebKit->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtWebKit->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtWebKit->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtWebKit->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtWebKit->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtWebKit->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtWebKit->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtWebKit->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtWebKit->api_connect_rx
#define sipConvertRx                sipAPI_QtWebKit->api_convert_rx
#define sipDisconnectRx             sipAPI_QtWebKit->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtWebKit->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtWebKit->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtWebKit->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtWebKit->api_same_slot
#define sipSaveSlot                 sipAPI_QtWebKit->api_save_slot
#define sipVisitSlot                sipAPI_QtWebKit->api_visit_slot
#define sipIsPyMethod               sipAPI_QtWebKit->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtWebKit[];

#define sipType_QWebDatabase sipExportedTypes_QtWebKit[6]

extern sipClassTypeDef sipTypeDef_QtWebKit_QWebDatabase;

#define sipType_QWebFrame sipExportedTypes_QtWebKit[10]

#define sipType_QWebElement sipExportedTypes_QtWebKit[7]

#define sipType_QWebElement_StyleResolveStrategy sipExportedTypes_QtWebKit[8]

extern sipClassTypeDef sipTypeDef_QtWebKit_QWebElement;

#define sipType_QWebElementCollection sipExportedTypes_QtWebKit[9]

extern sipClassTypeDef sipTypeDef_QtWebKit_QWebElementCollection;

#define sipType_QWebHistoryItem sipExportedTypes_QtWebKit[13]

extern sipClassTypeDef sipTypeDef_QtWebKit_QWebHistoryItem;

#define sipType_QWebHistory sipExportedTypes_QtWebKit[11]

extern sipClassTypeDef sipTypeDef_QtWebKit_QWebHistory;

#define sipType_QWebHistoryInterface sipExportedTypes_QtWebKit[12]

extern sipClassTypeDef sipTypeDef_QtWebKit_QWebHistoryInterface;

#define sipType_QWebPluginFactory sipExportedTypes_QtWebKit[14]

#define sipType_QWebPluginFactory_Extension sipExportedTypes_QtWebKit[15]

extern sipClassTypeDef sipTypeDef_QtWebKit_QWebPluginFactory;

#define sipType_QWebPluginFactory_MimeType sipExportedTypes_QtWebKit[18]

extern sipClassTypeDef sipTypeDef_QtWebKit_QWebPluginFactory_MimeType;

#define sipType_QWebPluginFactory_Plugin sipExportedTypes_QtWebKit[19]

extern sipClassTypeDef sipTypeDef_QtWebKit_QWebPluginFactory_Plugin;

#define sipType_QWebPluginFactory_ExtensionOption sipExportedTypes_QtWebKit[16]

extern sipClassTypeDef sipTypeDef_QtWebKit_QWebPluginFactory_ExtensionOption;

#define sipType_QWebPluginFactory_ExtensionReturn sipExportedTypes_QtWebKit[17]

extern sipClassTypeDef sipTypeDef_QtWebKit_QWebPluginFactory_ExtensionReturn;

#define sipType_QWebSecurityOrigin sipExportedTypes_QtWebKit[20]

#define sipType_QWebSecurityOrigin_SubdomainSetting sipExportedTypes_QtWebKit[21]

extern sipClassTypeDef sipTypeDef_QtWebKit_QWebSecurityOrigin;

#define sipType_QWebSettings sipExportedTypes_QtWebKit[22]

#define sipType_QWebSettings_ThirdPartyCookiePolicy sipExportedTypes_QtWebKit[25]

#define sipType_QWebSettings_FontSize sipExportedTypes_QtWebKit[24]

#define sipType_QWebSettings_WebGraphic sipExportedTypes_QtWebKit[27]

#define sipType_QWebSettings_WebAttribute sipExportedTypes_QtWebKit[26]

#define sipType_QWebSettings_FontFamily sipExportedTypes_QtWebKit[23]

extern sipClassTypeDef sipTypeDef_QtWebKit_QWebSettings;

#define sipType_QList_0100QWebDatabase sipExportedTypes_QtWebKit[0]

extern sipMappedTypeDef sipTypeDef_QtWebKit_QList_0100QWebDatabase;

#define sipType_QList_0100QWebSecurityOrigin sipExportedTypes_QtWebKit[5]

extern sipMappedTypeDef sipTypeDef_QtWebKit_QList_0100QWebSecurityOrigin;

#define sipType_QList_0100QWebPluginFactory_Plugin sipExportedTypes_QtWebKit[4]

extern sipMappedTypeDef sipTypeDef_QtWebKit_QList_0100QWebPluginFactory_Plugin;

#define sipType_QList_0100QWebHistoryItem sipExportedTypes_QtWebKit[2]

extern sipMappedTypeDef sipTypeDef_QtWebKit_QList_0100QWebHistoryItem;

#define sipType_QList_0100QWebElement sipExportedTypes_QtWebKit[1]

extern sipMappedTypeDef sipTypeDef_QtWebKit_QList_0100QWebElement;

#define sipType_QList_0100QWebPluginFactory_MimeType sipExportedTypes_QtWebKit[3]

extern sipMappedTypeDef sipTypeDef_QtWebKit_QList_0100QWebPluginFactory_MimeType;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtWebKit;
extern sipExportedModuleDef sipModuleAPI_QtWebKit;
extern sipTypeDef *sipExportedTypes_QtWebKit[];

#define sipType_QObject sipImportedTypes_QtWebKit_QtCore[5].it_td

#define sipType_QEvent sipImportedTypes_QtWebKit_QtCore[3].it_td

#define sipType_QTimerEvent sipImportedTypes_QtWebKit_QtCore[9].it_td

#define sipType_QChildEvent sipImportedTypes_QtWebKit_QtCore[0].it_td

#define sipType_QDataStream sipImportedTypes_QtWebKit_QtCore[1].it_td

#define sipType_QDateTime sipImportedTypes_QtWebKit_QtCore[2].it_td

#define sipType_QMetaMethod sipImportedTypes_QtWebKit_QtCore[4].it_td

#define sipType_QRect sipImportedTypes_QtWebKit_QtCore[6].it_td

#define sipType_QUrl sipImportedTypes_QtWebKit_QtCore[10].it_td

#define sipType_QVariant sipImportedTypes_QtWebKit_QtCore[11].it_td

#define sipType_QStringList sipImportedTypes_QtWebKit_QtCore[8].it_td

#define sipType_QString sipImportedTypes_QtWebKit_QtCore[7].it_td
extern sipImportedTypeDef sipImportedTypes_QtWebKit_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtWebKit_QtCore[];

#define sipType_QPixmap sipImportedTypes_QtWebKit_QtGui[2].it_td

#define sipType_QIcon sipImportedTypes_QtWebKit_QtGui[0].it_td

#define sipType_QPainter sipImportedTypes_QtWebKit_QtGui[1].it_td
extern sipImportedTypeDef sipImportedTypes_QtWebKit_QtGui[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtWebKit_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtWebKit_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtWebKit_qt_metacast;

#endif
