/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlistmodel.sip"
#include <qstringlistmodel.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmimedata.sip"
#include <qmimedata.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 275 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qhash.sip"
#include <qhash.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qdatastream.sip"
#include <qdatastream.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 76 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 442 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 122 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 125 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 128 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 131 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQStringListModel.cpp"


class sipQStringListModel : public ::QStringListModel
{
public:
    sipQStringListModel(::QObject*);
    sipQStringListModel(const ::QStringList&, ::QObject*);
    virtual ~sipQStringListModel();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool moveColumns(const ::QModelIndex&, int, int, const ::QModelIndex&, int) SIP_OVERRIDE;
    bool moveRows(const ::QModelIndex&, int, int, const ::QModelIndex&, int) SIP_OVERRIDE;
    bool canDropMimeData(const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&) const SIP_OVERRIDE;
    QHash<int, ::QByteArray> roleNames() const SIP_OVERRIDE;
    ::Qt::DropActions supportedDragActions() const SIP_OVERRIDE;
    void revert() SIP_OVERRIDE;
    bool submit() SIP_OVERRIDE;
    ::QSize span(const ::QModelIndex&) const SIP_OVERRIDE;
    ::QModelIndexList match(const ::QModelIndex&, int, const ::QVariant&, int, ::Qt::MatchFlags) const SIP_OVERRIDE;
    ::QModelIndex buddy(const ::QModelIndex&) const SIP_OVERRIDE;
    void sort(int, ::Qt::SortOrder) SIP_OVERRIDE;
    ::Qt::ItemFlags flags(const ::QModelIndex&) const SIP_OVERRIDE;
    bool canFetchMore(const ::QModelIndex&) const SIP_OVERRIDE;
    void fetchMore(const ::QModelIndex&) SIP_OVERRIDE;
    bool removeColumns(int, int, const ::QModelIndex&) SIP_OVERRIDE;
    bool removeRows(int, int, const ::QModelIndex&) SIP_OVERRIDE;
    bool insertColumns(int, int, const ::QModelIndex&) SIP_OVERRIDE;
    bool insertRows(int, int, const ::QModelIndex&) SIP_OVERRIDE;
    ::Qt::DropActions supportedDropActions() const SIP_OVERRIDE;
    bool dropMimeData(const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&) SIP_OVERRIDE;
    ::QMimeData* mimeData(const ::QModelIndexList&) const SIP_OVERRIDE;
    ::QStringList mimeTypes() const SIP_OVERRIDE;
    bool setItemData(const ::QModelIndex&, const QMap<int, ::QVariant>&) SIP_OVERRIDE;
    QMap<int, ::QVariant> itemData(const ::QModelIndex&) const SIP_OVERRIDE;
    bool setHeaderData(int, ::Qt::Orientation, const ::QVariant&, int) SIP_OVERRIDE;
    ::QVariant headerData(int, ::Qt::Orientation, int) const SIP_OVERRIDE;
    bool setData(const ::QModelIndex&, const ::QVariant&, int) SIP_OVERRIDE;
    ::QVariant data(const ::QModelIndex&, int) const SIP_OVERRIDE;
    int rowCount(const ::QModelIndex&) const SIP_OVERRIDE;
    ::QModelIndex sibling(int, int, const ::QModelIndex&) const SIP_OVERRIDE;
    ::QModelIndex index(int, int, const ::QModelIndex&) const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQStringListModel(const sipQStringListModel &);
    sipQStringListModel &operator = (const sipQStringListModel &);

    char sipPyMethods[38];
};

sipQStringListModel::sipQStringListModel(::QObject*a0): ::QStringListModel(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQStringListModel::sipQStringListModel(const ::QStringList& a0, ::QObject*a1): ::QStringListModel(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQStringListModel::~sipQStringListModel()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQStringListModel::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtCore_qt_metaobject(sipPySelf, sipType_QStringListModel);

    return ::QStringListModel::metaObject();
}

int sipQStringListModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QStringListModel::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtCore_qt_metacall(sipPySelf, sipType_QStringListModel, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQStringListModel::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtCore_qt_metacast(sipPySelf, sipType_QStringListModel, _clname, &sipCpp) ? sipCpp : ::QStringListModel::qt_metacast(_clname));
}

bool sipQStringListModel::moveColumns(const ::QModelIndex& a0, int a1, int a2, const ::QModelIndex& a3, int a4)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_moveColumns);

    if (!sipMeth)
        return ::QStringListModel::moveColumns(a0, a1, a2, a3, a4);

    extern bool sipVH_QtCore_40(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, int, const ::QModelIndex&, int);

    return sipVH_QtCore_40(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

bool sipQStringListModel::moveRows(const ::QModelIndex& a0, int a1, int a2, const ::QModelIndex& a3, int a4)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_moveRows);

    if (!sipMeth)
        return ::QStringListModel::moveRows(a0, a1, a2, a3, a4);

    extern bool sipVH_QtCore_40(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, int, const ::QModelIndex&, int);

    return sipVH_QtCore_40(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

bool sipQStringListModel::canDropMimeData(const ::QMimeData*a0, ::Qt::DropAction a1, int a2, int a3, const ::QModelIndex& a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_canDropMimeData);

    if (!sipMeth)
        return ::QStringListModel::canDropMimeData(a0, a1, a2, a3, a4);

    extern bool sipVH_QtCore_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&);

    return sipVH_QtCore_31(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

QHash<int, ::QByteArray> sipQStringListModel::roleNames() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_roleNames);

    if (!sipMeth)
        return ::QStringListModel::roleNames();

    extern QHash<int, ::QByteArray> sipVH_QtCore_39(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_39(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth);
}

::Qt::DropActions sipQStringListModel::supportedDragActions() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_supportedDragActions);

    if (!sipMeth)
        return ::QStringListModel::supportedDragActions();

    extern ::Qt::DropActions sipVH_QtCore_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_32(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth);
}

void sipQStringListModel::revert()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_revert);

    if (!sipMeth)
    {
        ::QStringListModel::revert();
        return;
    }

    extern void sipVH_QtCore_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtCore_17(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth);
}

bool sipQStringListModel::submit()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_submit);

    if (!sipMeth)
        return ::QStringListModel::submit();

    extern bool sipVH_QtCore_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_11(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth);
}

::QSize sipQStringListModel::span(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_span);

    if (!sipMeth)
        return ::QStringListModel::span(a0);

    extern ::QSize sipVH_QtCore_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_38(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

::QModelIndexList sipQStringListModel::match(const ::QModelIndex& a0, int a1, const ::QVariant& a2, int a3, ::Qt::MatchFlags a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_match);

    if (!sipMeth)
        return ::QStringListModel::match(a0, a1, a2, a3, a4);

    extern ::QModelIndexList sipVH_QtCore_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, const ::QVariant&, int, ::Qt::MatchFlags);

    return sipVH_QtCore_37(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

::QModelIndex sipQStringListModel::buddy(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_buddy);

    if (!sipMeth)
        return ::QStringListModel::buddy(a0);

    extern ::QModelIndex sipVH_QtCore_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_20(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQStringListModel::sort(int a0, ::Qt::SortOrder a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_sort);

    if (!sipMeth)
    {
        ::QStringListModel::sort(a0, a1);
        return;
    }

    extern void sipVH_QtCore_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::SortOrder);

    sipVH_QtCore_36(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1);
}

::Qt::ItemFlags sipQStringListModel::flags(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_flags);

    if (!sipMeth)
        return ::QStringListModel::flags(a0);

    extern ::Qt::ItemFlags sipVH_QtCore_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_35(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQStringListModel::canFetchMore(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_canFetchMore);

    if (!sipMeth)
        return ::QStringListModel::canFetchMore(a0);

    extern bool sipVH_QtCore_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_22(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQStringListModel::fetchMore(const ::QModelIndex& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_fetchMore);

    if (!sipMeth)
    {
        ::QStringListModel::fetchMore(a0);
        return;
    }

    extern void sipVH_QtCore_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    sipVH_QtCore_34(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQStringListModel::removeColumns(int a0, int a1, const ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_removeColumns);

    if (!sipMeth)
        return ::QStringListModel::removeColumns(a0, a1, a2);

    extern bool sipVH_QtCore_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtCore_33(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQStringListModel::removeRows(int a0, int a1, const ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_removeRows);

    if (!sipMeth)
        return ::QStringListModel::removeRows(a0, a1, a2);

    extern bool sipVH_QtCore_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtCore_33(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQStringListModel::insertColumns(int a0, int a1, const ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_insertColumns);

    if (!sipMeth)
        return ::QStringListModel::insertColumns(a0, a1, a2);

    extern bool sipVH_QtCore_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtCore_33(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQStringListModel::insertRows(int a0, int a1, const ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_insertRows);

    if (!sipMeth)
        return ::QStringListModel::insertRows(a0, a1, a2);

    extern bool sipVH_QtCore_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtCore_33(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

::Qt::DropActions sipQStringListModel::supportedDropActions() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[18]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_supportedDropActions);

    if (!sipMeth)
        return ::QStringListModel::supportedDropActions();

    extern ::Qt::DropActions sipVH_QtCore_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_32(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth);
}

bool sipQStringListModel::dropMimeData(const ::QMimeData*a0, ::Qt::DropAction a1, int a2, int a3, const ::QModelIndex& a4)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_dropMimeData);

    if (!sipMeth)
        return ::QStringListModel::dropMimeData(a0, a1, a2, a3, a4);

    extern bool sipVH_QtCore_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&);

    return sipVH_QtCore_31(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

::QMimeData* sipQStringListModel::mimeData(const ::QModelIndexList& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[20]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_mimeData);

    if (!sipMeth)
        return ::QStringListModel::mimeData(a0);

    extern ::QMimeData* sipVH_QtCore_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndexList&);

    return sipVH_QtCore_30(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

::QStringList sipQStringListModel::mimeTypes() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[21]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_mimeTypes);

    if (!sipMeth)
        return ::QStringListModel::mimeTypes();

    extern ::QStringList sipVH_QtCore_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtCore_29(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth);
}

bool sipQStringListModel::setItemData(const ::QModelIndex& a0, const QMap<int, ::QVariant>& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_setItemData);

    if (!sipMeth)
        return ::QStringListModel::setItemData(a0, a1);

    extern bool sipVH_QtCore_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const QMap<int, ::QVariant>&);

    return sipVH_QtCore_28(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1);
}

QMap<int, ::QVariant> sipQStringListModel::itemData(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[23]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_itemData);

    if (!sipMeth)
        return ::QStringListModel::itemData(a0);

    extern QMap<int, ::QVariant> sipVH_QtCore_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_27(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQStringListModel::setHeaderData(int a0, ::Qt::Orientation a1, const ::QVariant& a2, int a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_setHeaderData);

    if (!sipMeth)
        return ::QStringListModel::setHeaderData(a0, a1, a2, a3);

    extern bool sipVH_QtCore_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::Orientation, const ::QVariant&, int);

    return sipVH_QtCore_26(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2, a3);
}

::QVariant sipQStringListModel::headerData(int a0, ::Qt::Orientation a1, int a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[25]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_headerData);

    if (!sipMeth)
        return ::QStringListModel::headerData(a0, a1, a2);

    extern ::QVariant sipVH_QtCore_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::Orientation, int);

    return sipVH_QtCore_25(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQStringListModel::setData(const ::QModelIndex& a0, const ::QVariant& a1, int a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_setData);

    if (!sipMeth)
        return ::QStringListModel::setData(a0, a1, a2);

    extern bool sipVH_QtCore_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const ::QVariant&, int);

    return sipVH_QtCore_24(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

::QVariant sipQStringListModel::data(const ::QModelIndex& a0, int a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[27]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_data);

    if (!sipMeth)
        return ::QStringListModel::data(a0, a1);

    extern ::QVariant sipVH_QtCore_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int);

    return sipVH_QtCore_23(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1);
}

int sipQStringListModel::rowCount(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[28]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_rowCount);

    if (!sipMeth)
        return ::QStringListModel::rowCount(a0);

    extern int sipVH_QtCore_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtCore_21(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

::QModelIndex sipQStringListModel::sibling(int a0, int a1, const ::QModelIndex& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[29]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sibling);

    if (!sipMeth)
        return ::QStringListModel::sibling(a0, a1, a2);

    extern ::QModelIndex sipVH_QtCore_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtCore_19(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

::QModelIndex sipQStringListModel::index(int a0, int a1, const ::QModelIndex& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[30]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_index);

    if (!sipMeth)
        return ::QStringListModel::index(a0, a1, a2);

    extern ::QModelIndex sipVH_QtCore_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtCore_19(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQStringListModel::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QStringListModel::event(a0);

    extern bool sipVH_QtCore_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtCore_0(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

bool sipQStringListModel::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QStringListModel::eventFilter(a0, a1);

    extern bool sipVH_QtCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtCore_1(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0, a1);
}

void sipQStringListModel::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QStringListModel::timerEvent(a0);
        return;
    }

    extern void sipVH_QtCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtCore_2(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQStringListModel::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QStringListModel::childEvent(a0);
        return;
    }

    extern void sipVH_QtCore_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtCore_3(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQStringListModel::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QStringListModel::customEvent(a0);
        return;
    }

    extern void sipVH_QtCore_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtCore_4(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQStringListModel::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QStringListModel::connectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}

void sipQStringListModel::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QStringListModel::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtCore_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtCore_5(sipGILState, sipVEH_QtCore_PyQt5, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QStringListModel_rowCount, "rowCount(self, parent: QModelIndex = QModelIndex()) -> int");

extern "C" {static PyObject *meth_QStringListModel_rowCount(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStringListModel_rowCount(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex& a0def = QModelIndex();
        const ::QModelIndex* a0 = &a0def;
        const ::QStringListModel *sipCpp;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QStringListModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QStringListModel::rowCount(*a0) : sipCpp->rowCount(*a0));

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStringListModel, sipName_rowCount, doc_QStringListModel_rowCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStringListModel_data, "data(self, index: QModelIndex, role: int) -> Any");

extern "C" {static PyObject *meth_QStringListModel_data(PyObject *, PyObject *);}
static PyObject *meth_QStringListModel_data(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        int a1;
        const ::QStringListModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9i", &sipSelf, sipType_QStringListModel, &sipCpp, sipType_QModelIndex, &a0, &a1))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QStringListModel::data(*a0, a1) : sipCpp->data(*a0, a1)));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStringListModel, sipName_data, doc_QStringListModel_data);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStringListModel_setData, "setData(self, index: QModelIndex, value: Any, role: int = Qt.EditRole) -> bool");

extern "C" {static PyObject *meth_QStringListModel_setData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStringListModel_setData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QVariant* a1;
        int a1State = 0;
        int a2 = Qt::EditRole;
        ::QStringListModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9J1|i", &sipSelf, sipType_QStringListModel, &sipCpp, sipType_QModelIndex, &a0, sipType_QVariant, &a1, &a1State, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QStringListModel::setData(*a0, *a1, a2) : sipCpp->setData(*a0, *a1, a2));
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStringListModel, sipName_setData, doc_QStringListModel_setData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStringListModel_flags, "flags(self, index: QModelIndex) -> Qt.ItemFlags");

extern "C" {static PyObject *meth_QStringListModel_flags(PyObject *, PyObject *);}
static PyObject *meth_QStringListModel_flags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QStringListModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QStringListModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::Qt::ItemFlags*sipRes;

            sipRes = new ::Qt::ItemFlags((sipSelfWasArg ? sipCpp->::QStringListModel::flags(*a0) : sipCpp->flags(*a0)));

            return sipConvertFromNewType(sipRes, sipType_Qt_ItemFlags, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStringListModel, sipName_flags, doc_QStringListModel_flags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStringListModel_insertRows, "insertRows(self, row: int, count: int, parent: QModelIndex = QModelIndex()) -> bool");

extern "C" {static PyObject *meth_QStringListModel_insertRows(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStringListModel_insertRows(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        const ::QModelIndex& a2def = QModelIndex();
        const ::QModelIndex* a2 = &a2def;
        ::QStringListModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QStringListModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QStringListModel::insertRows(a0, a1, *a2) : sipCpp->insertRows(a0, a1, *a2));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStringListModel, sipName_insertRows, doc_QStringListModel_insertRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStringListModel_removeRows, "removeRows(self, row: int, count: int, parent: QModelIndex = QModelIndex()) -> bool");

extern "C" {static PyObject *meth_QStringListModel_removeRows(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStringListModel_removeRows(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        const ::QModelIndex& a2def = QModelIndex();
        const ::QModelIndex* a2 = &a2def;
        ::QStringListModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QStringListModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QStringListModel::removeRows(a0, a1, *a2) : sipCpp->removeRows(a0, a1, *a2));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStringListModel, sipName_removeRows, doc_QStringListModel_removeRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStringListModel_stringList, "stringList(self) -> list[str]");

extern "C" {static PyObject *meth_QStringListModel_stringList(PyObject *, PyObject *);}
static PyObject *meth_QStringListModel_stringList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringListModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStringListModel, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->stringList());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStringListModel, sipName_stringList, doc_QStringListModel_stringList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStringListModel_setStringList, "setStringList(self, strings: Iterable[Optional[str]])");

extern "C" {static PyObject *meth_QStringListModel_setStringList(PyObject *, PyObject *);}
static PyObject *meth_QStringListModel_setStringList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QStringListModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStringListModel, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setStringList(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStringListModel, sipName_setStringList, doc_QStringListModel_setStringList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStringListModel_sort, "sort(self, column: int, order: Qt.SortOrder = Qt.AscendingOrder)");

extern "C" {static PyObject *meth_QStringListModel_sort(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStringListModel_sort(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::Qt::SortOrder a1 = Qt::AscendingOrder;
        ::QStringListModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_order,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|E", &sipSelf, sipType_QStringListModel, &sipCpp, &a0, sipType_Qt_SortOrder, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QStringListModel::sort(a0, a1) : sipCpp->sort(a0, a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStringListModel, sipName_sort, doc_QStringListModel_sort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStringListModel_supportedDropActions, "supportedDropActions(self) -> Qt.DropActions");

extern "C" {static PyObject *meth_QStringListModel_supportedDropActions(PyObject *, PyObject *);}
static PyObject *meth_QStringListModel_supportedDropActions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QStringListModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStringListModel, &sipCpp))
        {
            ::Qt::DropActions*sipRes;

            sipRes = new ::Qt::DropActions((sipSelfWasArg ? sipCpp->::QStringListModel::supportedDropActions() : sipCpp->supportedDropActions()));

            return sipConvertFromNewType(sipRes, sipType_Qt_DropActions, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStringListModel, sipName_supportedDropActions, doc_QStringListModel_supportedDropActions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStringListModel_sibling, "sibling(self, row: int, column: int, idx: QModelIndex) -> QModelIndex");

extern "C" {static PyObject *meth_QStringListModel_sibling(PyObject *, PyObject *);}
static PyObject *meth_QStringListModel_sibling(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        const ::QModelIndex* a2;
        const ::QStringListModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiJ9", &sipSelf, sipType_QStringListModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex((sipSelfWasArg ? sipCpp->::QStringListModel::sibling(a0, a1, *a2) : sipCpp->sibling(a0, a1, *a2)));

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStringListModel, sipName_sibling, doc_QStringListModel_sibling);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStringListModel_moveRows, "moveRows(self, sourceParent: QModelIndex, sourceRow: int, count: int, destinationParent: QModelIndex, destinationChild: int) -> bool");

extern "C" {static PyObject *meth_QStringListModel_moveRows(PyObject *, PyObject *);}
static PyObject *meth_QStringListModel_moveRows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        int a1;
        int a2;
        const ::QModelIndex* a3;
        int a4;
        ::QStringListModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9iiJ9i", &sipSelf, sipType_QStringListModel, &sipCpp, sipType_QModelIndex, &a0, &a1, &a2, sipType_QModelIndex, &a3, &a4))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QStringListModel::moveRows(*a0, a1, a2, *a3, a4) : sipCpp->moveRows(*a0, a1, a2, *a3, a4));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStringListModel, sipName_moveRows, doc_QStringListModel_moveRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStringListModel_itemData, "itemData(self, index: QModelIndex) -> dict[int, Any]");

extern "C" {static PyObject *meth_QStringListModel_itemData(PyObject *, PyObject *);}
static PyObject *meth_QStringListModel_itemData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QStringListModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QStringListModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            QMap<int, ::QVariant>*sipRes;

            sipRes = new QMap<int, ::QVariant>((sipSelfWasArg ? sipCpp->::QStringListModel::itemData(*a0) : sipCpp->itemData(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QMap_1800_0100QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStringListModel, sipName_itemData, doc_QStringListModel_itemData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStringListModel_setItemData, "setItemData(self, index: QModelIndex, roles: dict[int, Any]) -> bool");

extern "C" {static PyObject *meth_QStringListModel_setItemData(PyObject *, PyObject *);}
static PyObject *meth_QStringListModel_setItemData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const QMap<int, ::QVariant>* a1;
        int a1State = 0;
        ::QStringListModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QStringListModel, &sipCpp, sipType_QModelIndex, &a0, sipType_QMap_1800_0100QVariant, &a1, &a1State))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QStringListModel::setItemData(*a0, *a1) : sipCpp->setItemData(*a0, *a1));
            sipReleaseType(const_cast<QMap<int, ::QVariant> *>(a1), sipType_QMap_1800_0100QVariant, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStringListModel, sipName_setItemData, doc_QStringListModel_setItemData);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QStringListModel(void *, const sipTypeDef *);}
static void *cast_QStringListModel(void *sipCppV, const sipTypeDef *targetType)
{
    ::QStringListModel *sipCpp = reinterpret_cast< ::QStringListModel *>(sipCppV);

    if (targetType == sipType_QStringListModel)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QAbstractListModel)->ctd_cast(static_cast< ::QAbstractListModel *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QStringListModel(void *, int);}
static void release_QStringListModel(void *sipCppV, int)
{
    ::QStringListModel *sipCpp = reinterpret_cast< ::QStringListModel *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QStringListModel(Py_ssize_t);}
static void *array_QStringListModel(Py_ssize_t sipNrElem)
{
    return new ::QStringListModel[sipNrElem];
}


extern "C" {static void array_delete_QStringListModel(void *);}
static void array_delete_QStringListModel(void *sipCpp)
{
    delete[] reinterpret_cast< ::QStringListModel *>(sipCpp);
}


extern "C" {static void dealloc_QStringListModel(sipSimpleWrapper *);}
static void dealloc_QStringListModel(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQStringListModel *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QStringListModel(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QStringListModel(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QStringListModel(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQStringListModel *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQStringListModel(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QStringList, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQStringListModel(*a0, a1);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QStringListModel[] = {{10, 255, 1}};


static PyMethodDef methods_QStringListModel[] = {
    {sipName_data, meth_QStringListModel_data, METH_VARARGS, doc_QStringListModel_data},
    {sipName_flags, meth_QStringListModel_flags, METH_VARARGS, doc_QStringListModel_flags},
    {sipName_insertRows, SIP_MLMETH_CAST(meth_QStringListModel_insertRows), METH_VARARGS|METH_KEYWORDS, doc_QStringListModel_insertRows},
    {sipName_itemData, meth_QStringListModel_itemData, METH_VARARGS, doc_QStringListModel_itemData},
    {sipName_moveRows, meth_QStringListModel_moveRows, METH_VARARGS, doc_QStringListModel_moveRows},
    {sipName_removeRows, SIP_MLMETH_CAST(meth_QStringListModel_removeRows), METH_VARARGS|METH_KEYWORDS, doc_QStringListModel_removeRows},
    {sipName_rowCount, SIP_MLMETH_CAST(meth_QStringListModel_rowCount), METH_VARARGS|METH_KEYWORDS, doc_QStringListModel_rowCount},
    {sipName_setData, SIP_MLMETH_CAST(meth_QStringListModel_setData), METH_VARARGS|METH_KEYWORDS, doc_QStringListModel_setData},
    {sipName_setItemData, meth_QStringListModel_setItemData, METH_VARARGS, doc_QStringListModel_setItemData},
    {sipName_setStringList, meth_QStringListModel_setStringList, METH_VARARGS, doc_QStringListModel_setStringList},
    {sipName_sibling, meth_QStringListModel_sibling, METH_VARARGS, doc_QStringListModel_sibling},
    {sipName_sort, SIP_MLMETH_CAST(meth_QStringListModel_sort), METH_VARARGS|METH_KEYWORDS, doc_QStringListModel_sort},
    {sipName_stringList, meth_QStringListModel_stringList, METH_VARARGS, doc_QStringListModel_stringList},
    {sipName_supportedDropActions, meth_QStringListModel_supportedDropActions, METH_VARARGS, doc_QStringListModel_supportedDropActions}
};

PyDoc_STRVAR(doc_QStringListModel, "\1QStringListModel(parent: Optional[QObject] = None)\n"
"QStringListModel(strings: Iterable[Optional[str]], parent: Optional[QObject] = None)");


static pyqt5ClassPluginDef plugin_QStringListModel = {
    &::QStringListModel::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QStringListModel = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QStringListModel,
        SIP_NULLPTR,
        &plugin_QStringListModel,
    },
    {
        sipNameNr_QStringListModel,
        {0, 0, 1},
        14, methods_QStringListModel,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QStringListModel,
    -1,
    -1,
    supers_QStringListModel,
    SIP_NULLPTR,
    init_type_QStringListModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QStringListModel,
    SIP_NULLPTR,
    array_QStringListModel,
    SIP_NULLPTR,
    release_QStringListModel,
    cast_QStringListModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QStringListModel,
    sizeof (::QStringListModel),
};
