/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeocodereply.sip"
#include <qgeocodereply.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeolocation.sip"
#include <qgeolocation.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeoshape.sip"
#include <qgeoshape.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodeReply.cpp"


class sipQGeoCodeReply : public ::QGeoCodeReply
{
public:
    sipQGeoCodeReply(::QGeoCodeReply::Error, const ::QString&, ::QObject*);
    sipQGeoCodeReply(::QObject*);
    virtual ~sipQGeoCodeReply();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void abort() SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQGeoCodeReply(const sipQGeoCodeReply &);
    sipQGeoCodeReply &operator = (const sipQGeoCodeReply &);

    char sipPyMethods[8];
};

sipQGeoCodeReply::sipQGeoCodeReply(::QGeoCodeReply::Error a0, const ::QString& a1, ::QObject*a2): ::QGeoCodeReply(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGeoCodeReply::sipQGeoCodeReply(::QObject*a0): ::QGeoCodeReply(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGeoCodeReply::~sipQGeoCodeReply()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQGeoCodeReply::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtLocation_qt_metaobject(sipPySelf, sipType_QGeoCodeReply);

    return ::QGeoCodeReply::metaObject();
}

int sipQGeoCodeReply::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QGeoCodeReply::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtLocation_qt_metacall(sipPySelf, sipType_QGeoCodeReply, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQGeoCodeReply::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtLocation_qt_metacast(sipPySelf, sipType_QGeoCodeReply, _clname, &sipCpp) ? sipCpp : ::QGeoCodeReply::qt_metacast(_clname));
}

void sipQGeoCodeReply::abort()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_abort);

    if (!sipMeth)
    {
        ::QGeoCodeReply::abort();
        return;
    }

    extern void sipVH_QtLocation_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtLocation_6(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQGeoCodeReply::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QGeoCodeReply::event(a0);

    extern bool sipVH_QtLocation_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtLocation_5(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGeoCodeReply::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QGeoCodeReply::eventFilter(a0, a1);

    extern bool sipVH_QtLocation_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtLocation_4(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGeoCodeReply::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QGeoCodeReply::timerEvent(a0);
        return;
    }

    extern void sipVH_QtLocation_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtLocation_3(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoCodeReply::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QGeoCodeReply::childEvent(a0);
        return;
    }

    extern void sipVH_QtLocation_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtLocation_2(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoCodeReply::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QGeoCodeReply::customEvent(a0);
        return;
    }

    extern void sipVH_QtLocation_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtLocation_1(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoCodeReply::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QGeoCodeReply::connectNotify(a0);
        return;
    }

    extern void sipVH_QtLocation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtLocation_0(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoCodeReply::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QGeoCodeReply::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtLocation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtLocation_0(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QGeoCodeReply_isFinished, "isFinished(self) -> bool");

extern "C" {static PyObject *meth_QGeoCodeReply_isFinished(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodeReply_isFinished(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCodeReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoCodeReply, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isFinished();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_isFinished, doc_QGeoCodeReply_isFinished);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodeReply_error, "error(self) -> QGeoCodeReply.Error");

extern "C" {static PyObject *meth_QGeoCodeReply_error(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QGeoCodeReply_error(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCodeReply *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "B", &sipSelf, sipType_QGeoCodeReply, &sipCpp))
        {
            ::QGeoCodeReply::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoCodeReply_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_error, doc_QGeoCodeReply_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodeReply_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QGeoCodeReply_errorString(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodeReply_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCodeReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoCodeReply, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_errorString, doc_QGeoCodeReply_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodeReply_viewport, "viewport(self) -> QGeoShape");

extern "C" {static PyObject *meth_QGeoCodeReply_viewport(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodeReply_viewport(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCodeReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoCodeReply, &sipCpp))
        {
            ::QGeoShape*sipRes;

            sipRes = new ::QGeoShape(sipCpp->viewport());

            return sipConvertFromNewType(sipRes, sipType_QGeoShape, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_viewport, doc_QGeoCodeReply_viewport);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodeReply_locations, "locations(self) -> list[QGeoLocation]");

extern "C" {static PyObject *meth_QGeoCodeReply_locations(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodeReply_locations(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCodeReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoCodeReply, &sipCpp))
        {
            QList< ::QGeoLocation>*sipRes;

            sipRes = new QList< ::QGeoLocation>(sipCpp->locations());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QGeoLocation, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_locations, doc_QGeoCodeReply_locations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodeReply_limit, "limit(self) -> int");

extern "C" {static PyObject *meth_QGeoCodeReply_limit(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodeReply_limit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCodeReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoCodeReply, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->limit();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_limit, doc_QGeoCodeReply_limit);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodeReply_offset, "offset(self) -> int");

extern "C" {static PyObject *meth_QGeoCodeReply_offset(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodeReply_offset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCodeReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoCodeReply, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->offset();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_offset, doc_QGeoCodeReply_offset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodeReply_abort, "abort(self)");

extern "C" {static PyObject *meth_QGeoCodeReply_abort(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodeReply_abort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QGeoCodeReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoCodeReply, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QGeoCodeReply::abort() : sipCpp->abort());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_abort, doc_QGeoCodeReply_abort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodeReply_setError, "setError(self, error: QGeoCodeReply.Error, errorString: Optional[str])");

extern "C" {static PyObject *meth_QGeoCodeReply_setError(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodeReply_setError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoCodeReply::Error a0;
        const ::QString* a1;
        int a1State = 0;
        ::QGeoCodeReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pEJ1", &sipSelf, sipType_QGeoCodeReply, &sipCpp, sipType_QGeoCodeReply_Error, &a0, sipType_QString, &a1, &a1State))
        {
            sipCpp->setError(a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_setError, doc_QGeoCodeReply_setError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodeReply_setFinished, "setFinished(self, finished: bool)");

extern "C" {static PyObject *meth_QGeoCodeReply_setFinished(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodeReply_setFinished(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QGeoCodeReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pb", &sipSelf, sipType_QGeoCodeReply, &sipCpp, &a0))
        {
            sipCpp->setFinished(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_setFinished, doc_QGeoCodeReply_setFinished);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodeReply_setViewport, "setViewport(self, viewport: QGeoShape)");

extern "C" {static PyObject *meth_QGeoCodeReply_setViewport(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodeReply_setViewport(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoShape* a0;
        ::QGeoCodeReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QGeoCodeReply, &sipCpp, sipType_QGeoShape, &a0))
        {
            sipCpp->setViewport(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_setViewport, doc_QGeoCodeReply_setViewport);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodeReply_addLocation, "addLocation(self, location: QGeoLocation)");

extern "C" {static PyObject *meth_QGeoCodeReply_addLocation(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodeReply_addLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoLocation* a0;
        ::QGeoCodeReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QGeoCodeReply, &sipCpp, sipType_QGeoLocation, &a0))
        {
            sipCpp->addLocation(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_addLocation, doc_QGeoCodeReply_addLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodeReply_setLocations, "setLocations(self, locations: Iterable[QGeoLocation])");

extern "C" {static PyObject *meth_QGeoCodeReply_setLocations(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodeReply_setLocations(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QGeoLocation>* a0;
        int a0State = 0;
        ::QGeoCodeReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QGeoCodeReply, &sipCpp, sipType_QList_0100QGeoLocation, &a0, &a0State))
        {
            sipCpp->setLocations(*a0);
            sipReleaseType(const_cast<QList< ::QGeoLocation> *>(a0), sipType_QList_0100QGeoLocation, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_setLocations, doc_QGeoCodeReply_setLocations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodeReply_setLimit, "setLimit(self, limit: int)");

extern "C" {static PyObject *meth_QGeoCodeReply_setLimit(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodeReply_setLimit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QGeoCodeReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pi", &sipSelf, sipType_QGeoCodeReply, &sipCpp, &a0))
        {
            sipCpp->setLimit(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_setLimit, doc_QGeoCodeReply_setLimit);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodeReply_setOffset, "setOffset(self, offset: int)");

extern "C" {static PyObject *meth_QGeoCodeReply_setOffset(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodeReply_setOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QGeoCodeReply *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pi", &sipSelf, sipType_QGeoCodeReply, &sipCpp, &a0))
        {
            sipCpp->setOffset(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_setOffset, doc_QGeoCodeReply_setOffset);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGeoCodeReply(void *, const sipTypeDef *);}
static void *cast_QGeoCodeReply(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGeoCodeReply *sipCpp = reinterpret_cast< ::QGeoCodeReply *>(sipCppV);

    if (targetType == sipType_QGeoCodeReply)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoCodeReply(void *, int);}
static void release_QGeoCodeReply(void *sipCppV, int)
{
    ::QGeoCodeReply *sipCpp = reinterpret_cast< ::QGeoCodeReply *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QGeoCodeReply(Py_ssize_t);}
static void *array_QGeoCodeReply(Py_ssize_t sipNrElem)
{
    return new ::QGeoCodeReply[sipNrElem];
}


extern "C" {static void array_delete_QGeoCodeReply(void *);}
static void array_delete_QGeoCodeReply(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGeoCodeReply *>(sipCpp);
}


extern "C" {static void dealloc_QGeoCodeReply(sipSimpleWrapper *);}
static void dealloc_QGeoCodeReply(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQGeoCodeReply *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoCodeReply(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QGeoCodeReply(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoCodeReply(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQGeoCodeReply *sipCpp = SIP_NULLPTR;

    {
        ::QGeoCodeReply::Error a0;
        const ::QString* a1;
        int a1State = 0;
        ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "EJ1|JH", sipType_QGeoCodeReply_Error, &a0, sipType_QString, &a1, &a1State, sipType_QObject, &a2, sipOwner))
        {
            sipCpp = new sipQGeoCodeReply(a0, *a1, a2);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQGeoCodeReply(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGeoCodeReply[] = {{7, 0, 1}};


static PyMethodDef methods_QGeoCodeReply[] = {
    {sipName_abort, meth_QGeoCodeReply_abort, METH_VARARGS, doc_QGeoCodeReply_abort},
    {sipName_addLocation, meth_QGeoCodeReply_addLocation, METH_VARARGS, doc_QGeoCodeReply_addLocation},
    {sipName_error, SIP_MLMETH_CAST(meth_QGeoCodeReply_error), METH_VARARGS|METH_KEYWORDS, doc_QGeoCodeReply_error},
    {sipName_errorString, meth_QGeoCodeReply_errorString, METH_VARARGS, doc_QGeoCodeReply_errorString},
    {sipName_isFinished, meth_QGeoCodeReply_isFinished, METH_VARARGS, doc_QGeoCodeReply_isFinished},
    {sipName_limit, meth_QGeoCodeReply_limit, METH_VARARGS, doc_QGeoCodeReply_limit},
    {sipName_locations, meth_QGeoCodeReply_locations, METH_VARARGS, doc_QGeoCodeReply_locations},
    {sipName_offset, meth_QGeoCodeReply_offset, METH_VARARGS, doc_QGeoCodeReply_offset},
    {sipName_setError, meth_QGeoCodeReply_setError, METH_VARARGS, doc_QGeoCodeReply_setError},
    {sipName_setFinished, meth_QGeoCodeReply_setFinished, METH_VARARGS, doc_QGeoCodeReply_setFinished},
    {sipName_setLimit, meth_QGeoCodeReply_setLimit, METH_VARARGS, doc_QGeoCodeReply_setLimit},
    {sipName_setLocations, meth_QGeoCodeReply_setLocations, METH_VARARGS, doc_QGeoCodeReply_setLocations},
    {sipName_setOffset, meth_QGeoCodeReply_setOffset, METH_VARARGS, doc_QGeoCodeReply_setOffset},
    {sipName_setViewport, meth_QGeoCodeReply_setViewport, METH_VARARGS, doc_QGeoCodeReply_setViewport},
    {sipName_viewport, meth_QGeoCodeReply_viewport, METH_VARARGS, doc_QGeoCodeReply_viewport}
};

static sipEnumMemberDef enummembers_QGeoCodeReply[] = {
    {sipName_CombinationError, static_cast<int>(::QGeoCodeReply::CombinationError), 1},
    {sipName_CommunicationError, static_cast<int>(::QGeoCodeReply::CommunicationError), 1},
    {sipName_EngineNotSetError, static_cast<int>(::QGeoCodeReply::EngineNotSetError), 1},
    {sipName_NoError, static_cast<int>(::QGeoCodeReply::NoError), 1},
    {sipName_ParseError, static_cast<int>(::QGeoCodeReply::ParseError), 1},
    {sipName_UnknownError, static_cast<int>(::QGeoCodeReply::UnknownError), 1},
    {sipName_UnsupportedOptionError, static_cast<int>(::QGeoCodeReply::UnsupportedOptionError), 1},
};

PyDoc_STRVAR(doc_QGeoCodeReply, "\1QGeoCodeReply(error: QGeoCodeReply.Error, errorString: Optional[str], parent: Optional[QObject] = None)\n"
"QGeoCodeReply(parent: Optional[QObject] = None)");


extern "C" {static int emit_QGeoCodeReply_error(void *, PyObject *);}

static int emit_QGeoCodeReply_error(void *sipCppV, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    ::QGeoCodeReply *sipCpp = reinterpret_cast< ::QGeoCodeReply *>(sipCppV);

    {
        ::QGeoCodeReply::Error a0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "E|J1", sipType_QGeoCodeReply_Error, &a0, sipType_QString, &a1, &a1State))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->error(a0, *a1);
            Py_END_ALLOW_THREADS

            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return 0;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodeReply, sipName_error, SIP_NULLPTR);

    return -1;
}


/* Define this type's signals. */
static const pyqt5QtSignal signals_QGeoCodeReply[] = {
    {"finished()", "\1finished(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"aborted()", "\1aborted(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QGeoCodeReply::Error,QString)", "\1error(self, error: QGeoCodeReply.Error, errorString: Optional[str] = '')", &methods_QGeoCodeReply[2], emit_QGeoCodeReply_error},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QGeoCodeReply = {
    &::QGeoCodeReply::staticMetaObject,
    0,
    signals_QGeoCodeReply,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QGeoCodeReply = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoCodeReply,
        SIP_NULLPTR,
        &plugin_QGeoCodeReply,
    },
    {
        sipNameNr_QGeoCodeReply,
        {0, 0, 1},
        15, methods_QGeoCodeReply,
        7, enummembers_QGeoCodeReply,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoCodeReply,
    -1,
    -1,
    supers_QGeoCodeReply,
    SIP_NULLPTR,
    init_type_QGeoCodeReply,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoCodeReply,
    SIP_NULLPTR,
    array_QGeoCodeReply,
    SIP_NULLPTR,
    release_QGeoCodeReply,
    cast_QGeoCodeReply,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGeoCodeReply,
    sizeof (::QGeoCodeReply),
};
