/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecontactdetail.sip"
#include <qplacecontactdetail.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceContactDetail.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceContactDetail.cpp"


class sipQPlaceContactDetail : public ::QPlaceContactDetail
{
public:
    sipQPlaceContactDetail();
    sipQPlaceContactDetail(const ::QPlaceContactDetail&);
    ~sipQPlaceContactDetail();

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPlaceContactDetail(const sipQPlaceContactDetail &);
    sipQPlaceContactDetail &operator = (const sipQPlaceContactDetail &);
};

sipQPlaceContactDetail::sipQPlaceContactDetail(): ::QPlaceContactDetail(), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceContactDetail::sipQPlaceContactDetail(const ::QPlaceContactDetail& a0): ::QPlaceContactDetail(a0), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceContactDetail::~sipQPlaceContactDetail()
{
    sipInstanceDestroyedEx(&sipPySelf);
}


PyDoc_STRVAR(doc_QPlaceContactDetail_label, "label(self) -> str");

extern "C" {static PyObject *meth_QPlaceContactDetail_label(PyObject *, PyObject *);}
static PyObject *meth_QPlaceContactDetail_label(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceContactDetail *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceContactDetail, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->label());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceContactDetail, sipName_label, doc_QPlaceContactDetail_label);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceContactDetail_setLabel, "setLabel(self, label: Optional[str])");

extern "C" {static PyObject *meth_QPlaceContactDetail_setLabel(PyObject *, PyObject *);}
static PyObject *meth_QPlaceContactDetail_setLabel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceContactDetail *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceContactDetail, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setLabel(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceContactDetail, sipName_setLabel, doc_QPlaceContactDetail_setLabel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceContactDetail_value, "value(self) -> str");

extern "C" {static PyObject *meth_QPlaceContactDetail_value(PyObject *, PyObject *);}
static PyObject *meth_QPlaceContactDetail_value(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceContactDetail *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceContactDetail, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->value());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceContactDetail, sipName_value, doc_QPlaceContactDetail_value);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceContactDetail_setValue, "setValue(self, value: Optional[str])");

extern "C" {static PyObject *meth_QPlaceContactDetail_setValue(PyObject *, PyObject *);}
static PyObject *meth_QPlaceContactDetail_setValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceContactDetail *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceContactDetail, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setValue(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceContactDetail, sipName_setValue, doc_QPlaceContactDetail_setValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceContactDetail_clear, "clear(self)");

extern "C" {static PyObject *meth_QPlaceContactDetail_clear(PyObject *, PyObject *);}
static PyObject *meth_QPlaceContactDetail_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPlaceContactDetail *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceContactDetail, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceContactDetail, sipName_clear, doc_QPlaceContactDetail_clear);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QPlaceContactDetail___ne__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceContactDetail___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceContactDetail *sipCpp = reinterpret_cast< ::QPlaceContactDetail *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceContactDetail));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceContactDetail* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceContactDetail, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceContactDetail::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, ne_slot, sipType_QPlaceContactDetail, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QPlaceContactDetail___eq__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceContactDetail___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceContactDetail *sipCpp = reinterpret_cast< ::QPlaceContactDetail *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceContactDetail));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceContactDetail* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceContactDetail, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceContactDetail::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, eq_slot, sipType_QPlaceContactDetail, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QPlaceContactDetail(void *, int);}
static void release_QPlaceContactDetail(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQPlaceContactDetail *>(sipCppV);
    else
        delete reinterpret_cast< ::QPlaceContactDetail *>(sipCppV);
}


extern "C" {static void *array_QPlaceContactDetail(Py_ssize_t);}
static void *array_QPlaceContactDetail(Py_ssize_t sipNrElem)
{
    return new ::QPlaceContactDetail[sipNrElem];
}


extern "C" {static void array_delete_QPlaceContactDetail(void *);}
static void array_delete_QPlaceContactDetail(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPlaceContactDetail *>(sipCpp);
}


extern "C" {static void assign_QPlaceContactDetail(void *, Py_ssize_t, void *);}
static void assign_QPlaceContactDetail(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPlaceContactDetail *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPlaceContactDetail *>(sipSrc);
}


extern "C" {static void *copy_QPlaceContactDetail(const void *, Py_ssize_t);}
static void *copy_QPlaceContactDetail(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPlaceContactDetail(reinterpret_cast<const ::QPlaceContactDetail *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPlaceContactDetail(sipSimpleWrapper *);}
static void dealloc_QPlaceContactDetail(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPlaceContactDetail *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPlaceContactDetail(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPlaceContactDetail(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPlaceContactDetail(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQPlaceContactDetail *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQPlaceContactDetail();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QPlaceContactDetail* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPlaceContactDetail, &a0))
        {
            sipCpp = new sipQPlaceContactDetail(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QPlaceContactDetail[] = {
    {(void *)slot_QPlaceContactDetail___ne__, ne_slot},
    {(void *)slot_QPlaceContactDetail___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QPlaceContactDetail[] = {
    {sipName_clear, meth_QPlaceContactDetail_clear, METH_VARARGS, doc_QPlaceContactDetail_clear},
    {sipName_label, meth_QPlaceContactDetail_label, METH_VARARGS, doc_QPlaceContactDetail_label},
    {sipName_setLabel, meth_QPlaceContactDetail_setLabel, METH_VARARGS, doc_QPlaceContactDetail_setLabel},
    {sipName_setValue, meth_QPlaceContactDetail_setValue, METH_VARARGS, doc_QPlaceContactDetail_setValue},
    {sipName_value, meth_QPlaceContactDetail_value, METH_VARARGS, doc_QPlaceContactDetail_value}
};


extern "C" {static PyObject *varget_QPlaceContactDetail_Email(void *, PyObject *, PyObject *);}
static PyObject *varget_QPlaceContactDetail_Email(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QPlaceContactDetail::Email);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QPlaceContactDetail_Fax(void *, PyObject *, PyObject *);}
static PyObject *varget_QPlaceContactDetail_Fax(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QPlaceContactDetail::Fax);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QPlaceContactDetail_Phone(void *, PyObject *, PyObject *);}
static PyObject *varget_QPlaceContactDetail_Phone(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QPlaceContactDetail::Phone);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QPlaceContactDetail_Website(void *, PyObject *, PyObject *);}
static PyObject *varget_QPlaceContactDetail_Website(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QPlaceContactDetail::Website);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}

sipVariableDef variables_QPlaceContactDetail[] = {
    {ClassVariable, sipName_Email, (PyMethodDef *)varget_QPlaceContactDetail_Email, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Fax, (PyMethodDef *)varget_QPlaceContactDetail_Fax, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Phone, (PyMethodDef *)varget_QPlaceContactDetail_Phone, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Website, (PyMethodDef *)varget_QPlaceContactDetail_Website, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QPlaceContactDetail, "\1QPlaceContactDetail()\n"
"QPlaceContactDetail(other: QPlaceContactDetail)");


static pyqt5ClassPluginDef plugin_QPlaceContactDetail = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QPlaceContactDetail = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPlaceContactDetail,
        SIP_NULLPTR,
        &plugin_QPlaceContactDetail,
    },
    {
        sipNameNr_QPlaceContactDetail,
        {0, 0, 1},
        5, methods_QPlaceContactDetail,
        0, SIP_NULLPTR,
        4, variables_QPlaceContactDetail,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPlaceContactDetail,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QPlaceContactDetail,
    init_type_QPlaceContactDetail,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPlaceContactDetail,
    assign_QPlaceContactDetail,
    array_QPlaceContactDetail,
    copy_QPlaceContactDetail,
    release_QPlaceContactDetail,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPlaceContactDetail,
    sizeof (::QPlaceContactDetail),
};
