/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerafeedbackcontrol.sip"
#include <qcamerafeedbackcontrol.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFeedbackControl.cpp"


class sipQCameraFeedbackControl : public ::QCameraFeedbackControl
{
public:
    sipQCameraFeedbackControl(::QObject*);
    virtual ~sipQCameraFeedbackControl();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool setEventFeedbackSound(::QCameraFeedbackControl::EventType, const ::QString&) SIP_OVERRIDE;
    void resetEventFeedback(::QCameraFeedbackControl::EventType) SIP_OVERRIDE;
    bool setEventFeedbackEnabled(::QCameraFeedbackControl::EventType, bool) SIP_OVERRIDE;
    bool isEventFeedbackEnabled(::QCameraFeedbackControl::EventType) const SIP_OVERRIDE;
    bool isEventFeedbackLocked(::QCameraFeedbackControl::EventType) const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQCameraFeedbackControl(const sipQCameraFeedbackControl &);
    sipQCameraFeedbackControl &operator = (const sipQCameraFeedbackControl &);

    char sipPyMethods[12];
};

sipQCameraFeedbackControl::sipQCameraFeedbackControl(::QObject*a0): ::QCameraFeedbackControl(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCameraFeedbackControl::~sipQCameraFeedbackControl()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQCameraFeedbackControl::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QCameraFeedbackControl);

    return ::QCameraFeedbackControl::metaObject();
}

int sipQCameraFeedbackControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QCameraFeedbackControl::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QCameraFeedbackControl, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQCameraFeedbackControl::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QCameraFeedbackControl, _clname, &sipCpp) ? sipCpp : ::QCameraFeedbackControl::qt_metacast(_clname));
}

bool sipQCameraFeedbackControl::setEventFeedbackSound(::QCameraFeedbackControl::EventType a0, const ::QString& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, sipName_QCameraFeedbackControl, sipName_setEventFeedbackSound);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_61(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCameraFeedbackControl::EventType, const ::QString&);

    return sipVH_QtMultimedia_61(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQCameraFeedbackControl::resetEventFeedback(::QCameraFeedbackControl::EventType a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, sipName_QCameraFeedbackControl, sipName_resetEventFeedback);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_60(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCameraFeedbackControl::EventType);

    sipVH_QtMultimedia_60(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCameraFeedbackControl::setEventFeedbackEnabled(::QCameraFeedbackControl::EventType a0, bool a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, sipName_QCameraFeedbackControl, sipName_setEventFeedbackEnabled);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCameraFeedbackControl::EventType, bool);

    return sipVH_QtMultimedia_59(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQCameraFeedbackControl::isEventFeedbackEnabled(::QCameraFeedbackControl::EventType a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraFeedbackControl, sipName_isEventFeedbackEnabled);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_58(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCameraFeedbackControl::EventType);

    return sipVH_QtMultimedia_58(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCameraFeedbackControl::isEventFeedbackLocked(::QCameraFeedbackControl::EventType a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QCameraFeedbackControl, sipName_isEventFeedbackLocked);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_58(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCameraFeedbackControl::EventType);

    return sipVH_QtMultimedia_58(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraFeedbackControl::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QCameraFeedbackControl::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraFeedbackControl::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QCameraFeedbackControl::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraFeedbackControl::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QCameraFeedbackControl::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraFeedbackControl::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QCameraFeedbackControl::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraFeedbackControl::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QCameraFeedbackControl::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCameraFeedbackControl::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QCameraFeedbackControl::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQCameraFeedbackControl::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QCameraFeedbackControl::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QCameraFeedbackControl_isEventFeedbackLocked, "isEventFeedbackLocked(self, a0: QCameraFeedbackControl.EventType) -> bool");

extern "C" {static PyObject *meth_QCameraFeedbackControl_isEventFeedbackLocked(PyObject *, PyObject *);}
static PyObject *meth_QCameraFeedbackControl_isEventFeedbackLocked(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCameraFeedbackControl::EventType a0;
        const ::QCameraFeedbackControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraFeedbackControl, &sipCpp, sipType_QCameraFeedbackControl_EventType, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraFeedbackControl, sipName_isEventFeedbackLocked);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isEventFeedbackLocked(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFeedbackControl, sipName_isEventFeedbackLocked, doc_QCameraFeedbackControl_isEventFeedbackLocked);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFeedbackControl_isEventFeedbackEnabled, "isEventFeedbackEnabled(self, a0: QCameraFeedbackControl.EventType) -> bool");

extern "C" {static PyObject *meth_QCameraFeedbackControl_isEventFeedbackEnabled(PyObject *, PyObject *);}
static PyObject *meth_QCameraFeedbackControl_isEventFeedbackEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCameraFeedbackControl::EventType a0;
        const ::QCameraFeedbackControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraFeedbackControl, &sipCpp, sipType_QCameraFeedbackControl_EventType, &a0))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraFeedbackControl, sipName_isEventFeedbackEnabled);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isEventFeedbackEnabled(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFeedbackControl, sipName_isEventFeedbackEnabled, doc_QCameraFeedbackControl_isEventFeedbackEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFeedbackControl_setEventFeedbackEnabled, "setEventFeedbackEnabled(self, a0: QCameraFeedbackControl.EventType, a1: bool) -> bool");

extern "C" {static PyObject *meth_QCameraFeedbackControl_setEventFeedbackEnabled(PyObject *, PyObject *);}
static PyObject *meth_QCameraFeedbackControl_setEventFeedbackEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCameraFeedbackControl::EventType a0;
        bool a1;
        ::QCameraFeedbackControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEb", &sipSelf, sipType_QCameraFeedbackControl, &sipCpp, sipType_QCameraFeedbackControl_EventType, &a0, &a1))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraFeedbackControl, sipName_setEventFeedbackEnabled);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->setEventFeedbackEnabled(a0, a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFeedbackControl, sipName_setEventFeedbackEnabled, doc_QCameraFeedbackControl_setEventFeedbackEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFeedbackControl_resetEventFeedback, "resetEventFeedback(self, a0: QCameraFeedbackControl.EventType)");

extern "C" {static PyObject *meth_QCameraFeedbackControl_resetEventFeedback(PyObject *, PyObject *);}
static PyObject *meth_QCameraFeedbackControl_resetEventFeedback(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCameraFeedbackControl::EventType a0;
        ::QCameraFeedbackControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraFeedbackControl, &sipCpp, sipType_QCameraFeedbackControl_EventType, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraFeedbackControl, sipName_resetEventFeedback);
                return SIP_NULLPTR;
            }

            sipCpp->resetEventFeedback(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFeedbackControl, sipName_resetEventFeedback, doc_QCameraFeedbackControl_resetEventFeedback);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFeedbackControl_setEventFeedbackSound, "setEventFeedbackSound(self, a0: QCameraFeedbackControl.EventType, filePath: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QCameraFeedbackControl_setEventFeedbackSound(PyObject *, PyObject *);}
static PyObject *meth_QCameraFeedbackControl_setEventFeedbackSound(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QCameraFeedbackControl::EventType a0;
        const ::QString* a1;
        int a1State = 0;
        ::QCameraFeedbackControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ1", &sipSelf, sipType_QCameraFeedbackControl, &sipCpp, sipType_QCameraFeedbackControl_EventType, &a0, sipType_QString, &a1, &a1State))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QCameraFeedbackControl, sipName_setEventFeedbackSound);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->setEventFeedbackSound(a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFeedbackControl, sipName_setEventFeedbackSound, doc_QCameraFeedbackControl_setEventFeedbackSound);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QCameraFeedbackControl(void *, const sipTypeDef *);}
static void *cast_QCameraFeedbackControl(void *sipCppV, const sipTypeDef *targetType)
{
    ::QCameraFeedbackControl *sipCpp = reinterpret_cast< ::QCameraFeedbackControl *>(sipCppV);

    if (targetType == sipType_QCameraFeedbackControl)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaControl)->ctd_cast(static_cast< ::QMediaControl *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QCameraFeedbackControl(void *, int);}
static void release_QCameraFeedbackControl(void *sipCppV, int)
{
    ::QCameraFeedbackControl *sipCpp = reinterpret_cast< ::QCameraFeedbackControl *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QCameraFeedbackControl(sipSimpleWrapper *);}
static void dealloc_QCameraFeedbackControl(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQCameraFeedbackControl *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QCameraFeedbackControl(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QCameraFeedbackControl(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QCameraFeedbackControl(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQCameraFeedbackControl *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQCameraFeedbackControl(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QCameraFeedbackControl[] = {{104, 255, 1}};


static PyMethodDef methods_QCameraFeedbackControl[] = {
    {sipName_isEventFeedbackEnabled, meth_QCameraFeedbackControl_isEventFeedbackEnabled, METH_VARARGS, doc_QCameraFeedbackControl_isEventFeedbackEnabled},
    {sipName_isEventFeedbackLocked, meth_QCameraFeedbackControl_isEventFeedbackLocked, METH_VARARGS, doc_QCameraFeedbackControl_isEventFeedbackLocked},
    {sipName_resetEventFeedback, meth_QCameraFeedbackControl_resetEventFeedback, METH_VARARGS, doc_QCameraFeedbackControl_resetEventFeedback},
    {sipName_setEventFeedbackEnabled, meth_QCameraFeedbackControl_setEventFeedbackEnabled, METH_VARARGS, doc_QCameraFeedbackControl_setEventFeedbackEnabled},
    {sipName_setEventFeedbackSound, meth_QCameraFeedbackControl_setEventFeedbackSound, METH_VARARGS, doc_QCameraFeedbackControl_setEventFeedbackSound}
};

static sipEnumMemberDef enummembers_QCameraFeedbackControl[] = {
    {sipName_AutoFocusFailed, static_cast<int>(::QCameraFeedbackControl::AutoFocusFailed), 54},
    {sipName_AutoFocusInProgress, static_cast<int>(::QCameraFeedbackControl::AutoFocusInProgress), 54},
    {sipName_AutoFocusLocked, static_cast<int>(::QCameraFeedbackControl::AutoFocusLocked), 54},
    {sipName_ImageCaptured, static_cast<int>(::QCameraFeedbackControl::ImageCaptured), 54},
    {sipName_ImageError, static_cast<int>(::QCameraFeedbackControl::ImageError), 54},
    {sipName_ImageSaved, static_cast<int>(::QCameraFeedbackControl::ImageSaved), 54},
    {sipName_RecordingInProgress, static_cast<int>(::QCameraFeedbackControl::RecordingInProgress), 54},
    {sipName_RecordingStarted, static_cast<int>(::QCameraFeedbackControl::RecordingStarted), 54},
    {sipName_RecordingStopped, static_cast<int>(::QCameraFeedbackControl::RecordingStopped), 54},
    {sipName_ViewfinderStarted, static_cast<int>(::QCameraFeedbackControl::ViewfinderStarted), 54},
    {sipName_ViewfinderStopped, static_cast<int>(::QCameraFeedbackControl::ViewfinderStopped), 54},
};

PyDoc_STRVAR(doc_QCameraFeedbackControl, "\1QCameraFeedbackControl(parent: Optional[QObject] = None)");


static pyqt5ClassPluginDef plugin_QCameraFeedbackControl = {
    &::QCameraFeedbackControl::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QCameraFeedbackControl = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCameraFeedbackControl,
        SIP_NULLPTR,
        &plugin_QCameraFeedbackControl,
    },
    {
        sipNameNr_QCameraFeedbackControl,
        {0, 0, 1},
        5, methods_QCameraFeedbackControl,
        11, enummembers_QCameraFeedbackControl,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QCameraFeedbackControl,
    -1,
    -1,
    supers_QCameraFeedbackControl,
    SIP_NULLPTR,
    init_type_QCameraFeedbackControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QCameraFeedbackControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QCameraFeedbackControl,
    cast_QCameraFeedbackControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QCameraFeedbackControl),
};
