/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKitWidgets.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebview.sip"
#include <qwebview.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 509 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 384 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 570 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 592 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 619 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 608 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 363 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 253 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 482 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 205 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 398 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 425 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qprinter.sip"
#include <qprinter.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 99 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 102 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 105 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 108 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebsettings.sip"
#include <qwebsettings.h>
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebhistory.sip"
#include <qwebhistory.h>
#line 114 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 117 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qnetworkrequest.sip"
#include <qnetworkrequest.h>
#line 120 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qnetworkaccessmanager.sip"
#include <qnetworkaccessmanager.h>
#line 123 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 126 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 129 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 132 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 135 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 138 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 141 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 144 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 147 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 150 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 153 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 156 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 159 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 162 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 165 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 168 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 171 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 174 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 177 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 180 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 471 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 183 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 460 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 186 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 675 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 189 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 302 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 192 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 438 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 412 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 198 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 201 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 204 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 207 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 210 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 213 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 216 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 219 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 222 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 225 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 228 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 233 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 236 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 239 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 242 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 245 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 248 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 251 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 254 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 257 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 260 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 263 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 266 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebView.cpp"


class sipQWebView : public ::QWebView
{
public:
    sipQWebView(::QWidget*);
    virtual ~sipQWebView();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QWebView* createWindow(::QWebPage::WebWindowType) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void enterEvent(::QEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, long*) SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    void initPainter(::QPainter*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQWebView(const sipQWebView &);
    sipQWebView &operator = (const sipQWebView &);

    char sipPyMethods[47];
};

sipQWebView::sipQWebView(::QWidget*a0): ::QWebView(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQWebView::~sipQWebView()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQWebView::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWebKitWidgets_qt_metaobject(sipPySelf, sipType_QWebView);

    return ::QWebView::metaObject();
}

int sipQWebView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QWebView::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWebKitWidgets_qt_metacall(sipPySelf, sipType_QWebView, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQWebView::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWebKitWidgets_qt_metacast(sipPySelf, sipType_QWebView, _clname, &sipCpp) ? sipCpp : ::QWebView::qt_metacast(_clname));
}

::QWebView* sipQWebView::createWindow(::QWebPage::WebWindowType a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_createWindow);

    if (!sipMeth)
        return ::QWebView::createWindow(a0);

    extern ::QWebView* sipVH_QtWebKitWidgets_71(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWebPage::WebWindowType);

    return sipVH_QtWebKitWidgets_71(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QWebView::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebKitWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QWebView::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebKitWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QWebView::customEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebKitWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QWebView::childEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWebKitWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QWebView::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWebKitWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWebView::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QWebView::eventFilter(a0, a1);

    extern bool sipVH_QtWebKitWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWebKitWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQWebView::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QWebView::event(a0);

    extern bool sipVH_QtWebKitWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWebKitWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQWebView::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QWebView::metric(a0);

    extern int sipVH_QtWebKitWidgets_58(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtWebKitWidgets_58(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPaintEngine* sipQWebView::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QWebView::paintEngine();

    extern ::QPaintEngine* sipVH_QtWebKitWidgets_57(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWebKitWidgets_57(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQWebView::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QWebView::devType();

    extern int sipVH_QtWebKitWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWebKitWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQWebView::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QWebView::setVisible(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_56(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtWebKitWidgets_56(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQWebView::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QWebView::sizeHint();

    extern ::QSize sipVH_QtWebKitWidgets_55(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWebKitWidgets_55(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQWebView::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QWebView::minimumSizeHint();

    extern ::QSize sipVH_QtWebKitWidgets_55(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWebKitWidgets_55(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQWebView::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[14]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QWebView::heightForWidth(a0);

    extern int sipVH_QtWebKitWidgets_54(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWebKitWidgets_54(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QWebView::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_53(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWebKitWidgets_53(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QWebView::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_53(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWebKitWidgets_53(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QWebView::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_53(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWebKitWidgets_53(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QWebView::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_53(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWebKitWidgets_53(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QWebView::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_52(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtWebKitWidgets_52(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QWebView::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWebKitWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QWebView::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWebKitWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QWebView::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWebKitWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QWebView::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWebKitWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::enterEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QWebView::enterEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebKitWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QWebView::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebKitWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QWebView::paintEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_51(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtWebKitWidgets_51(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QWebView::moveEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_50(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtWebKitWidgets_50(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QWebView::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_49(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtWebKitWidgets_49(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QWebView::closeEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtWebKitWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QWebView::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtWebKitWidgets_48(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QWebView::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtWebKitWidgets_47(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QWebView::actionEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_46(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtWebKitWidgets_46(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QWebView::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_45(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtWebKitWidgets_45(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QWebView::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_44(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtWebKitWidgets_44(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QWebView::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_43(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtWebKitWidgets_43(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QWebView::dropEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_42(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtWebKitWidgets_42(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QWebView::showEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtWebKitWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[38], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QWebView::hideEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtWebKitWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QWebView::changeEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebKitWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebView::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QWebView::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtWebKitWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQWebView::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[41]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QWebView::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtWebKitWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtWebKitWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWebView::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[42], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QWebView::focusNextPrevChild(a0);

    extern bool sipVH_QtWebKitWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtWebKitWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWebView::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[43]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QWebView::hasHeightForWidth();

    extern bool sipVH_QtWebKitWidgets_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWebKitWidgets_41(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQWebView::nativeEvent(const ::QByteArray& a0, void*a1, long*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[44], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QWebView::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtWebKitWidgets_40(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, long*);

    return sipVH_QtWebKitWidgets_40(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPainter* sipQWebView::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[45]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QWebView::sharedPainter();

    extern ::QPainter* sipVH_QtWebKitWidgets_39(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWebKitWidgets_39(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQWebView::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[46]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QWebView::initPainter(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtWebKitWidgets_38(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QWebView_page, "page(self) -> Optional[QWebPage]");

extern "C" {static PyObject *meth_QWebView_page(PyObject *, PyObject *);}
static PyObject *meth_QWebView_page(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            ::QWebPage*sipRes;

            sipRes = sipCpp->page();

            return sipConvertFromType(sipRes, sipType_QWebPage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_page, doc_QWebView_page);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_setPage, "setPage(self, page: Optional[QWebPage])");

extern "C" {static PyObject *meth_QWebView_setPage(PyObject *, PyObject *);}
static PyObject *meth_QWebView_setPage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebPage* a0;
        PyObject *a0Keep;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QWebView, &sipCpp, &a0Keep, sipType_QWebPage, &a0))
        {
            sipCpp->setPage(a0);

            sipKeepReference(sipSelf, -6, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_setPage, doc_QWebView_setPage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_load, "load(self, url: QUrl)\n"
"load(self, request: QNetworkRequest, operation: QNetworkAccessManager.Operation = QNetworkAccessManager.GetOperation, body: Union[QByteArray, bytes, bytearray] = QByteArray())");

extern "C" {static PyObject *meth_QWebView_load(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebView_load(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QWebView *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ9", &sipSelf, sipType_QWebView, &sipCpp, sipType_QUrl, &a0))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->load(*a0);
            Py_END_ALLOW_THREADS

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QNetworkRequest* a0;
        ::QNetworkAccessManager::Operation a1 = QNetworkAccessManager::GetOperation;
        const ::QByteArray& a2def = QByteArray();
        const ::QByteArray* a2 = &a2def;
        int a2State = 0;
        ::QWebView *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_operation,
            sipName_body,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|EJ1", &sipSelf, sipType_QWebView, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QNetworkAccessManager_Operation, &a1, sipType_QByteArray, &a2, &a2State))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->load(*a0, a1, *a2);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QByteArray *>(a2), sipType_QByteArray, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_load, doc_QWebView_load);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_setHtml, "setHtml(self, html: Optional[str], baseUrl: QUrl = QUrl())");

extern "C" {static PyObject *meth_QWebView_setHtml(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebView_setHtml(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QUrl& a1def = QUrl();
        const ::QUrl* a1 = &a1def;
        ::QWebView *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_baseUrl,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J9", &sipSelf, sipType_QWebView, &sipCpp, sipType_QString, &a0, &a0State, sipType_QUrl, &a1))
        {
            sipCpp->setHtml(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_setHtml, doc_QWebView_setHtml);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_setContent, "setContent(self, data: Union[QByteArray, bytes, bytearray], mimeType: Optional[str] = '', baseUrl: QUrl = QUrl())");

extern "C" {static PyObject *meth_QWebView_setContent(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebView_setContent(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        const ::QUrl& a2def = QUrl();
        const ::QUrl* a2 = &a2def;
        ::QWebView *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mimeType,
            sipName_baseUrl,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1J9", &sipSelf, sipType_QWebView, &sipCpp, sipType_QByteArray, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QUrl, &a2))
        {
            sipCpp->setContent(*a0, *a1, *a2);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_setContent, doc_QWebView_setContent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_history, "history(self) -> Optional[QWebHistory]");

extern "C" {static PyObject *meth_QWebView_history(PyObject *, PyObject *);}
static PyObject *meth_QWebView_history(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            ::QWebHistory*sipRes;

            sipRes = sipCpp->history();

            return sipConvertFromType(sipRes, sipType_QWebHistory, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_history, doc_QWebView_history);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_settings, "settings(self) -> Optional[QWebSettings]");

extern "C" {static PyObject *meth_QWebView_settings(PyObject *, PyObject *);}
static PyObject *meth_QWebView_settings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            ::QWebSettings*sipRes;

            sipRes = sipCpp->settings();

            return sipConvertFromType(sipRes, sipType_QWebSettings, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_settings, doc_QWebView_settings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_title, "title(self) -> str");

extern "C" {static PyObject *meth_QWebView_title(PyObject *, PyObject *);}
static PyObject *meth_QWebView_title(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->title());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_title, doc_QWebView_title);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_setUrl, "setUrl(self, url: QUrl)");

extern "C" {static PyObject *meth_QWebView_setUrl(PyObject *, PyObject *);}
static PyObject *meth_QWebView_setUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebView, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setUrl(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_setUrl, doc_QWebView_setUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_url, "url(self) -> QUrl");

extern "C" {static PyObject *meth_QWebView_url(PyObject *, PyObject *);}
static PyObject *meth_QWebView_url(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->url());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_url, doc_QWebView_url);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_icon, "icon(self) -> QIcon");

extern "C" {static PyObject *meth_QWebView_icon(PyObject *, PyObject *);}
static PyObject *meth_QWebView_icon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            ::QIcon*sipRes;

            sipRes = new ::QIcon(sipCpp->icon());

            return sipConvertFromNewType(sipRes, sipType_QIcon, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_icon, doc_QWebView_icon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_selectedText, "selectedText(self) -> str");

extern "C" {static PyObject *meth_QWebView_selectedText(PyObject *, PyObject *);}
static PyObject *meth_QWebView_selectedText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->selectedText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_selectedText, doc_QWebView_selectedText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_pageAction, "pageAction(self, action: QWebPage.WebAction) -> Optional[QAction]");

extern "C" {static PyObject *meth_QWebView_pageAction(PyObject *, PyObject *);}
static PyObject *meth_QWebView_pageAction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebPage::WebAction a0;
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebView, &sipCpp, sipType_QWebPage_WebAction, &a0))
        {
            ::QAction*sipRes;

            sipRes = sipCpp->pageAction(a0);

            return sipConvertFromType(sipRes, sipType_QAction, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_pageAction, doc_QWebView_pageAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_triggerPageAction, "triggerPageAction(self, action: QWebPage.WebAction, checked: bool = False)");

extern "C" {static PyObject *meth_QWebView_triggerPageAction(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebView_triggerPageAction(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebPage::WebAction a0;
        bool a1 = 0;
        ::QWebView *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_checked,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|b", &sipSelf, sipType_QWebView, &sipCpp, sipType_QWebPage_WebAction, &a0, &a1))
        {
            sipCpp->triggerPageAction(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_triggerPageAction, doc_QWebView_triggerPageAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_isModified, "isModified(self) -> bool");

extern "C" {static PyObject *meth_QWebView_isModified(PyObject *, PyObject *);}
static PyObject *meth_QWebView_isModified(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isModified();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_isModified, doc_QWebView_isModified);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_inputMethodQuery, "inputMethodQuery(self, property: Qt.InputMethodQuery) -> Any");

extern "C" {static PyObject *meth_QWebView_inputMethodQuery(PyObject *, PyObject *);}
static PyObject *meth_QWebView_inputMethodQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::Qt::InputMethodQuery a0;
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebView, &sipCpp, sipType_Qt_InputMethodQuery, &a0))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QWebView::inputMethodQuery(a0) : sipCpp->inputMethodQuery(a0)));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_inputMethodQuery, doc_QWebView_inputMethodQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_sizeHint, "sizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QWebView_sizeHint(PyObject *, PyObject *);}
static PyObject *meth_QWebView_sizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QWebView::sizeHint() : sipCpp->sizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_sizeHint, doc_QWebView_sizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_findText, "findText(self, subString: Optional[str], options: QWebPage.FindFlags = 0) -> bool");

extern "C" {static PyObject *meth_QWebView_findText(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebView_findText(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebPage::FindFlags a1def = 0;
        ::QWebPage::FindFlags* a1 = &a1def;
        int a1State = 0;
        ::QWebView *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1", &sipSelf, sipType_QWebView, &sipCpp, sipType_QString, &a0, &a0State, sipType_QWebPage_FindFlags, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->findText(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(a1, sipType_QWebPage_FindFlags, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_findText, doc_QWebView_findText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_event, "event(self, a0: Optional[QEvent]) -> bool");

extern "C" {static PyObject *meth_QWebView_event(PyObject *, PyObject *);}
static PyObject *meth_QWebView_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWebView::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_event, doc_QWebView_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_stop, "stop(self)");

extern "C" {static PyObject *meth_QWebView_stop(PyObject *, PyObject *);}
static PyObject *meth_QWebView_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_stop, doc_QWebView_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_back, "back(self)");

extern "C" {static PyObject *meth_QWebView_back(PyObject *, PyObject *);}
static PyObject *meth_QWebView_back(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            sipCpp->back();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_back, doc_QWebView_back);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_forward, "forward(self)");

extern "C" {static PyObject *meth_QWebView_forward(PyObject *, PyObject *);}
static PyObject *meth_QWebView_forward(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            sipCpp->forward();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_forward, doc_QWebView_forward);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_reload, "reload(self)");

extern "C" {static PyObject *meth_QWebView_reload(PyObject *, PyObject *);}
static PyObject *meth_QWebView_reload(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            sipCpp->reload();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_reload, doc_QWebView_reload);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_print_, "print_(self, printer: Optional[QPrinter])");

extern "C" {static PyObject *meth_QWebView_print_(PyObject *, PyObject *);}
static PyObject *meth_QWebView_print_(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrinter* a0;
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QPrinter, &a0))
        {
            sipCpp->print(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_print_, doc_QWebView_print_);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_print, "print(self, printer: Optional[QPrinter])");

extern "C" {static PyObject *meth_QWebView_print(PyObject *, PyObject *);}
static PyObject *meth_QWebView_print(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPrinter* a0;
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QPrinter, &a0))
        {
            sipCpp->print(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_print, doc_QWebView_print);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_createWindow, "createWindow(self, type: QWebPage.WebWindowType) -> Optional[QWebView]");

extern "C" {static PyObject *meth_QWebView_createWindow(PyObject *, PyObject *);}
static PyObject *meth_QWebView_createWindow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWebPage::WebWindowType a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QWebView, &sipCpp, sipType_QWebPage_WebWindowType, &a0))
        {
            ::QWebView*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWebView::createWindow(a0) : sipCpp->createWindow(a0));

            return sipConvertFromType(sipRes, sipType_QWebView, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_createWindow, doc_QWebView_createWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_resizeEvent, "resizeEvent(self, e: Optional[QResizeEvent])");

extern "C" {static PyObject *meth_QWebView_resizeEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_resizeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QResizeEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QResizeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::resizeEvent(a0) : sipCpp->resizeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_resizeEvent, doc_QWebView_resizeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_paintEvent, "paintEvent(self, ev: Optional[QPaintEvent])");

extern "C" {static PyObject *meth_QWebView_paintEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_paintEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QPaintEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::paintEvent(a0) : sipCpp->paintEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_paintEvent, doc_QWebView_paintEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_changeEvent, "changeEvent(self, a0: Optional[QEvent])");

extern "C" {static PyObject *meth_QWebView_changeEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_changeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::changeEvent(a0) : sipCpp->changeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_changeEvent, doc_QWebView_changeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_mouseMoveEvent, "mouseMoveEvent(self, a0: Optional[QMouseEvent])");

extern "C" {static PyObject *meth_QWebView_mouseMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_mouseMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::mouseMoveEvent(a0) : sipCpp->mouseMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_mouseMoveEvent, doc_QWebView_mouseMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_mousePressEvent, "mousePressEvent(self, a0: Optional[QMouseEvent])");

extern "C" {static PyObject *meth_QWebView_mousePressEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_mousePressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::mousePressEvent(a0) : sipCpp->mousePressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_mousePressEvent, doc_QWebView_mousePressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_mouseDoubleClickEvent, "mouseDoubleClickEvent(self, a0: Optional[QMouseEvent])");

extern "C" {static PyObject *meth_QWebView_mouseDoubleClickEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_mouseDoubleClickEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::mouseDoubleClickEvent(a0) : sipCpp->mouseDoubleClickEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_mouseDoubleClickEvent, doc_QWebView_mouseDoubleClickEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_mouseReleaseEvent, "mouseReleaseEvent(self, a0: Optional[QMouseEvent])");

extern "C" {static PyObject *meth_QWebView_mouseReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_mouseReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::mouseReleaseEvent(a0) : sipCpp->mouseReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_mouseReleaseEvent, doc_QWebView_mouseReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_contextMenuEvent, "contextMenuEvent(self, a0: Optional[QContextMenuEvent])");

extern "C" {static PyObject *meth_QWebView_contextMenuEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_contextMenuEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QContextMenuEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QContextMenuEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::contextMenuEvent(a0) : sipCpp->contextMenuEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_contextMenuEvent, doc_QWebView_contextMenuEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_wheelEvent, "wheelEvent(self, a0: Optional[QWheelEvent])");

extern "C" {static PyObject *meth_QWebView_wheelEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_wheelEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWheelEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QWheelEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::wheelEvent(a0) : sipCpp->wheelEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_wheelEvent, doc_QWebView_wheelEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_keyPressEvent, "keyPressEvent(self, a0: Optional[QKeyEvent])");

extern "C" {static PyObject *meth_QWebView_keyPressEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_keyPressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QKeyEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::keyPressEvent(a0) : sipCpp->keyPressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_keyPressEvent, doc_QWebView_keyPressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_keyReleaseEvent, "keyReleaseEvent(self, a0: Optional[QKeyEvent])");

extern "C" {static PyObject *meth_QWebView_keyReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_keyReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QKeyEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::keyReleaseEvent(a0) : sipCpp->keyReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_keyReleaseEvent, doc_QWebView_keyReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_dragEnterEvent, "dragEnterEvent(self, a0: Optional[QDragEnterEvent])");

extern "C" {static PyObject *meth_QWebView_dragEnterEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_dragEnterEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QDragEnterEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QDragEnterEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::dragEnterEvent(a0) : sipCpp->dragEnterEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_dragEnterEvent, doc_QWebView_dragEnterEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_dragLeaveEvent, "dragLeaveEvent(self, a0: Optional[QDragLeaveEvent])");

extern "C" {static PyObject *meth_QWebView_dragLeaveEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_dragLeaveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QDragLeaveEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QDragLeaveEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::dragLeaveEvent(a0) : sipCpp->dragLeaveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_dragLeaveEvent, doc_QWebView_dragLeaveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_dragMoveEvent, "dragMoveEvent(self, a0: Optional[QDragMoveEvent])");

extern "C" {static PyObject *meth_QWebView_dragMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_dragMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QDragMoveEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QDragMoveEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::dragMoveEvent(a0) : sipCpp->dragMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_dragMoveEvent, doc_QWebView_dragMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_dropEvent, "dropEvent(self, a0: Optional[QDropEvent])");

extern "C" {static PyObject *meth_QWebView_dropEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_dropEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QDropEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QDropEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::dropEvent(a0) : sipCpp->dropEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_dropEvent, doc_QWebView_dropEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_focusInEvent, "focusInEvent(self, a0: Optional[QFocusEvent])");

extern "C" {static PyObject *meth_QWebView_focusInEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_focusInEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QFocusEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QFocusEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::focusInEvent(a0) : sipCpp->focusInEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_focusInEvent, doc_QWebView_focusInEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_focusOutEvent, "focusOutEvent(self, a0: Optional[QFocusEvent])");

extern "C" {static PyObject *meth_QWebView_focusOutEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_focusOutEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QFocusEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QFocusEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::focusOutEvent(a0) : sipCpp->focusOutEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_focusOutEvent, doc_QWebView_focusOutEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_inputMethodEvent, "inputMethodEvent(self, a0: Optional[QInputMethodEvent])");

extern "C" {static PyObject *meth_QWebView_inputMethodEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebView_inputMethodEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QInputMethodEvent* a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QWebView, &sipCpp, sipType_QInputMethodEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QWebView::inputMethodEvent(a0) : sipCpp->inputMethodEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_inputMethodEvent, doc_QWebView_inputMethodEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_focusNextPrevChild, "focusNextPrevChild(self, next: bool) -> bool");

extern "C" {static PyObject *meth_QWebView_focusNextPrevChild(PyObject *, PyObject *);}
static PyObject *meth_QWebView_focusNextPrevChild(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        bool a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pb", &sipSelf, sipType_QWebView, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWebView::focusNextPrevChild(a0) : sipCpp->focusNextPrevChild(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_focusNextPrevChild, doc_QWebView_focusNextPrevChild);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_zoomFactor, "zoomFactor(self) -> float");

extern "C" {static PyObject *meth_QWebView_zoomFactor(PyObject *, PyObject *);}
static PyObject *meth_QWebView_zoomFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->zoomFactor();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_zoomFactor, doc_QWebView_zoomFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_setZoomFactor, "setZoomFactor(self, factor: float)");

extern "C" {static PyObject *meth_QWebView_setZoomFactor(PyObject *, PyObject *);}
static PyObject *meth_QWebView_setZoomFactor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QWebView, &sipCpp, &a0))
        {
            sipCpp->setZoomFactor(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_setZoomFactor, doc_QWebView_setZoomFactor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_renderHints, "renderHints(self) -> QPainter.RenderHints");

extern "C" {static PyObject *meth_QWebView_renderHints(PyObject *, PyObject *);}
static PyObject *meth_QWebView_renderHints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            ::QPainter::RenderHints*sipRes;

            sipRes = new ::QPainter::RenderHints(sipCpp->renderHints());

            return sipConvertFromNewType(sipRes, sipType_QPainter_RenderHints, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_renderHints, doc_QWebView_renderHints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_setRenderHints, "setRenderHints(self, hints: QPainter.RenderHints)");

extern "C" {static PyObject *meth_QWebView_setRenderHints(PyObject *, PyObject *);}
static PyObject *meth_QWebView_setRenderHints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPainter::RenderHints* a0;
        int a0State = 0;
        ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebView, &sipCpp, sipType_QPainter_RenderHints, &a0, &a0State))
        {
            sipCpp->setRenderHints(*a0);
            sipReleaseType(a0, sipType_QPainter_RenderHints, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_setRenderHints, doc_QWebView_setRenderHints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_setRenderHint, "setRenderHint(self, hint: QPainter.RenderHint, enabled: bool = True)");

extern "C" {static PyObject *meth_QWebView_setRenderHint(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebView_setRenderHint(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPainter::RenderHint a0;
        bool a1 = 1;
        ::QWebView *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_enabled,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|b", &sipSelf, sipType_QWebView, &sipCpp, sipType_QPainter_RenderHint, &a0, &a1))
        {
            sipCpp->setRenderHint(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_setRenderHint, doc_QWebView_setRenderHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_hasSelection, "hasSelection(self) -> bool");

extern "C" {static PyObject *meth_QWebView_hasSelection(PyObject *, PyObject *);}
static PyObject *meth_QWebView_hasSelection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasSelection();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_hasSelection, doc_QWebView_hasSelection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebView_selectedHtml, "selectedHtml(self) -> str");

extern "C" {static PyObject *meth_QWebView_selectedHtml(PyObject *, PyObject *);}
static PyObject *meth_QWebView_selectedHtml(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebView, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->selectedHtml());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebView, sipName_selectedHtml, doc_QWebView_selectedHtml);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QWebView(void *, const sipTypeDef *);}
static void *cast_QWebView(void *sipCppV, const sipTypeDef *targetType)
{
    ::QWebView *sipCpp = reinterpret_cast< ::QWebView *>(sipCppV);

    if (targetType == sipType_QWebView)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QWidget)->ctd_cast(static_cast< ::QWidget *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebView(void *, int);}
static void release_QWebView(void *sipCppV, int)
{
    ::QWebView *sipCpp = reinterpret_cast< ::QWebView *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QWebView(Py_ssize_t);}
static void *array_QWebView(Py_ssize_t sipNrElem)
{
    return new ::QWebView[sipNrElem];
}


extern "C" {static void array_delete_QWebView(void *);}
static void array_delete_QWebView(void *sipCpp)
{
    delete[] reinterpret_cast< ::QWebView *>(sipCpp);
}


extern "C" {static void dealloc_QWebView(sipSimpleWrapper *);}
static void dealloc_QWebView(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQWebView *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWebView(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QWebView(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWebView(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQWebView *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QWidget, &a0, sipOwner))
        {
            sipCpp = new sipQWebView(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QWebView[] = {{17, 3, 1}};


static PyMethodDef methods_QWebView[] = {
    {sipName_back, meth_QWebView_back, METH_VARARGS, doc_QWebView_back},
    {sipName_changeEvent, meth_QWebView_changeEvent, METH_VARARGS, doc_QWebView_changeEvent},
    {sipName_contextMenuEvent, meth_QWebView_contextMenuEvent, METH_VARARGS, doc_QWebView_contextMenuEvent},
    {sipName_createWindow, meth_QWebView_createWindow, METH_VARARGS, doc_QWebView_createWindow},
    {sipName_dragEnterEvent, meth_QWebView_dragEnterEvent, METH_VARARGS, doc_QWebView_dragEnterEvent},
    {sipName_dragLeaveEvent, meth_QWebView_dragLeaveEvent, METH_VARARGS, doc_QWebView_dragLeaveEvent},
    {sipName_dragMoveEvent, meth_QWebView_dragMoveEvent, METH_VARARGS, doc_QWebView_dragMoveEvent},
    {sipName_dropEvent, meth_QWebView_dropEvent, METH_VARARGS, doc_QWebView_dropEvent},
    {sipName_event, meth_QWebView_event, METH_VARARGS, doc_QWebView_event},
    {sipName_findText, SIP_MLMETH_CAST(meth_QWebView_findText), METH_VARARGS|METH_KEYWORDS, doc_QWebView_findText},
    {sipName_focusInEvent, meth_QWebView_focusInEvent, METH_VARARGS, doc_QWebView_focusInEvent},
    {sipName_focusNextPrevChild, meth_QWebView_focusNextPrevChild, METH_VARARGS, doc_QWebView_focusNextPrevChild},
    {sipName_focusOutEvent, meth_QWebView_focusOutEvent, METH_VARARGS, doc_QWebView_focusOutEvent},
    {sipName_forward, meth_QWebView_forward, METH_VARARGS, doc_QWebView_forward},
    {sipName_hasSelection, meth_QWebView_hasSelection, METH_VARARGS, doc_QWebView_hasSelection},
    {sipName_history, meth_QWebView_history, METH_VARARGS, doc_QWebView_history},
    {sipName_icon, meth_QWebView_icon, METH_VARARGS, doc_QWebView_icon},
    {sipName_inputMethodEvent, meth_QWebView_inputMethodEvent, METH_VARARGS, doc_QWebView_inputMethodEvent},
    {sipName_inputMethodQuery, meth_QWebView_inputMethodQuery, METH_VARARGS, doc_QWebView_inputMethodQuery},
    {sipName_isModified, meth_QWebView_isModified, METH_VARARGS, doc_QWebView_isModified},
    {sipName_keyPressEvent, meth_QWebView_keyPressEvent, METH_VARARGS, doc_QWebView_keyPressEvent},
    {sipName_keyReleaseEvent, meth_QWebView_keyReleaseEvent, METH_VARARGS, doc_QWebView_keyReleaseEvent},
    {sipName_load, SIP_MLMETH_CAST(meth_QWebView_load), METH_VARARGS|METH_KEYWORDS, doc_QWebView_load},
    {sipName_mouseDoubleClickEvent, meth_QWebView_mouseDoubleClickEvent, METH_VARARGS, doc_QWebView_mouseDoubleClickEvent},
    {sipName_mouseMoveEvent, meth_QWebView_mouseMoveEvent, METH_VARARGS, doc_QWebView_mouseMoveEvent},
    {sipName_mousePressEvent, meth_QWebView_mousePressEvent, METH_VARARGS, doc_QWebView_mousePressEvent},
    {sipName_mouseReleaseEvent, meth_QWebView_mouseReleaseEvent, METH_VARARGS, doc_QWebView_mouseReleaseEvent},
    {sipName_page, meth_QWebView_page, METH_VARARGS, doc_QWebView_page},
    {sipName_pageAction, meth_QWebView_pageAction, METH_VARARGS, doc_QWebView_pageAction},
    {sipName_paintEvent, meth_QWebView_paintEvent, METH_VARARGS, doc_QWebView_paintEvent},
    {sipName_print, meth_QWebView_print, METH_VARARGS, doc_QWebView_print},
    {sipName_print_, meth_QWebView_print_, METH_VARARGS, doc_QWebView_print_},
    {sipName_reload, meth_QWebView_reload, METH_VARARGS, doc_QWebView_reload},
    {sipName_renderHints, meth_QWebView_renderHints, METH_VARARGS, doc_QWebView_renderHints},
    {sipName_resizeEvent, meth_QWebView_resizeEvent, METH_VARARGS, doc_QWebView_resizeEvent},
    {sipName_selectedHtml, meth_QWebView_selectedHtml, METH_VARARGS, doc_QWebView_selectedHtml},
    {sipName_selectedText, meth_QWebView_selectedText, METH_VARARGS, doc_QWebView_selectedText},
    {sipName_setContent, SIP_MLMETH_CAST(meth_QWebView_setContent), METH_VARARGS|METH_KEYWORDS, doc_QWebView_setContent},
    {sipName_setHtml, SIP_MLMETH_CAST(meth_QWebView_setHtml), METH_VARARGS|METH_KEYWORDS, doc_QWebView_setHtml},
    {sipName_setPage, meth_QWebView_setPage, METH_VARARGS, doc_QWebView_setPage},
    {sipName_setRenderHint, SIP_MLMETH_CAST(meth_QWebView_setRenderHint), METH_VARARGS|METH_KEYWORDS, doc_QWebView_setRenderHint},
    {sipName_setRenderHints, meth_QWebView_setRenderHints, METH_VARARGS, doc_QWebView_setRenderHints},
    {sipName_setUrl, meth_QWebView_setUrl, METH_VARARGS, doc_QWebView_setUrl},
    {sipName_setZoomFactor, meth_QWebView_setZoomFactor, METH_VARARGS, doc_QWebView_setZoomFactor},
    {sipName_settings, meth_QWebView_settings, METH_VARARGS, doc_QWebView_settings},
    {sipName_sizeHint, meth_QWebView_sizeHint, METH_VARARGS, doc_QWebView_sizeHint},
    {sipName_stop, meth_QWebView_stop, METH_VARARGS, doc_QWebView_stop},
    {sipName_title, meth_QWebView_title, METH_VARARGS, doc_QWebView_title},
    {sipName_triggerPageAction, SIP_MLMETH_CAST(meth_QWebView_triggerPageAction), METH_VARARGS|METH_KEYWORDS, doc_QWebView_triggerPageAction},
    {sipName_url, meth_QWebView_url, METH_VARARGS, doc_QWebView_url},
    {sipName_wheelEvent, meth_QWebView_wheelEvent, METH_VARARGS, doc_QWebView_wheelEvent},
    {sipName_zoomFactor, meth_QWebView_zoomFactor, METH_VARARGS, doc_QWebView_zoomFactor}
};

PyDoc_STRVAR(doc_QWebView, "\1QWebView(parent: Optional[QWidget] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QWebView[] = {
    {"urlChanged(QUrl)", "\1urlChanged(self, url: QUrl)", SIP_NULLPTR, SIP_NULLPTR},
    {"iconChanged()", "\1iconChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"selectionChanged()", "\1selectionChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"linkClicked(QUrl)", "\1linkClicked(self, url: QUrl)", SIP_NULLPTR, SIP_NULLPTR},
    {"statusBarMessage(QString)", "\1statusBarMessage(self, text: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"titleChanged(QString)", "\1titleChanged(self, title: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"loadFinished(bool)", "\1loadFinished(self, a0: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"loadProgress(int)", "\1loadProgress(self, progress: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"loadStarted()", "\1loadStarted(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QWebView = {
    &::QWebView::staticMetaObject,
    0,
    signals_QWebView,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebView = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebView,
        SIP_NULLPTR,
        &plugin_QWebView,
    },
    {
        sipNameNr_QWebView,
        {0, 0, 1},
        52, methods_QWebView,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWebView,
    -1,
    -1,
    supers_QWebView,
    SIP_NULLPTR,
    init_type_QWebView,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWebView,
    SIP_NULLPTR,
    array_QWebView,
    SIP_NULLPTR,
    release_QWebView,
    cast_QWebView,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QWebView,
    sizeof (::QWebView),
};
