/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeocodingmanagerengine.sip"
#include <qgeocodingmanagerengine.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"

#line 24 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeocodereply.sip"
#include <qgeocodereply.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeocoordinate.sip"
#include <qgeocoordinate.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeoshape.sip"
#include <qgeoshape.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeoaddress.sip"
#include <qgeoaddress.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoCodingManagerEngine.cpp"


class sipQGeoCodingManagerEngine : public ::QGeoCodingManagerEngine
{
public:
    sipQGeoCodingManagerEngine(const ::QVariantMap&, ::QObject*);
    virtual ~sipQGeoCodingManagerEngine();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QGeoCodeReply* reverseGeocode(const ::QGeoCoordinate&, const ::QGeoShape&) SIP_OVERRIDE;
    ::QGeoCodeReply* geocode(const ::QString&, int, int, const ::QGeoShape&) SIP_OVERRIDE;
    ::QGeoCodeReply* geocode(const ::QGeoAddress&, const ::QGeoShape&) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQGeoCodingManagerEngine(const sipQGeoCodingManagerEngine &);
    sipQGeoCodingManagerEngine &operator = (const sipQGeoCodingManagerEngine &);

    char sipPyMethods[10];
};

sipQGeoCodingManagerEngine::sipQGeoCodingManagerEngine(const ::QVariantMap& a0, ::QObject*a1): ::QGeoCodingManagerEngine(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGeoCodingManagerEngine::~sipQGeoCodingManagerEngine()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQGeoCodingManagerEngine::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtLocation_qt_metaobject(sipPySelf, sipType_QGeoCodingManagerEngine);

    return ::QGeoCodingManagerEngine::metaObject();
}

int sipQGeoCodingManagerEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QGeoCodingManagerEngine::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtLocation_qt_metacall(sipPySelf, sipType_QGeoCodingManagerEngine, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQGeoCodingManagerEngine::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtLocation_qt_metacast(sipPySelf, sipType_QGeoCodingManagerEngine, _clname, &sipCpp) ? sipCpp : ::QGeoCodingManagerEngine::qt_metacast(_clname));
}

::QGeoCodeReply* sipQGeoCodingManagerEngine::reverseGeocode(const ::QGeoCoordinate& a0, const ::QGeoShape& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_reverseGeocode);

    if (!sipMeth)
        return ::QGeoCodingManagerEngine::reverseGeocode(a0, a1);

    extern ::QGeoCodeReply* sipVH_QtLocation_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGeoCoordinate&, const ::QGeoShape&);

    return sipVH_QtLocation_9(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QGeoCodeReply* sipQGeoCodingManagerEngine::geocode(const ::QString& a0, int a1, int a2, const ::QGeoShape& a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_geocode);

    if (!sipMeth)
        return ::QGeoCodingManagerEngine::geocode(a0, a1, a2, a3);

    extern ::QGeoCodeReply* sipVH_QtLocation_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&, int, int, const ::QGeoShape&);

    return sipVH_QtLocation_8(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

::QGeoCodeReply* sipQGeoCodingManagerEngine::geocode(const ::QGeoAddress& a0, const ::QGeoShape& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_geocode);

    if (!sipMeth)
        return ::QGeoCodingManagerEngine::geocode(a0, a1);

    extern ::QGeoCodeReply* sipVH_QtLocation_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGeoAddress&, const ::QGeoShape&);

    return sipVH_QtLocation_7(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGeoCodingManagerEngine::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QGeoCodingManagerEngine::event(a0);

    extern bool sipVH_QtLocation_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtLocation_5(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGeoCodingManagerEngine::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QGeoCodingManagerEngine::eventFilter(a0, a1);

    extern bool sipVH_QtLocation_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtLocation_4(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGeoCodingManagerEngine::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QGeoCodingManagerEngine::timerEvent(a0);
        return;
    }

    extern void sipVH_QtLocation_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtLocation_3(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoCodingManagerEngine::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QGeoCodingManagerEngine::childEvent(a0);
        return;
    }

    extern void sipVH_QtLocation_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtLocation_2(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoCodingManagerEngine::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QGeoCodingManagerEngine::customEvent(a0);
        return;
    }

    extern void sipVH_QtLocation_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtLocation_1(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoCodingManagerEngine::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QGeoCodingManagerEngine::connectNotify(a0);
        return;
    }

    extern void sipVH_QtLocation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtLocation_0(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoCodingManagerEngine::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QGeoCodingManagerEngine::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtLocation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtLocation_0(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QGeoCodingManagerEngine_managerName, "managerName(self) -> str");

extern "C" {static PyObject *meth_QGeoCodingManagerEngine_managerName(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodingManagerEngine_managerName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCodingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoCodingManagerEngine, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->managerName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodingManagerEngine, sipName_managerName, doc_QGeoCodingManagerEngine_managerName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodingManagerEngine_managerVersion, "managerVersion(self) -> int");

extern "C" {static PyObject *meth_QGeoCodingManagerEngine_managerVersion(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodingManagerEngine_managerVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCodingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoCodingManagerEngine, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->managerVersion();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodingManagerEngine, sipName_managerVersion, doc_QGeoCodingManagerEngine_managerVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodingManagerEngine_geocode, "geocode(self, address: QGeoAddress, bounds: QGeoShape) -> Optional[QGeoCodeReply]\n"
"geocode(self, address: Optional[str], limit: int, offset: int, bounds: QGeoShape) -> Optional[QGeoCodeReply]");

extern "C" {static PyObject *meth_QGeoCodingManagerEngine_geocode(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodingManagerEngine_geocode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QGeoAddress* a0;
        const ::QGeoShape* a1;
        ::QGeoCodingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QGeoCodingManagerEngine, &sipCpp, sipType_QGeoAddress, &a0, sipType_QGeoShape, &a1))
        {
            ::QGeoCodeReply*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGeoCodingManagerEngine::geocode(*a0, *a1) : sipCpp->geocode(*a0, *a1));

            return sipConvertFromNewType(sipRes, sipType_QGeoCodeReply, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        int a1;
        int a2;
        const ::QGeoShape* a3;
        ::QGeoCodingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1iiJ9", &sipSelf, sipType_QGeoCodingManagerEngine, &sipCpp, sipType_QString, &a0, &a0State, &a1, &a2, sipType_QGeoShape, &a3))
        {
            ::QGeoCodeReply*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGeoCodingManagerEngine::geocode(*a0, a1, a2, *a3) : sipCpp->geocode(*a0, a1, a2, *a3));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QGeoCodeReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodingManagerEngine, sipName_geocode, doc_QGeoCodingManagerEngine_geocode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodingManagerEngine_reverseGeocode, "reverseGeocode(self, coordinate: QGeoCoordinate, bounds: QGeoShape) -> Optional[QGeoCodeReply]");

extern "C" {static PyObject *meth_QGeoCodingManagerEngine_reverseGeocode(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodingManagerEngine_reverseGeocode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QGeoCoordinate* a0;
        const ::QGeoShape* a1;
        ::QGeoCodingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QGeoCodingManagerEngine, &sipCpp, sipType_QGeoCoordinate, &a0, sipType_QGeoShape, &a1))
        {
            ::QGeoCodeReply*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGeoCodingManagerEngine::reverseGeocode(*a0, *a1) : sipCpp->reverseGeocode(*a0, *a1));

            return sipConvertFromNewType(sipRes, sipType_QGeoCodeReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodingManagerEngine, sipName_reverseGeocode, doc_QGeoCodingManagerEngine_reverseGeocode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodingManagerEngine_setLocale, "setLocale(self, locale: QLocale)");

extern "C" {static PyObject *meth_QGeoCodingManagerEngine_setLocale(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodingManagerEngine_setLocale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale* a0;
        ::QGeoCodingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoCodingManagerEngine, &sipCpp, sipType_QLocale, &a0))
        {
            sipCpp->setLocale(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodingManagerEngine, sipName_setLocale, doc_QGeoCodingManagerEngine_setLocale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoCodingManagerEngine_locale, "locale(self) -> QLocale");

extern "C" {static PyObject *meth_QGeoCodingManagerEngine_locale(PyObject *, PyObject *);}
static PyObject *meth_QGeoCodingManagerEngine_locale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCodingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoCodingManagerEngine, &sipCpp))
        {
            ::QLocale*sipRes;

            sipRes = new ::QLocale(sipCpp->locale());

            return sipConvertFromNewType(sipRes, sipType_QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodingManagerEngine, sipName_locale, doc_QGeoCodingManagerEngine_locale);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGeoCodingManagerEngine(void *, const sipTypeDef *);}
static void *cast_QGeoCodingManagerEngine(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGeoCodingManagerEngine *sipCpp = reinterpret_cast< ::QGeoCodingManagerEngine *>(sipCppV);

    if (targetType == sipType_QGeoCodingManagerEngine)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoCodingManagerEngine(void *, int);}
static void release_QGeoCodingManagerEngine(void *sipCppV, int)
{
    ::QGeoCodingManagerEngine *sipCpp = reinterpret_cast< ::QGeoCodingManagerEngine *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QGeoCodingManagerEngine(sipSimpleWrapper *);}
static void dealloc_QGeoCodingManagerEngine(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQGeoCodingManagerEngine *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoCodingManagerEngine(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QGeoCodingManagerEngine(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoCodingManagerEngine(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQGeoCodingManagerEngine *sipCpp = SIP_NULLPTR;

    {
        const ::QVariantMap* a0;
        int a0State = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QVariantMap, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQGeoCodingManagerEngine(*a0, a1);
            sipReleaseType(const_cast< ::QVariantMap *>(a0), sipType_QVariantMap, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGeoCodingManagerEngine[] = {{7, 0, 1}};


static PyMethodDef methods_QGeoCodingManagerEngine[] = {
    {sipName_geocode, meth_QGeoCodingManagerEngine_geocode, METH_VARARGS, doc_QGeoCodingManagerEngine_geocode},
    {sipName_locale, meth_QGeoCodingManagerEngine_locale, METH_VARARGS, doc_QGeoCodingManagerEngine_locale},
    {sipName_managerName, meth_QGeoCodingManagerEngine_managerName, METH_VARARGS, doc_QGeoCodingManagerEngine_managerName},
    {sipName_managerVersion, meth_QGeoCodingManagerEngine_managerVersion, METH_VARARGS, doc_QGeoCodingManagerEngine_managerVersion},
    {sipName_reverseGeocode, meth_QGeoCodingManagerEngine_reverseGeocode, METH_VARARGS, doc_QGeoCodingManagerEngine_reverseGeocode},
    {sipName_setLocale, meth_QGeoCodingManagerEngine_setLocale, METH_VARARGS, doc_QGeoCodingManagerEngine_setLocale}
};

PyDoc_STRVAR(doc_QGeoCodingManagerEngine, "\1QGeoCodingManagerEngine(parameters: dict[str, Any], parent: Optional[QObject] = None)");


extern "C" {static int emit_QGeoCodingManagerEngine_error(void *, PyObject *);}

static int emit_QGeoCodingManagerEngine_error(void *sipCppV, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    ::QGeoCodingManagerEngine *sipCpp = reinterpret_cast< ::QGeoCodingManagerEngine *>(sipCppV);

    {
        ::QGeoCodeReply* a0;
        ::QGeoCodeReply::Error a1;
        ::QString a2def = QString();
        ::QString* a2 = &a2def;
        int a2State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8E|J1", sipType_QGeoCodeReply, &a0, sipType_QGeoCodeReply_Error, &a1, sipType_QString, &a2, &a2State))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->error(a0, a1, *a2);
            Py_END_ALLOW_THREADS

            sipReleaseType(a2, sipType_QString, a2State);

            return 0;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoCodingManagerEngine, sipName_error, SIP_NULLPTR);

    return -1;
}


/* Define this type's signals. */
static const pyqt5QtSignal signals_QGeoCodingManagerEngine[] = {
    {"error(QGeoCodeReply*,QGeoCodeReply::Error,QString)", "\1error(self, reply: Optional[QGeoCodeReply], error: QGeoCodeReply.Error, errorString: Optional[str] = '')", SIP_NULLPTR, emit_QGeoCodingManagerEngine_error},
    {"finished(QGeoCodeReply*)", "\1finished(self, reply: Optional[QGeoCodeReply])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QGeoCodingManagerEngine = {
    &::QGeoCodingManagerEngine::staticMetaObject,
    0,
    signals_QGeoCodingManagerEngine,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QGeoCodingManagerEngine = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoCodingManagerEngine,
        SIP_NULLPTR,
        &plugin_QGeoCodingManagerEngine,
    },
    {
        sipNameNr_QGeoCodingManagerEngine,
        {0, 0, 1},
        6, methods_QGeoCodingManagerEngine,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoCodingManagerEngine,
    -1,
    -1,
    supers_QGeoCodingManagerEngine,
    SIP_NULLPTR,
    init_type_QGeoCodingManagerEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoCodingManagerEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QGeoCodingManagerEngine,
    cast_QGeoCodingManagerEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QGeoCodingManagerEngine),
};
