/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 95 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qline.sip"
#include <qline.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQLineF.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qline.sip"
#include <qline.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQLineF.cpp"
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQLineF.cpp"


PyDoc_STRVAR(doc_QLineF_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QLineF_isNull(PyObject *, PyObject *);}
static PyObject *meth_QLineF_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLineF, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_isNull, doc_QLineF_isNull);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_length, "length(self) -> float");

extern "C" {static PyObject *meth_QLineF_length(PyObject *, PyObject *);}
static PyObject *meth_QLineF_length(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLineF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->length();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_length, doc_QLineF_length);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_unitVector, "unitVector(self) -> QLineF");

extern "C" {static PyObject *meth_QLineF_unitVector(PyObject *, PyObject *);}
static PyObject *meth_QLineF_unitVector(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLineF, &sipCpp))
        {
            ::QLineF*sipRes;

            sipRes = new ::QLineF(sipCpp->unitVector());

            return sipConvertFromNewType(sipRes, sipType_QLineF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_unitVector, doc_QLineF_unitVector);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_intersect, "intersect(self, l: QLineF, intersectionPoint: Optional[Union[QPointF, QPoint]]) -> QLineF.IntersectType");

extern "C" {static PyObject *meth_QLineF_intersect(PyObject *, PyObject *);}
static PyObject *meth_QLineF_intersect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF* a0;
        ::QPointF* a1;
        int a1State = 0;
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J0", &sipSelf, sipType_QLineF, &sipCpp, sipType_QLineF, &a0, sipType_QPointF, &a1, &a1State))
        {
            ::QLineF::IntersectType sipRes;

            sipRes = sipCpp->intersect(*a0, a1);
            sipReleaseType(a1, sipType_QPointF, a1State);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLineF_IntersectType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_intersect, doc_QLineF_intersect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_intersects, "intersects(self, l: QLineF) -> (QLineF.IntersectType, Optional[QPointF])");

extern "C" {static PyObject *meth_QLineF_intersects(PyObject *, PyObject *);}
static PyObject *meth_QLineF_intersects(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF* a0;
        ::QPointF* a1;
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLineF, &sipCpp, sipType_QLineF, &a0))
        {
            ::QLineF::IntersectionType sipRes;
            a1 = new ::QPointF();

            sipRes = sipCpp->intersects(*a0, a1);

            return sipBuildResult(0, "(FN)", sipRes, sipType_QLineF_IntersectType, a1, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_intersects, doc_QLineF_intersects);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_x1, "x1(self) -> float");

extern "C" {static PyObject *meth_QLineF_x1(PyObject *, PyObject *);}
static PyObject *meth_QLineF_x1(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLineF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->x1();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_x1, doc_QLineF_x1);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_y1, "y1(self) -> float");

extern "C" {static PyObject *meth_QLineF_y1(PyObject *, PyObject *);}
static PyObject *meth_QLineF_y1(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLineF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->y1();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_y1, doc_QLineF_y1);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_x2, "x2(self) -> float");

extern "C" {static PyObject *meth_QLineF_x2(PyObject *, PyObject *);}
static PyObject *meth_QLineF_x2(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLineF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->x2();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_x2, doc_QLineF_x2);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_y2, "y2(self) -> float");

extern "C" {static PyObject *meth_QLineF_y2(PyObject *, PyObject *);}
static PyObject *meth_QLineF_y2(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLineF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->y2();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_y2, doc_QLineF_y2);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_p1, "p1(self) -> QPointF");

extern "C" {static PyObject *meth_QLineF_p1(PyObject *, PyObject *);}
static PyObject *meth_QLineF_p1(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLineF, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->p1());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_p1, doc_QLineF_p1);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_p2, "p2(self) -> QPointF");

extern "C" {static PyObject *meth_QLineF_p2(PyObject *, PyObject *);}
static PyObject *meth_QLineF_p2(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLineF, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->p2());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_p2, doc_QLineF_p2);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_dx, "dx(self) -> float");

extern "C" {static PyObject *meth_QLineF_dx(PyObject *, PyObject *);}
static PyObject *meth_QLineF_dx(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLineF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->dx();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_dx, doc_QLineF_dx);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_dy, "dy(self) -> float");

extern "C" {static PyObject *meth_QLineF_dy(PyObject *, PyObject *);}
static PyObject *meth_QLineF_dy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLineF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->dy();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_dy, doc_QLineF_dy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_normalVector, "normalVector(self) -> QLineF");

extern "C" {static PyObject *meth_QLineF_normalVector(PyObject *, PyObject *);}
static PyObject *meth_QLineF_normalVector(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLineF, &sipCpp))
        {
            ::QLineF*sipRes;

            sipRes = new ::QLineF(sipCpp->normalVector());

            return sipConvertFromNewType(sipRes, sipType_QLineF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_normalVector, doc_QLineF_normalVector);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_translate, "translate(self, point: Union[QPointF, QPoint])\n"
"translate(self, adx: float, ady: float)");

extern "C" {static PyObject *meth_QLineF_translate(PyObject *, PyObject *);}
static PyObject *meth_QLineF_translate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        int a0State = 0;
        ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLineF, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
            sipCpp->translate(*a0);
            sipReleaseType(const_cast< ::QPointF *>(a0), sipType_QPointF, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::qreal a0;
        ::qreal a1;
        ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QLineF, &sipCpp, &a0, &a1))
        {
            sipCpp->translate(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_translate, doc_QLineF_translate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_setLength, "setLength(self, len: float)");

extern "C" {static PyObject *meth_QLineF_setLength(PyObject *, PyObject *);}
static PyObject *meth_QLineF_setLength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QLineF, &sipCpp, &a0))
        {
            sipCpp->setLength(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_setLength, doc_QLineF_setLength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_pointAt, "pointAt(self, t: float) -> QPointF");

extern "C" {static PyObject *meth_QLineF_pointAt(PyObject *, PyObject *);}
static PyObject *meth_QLineF_pointAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QLineF, &sipCpp, &a0))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->pointAt(a0));

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_pointAt, doc_QLineF_pointAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_toLine, "toLine(self) -> QLine");

extern "C" {static PyObject *meth_QLineF_toLine(PyObject *, PyObject *);}
static PyObject *meth_QLineF_toLine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLineF, &sipCpp))
        {
            ::QLine*sipRes;

            sipRes = new ::QLine(sipCpp->toLine());

            return sipConvertFromNewType(sipRes, sipType_QLine, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_toLine, doc_QLineF_toLine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_fromPolar, "fromPolar(length: float, angle: float) -> QLineF");

extern "C" {static PyObject *meth_QLineF_fromPolar(PyObject *, PyObject *);}
static PyObject *meth_QLineF_fromPolar(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::qreal a1;

        if (sipParseArgs(&sipParseErr, sipArgs, "dd", &a0, &a1))
        {
            ::QLineF*sipRes;

            sipRes = new ::QLineF(::QLineF::fromPolar(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QLineF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_fromPolar, doc_QLineF_fromPolar);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_angle, "angle(self) -> float");

extern "C" {static PyObject *meth_QLineF_angle(PyObject *, PyObject *);}
static PyObject *meth_QLineF_angle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLineF, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->angle();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_angle, doc_QLineF_angle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_setAngle, "setAngle(self, angle: float)");

extern "C" {static PyObject *meth_QLineF_setAngle(PyObject *, PyObject *);}
static PyObject *meth_QLineF_setAngle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QLineF, &sipCpp, &a0))
        {
            sipCpp->setAngle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_setAngle, doc_QLineF_setAngle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_angleTo, "angleTo(self, l: QLineF) -> float");

extern "C" {static PyObject *meth_QLineF_angleTo(PyObject *, PyObject *);}
static PyObject *meth_QLineF_angleTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF* a0;
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLineF, &sipCpp, sipType_QLineF, &a0))
        {
            ::qreal sipRes;

            sipRes = sipCpp->angleTo(*a0);

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_angleTo, doc_QLineF_angleTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_translated, "translated(self, p: Union[QPointF, QPoint]) -> QLineF\n"
"translated(self, adx: float, ady: float) -> QLineF");

extern "C" {static PyObject *meth_QLineF_translated(PyObject *, PyObject *);}
static PyObject *meth_QLineF_translated(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        int a0State = 0;
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLineF, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
            ::QLineF*sipRes;

            sipRes = new ::QLineF(sipCpp->translated(*a0));
            sipReleaseType(const_cast< ::QPointF *>(a0), sipType_QPointF, a0State);

            return sipConvertFromNewType(sipRes, sipType_QLineF, SIP_NULLPTR);
        }
    }

    {
        ::qreal a0;
        ::qreal a1;
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QLineF, &sipCpp, &a0, &a1))
        {
            ::QLineF*sipRes;

            sipRes = new ::QLineF(sipCpp->translated(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QLineF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_translated, doc_QLineF_translated);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_setP1, "setP1(self, aP1: Union[QPointF, QPoint])");

extern "C" {static PyObject *meth_QLineF_setP1(PyObject *, PyObject *);}
static PyObject *meth_QLineF_setP1(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        int a0State = 0;
        ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLineF, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
            sipCpp->setP1(*a0);
            sipReleaseType(const_cast< ::QPointF *>(a0), sipType_QPointF, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_setP1, doc_QLineF_setP1);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_setP2, "setP2(self, aP2: Union[QPointF, QPoint])");

extern "C" {static PyObject *meth_QLineF_setP2(PyObject *, PyObject *);}
static PyObject *meth_QLineF_setP2(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        int a0State = 0;
        ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLineF, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
            sipCpp->setP2(*a0);
            sipReleaseType(const_cast< ::QPointF *>(a0), sipType_QPointF, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_setP2, doc_QLineF_setP2);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_setPoints, "setPoints(self, aP1: Union[QPointF, QPoint], aP2: Union[QPointF, QPoint])");

extern "C" {static PyObject *meth_QLineF_setPoints(PyObject *, PyObject *);}
static PyObject *meth_QLineF_setPoints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPointF* a0;
        int a0State = 0;
        const ::QPointF* a1;
        int a1State = 0;
        ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QLineF, &sipCpp, sipType_QPointF, &a0, &a0State, sipType_QPointF, &a1, &a1State))
        {
            sipCpp->setPoints(*a0, *a1);
            sipReleaseType(const_cast< ::QPointF *>(a0), sipType_QPointF, a0State);
            sipReleaseType(const_cast< ::QPointF *>(a1), sipType_QPointF, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_setPoints, doc_QLineF_setPoints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_setLine, "setLine(self, aX1: float, aY1: float, aX2: float, aY2: float)");

extern "C" {static PyObject *meth_QLineF_setLine(PyObject *, PyObject *);}
static PyObject *meth_QLineF_setLine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::qreal a1;
        ::qreal a2;
        ::qreal a3;
        ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdddd", &sipSelf, sipType_QLineF, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->setLine(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_setLine, doc_QLineF_setLine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLineF_center, "center(self) -> QPointF");

extern "C" {static PyObject *meth_QLineF_center(PyObject *, PyObject *);}
static PyObject *meth_QLineF_center(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLineF, &sipCpp))
        {
            ::QPointF*sipRes;

            sipRes = new ::QPointF(sipCpp->center());

            return sipConvertFromNewType(sipRes, sipType_QPointF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLineF, sipName_center, doc_QLineF_center);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QLineF___eq__(PyObject *, PyObject *);}
static PyObject *slot_QLineF___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLineF *sipCpp = reinterpret_cast< ::QLineF *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLineF));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLineF, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QLineF::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, eq_slot, sipType_QLineF, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QLineF___repr__(PyObject *);}
static PyObject *slot_QLineF___repr__(PyObject *sipSelf)
{
    ::QLineF *sipCpp = reinterpret_cast< ::QLineF *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLineF));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            PyObject * sipRes = SIP_NULLPTR;

#line 132 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qline.sip"
        if (sipCpp->isNull())
        {
        #if PY_MAJOR_VERSION >= 3
            sipRes = PyUnicode_FromString("PyQt5.QtCore.QLineF()");
        #else
            sipRes = PyString_FromString("PyQt5.QtCore.QLineF()");
        #endif
        }
        else
        {
            PyObject *x1 = PyFloat_FromDouble(sipCpp->x1());
            PyObject *y1 = PyFloat_FromDouble(sipCpp->y1());
            PyObject *x2 = PyFloat_FromDouble(sipCpp->x2());
            PyObject *y2 = PyFloat_FromDouble(sipCpp->y2());
        
            if (x1 && y1 && x2 && y2)
            {
        #if PY_MAJOR_VERSION >= 3
                sipRes = PyUnicode_FromFormat("PyQt5.QtCore.QLineF(%R, %R, %R, %R)",
                        x1, y1, x2, y2);
        #else
                sipRes = PyString_FromString("PyQt5.QtCore.QLineF(");
                PyString_ConcatAndDel(&sipRes, PyObject_Repr(x1));
                PyString_ConcatAndDel(&sipRes, PyString_FromString(", "));
                PyString_ConcatAndDel(&sipRes, PyObject_Repr(y1));
                PyString_ConcatAndDel(&sipRes, PyString_FromString(", "));
                PyString_ConcatAndDel(&sipRes, PyObject_Repr(x2));
                PyString_ConcatAndDel(&sipRes, PyString_FromString(", "));
                PyString_ConcatAndDel(&sipRes, PyObject_Repr(y2));
                PyString_ConcatAndDel(&sipRes, PyString_FromString(")"));
        #endif
            }
        
            Py_XDECREF(x1);
            Py_XDECREF(y1);
            Py_XDECREF(x2);
            Py_XDECREF(y2);
        }
#line 906 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQLineF.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QLineF___ne__(PyObject *, PyObject *);}
static PyObject *slot_QLineF___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLineF *sipCpp = reinterpret_cast< ::QLineF *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLineF));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLineF* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLineF, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QLineF::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, ne_slot, sipType_QLineF, sipSelf, sipArg);
}


extern "C" {static int slot_QLineF___bool__(PyObject *);}
static int slot_QLineF___bool__(PyObject *sipSelf)
{
    ::QLineF *sipCpp = reinterpret_cast< ::QLineF *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLineF));

    if (!sipCpp)
        return -1;


    {
        {
            int sipRes = 0;

#line 114 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qline.sip"
        sipRes = !sipCpp->isNull();
#line 960 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQLineF.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QLineF(void *, int);}
static void release_QLineF(void *sipCppV, int)
{
    delete reinterpret_cast< ::QLineF *>(sipCppV);
}


extern "C" {static PyObject *pickle_QLineF(void *);}
static PyObject *pickle_QLineF(void *sipCppV)
{
    ::QLineF *sipCpp = reinterpret_cast< ::QLineF *>(sipCppV);
    PyObject *sipRes;

#line 99 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qline.sip"
    sipRes = Py_BuildValue((char *)"dddd", sipCpp->x1(), sipCpp->y1(), sipCpp->x2(), sipCpp->y2());
#line 986 "/build/pyqt5/src/PyQt5-5.15.11/build/QtCore/sipQtCoreQLineF.cpp"

    return sipRes;
}


extern "C" {static void *array_QLineF(Py_ssize_t);}
static void *array_QLineF(Py_ssize_t sipNrElem)
{
    return new ::QLineF[sipNrElem];
}


extern "C" {static void array_delete_QLineF(void *);}
static void array_delete_QLineF(void *sipCpp)
{
    delete[] reinterpret_cast< ::QLineF *>(sipCpp);
}


extern "C" {static void assign_QLineF(void *, Py_ssize_t, void *);}
static void assign_QLineF(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QLineF *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QLineF *>(sipSrc);
}


extern "C" {static void *copy_QLineF(const void *, Py_ssize_t);}
static void *copy_QLineF(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QLineF(reinterpret_cast<const ::QLineF *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QLineF(sipSimpleWrapper *);}
static void dealloc_QLineF(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QLineF(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QLineF(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QLineF(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QLineF *sipCpp = SIP_NULLPTR;

    {
        const ::QLine* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QLine, &a0))
        {
            sipCpp = new ::QLineF(*a0);

            return sipCpp;
        }
    }

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QLineF();

            return sipCpp;
        }
    }

    {
        const ::QPointF* a0;
        int a0State = 0;
        const ::QPointF* a1;
        int a1State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1J1", sipType_QPointF, &a0, &a0State, sipType_QPointF, &a1, &a1State))
        {
            sipCpp = new ::QLineF(*a0, *a1);
            sipReleaseType(const_cast< ::QPointF *>(a0), sipType_QPointF, a0State);
            sipReleaseType(const_cast< ::QPointF *>(a1), sipType_QPointF, a1State);

            return sipCpp;
        }
    }

    {
        ::qreal a0;
        ::qreal a1;
        ::qreal a2;
        ::qreal a3;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "dddd", &a0, &a1, &a2, &a3))
        {
            sipCpp = new ::QLineF(a0, a1, a2, a3);

            return sipCpp;
        }
    }

    {
        const ::QLineF* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QLineF, &a0))
        {
            sipCpp = new ::QLineF(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QLineF[] = {
    {(void *)slot_QLineF___eq__, eq_slot},
    {(void *)slot_QLineF___repr__, repr_slot},
    {(void *)slot_QLineF___ne__, ne_slot},
    {(void *)slot_QLineF___bool__, bool_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QLineF[] = {
    {sipName_angle, meth_QLineF_angle, METH_VARARGS, doc_QLineF_angle},
    {sipName_angleTo, meth_QLineF_angleTo, METH_VARARGS, doc_QLineF_angleTo},
    {sipName_center, meth_QLineF_center, METH_VARARGS, doc_QLineF_center},
    {sipName_dx, meth_QLineF_dx, METH_VARARGS, doc_QLineF_dx},
    {sipName_dy, meth_QLineF_dy, METH_VARARGS, doc_QLineF_dy},
    {sipName_fromPolar, meth_QLineF_fromPolar, METH_VARARGS, doc_QLineF_fromPolar},
    {sipName_intersect, meth_QLineF_intersect, METH_VARARGS, doc_QLineF_intersect},
    {sipName_intersects, meth_QLineF_intersects, METH_VARARGS, doc_QLineF_intersects},
    {sipName_isNull, meth_QLineF_isNull, METH_VARARGS, doc_QLineF_isNull},
    {sipName_length, meth_QLineF_length, METH_VARARGS, doc_QLineF_length},
    {sipName_normalVector, meth_QLineF_normalVector, METH_VARARGS, doc_QLineF_normalVector},
    {sipName_p1, meth_QLineF_p1, METH_VARARGS, doc_QLineF_p1},
    {sipName_p2, meth_QLineF_p2, METH_VARARGS, doc_QLineF_p2},
    {sipName_pointAt, meth_QLineF_pointAt, METH_VARARGS, doc_QLineF_pointAt},
    {sipName_setAngle, meth_QLineF_setAngle, METH_VARARGS, doc_QLineF_setAngle},
    {sipName_setLength, meth_QLineF_setLength, METH_VARARGS, doc_QLineF_setLength},
    {sipName_setLine, meth_QLineF_setLine, METH_VARARGS, doc_QLineF_setLine},
    {sipName_setP1, meth_QLineF_setP1, METH_VARARGS, doc_QLineF_setP1},
    {sipName_setP2, meth_QLineF_setP2, METH_VARARGS, doc_QLineF_setP2},
    {sipName_setPoints, meth_QLineF_setPoints, METH_VARARGS, doc_QLineF_setPoints},
    {sipName_toLine, meth_QLineF_toLine, METH_VARARGS, doc_QLineF_toLine},
    {sipName_translate, meth_QLineF_translate, METH_VARARGS, doc_QLineF_translate},
    {sipName_translated, meth_QLineF_translated, METH_VARARGS, doc_QLineF_translated},
    {sipName_unitVector, meth_QLineF_unitVector, METH_VARARGS, doc_QLineF_unitVector},
    {sipName_x1, meth_QLineF_x1, METH_VARARGS, doc_QLineF_x1},
    {sipName_x2, meth_QLineF_x2, METH_VARARGS, doc_QLineF_x2},
    {sipName_y1, meth_QLineF_y1, METH_VARARGS, doc_QLineF_y1},
    {sipName_y2, meth_QLineF_y2, METH_VARARGS, doc_QLineF_y2}
};

static sipEnumMemberDef enummembers_QLineF[] = {
    {sipName_BoundedIntersection, static_cast<int>(::QLineF::BoundedIntersection), 127},
    {sipName_NoIntersection, static_cast<int>(::QLineF::NoIntersection), 127},
    {sipName_UnboundedIntersection, static_cast<int>(::QLineF::UnboundedIntersection), 127},
};

PyDoc_STRVAR(doc_QLineF, "\1QLineF(line: QLine)\n"
"QLineF()\n"
"QLineF(apt1: Union[QPointF, QPoint], apt2: Union[QPointF, QPoint])\n"
"QLineF(x1pos: float, y1pos: float, x2pos: float, y2pos: float)\n"
"QLineF(a0: QLineF)");


static pyqt5ClassPluginDef plugin_QLineF = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QLineF = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QLineF,
        SIP_NULLPTR,
        &plugin_QLineF,
    },
    {
        sipNameNr_QLineF,
        {0, 0, 1},
        28, methods_QLineF,
        3, enummembers_QLineF,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QLineF,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QLineF,
    init_type_QLineF,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QLineF,
    assign_QLineF,
    array_QLineF,
    copy_QLineF,
    release_QLineF,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    pickle_QLineF,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QLineF,
    sizeof (::QLineF),
};
