/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacemanagerengine.sip"
#include <qplacemanagerengine.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"

#line 24 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacemanager.sip"
#include <qplacemanager.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecategory.sip"
#include <qplacecategory.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacereply.sip"
#include <qplacereply.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacematchreply.sip"
#include <qplacematchreply.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacematchrequest.sip"
#include <qplacematchrequest.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplace.sip"
#include <qplace.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceicon.sip"
#include <qplaceicon.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceidreply.sip"
#include <qplaceidreply.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesearchsuggestionreply.sip"
#include <qplacesearchsuggestionreply.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesearchrequest.sip"
#include <qplacesearchrequest.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesearchreply.sip"
#include <qplacesearchreply.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecontentreply.sip"
#include <qplacecontentreply.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecontentrequest.sip"
#include <qplacecontentrequest.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacedetailsreply.sip"
#include <qplacedetailsreply.h>
#line 99 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 122 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 125 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 128 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 131 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 134 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 137 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 140 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 143 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManagerEngine.cpp"


class sipQPlaceManagerEngine : public ::QPlaceManagerEngine
{
public:
    sipQPlaceManagerEngine(const ::QVariantMap&, ::QObject*);
    virtual ~sipQPlaceManagerEngine();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QPlaceMatchReply* matchingPlaces(const ::QPlaceMatchRequest&) SIP_OVERRIDE;
    ::QPlace compatiblePlace(const ::QPlace&) const SIP_OVERRIDE;
    ::QUrl constructIconUrl(const ::QPlaceIcon&, const ::QSize&) const SIP_OVERRIDE;
    void setLocales(const QList< ::QLocale>&) SIP_OVERRIDE;
    QList< ::QLocale> locales() const SIP_OVERRIDE;
    QList< ::QPlaceCategory> childCategories(const ::QString&) const SIP_OVERRIDE;
    ::QPlaceCategory category(const ::QString&) const SIP_OVERRIDE;
    ::QStringList childCategoryIds(const ::QString&) const SIP_OVERRIDE;
    ::QString parentCategoryId(const ::QString&) const SIP_OVERRIDE;
    ::QPlaceReply* initializeCategories() SIP_OVERRIDE;
    ::QPlaceIdReply* removeCategory(const ::QString&) SIP_OVERRIDE;
    ::QPlaceIdReply* saveCategory(const ::QPlaceCategory&, const ::QString&) SIP_OVERRIDE;
    ::QPlaceIdReply* removePlace(const ::QString&) SIP_OVERRIDE;
    ::QPlaceIdReply* savePlace(const ::QPlace&) SIP_OVERRIDE;
    ::QPlaceSearchSuggestionReply* searchSuggestions(const ::QPlaceSearchRequest&) SIP_OVERRIDE;
    ::QPlaceSearchReply* search(const ::QPlaceSearchRequest&) SIP_OVERRIDE;
    ::QPlaceContentReply* getPlaceContent(const ::QPlaceContentRequest&) SIP_OVERRIDE;
    ::QPlaceDetailsReply* getPlaceDetails(const ::QString&) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPlaceManagerEngine(const sipQPlaceManagerEngine &);
    sipQPlaceManagerEngine &operator = (const sipQPlaceManagerEngine &);

    char sipPyMethods[25];
};

sipQPlaceManagerEngine::sipQPlaceManagerEngine(const ::QVariantMap& a0, ::QObject*a1): ::QPlaceManagerEngine(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQPlaceManagerEngine::~sipQPlaceManagerEngine()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQPlaceManagerEngine::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtLocation_qt_metaobject(sipPySelf, sipType_QPlaceManagerEngine);

    return ::QPlaceManagerEngine::metaObject();
}

int sipQPlaceManagerEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QPlaceManagerEngine::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtLocation_qt_metacall(sipPySelf, sipType_QPlaceManagerEngine, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQPlaceManagerEngine::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtLocation_qt_metacast(sipPySelf, sipType_QPlaceManagerEngine, _clname, &sipCpp) ? sipCpp : ::QPlaceManagerEngine::qt_metacast(_clname));
}

::QPlaceMatchReply* sipQPlaceManagerEngine::matchingPlaces(const ::QPlaceMatchRequest& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_matchingPlaces);

    if (!sipMeth)
        return ::QPlaceManagerEngine::matchingPlaces(a0);

    extern ::QPlaceMatchReply* sipVH_QtLocation_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPlaceMatchRequest&);

    return sipVH_QtLocation_29(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPlace sipQPlaceManagerEngine::compatiblePlace(const ::QPlace& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_compatiblePlace);

    if (!sipMeth)
        return ::QPlaceManagerEngine::compatiblePlace(a0);

    extern ::QPlace sipVH_QtLocation_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPlace&);

    return sipVH_QtLocation_28(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QUrl sipQPlaceManagerEngine::constructIconUrl(const ::QPlaceIcon& a0, const ::QSize& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_constructIconUrl);

    if (!sipMeth)
        return ::QPlaceManagerEngine::constructIconUrl(a0, a1);

    extern ::QUrl sipVH_QtLocation_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPlaceIcon&, const ::QSize&);

    return sipVH_QtLocation_27(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQPlaceManagerEngine::setLocales(const QList< ::QLocale>& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_setLocales);

    if (!sipMeth)
    {
        ::QPlaceManagerEngine::setLocales(a0);
        return;
    }

    extern void sipVH_QtLocation_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const QList< ::QLocale>&);

    sipVH_QtLocation_26(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

QList< ::QLocale> sipQPlaceManagerEngine::locales() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_locales);

    if (!sipMeth)
        return ::QPlaceManagerEngine::locales();

    extern QList< ::QLocale> sipVH_QtLocation_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtLocation_25(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

QList< ::QPlaceCategory> sipQPlaceManagerEngine::childCategories(const ::QString& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_childCategories);

    if (!sipMeth)
        return ::QPlaceManagerEngine::childCategories(a0);

    extern QList< ::QPlaceCategory> sipVH_QtLocation_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtLocation_24(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPlaceCategory sipQPlaceManagerEngine::category(const ::QString& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_category);

    if (!sipMeth)
        return ::QPlaceManagerEngine::category(a0);

    extern ::QPlaceCategory sipVH_QtLocation_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtLocation_23(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QStringList sipQPlaceManagerEngine::childCategoryIds(const ::QString& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_childCategoryIds);

    if (!sipMeth)
        return ::QPlaceManagerEngine::childCategoryIds(a0);

    extern ::QStringList sipVH_QtLocation_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtLocation_22(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QString sipQPlaceManagerEngine::parentCategoryId(const ::QString& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_parentCategoryId);

    if (!sipMeth)
        return ::QPlaceManagerEngine::parentCategoryId(a0);

    extern ::QString sipVH_QtLocation_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtLocation_21(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPlaceReply* sipQPlaceManagerEngine::initializeCategories()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_initializeCategories);

    if (!sipMeth)
        return ::QPlaceManagerEngine::initializeCategories();

    extern ::QPlaceReply* sipVH_QtLocation_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtLocation_20(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QPlaceIdReply* sipQPlaceManagerEngine::removeCategory(const ::QString& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_removeCategory);

    if (!sipMeth)
        return ::QPlaceManagerEngine::removeCategory(a0);

    extern ::QPlaceIdReply* sipVH_QtLocation_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtLocation_18(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPlaceIdReply* sipQPlaceManagerEngine::saveCategory(const ::QPlaceCategory& a0, const ::QString& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_saveCategory);

    if (!sipMeth)
        return ::QPlaceManagerEngine::saveCategory(a0, a1);

    extern ::QPlaceIdReply* sipVH_QtLocation_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPlaceCategory&, const ::QString&);

    return sipVH_QtLocation_19(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QPlaceIdReply* sipQPlaceManagerEngine::removePlace(const ::QString& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_removePlace);

    if (!sipMeth)
        return ::QPlaceManagerEngine::removePlace(a0);

    extern ::QPlaceIdReply* sipVH_QtLocation_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtLocation_18(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPlaceIdReply* sipQPlaceManagerEngine::savePlace(const ::QPlace& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_savePlace);

    if (!sipMeth)
        return ::QPlaceManagerEngine::savePlace(a0);

    extern ::QPlaceIdReply* sipVH_QtLocation_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPlace&);

    return sipVH_QtLocation_17(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPlaceSearchSuggestionReply* sipQPlaceManagerEngine::searchSuggestions(const ::QPlaceSearchRequest& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_searchSuggestions);

    if (!sipMeth)
        return ::QPlaceManagerEngine::searchSuggestions(a0);

    extern ::QPlaceSearchSuggestionReply* sipVH_QtLocation_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPlaceSearchRequest&);

    return sipVH_QtLocation_16(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPlaceSearchReply* sipQPlaceManagerEngine::search(const ::QPlaceSearchRequest& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_search);

    if (!sipMeth)
        return ::QPlaceManagerEngine::search(a0);

    extern ::QPlaceSearchReply* sipVH_QtLocation_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPlaceSearchRequest&);

    return sipVH_QtLocation_15(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPlaceContentReply* sipQPlaceManagerEngine::getPlaceContent(const ::QPlaceContentRequest& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_getPlaceContent);

    if (!sipMeth)
        return ::QPlaceManagerEngine::getPlaceContent(a0);

    extern ::QPlaceContentReply* sipVH_QtLocation_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPlaceContentRequest&);

    return sipVH_QtLocation_14(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPlaceDetailsReply* sipQPlaceManagerEngine::getPlaceDetails(const ::QString& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_getPlaceDetails);

    if (!sipMeth)
        return ::QPlaceManagerEngine::getPlaceDetails(a0);

    extern ::QPlaceDetailsReply* sipVH_QtLocation_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtLocation_13(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPlaceManagerEngine::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QPlaceManagerEngine::event(a0);

    extern bool sipVH_QtLocation_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtLocation_5(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPlaceManagerEngine::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QPlaceManagerEngine::eventFilter(a0, a1);

    extern bool sipVH_QtLocation_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtLocation_4(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQPlaceManagerEngine::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QPlaceManagerEngine::timerEvent(a0);
        return;
    }

    extern void sipVH_QtLocation_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtLocation_3(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPlaceManagerEngine::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QPlaceManagerEngine::childEvent(a0);
        return;
    }

    extern void sipVH_QtLocation_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtLocation_2(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPlaceManagerEngine::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QPlaceManagerEngine::customEvent(a0);
        return;
    }

    extern void sipVH_QtLocation_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtLocation_1(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPlaceManagerEngine::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QPlaceManagerEngine::connectNotify(a0);
        return;
    }

    extern void sipVH_QtLocation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtLocation_0(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPlaceManagerEngine::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QPlaceManagerEngine::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtLocation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtLocation_0(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_managerName, "managerName(self) -> str");

extern "C" {static PyObject *meth_QPlaceManagerEngine_managerName(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_managerName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->managerName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_managerName, doc_QPlaceManagerEngine_managerName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_managerVersion, "managerVersion(self) -> int");

extern "C" {static PyObject *meth_QPlaceManagerEngine_managerVersion(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_managerVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->managerVersion();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_managerVersion, doc_QPlaceManagerEngine_managerVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_getPlaceDetails, "getPlaceDetails(self, placeId: Optional[str]) -> Optional[QPlaceDetailsReply]");

extern "C" {static PyObject *meth_QPlaceManagerEngine_getPlaceDetails(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_getPlaceDetails(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QPlaceDetailsReply*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::getPlaceDetails(*a0) : sipCpp->getPlaceDetails(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromType(sipRes, sipType_QPlaceDetailsReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_getPlaceDetails, doc_QPlaceManagerEngine_getPlaceDetails);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_getPlaceContent, "getPlaceContent(self, request: QPlaceContentRequest) -> Optional[QPlaceContentReply]");

extern "C" {static PyObject *meth_QPlaceManagerEngine_getPlaceContent(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_getPlaceContent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPlaceContentRequest* a0;
        ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QPlaceContentRequest, &a0))
        {
            ::QPlaceContentReply*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::getPlaceContent(*a0) : sipCpp->getPlaceContent(*a0));

            return sipConvertFromType(sipRes, sipType_QPlaceContentReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_getPlaceContent, doc_QPlaceManagerEngine_getPlaceContent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_search, "search(self, request: QPlaceSearchRequest) -> Optional[QPlaceSearchReply]");

extern "C" {static PyObject *meth_QPlaceManagerEngine_search(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_search(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPlaceSearchRequest* a0;
        ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QPlaceSearchRequest, &a0))
        {
            ::QPlaceSearchReply*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::search(*a0) : sipCpp->search(*a0));

            return sipConvertFromType(sipRes, sipType_QPlaceSearchReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_search, doc_QPlaceManagerEngine_search);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_searchSuggestions, "searchSuggestions(self, request: QPlaceSearchRequest) -> Optional[QPlaceSearchSuggestionReply]");

extern "C" {static PyObject *meth_QPlaceManagerEngine_searchSuggestions(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_searchSuggestions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPlaceSearchRequest* a0;
        ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QPlaceSearchRequest, &a0))
        {
            ::QPlaceSearchSuggestionReply*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::searchSuggestions(*a0) : sipCpp->searchSuggestions(*a0));

            return sipConvertFromType(sipRes, sipType_QPlaceSearchSuggestionReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_searchSuggestions, doc_QPlaceManagerEngine_searchSuggestions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_savePlace, "savePlace(self, place: QPlace) -> Optional[QPlaceIdReply]");

extern "C" {static PyObject *meth_QPlaceManagerEngine_savePlace(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_savePlace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPlace* a0;
        ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QPlace, &a0))
        {
            ::QPlaceIdReply*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::savePlace(*a0) : sipCpp->savePlace(*a0));

            return sipConvertFromType(sipRes, sipType_QPlaceIdReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_savePlace, doc_QPlaceManagerEngine_savePlace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_removePlace, "removePlace(self, placeId: Optional[str]) -> Optional[QPlaceIdReply]");

extern "C" {static PyObject *meth_QPlaceManagerEngine_removePlace(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_removePlace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QPlaceIdReply*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::removePlace(*a0) : sipCpp->removePlace(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromType(sipRes, sipType_QPlaceIdReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_removePlace, doc_QPlaceManagerEngine_removePlace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_saveCategory, "saveCategory(self, category: QPlaceCategory, parentId: Optional[str]) -> Optional[QPlaceIdReply]");

extern "C" {static PyObject *meth_QPlaceManagerEngine_saveCategory(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_saveCategory(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPlaceCategory* a0;
        const ::QString* a1;
        int a1State = 0;
        ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QPlaceCategory, &a0, sipType_QString, &a1, &a1State))
        {
            ::QPlaceIdReply*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::saveCategory(*a0, *a1) : sipCpp->saveCategory(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromType(sipRes, sipType_QPlaceIdReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_saveCategory, doc_QPlaceManagerEngine_saveCategory);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_removeCategory, "removeCategory(self, categoryId: Optional[str]) -> Optional[QPlaceIdReply]");

extern "C" {static PyObject *meth_QPlaceManagerEngine_removeCategory(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_removeCategory(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QPlaceIdReply*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::removeCategory(*a0) : sipCpp->removeCategory(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromType(sipRes, sipType_QPlaceIdReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_removeCategory, doc_QPlaceManagerEngine_removeCategory);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_initializeCategories, "initializeCategories(self) -> Optional[QPlaceReply]");

extern "C" {static PyObject *meth_QPlaceManagerEngine_initializeCategories(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_initializeCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp))
        {
            ::QPlaceReply*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::initializeCategories() : sipCpp->initializeCategories());

            return sipConvertFromType(sipRes, sipType_QPlaceReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_initializeCategories, doc_QPlaceManagerEngine_initializeCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_parentCategoryId, "parentCategoryId(self, categoryId: Optional[str]) -> str");

extern "C" {static PyObject *meth_QPlaceManagerEngine_parentCategoryId(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_parentCategoryId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString((sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::parentCategoryId(*a0) : sipCpp->parentCategoryId(*a0)));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_parentCategoryId, doc_QPlaceManagerEngine_parentCategoryId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_childCategoryIds, "childCategoryIds(self, categoryId: Optional[str]) -> list[str]");

extern "C" {static PyObject *meth_QPlaceManagerEngine_childCategoryIds(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_childCategoryIds(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList((sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::childCategoryIds(*a0) : sipCpp->childCategoryIds(*a0)));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_childCategoryIds, doc_QPlaceManagerEngine_childCategoryIds);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_category, "category(self, categoryId: Optional[str]) -> QPlaceCategory");

extern "C" {static PyObject *meth_QPlaceManagerEngine_category(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_category(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QPlaceCategory*sipRes;

            sipRes = new ::QPlaceCategory((sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::category(*a0) : sipCpp->category(*a0)));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QPlaceCategory, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_category, doc_QPlaceManagerEngine_category);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_childCategories, "childCategories(self, parentId: Optional[str]) -> list[QPlaceCategory]");

extern "C" {static PyObject *meth_QPlaceManagerEngine_childCategories(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_childCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            QList< ::QPlaceCategory>*sipRes;

            sipRes = new QList< ::QPlaceCategory>((sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::childCategories(*a0) : sipCpp->childCategories(*a0)));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QList_0100QPlaceCategory, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_childCategories, doc_QPlaceManagerEngine_childCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_locales, "locales(self) -> list[QLocale]");

extern "C" {static PyObject *meth_QPlaceManagerEngine_locales(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_locales(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp))
        {
            QList< ::QLocale>*sipRes;

            sipRes = new QList< ::QLocale>((sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::locales() : sipCpp->locales()));

            return sipConvertFromNewType(sipRes, sipType_QList_0100QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_locales, doc_QPlaceManagerEngine_locales);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_setLocales, "setLocales(self, locales: Iterable[QLocale])");

extern "C" {static PyObject *meth_QPlaceManagerEngine_setLocales(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_setLocales(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const QList< ::QLocale>* a0;
        int a0State = 0;
        ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QList_0100QLocale, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::setLocales(*a0) : sipCpp->setLocales(*a0));
            sipReleaseType(const_cast<QList< ::QLocale> *>(a0), sipType_QList_0100QLocale, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_setLocales, doc_QPlaceManagerEngine_setLocales);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_constructIconUrl, "constructIconUrl(self, icon: QPlaceIcon, size: QSize) -> QUrl");

extern "C" {static PyObject *meth_QPlaceManagerEngine_constructIconUrl(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_constructIconUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPlaceIcon* a0;
        const ::QSize* a1;
        const ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QPlaceIcon, &a0, sipType_QSize, &a1))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl((sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::constructIconUrl(*a0, *a1) : sipCpp->constructIconUrl(*a0, *a1)));

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_constructIconUrl, doc_QPlaceManagerEngine_constructIconUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_compatiblePlace, "compatiblePlace(self, original: QPlace) -> QPlace");

extern "C" {static PyObject *meth_QPlaceManagerEngine_compatiblePlace(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_compatiblePlace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPlace* a0;
        const ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QPlace, &a0))
        {
            ::QPlace*sipRes;

            sipRes = new ::QPlace((sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::compatiblePlace(*a0) : sipCpp->compatiblePlace(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QPlace, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_compatiblePlace, doc_QPlaceManagerEngine_compatiblePlace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_matchingPlaces, "matchingPlaces(self, request: QPlaceMatchRequest) -> Optional[QPlaceMatchReply]");

extern "C" {static PyObject *meth_QPlaceManagerEngine_matchingPlaces(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_matchingPlaces(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QPlaceMatchRequest* a0;
        ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp, sipType_QPlaceMatchRequest, &a0))
        {
            ::QPlaceMatchReply*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QPlaceManagerEngine::matchingPlaces(*a0) : sipCpp->matchingPlaces(*a0));

            return sipConvertFromType(sipRes, sipType_QPlaceMatchReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_matchingPlaces, doc_QPlaceManagerEngine_matchingPlaces);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManagerEngine_manager, "manager(self) -> Optional[QPlaceManager]");

extern "C" {static PyObject *meth_QPlaceManagerEngine_manager(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManagerEngine_manager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QPlaceManagerEngine, &sipCpp))
        {
            ::QPlaceManager*sipRes;

            sipRes = sipCpp->manager();

            return sipConvertFromType(sipRes, sipType_QPlaceManager, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_manager, doc_QPlaceManagerEngine_manager);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPlaceManagerEngine(void *, const sipTypeDef *);}
static void *cast_QPlaceManagerEngine(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPlaceManagerEngine *sipCpp = reinterpret_cast< ::QPlaceManagerEngine *>(sipCppV);

    if (targetType == sipType_QPlaceManagerEngine)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPlaceManagerEngine(void *, int);}
static void release_QPlaceManagerEngine(void *sipCppV, int)
{
    ::QPlaceManagerEngine *sipCpp = reinterpret_cast< ::QPlaceManagerEngine *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QPlaceManagerEngine(sipSimpleWrapper *);}
static void dealloc_QPlaceManagerEngine(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPlaceManagerEngine *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPlaceManagerEngine(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPlaceManagerEngine(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPlaceManagerEngine(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQPlaceManagerEngine *sipCpp = SIP_NULLPTR;

    {
        const ::QVariantMap* a0;
        int a0State = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QVariantMap, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQPlaceManagerEngine(*a0, a1);
            sipReleaseType(const_cast< ::QVariantMap *>(a0), sipType_QVariantMap, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPlaceManagerEngine[] = {{7, 0, 1}};


static PyMethodDef methods_QPlaceManagerEngine[] = {
    {sipName_category, meth_QPlaceManagerEngine_category, METH_VARARGS, doc_QPlaceManagerEngine_category},
    {sipName_childCategories, meth_QPlaceManagerEngine_childCategories, METH_VARARGS, doc_QPlaceManagerEngine_childCategories},
    {sipName_childCategoryIds, meth_QPlaceManagerEngine_childCategoryIds, METH_VARARGS, doc_QPlaceManagerEngine_childCategoryIds},
    {sipName_compatiblePlace, meth_QPlaceManagerEngine_compatiblePlace, METH_VARARGS, doc_QPlaceManagerEngine_compatiblePlace},
    {sipName_constructIconUrl, meth_QPlaceManagerEngine_constructIconUrl, METH_VARARGS, doc_QPlaceManagerEngine_constructIconUrl},
    {sipName_getPlaceContent, meth_QPlaceManagerEngine_getPlaceContent, METH_VARARGS, doc_QPlaceManagerEngine_getPlaceContent},
    {sipName_getPlaceDetails, meth_QPlaceManagerEngine_getPlaceDetails, METH_VARARGS, doc_QPlaceManagerEngine_getPlaceDetails},
    {sipName_initializeCategories, meth_QPlaceManagerEngine_initializeCategories, METH_VARARGS, doc_QPlaceManagerEngine_initializeCategories},
    {sipName_locales, meth_QPlaceManagerEngine_locales, METH_VARARGS, doc_QPlaceManagerEngine_locales},
    {sipName_manager, meth_QPlaceManagerEngine_manager, METH_VARARGS, doc_QPlaceManagerEngine_manager},
    {sipName_managerName, meth_QPlaceManagerEngine_managerName, METH_VARARGS, doc_QPlaceManagerEngine_managerName},
    {sipName_managerVersion, meth_QPlaceManagerEngine_managerVersion, METH_VARARGS, doc_QPlaceManagerEngine_managerVersion},
    {sipName_matchingPlaces, meth_QPlaceManagerEngine_matchingPlaces, METH_VARARGS, doc_QPlaceManagerEngine_matchingPlaces},
    {sipName_parentCategoryId, meth_QPlaceManagerEngine_parentCategoryId, METH_VARARGS, doc_QPlaceManagerEngine_parentCategoryId},
    {sipName_removeCategory, meth_QPlaceManagerEngine_removeCategory, METH_VARARGS, doc_QPlaceManagerEngine_removeCategory},
    {sipName_removePlace, meth_QPlaceManagerEngine_removePlace, METH_VARARGS, doc_QPlaceManagerEngine_removePlace},
    {sipName_saveCategory, meth_QPlaceManagerEngine_saveCategory, METH_VARARGS, doc_QPlaceManagerEngine_saveCategory},
    {sipName_savePlace, meth_QPlaceManagerEngine_savePlace, METH_VARARGS, doc_QPlaceManagerEngine_savePlace},
    {sipName_search, meth_QPlaceManagerEngine_search, METH_VARARGS, doc_QPlaceManagerEngine_search},
    {sipName_searchSuggestions, meth_QPlaceManagerEngine_searchSuggestions, METH_VARARGS, doc_QPlaceManagerEngine_searchSuggestions},
    {sipName_setLocales, meth_QPlaceManagerEngine_setLocales, METH_VARARGS, doc_QPlaceManagerEngine_setLocales}
};

PyDoc_STRVAR(doc_QPlaceManagerEngine, "\1QPlaceManagerEngine(parameters: dict[str, Any], parent: Optional[QObject] = None)");


extern "C" {static int emit_QPlaceManagerEngine_error(void *, PyObject *);}

static int emit_QPlaceManagerEngine_error(void *sipCppV, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    ::QPlaceManagerEngine *sipCpp = reinterpret_cast< ::QPlaceManagerEngine *>(sipCppV);

    {
        ::QPlaceReply* a0;
        ::QPlaceReply::Error a1;
        const ::QString& a2def = QString();
        const ::QString* a2 = &a2def;
        int a2State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8E|J1", sipType_QPlaceReply, &a0, sipType_QPlaceReply_Error, &a1, sipType_QString, &a2, &a2State))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->error(a0, a1, *a2);
            Py_END_ALLOW_THREADS

            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);

            return 0;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManagerEngine, sipName_error, SIP_NULLPTR);

    return -1;
}


/* Define this type's signals. */
static const pyqt5QtSignal signals_QPlaceManagerEngine[] = {
    {"dataChanged()", "\1dataChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"categoryRemoved(QString,QString)", "\1categoryRemoved(self, categoryId: Optional[str], parentCategoryId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"categoryUpdated(QPlaceCategory,QString)", "\1categoryUpdated(self, category: QPlaceCategory, parentCategoryId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"categoryAdded(QPlaceCategory,QString)", "\1categoryAdded(self, category: QPlaceCategory, parentCategoryId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"placeRemoved(QString)", "\1placeRemoved(self, placeId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"placeUpdated(QString)", "\1placeUpdated(self, placeId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"placeAdded(QString)", "\1placeAdded(self, placeId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QPlaceReply*,QPlaceReply::Error,QString)", "\1error(self, a0: Optional[QPlaceReply], error: QPlaceReply.Error, errorString: Optional[str] = '')", SIP_NULLPTR, emit_QPlaceManagerEngine_error},
    {"finished(QPlaceReply*)", "\1finished(self, reply: Optional[QPlaceReply])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QPlaceManagerEngine = {
    &::QPlaceManagerEngine::staticMetaObject,
    0,
    signals_QPlaceManagerEngine,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QPlaceManagerEngine = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPlaceManagerEngine,
        SIP_NULLPTR,
        &plugin_QPlaceManagerEngine,
    },
    {
        sipNameNr_QPlaceManagerEngine,
        {0, 0, 1},
        21, methods_QPlaceManagerEngine,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPlaceManagerEngine,
    -1,
    -1,
    supers_QPlaceManagerEngine,
    SIP_NULLPTR,
    init_type_QPlaceManagerEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPlaceManagerEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QPlaceManagerEngine,
    cast_QPlaceManagerEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QPlaceManagerEngine),
};
