/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoroutingmanager.sip"
#include <qgeoroutingmanager.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoroutereply.sip"
#include <qgeoroutereply.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoroute.sip"
#include <qgeoroute.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeocoordinate.sip"
#include <qgeocoordinate.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManager.cpp"


PyDoc_STRVAR(doc_QGeoRoutingManager_managerName, "managerName(self) -> str");

extern "C" {static PyObject *meth_QGeoRoutingManager_managerName(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManager_managerName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManager, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->managerName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManager, sipName_managerName, doc_QGeoRoutingManager_managerName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManager_managerVersion, "managerVersion(self) -> int");

extern "C" {static PyObject *meth_QGeoRoutingManager_managerVersion(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManager_managerVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManager, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->managerVersion();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManager, sipName_managerVersion, doc_QGeoRoutingManager_managerVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManager_calculateRoute, "calculateRoute(self, request: QGeoRouteRequest) -> Optional[QGeoRouteReply]");

extern "C" {static PyObject *meth_QGeoRoutingManager_calculateRoute(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManager_calculateRoute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteRequest* a0;
        ::QGeoRoutingManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRoutingManager, &sipCpp, sipType_QGeoRouteRequest, &a0))
        {
            ::QGeoRouteReply*sipRes;

            sipRes = sipCpp->calculateRoute(*a0);

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManager, sipName_calculateRoute, doc_QGeoRoutingManager_calculateRoute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManager_updateRoute, "updateRoute(self, route: QGeoRoute, position: QGeoCoordinate) -> Optional[QGeoRouteReply]");

extern "C" {static PyObject *meth_QGeoRoutingManager_updateRoute(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManager_updateRoute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoute* a0;
        const ::QGeoCoordinate* a1;
        ::QGeoRoutingManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QGeoRoutingManager, &sipCpp, sipType_QGeoRoute, &a0, sipType_QGeoCoordinate, &a1))
        {
            ::QGeoRouteReply*sipRes;

            sipRes = sipCpp->updateRoute(*a0, *a1);

            sipTransferTo(sipSelf, SIP_NULLPTR);

            return sipConvertFromType(sipRes, sipType_QGeoRouteReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManager, sipName_updateRoute, doc_QGeoRoutingManager_updateRoute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManager_supportedTravelModes, "supportedTravelModes(self) -> QGeoRouteRequest.TravelModes");

extern "C" {static PyObject *meth_QGeoRoutingManager_supportedTravelModes(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManager_supportedTravelModes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManager, &sipCpp))
        {
            ::QGeoRouteRequest::TravelModes*sipRes;

            sipRes = new ::QGeoRouteRequest::TravelModes(sipCpp->supportedTravelModes());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_TravelModes, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManager, sipName_supportedTravelModes, doc_QGeoRoutingManager_supportedTravelModes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManager_supportedFeatureTypes, "supportedFeatureTypes(self) -> QGeoRouteRequest.FeatureTypes");

extern "C" {static PyObject *meth_QGeoRoutingManager_supportedFeatureTypes(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManager_supportedFeatureTypes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManager, &sipCpp))
        {
            ::QGeoRouteRequest::FeatureTypes*sipRes;

            sipRes = new ::QGeoRouteRequest::FeatureTypes(sipCpp->supportedFeatureTypes());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_FeatureTypes, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManager, sipName_supportedFeatureTypes, doc_QGeoRoutingManager_supportedFeatureTypes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManager_supportedFeatureWeights, "supportedFeatureWeights(self) -> QGeoRouteRequest.FeatureWeights");

extern "C" {static PyObject *meth_QGeoRoutingManager_supportedFeatureWeights(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManager_supportedFeatureWeights(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManager, &sipCpp))
        {
            ::QGeoRouteRequest::FeatureWeights*sipRes;

            sipRes = new ::QGeoRouteRequest::FeatureWeights(sipCpp->supportedFeatureWeights());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_FeatureWeights, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManager, sipName_supportedFeatureWeights, doc_QGeoRoutingManager_supportedFeatureWeights);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManager_supportedRouteOptimizations, "supportedRouteOptimizations(self) -> QGeoRouteRequest.RouteOptimizations");

extern "C" {static PyObject *meth_QGeoRoutingManager_supportedRouteOptimizations(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManager_supportedRouteOptimizations(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManager, &sipCpp))
        {
            ::QGeoRouteRequest::RouteOptimizations*sipRes;

            sipRes = new ::QGeoRouteRequest::RouteOptimizations(sipCpp->supportedRouteOptimizations());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_RouteOptimizations, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManager, sipName_supportedRouteOptimizations, doc_QGeoRoutingManager_supportedRouteOptimizations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManager_supportedSegmentDetails, "supportedSegmentDetails(self) -> QGeoRouteRequest.SegmentDetails");

extern "C" {static PyObject *meth_QGeoRoutingManager_supportedSegmentDetails(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManager_supportedSegmentDetails(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManager, &sipCpp))
        {
            ::QGeoRouteRequest::SegmentDetails*sipRes;

            sipRes = new ::QGeoRouteRequest::SegmentDetails(sipCpp->supportedSegmentDetails());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_SegmentDetails, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManager, sipName_supportedSegmentDetails, doc_QGeoRoutingManager_supportedSegmentDetails);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManager_supportedManeuverDetails, "supportedManeuverDetails(self) -> QGeoRouteRequest.ManeuverDetails");

extern "C" {static PyObject *meth_QGeoRoutingManager_supportedManeuverDetails(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManager_supportedManeuverDetails(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManager, &sipCpp))
        {
            ::QGeoRouteRequest::ManeuverDetails*sipRes;

            sipRes = new ::QGeoRouteRequest::ManeuverDetails(sipCpp->supportedManeuverDetails());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_ManeuverDetails, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManager, sipName_supportedManeuverDetails, doc_QGeoRoutingManager_supportedManeuverDetails);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManager_setLocale, "setLocale(self, locale: QLocale)");

extern "C" {static PyObject *meth_QGeoRoutingManager_setLocale(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManager_setLocale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale* a0;
        ::QGeoRoutingManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRoutingManager, &sipCpp, sipType_QLocale, &a0))
        {
            sipCpp->setLocale(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManager, sipName_setLocale, doc_QGeoRoutingManager_setLocale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManager_locale, "locale(self) -> QLocale");

extern "C" {static PyObject *meth_QGeoRoutingManager_locale(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManager_locale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManager, &sipCpp))
        {
            ::QLocale*sipRes;

            sipRes = new ::QLocale(sipCpp->locale());

            return sipConvertFromNewType(sipRes, sipType_QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManager, sipName_locale, doc_QGeoRoutingManager_locale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManager_setMeasurementSystem, "setMeasurementSystem(self, system: QLocale.MeasurementSystem)");

extern "C" {static PyObject *meth_QGeoRoutingManager_setMeasurementSystem(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManager_setMeasurementSystem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::MeasurementSystem a0;
        ::QGeoRoutingManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGeoRoutingManager, &sipCpp, sipType_QLocale_MeasurementSystem, &a0))
        {
            sipCpp->setMeasurementSystem(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManager, sipName_setMeasurementSystem, doc_QGeoRoutingManager_setMeasurementSystem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManager_measurementSystem, "measurementSystem(self) -> QLocale.MeasurementSystem");

extern "C" {static PyObject *meth_QGeoRoutingManager_measurementSystem(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManager_measurementSystem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManager, &sipCpp))
        {
            ::QLocale::MeasurementSystem sipRes;

            sipRes = sipCpp->measurementSystem();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocale_MeasurementSystem);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManager, sipName_measurementSystem, doc_QGeoRoutingManager_measurementSystem);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGeoRoutingManager(void *, const sipTypeDef *);}
static void *cast_QGeoRoutingManager(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGeoRoutingManager *sipCpp = reinterpret_cast< ::QGeoRoutingManager *>(sipCppV);

    if (targetType == sipType_QGeoRoutingManager)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoRoutingManager(void *, int);}
static void release_QGeoRoutingManager(void *sipCppV, int)
{
    ::QGeoRoutingManager *sipCpp = reinterpret_cast< ::QGeoRoutingManager *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QGeoRoutingManager(sipSimpleWrapper *);}
static void dealloc_QGeoRoutingManager(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoRoutingManager(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGeoRoutingManager[] = {{7, 0, 1}};


static PyMethodDef methods_QGeoRoutingManager[] = {
    {sipName_calculateRoute, meth_QGeoRoutingManager_calculateRoute, METH_VARARGS, doc_QGeoRoutingManager_calculateRoute},
    {sipName_locale, meth_QGeoRoutingManager_locale, METH_VARARGS, doc_QGeoRoutingManager_locale},
    {sipName_managerName, meth_QGeoRoutingManager_managerName, METH_VARARGS, doc_QGeoRoutingManager_managerName},
    {sipName_managerVersion, meth_QGeoRoutingManager_managerVersion, METH_VARARGS, doc_QGeoRoutingManager_managerVersion},
    {sipName_measurementSystem, meth_QGeoRoutingManager_measurementSystem, METH_VARARGS, doc_QGeoRoutingManager_measurementSystem},
    {sipName_setLocale, meth_QGeoRoutingManager_setLocale, METH_VARARGS, doc_QGeoRoutingManager_setLocale},
    {sipName_setMeasurementSystem, meth_QGeoRoutingManager_setMeasurementSystem, METH_VARARGS, doc_QGeoRoutingManager_setMeasurementSystem},
    {sipName_supportedFeatureTypes, meth_QGeoRoutingManager_supportedFeatureTypes, METH_VARARGS, doc_QGeoRoutingManager_supportedFeatureTypes},
    {sipName_supportedFeatureWeights, meth_QGeoRoutingManager_supportedFeatureWeights, METH_VARARGS, doc_QGeoRoutingManager_supportedFeatureWeights},
    {sipName_supportedManeuverDetails, meth_QGeoRoutingManager_supportedManeuverDetails, METH_VARARGS, doc_QGeoRoutingManager_supportedManeuverDetails},
    {sipName_supportedRouteOptimizations, meth_QGeoRoutingManager_supportedRouteOptimizations, METH_VARARGS, doc_QGeoRoutingManager_supportedRouteOptimizations},
    {sipName_supportedSegmentDetails, meth_QGeoRoutingManager_supportedSegmentDetails, METH_VARARGS, doc_QGeoRoutingManager_supportedSegmentDetails},
    {sipName_supportedTravelModes, meth_QGeoRoutingManager_supportedTravelModes, METH_VARARGS, doc_QGeoRoutingManager_supportedTravelModes},
    {sipName_updateRoute, meth_QGeoRoutingManager_updateRoute, METH_VARARGS, doc_QGeoRoutingManager_updateRoute}
};


extern "C" {static int emit_QGeoRoutingManager_error(void *, PyObject *);}

static int emit_QGeoRoutingManager_error(void *sipCppV, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    ::QGeoRoutingManager *sipCpp = reinterpret_cast< ::QGeoRoutingManager *>(sipCppV);

    {
        ::QGeoRouteReply* a0;
        ::QGeoRouteReply::Error a1;
        ::QString a2def = QString();
        ::QString* a2 = &a2def;
        int a2State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8E|J1", sipType_QGeoRouteReply, &a0, sipType_QGeoRouteReply_Error, &a1, sipType_QString, &a2, &a2State))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->error(a0, a1, *a2);
            Py_END_ALLOW_THREADS

            sipReleaseType(a2, sipType_QString, a2State);

            return 0;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManager, sipName_error, SIP_NULLPTR);

    return -1;
}


/* Define this type's signals. */
static const pyqt5QtSignal signals_QGeoRoutingManager[] = {
    {"error(QGeoRouteReply*,QGeoRouteReply::Error,QString)", "\1error(self, reply: Optional[QGeoRouteReply], error: QGeoRouteReply.Error, errorString: Optional[str] = '')", SIP_NULLPTR, emit_QGeoRoutingManager_error},
    {"finished(QGeoRouteReply*)", "\1finished(self, reply: Optional[QGeoRouteReply])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QGeoRoutingManager = {
    &::QGeoRoutingManager::staticMetaObject,
    0,
    signals_QGeoRoutingManager,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QGeoRoutingManager = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoRoutingManager,
        SIP_NULLPTR,
        &plugin_QGeoRoutingManager,
    },
    {
        sipNameNr_QGeoRoutingManager,
        {0, 0, 1},
        14, methods_QGeoRoutingManager,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QGeoRoutingManager,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoRoutingManager,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QGeoRoutingManager,
    cast_QGeoRoutingManager,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
