/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameraimagecapture.sip"
#include <qcameraimagecapture.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaobject.sip"
#include <qmediaobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qvideoframe.sip"
#include <qvideoframe.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qimage.sip"
#include <qimage.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameraimagecapture.sip"
#include <qcameraimagecapture.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qpymultimedia_qlist.sip"
#include <qvideoframe.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaencodersettings.sip"
#include <qmediaencodersettings.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmultimedia.sip"
#include <qmultimedia.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageCapture.cpp"


class sipQCameraImageCapture : public ::QCameraImageCapture
{
public:
    sipQCameraImageCapture(::QMediaObject*, ::QObject*);
    virtual ~sipQCameraImageCapture();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QMediaObject* mediaObject() const SIP_OVERRIDE;
    bool setMediaObject(::QMediaObject*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQCameraImageCapture(const sipQCameraImageCapture &);
    sipQCameraImageCapture &operator = (const sipQCameraImageCapture &);

    char sipPyMethods[9];
};

sipQCameraImageCapture::sipQCameraImageCapture(::QMediaObject*a0, ::QObject*a1): ::QCameraImageCapture(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCameraImageCapture::~sipQCameraImageCapture()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQCameraImageCapture::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QCameraImageCapture);

    return ::QCameraImageCapture::metaObject();
}

int sipQCameraImageCapture::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QCameraImageCapture::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QCameraImageCapture, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQCameraImageCapture::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QCameraImageCapture, _clname, &sipCpp) ? sipCpp : ::QCameraImageCapture::qt_metacast(_clname));
}

::QMediaObject* sipQCameraImageCapture::mediaObject() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_mediaObject);

    if (!sipMeth)
        return ::QCameraImageCapture::mediaObject();

    extern ::QMediaObject* sipVH_QtMultimedia_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_36(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQCameraImageCapture::setMediaObject(::QMediaObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_setMediaObject);

    if (!sipMeth)
        return ::QCameraImageCapture::setMediaObject(a0);

    extern bool sipVH_QtMultimedia_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMediaObject*);

    return sipVH_QtMultimedia_37(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCameraImageCapture::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QCameraImageCapture::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCameraImageCapture::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QCameraImageCapture::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQCameraImageCapture::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QCameraImageCapture::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraImageCapture::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QCameraImageCapture::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraImageCapture::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QCameraImageCapture::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraImageCapture::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QCameraImageCapture::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCameraImageCapture::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QCameraImageCapture::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QCameraImageCapture_isAvailable, "isAvailable(self) -> bool");

extern "C" {static PyObject *meth_QCameraImageCapture_isAvailable(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_isAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageCapture, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_isAvailable, doc_QCameraImageCapture_isAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_availability, "availability(self) -> QMultimedia.AvailabilityStatus");

extern "C" {static PyObject *meth_QCameraImageCapture_availability(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_availability(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageCapture, &sipCpp))
        {
            ::QMultimedia::AvailabilityStatus sipRes;

            sipRes = sipCpp->availability();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMultimedia_AvailabilityStatus);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_availability, doc_QCameraImageCapture_availability);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_mediaObject, "mediaObject(self) -> Optional[QMediaObject]");

extern "C" {static PyObject *meth_QCameraImageCapture_mediaObject(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_mediaObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageCapture, &sipCpp))
        {
            ::QMediaObject*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QCameraImageCapture::mediaObject() : sipCpp->mediaObject());

            return sipConvertFromType(sipRes, sipType_QMediaObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_mediaObject, doc_QCameraImageCapture_mediaObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_error, "error(self) -> QCameraImageCapture.Error");

extern "C" {static PyObject *meth_QCameraImageCapture_error(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageCapture, &sipCpp))
        {
            ::QCameraImageCapture::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCameraImageCapture_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_error, doc_QCameraImageCapture_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QCameraImageCapture_errorString(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageCapture, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_errorString, doc_QCameraImageCapture_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_isReadyForCapture, "isReadyForCapture(self) -> bool");

extern "C" {static PyObject *meth_QCameraImageCapture_isReadyForCapture(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_isReadyForCapture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageCapture, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isReadyForCapture();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_isReadyForCapture, doc_QCameraImageCapture_isReadyForCapture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_supportedImageCodecs, "supportedImageCodecs(self) -> list[str]");

extern "C" {static PyObject *meth_QCameraImageCapture_supportedImageCodecs(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_supportedImageCodecs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageCapture, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->supportedImageCodecs());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_supportedImageCodecs, doc_QCameraImageCapture_supportedImageCodecs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_imageCodecDescription, "imageCodecDescription(self, codecName: Optional[str]) -> str");

extern "C" {static PyObject *meth_QCameraImageCapture_imageCodecDescription(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_imageCodecDescription(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCameraImageCapture, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->imageCodecDescription(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_imageCodecDescription, doc_QCameraImageCapture_imageCodecDescription);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_supportedResolutions, "supportedResolutions(self, settings: QImageEncoderSettings = QImageEncoderSettings()) -> (list[QSize], Optional[bool])");

extern "C" {static PyObject *meth_QCameraImageCapture_supportedResolutions(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_supportedResolutions(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImageEncoderSettings& a0def = QImageEncoderSettings();
        const ::QImageEncoderSettings* a0 = &a0def;
        bool a1;
        const ::QCameraImageCapture *sipCpp;

        static const char *sipKwdList[] = {
            sipName_settings,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QCameraImageCapture, &sipCpp, sipType_QImageEncoderSettings, &a0))
        {
            QList< ::QSize>*sipRes;

            sipRes = new QList< ::QSize>(sipCpp->supportedResolutions(*a0, &a1));

            PyObject *sipResObj = sipConvertFromNewType(sipRes, sipType_QList_0100QSize, SIP_NULLPTR);
            return sipBuildResult(0, "(Rb)", sipResObj, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_supportedResolutions, doc_QCameraImageCapture_supportedResolutions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_encodingSettings, "encodingSettings(self) -> QImageEncoderSettings");

extern "C" {static PyObject *meth_QCameraImageCapture_encodingSettings(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_encodingSettings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageCapture, &sipCpp))
        {
            ::QImageEncoderSettings*sipRes;

            sipRes = new ::QImageEncoderSettings(sipCpp->encodingSettings());

            return sipConvertFromNewType(sipRes, sipType_QImageEncoderSettings, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_encodingSettings, doc_QCameraImageCapture_encodingSettings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_setEncodingSettings, "setEncodingSettings(self, settings: QImageEncoderSettings)");

extern "C" {static PyObject *meth_QCameraImageCapture_setEncodingSettings(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_setEncodingSettings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImageEncoderSettings* a0;
        ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QCameraImageCapture, &sipCpp, sipType_QImageEncoderSettings, &a0))
        {
            sipCpp->setEncodingSettings(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_setEncodingSettings, doc_QCameraImageCapture_setEncodingSettings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_supportedBufferFormats, "supportedBufferFormats(self) -> list[QVideoFrame.PixelFormat]");

extern "C" {static PyObject *meth_QCameraImageCapture_supportedBufferFormats(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_supportedBufferFormats(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageCapture, &sipCpp))
        {
            ::QList< ::QVideoFrame::PixelFormat>*sipRes;

            sipRes = new ::QList< ::QVideoFrame::PixelFormat>(sipCpp->supportedBufferFormats());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QVideoFrame_PixelFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_supportedBufferFormats, doc_QCameraImageCapture_supportedBufferFormats);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_bufferFormat, "bufferFormat(self) -> QVideoFrame.PixelFormat");

extern "C" {static PyObject *meth_QCameraImageCapture_bufferFormat(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_bufferFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageCapture, &sipCpp))
        {
            ::QVideoFrame::PixelFormat sipRes;

            sipRes = sipCpp->bufferFormat();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QVideoFrame_PixelFormat);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_bufferFormat, doc_QCameraImageCapture_bufferFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_setBufferFormat, "setBufferFormat(self, format: QVideoFrame.PixelFormat)");

extern "C" {static PyObject *meth_QCameraImageCapture_setBufferFormat(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_setBufferFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVideoFrame::PixelFormat a0;
        ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraImageCapture, &sipCpp, sipType_QVideoFrame_PixelFormat, &a0))
        {
            sipCpp->setBufferFormat(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_setBufferFormat, doc_QCameraImageCapture_setBufferFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_isCaptureDestinationSupported, "isCaptureDestinationSupported(self, destination: Union[QCameraImageCapture.CaptureDestinations, QCameraImageCapture.CaptureDestination]) -> bool");

extern "C" {static PyObject *meth_QCameraImageCapture_isCaptureDestinationSupported(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_isCaptureDestinationSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCameraImageCapture::CaptureDestinations* a0;
        int a0State = 0;
        const ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCameraImageCapture, &sipCpp, sipType_QCameraImageCapture_CaptureDestinations, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->isCaptureDestinationSupported(*a0);
            sipReleaseType(a0, sipType_QCameraImageCapture_CaptureDestinations, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_isCaptureDestinationSupported, doc_QCameraImageCapture_isCaptureDestinationSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_captureDestination, "captureDestination(self) -> QCameraImageCapture.CaptureDestinations");

extern "C" {static PyObject *meth_QCameraImageCapture_captureDestination(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_captureDestination(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageCapture, &sipCpp))
        {
            ::QCameraImageCapture::CaptureDestinations*sipRes;

            sipRes = new ::QCameraImageCapture::CaptureDestinations(sipCpp->captureDestination());

            return sipConvertFromNewType(sipRes, sipType_QCameraImageCapture_CaptureDestinations, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_captureDestination, doc_QCameraImageCapture_captureDestination);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_setCaptureDestination, "setCaptureDestination(self, destination: Union[QCameraImageCapture.CaptureDestinations, QCameraImageCapture.CaptureDestination])");

extern "C" {static PyObject *meth_QCameraImageCapture_setCaptureDestination(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_setCaptureDestination(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCameraImageCapture::CaptureDestinations* a0;
        int a0State = 0;
        ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCameraImageCapture, &sipCpp, sipType_QCameraImageCapture_CaptureDestinations, &a0, &a0State))
        {
            sipCpp->setCaptureDestination(*a0);
            sipReleaseType(a0, sipType_QCameraImageCapture_CaptureDestinations, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_setCaptureDestination, doc_QCameraImageCapture_setCaptureDestination);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_capture, "capture(self, file: Optional[str] = '') -> int");

extern "C" {static PyObject *meth_QCameraImageCapture_capture(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_capture(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString& a0def = QString();
        const ::QString* a0 = &a0def;
        int a0State = 0;
        ::QCameraImageCapture *sipCpp;

        static const char *sipKwdList[] = {
            sipName_file,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QCameraImageCapture, &sipCpp, sipType_QString, &a0, &a0State))
        {
            int sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->capture(*a0);
            Py_END_ALLOW_THREADS
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_capture, doc_QCameraImageCapture_capture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_cancelCapture, "cancelCapture(self)");

extern "C" {static PyObject *meth_QCameraImageCapture_cancelCapture(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_cancelCapture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageCapture, &sipCpp))
        {
            sipCpp->cancelCapture();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_cancelCapture, doc_QCameraImageCapture_cancelCapture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageCapture_setMediaObject, "setMediaObject(self, a0: Optional[QMediaObject]) -> bool");

extern "C" {static PyObject *meth_QCameraImageCapture_setMediaObject(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageCapture_setMediaObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMediaObject* a0;
        ::QCameraImageCapture *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QCameraImageCapture, &sipCpp, sipType_QMediaObject, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QCameraImageCapture::setMediaObject(a0) : sipCpp->setMediaObject(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageCapture, sipName_setMediaObject, doc_QCameraImageCapture_setMediaObject);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QCameraImageCapture(void *, const sipTypeDef *);}
static void *cast_QCameraImageCapture(void *sipCppV, const sipTypeDef *targetType)
{
    ::QCameraImageCapture *sipCpp = reinterpret_cast< ::QCameraImageCapture *>(sipCppV);

    if (targetType == sipType_QCameraImageCapture)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    if (targetType == sipType_QMediaBindableInterface)
        return static_cast< ::QMediaBindableInterface *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QCameraImageCapture(void *, int);}
static void release_QCameraImageCapture(void *sipCppV, int)
{
    ::QCameraImageCapture *sipCpp = reinterpret_cast< ::QCameraImageCapture *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QCameraImageCapture(sipSimpleWrapper *);}
static void dealloc_QCameraImageCapture(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQCameraImageCapture *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QCameraImageCapture(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QCameraImageCapture(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QCameraImageCapture(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQCameraImageCapture *sipCpp = SIP_NULLPTR;

    {
        ::QMediaObject* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|JH", sipType_QMediaObject, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQCameraImageCapture(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QCameraImageCapture[] = {{9, 0, 0}, {101, 255, 1}};


static PyMethodDef methods_QCameraImageCapture[] = {
    {sipName_availability, meth_QCameraImageCapture_availability, METH_VARARGS, doc_QCameraImageCapture_availability},
    {sipName_bufferFormat, meth_QCameraImageCapture_bufferFormat, METH_VARARGS, doc_QCameraImageCapture_bufferFormat},
    {sipName_cancelCapture, meth_QCameraImageCapture_cancelCapture, METH_VARARGS, doc_QCameraImageCapture_cancelCapture},
    {sipName_capture, SIP_MLMETH_CAST(meth_QCameraImageCapture_capture), METH_VARARGS|METH_KEYWORDS, doc_QCameraImageCapture_capture},
    {sipName_captureDestination, meth_QCameraImageCapture_captureDestination, METH_VARARGS, doc_QCameraImageCapture_captureDestination},
    {sipName_encodingSettings, meth_QCameraImageCapture_encodingSettings, METH_VARARGS, doc_QCameraImageCapture_encodingSettings},
    {sipName_error, meth_QCameraImageCapture_error, METH_VARARGS, doc_QCameraImageCapture_error},
    {sipName_errorString, meth_QCameraImageCapture_errorString, METH_VARARGS, doc_QCameraImageCapture_errorString},
    {sipName_imageCodecDescription, meth_QCameraImageCapture_imageCodecDescription, METH_VARARGS, doc_QCameraImageCapture_imageCodecDescription},
    {sipName_isAvailable, meth_QCameraImageCapture_isAvailable, METH_VARARGS, doc_QCameraImageCapture_isAvailable},
    {sipName_isCaptureDestinationSupported, meth_QCameraImageCapture_isCaptureDestinationSupported, METH_VARARGS, doc_QCameraImageCapture_isCaptureDestinationSupported},
    {sipName_isReadyForCapture, meth_QCameraImageCapture_isReadyForCapture, METH_VARARGS, doc_QCameraImageCapture_isReadyForCapture},
    {sipName_mediaObject, meth_QCameraImageCapture_mediaObject, METH_VARARGS, doc_QCameraImageCapture_mediaObject},
    {sipName_setBufferFormat, meth_QCameraImageCapture_setBufferFormat, METH_VARARGS, doc_QCameraImageCapture_setBufferFormat},
    {sipName_setCaptureDestination, meth_QCameraImageCapture_setCaptureDestination, METH_VARARGS, doc_QCameraImageCapture_setCaptureDestination},
    {sipName_setEncodingSettings, meth_QCameraImageCapture_setEncodingSettings, METH_VARARGS, doc_QCameraImageCapture_setEncodingSettings},
    {sipName_setMediaObject, meth_QCameraImageCapture_setMediaObject, METH_VARARGS, doc_QCameraImageCapture_setMediaObject},
    {sipName_supportedBufferFormats, meth_QCameraImageCapture_supportedBufferFormats, METH_VARARGS, doc_QCameraImageCapture_supportedBufferFormats},
    {sipName_supportedImageCodecs, meth_QCameraImageCapture_supportedImageCodecs, METH_VARARGS, doc_QCameraImageCapture_supportedImageCodecs},
    {sipName_supportedResolutions, SIP_MLMETH_CAST(meth_QCameraImageCapture_supportedResolutions), METH_VARARGS|METH_KEYWORDS, doc_QCameraImageCapture_supportedResolutions}
};

static sipEnumMemberDef enummembers_QCameraImageCapture[] = {
    {sipName_CaptureToBuffer, static_cast<int>(::QCameraImageCapture::CaptureToBuffer), 64},
    {sipName_CaptureToFile, static_cast<int>(::QCameraImageCapture::CaptureToFile), 64},
    {sipName_FormatError, static_cast<int>(::QCameraImageCapture::FormatError), 67},
    {sipName_NoError, static_cast<int>(::QCameraImageCapture::NoError), 67},
    {sipName_NotReadyError, static_cast<int>(::QCameraImageCapture::NotReadyError), 67},
    {sipName_NotSupportedFeatureError, static_cast<int>(::QCameraImageCapture::NotSupportedFeatureError), 67},
    {sipName_OutOfSpaceError, static_cast<int>(::QCameraImageCapture::OutOfSpaceError), 67},
    {sipName_ResourceError, static_cast<int>(::QCameraImageCapture::ResourceError), 67},
    {sipName_SingleImageCapture, static_cast<int>(::QCameraImageCapture::SingleImageCapture), 66},
};

PyDoc_STRVAR(doc_QCameraImageCapture, "\1QCameraImageCapture(mediaObject: Optional[QMediaObject], parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QCameraImageCapture[] = {
    {"imageSaved(int,QString)", "\1imageSaved(self, id: int, fileName: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"imageAvailable(int,QVideoFrame)", "\1imageAvailable(self, id: int, image: QVideoFrame)", SIP_NULLPTR, SIP_NULLPTR},
    {"imageMetadataAvailable(int,QString,QVariant)", "\1imageMetadataAvailable(self, id: int, key: Optional[str], value: Any)", SIP_NULLPTR, SIP_NULLPTR},
    {"imageCaptured(int,QImage)", "\1imageCaptured(self, id: int, preview: QImage)", SIP_NULLPTR, SIP_NULLPTR},
    {"imageExposed(int)", "\1imageExposed(self, id: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"captureDestinationChanged(QCameraImageCapture::CaptureDestinations)", "\1captureDestinationChanged(self, a0: Union[QCameraImageCapture.CaptureDestinations, QCameraImageCapture.CaptureDestination])", SIP_NULLPTR, SIP_NULLPTR},
    {"bufferFormatChanged(QVideoFrame::PixelFormat)", "\1bufferFormatChanged(self, a0: QVideoFrame.PixelFormat)", SIP_NULLPTR, SIP_NULLPTR},
    {"readyForCaptureChanged(bool)", "\1readyForCaptureChanged(self, a0: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"error(int,QCameraImageCapture::Error,QString)", "\1error(self, id: int, error: QCameraImageCapture.Error, errorString: Optional[str])", &methods_QCameraImageCapture[6], SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QCameraImageCapture = {
    &::QCameraImageCapture::staticMetaObject,
    0,
    signals_QCameraImageCapture,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QCameraImageCapture = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCameraImageCapture,
        SIP_NULLPTR,
        &plugin_QCameraImageCapture,
    },
    {
        sipNameNr_QCameraImageCapture,
        {0, 0, 1},
        20, methods_QCameraImageCapture,
        9, enummembers_QCameraImageCapture,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QCameraImageCapture,
    -1,
    -1,
    supers_QCameraImageCapture,
    SIP_NULLPTR,
    init_type_QCameraImageCapture,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QCameraImageCapture,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QCameraImageCapture,
    cast_QCameraImageCapture,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QCameraImageCapture),
};
