/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtSensors.h"

#line 85 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qsensor.sip"
#include <qsensor.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"

#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qsensor.sip"
#include <qsensor.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qsensor.sip"
#include <qsensor.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 34 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSensors/qsensor.sip"
#include <qsensor.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 460 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#include <qpair.h>
#line 61 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 99 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 102 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSensors/sipQtSensorsQSensor.cpp"


class sipQSensor : public ::QSensor
{
public:
    sipQSensor(const ::QByteArray&, ::QObject*);
    virtual ~sipQSensor();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSensor(const sipQSensor &);
    sipQSensor &operator = (const sipQSensor &);

    char sipPyMethods[7];
};

sipQSensor::sipQSensor(const ::QByteArray& a0, ::QObject*a1): ::QSensor(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSensor::~sipQSensor()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQSensor::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtSensors_qt_metaobject(sipPySelf, sipType_QSensor);

    return ::QSensor::metaObject();
}

int sipQSensor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QSensor::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtSensors_qt_metacall(sipPySelf, sipType_QSensor, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQSensor::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtSensors_qt_metacast(sipPySelf, sipType_QSensor, _clname, &sipCpp) ? sipCpp : ::QSensor::qt_metacast(_clname));
}

bool sipQSensor::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QSensor::event(a0);

    extern bool sipVH_QtSensors_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtSensors_5(sipGILState, sipImportedVirtErrorHandlers_QtSensors_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSensor::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QSensor::eventFilter(a0, a1);

    extern bool sipVH_QtSensors_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtSensors_4(sipGILState, sipImportedVirtErrorHandlers_QtSensors_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQSensor::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QSensor::timerEvent(a0);
        return;
    }

    extern void sipVH_QtSensors_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtSensors_3(sipGILState, sipImportedVirtErrorHandlers_QtSensors_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSensor::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QSensor::childEvent(a0);
        return;
    }

    extern void sipVH_QtSensors_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtSensors_2(sipGILState, sipImportedVirtErrorHandlers_QtSensors_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSensor::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QSensor::customEvent(a0);
        return;
    }

    extern void sipVH_QtSensors_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtSensors_1(sipGILState, sipImportedVirtErrorHandlers_QtSensors_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSensor::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QSensor::connectNotify(a0);
        return;
    }

    extern void sipVH_QtSensors_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSensors_0(sipGILState, sipImportedVirtErrorHandlers_QtSensors_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSensor::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QSensor::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtSensors_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSensors_0(sipGILState, sipImportedVirtErrorHandlers_QtSensors_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QSensor_identifier, "identifier(self) -> QByteArray");

extern "C" {static PyObject *meth_QSensor_identifier(PyObject *, PyObject *);}
static PyObject *meth_QSensor_identifier(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->identifier());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_identifier, doc_QSensor_identifier);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_setIdentifier, "setIdentifier(self, identifier: Union[QByteArray, bytes, bytearray])");

extern "C" {static PyObject *meth_QSensor_setIdentifier(PyObject *, PyObject *);}
static PyObject *meth_QSensor_setIdentifier(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSensor, &sipCpp, sipType_QByteArray, &a0, &a0State))
        {
            sipCpp->setIdentifier(*a0);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_setIdentifier, doc_QSensor_setIdentifier);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_type, "type(self) -> QByteArray");

extern "C" {static PyObject *meth_QSensor_type(PyObject *, PyObject *);}
static PyObject *meth_QSensor_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->type());

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_type, doc_QSensor_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_connectToBackend, "connectToBackend(self) -> bool");

extern "C" {static PyObject *meth_QSensor_connectToBackend(PyObject *, PyObject *);}
static PyObject *meth_QSensor_connectToBackend(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->connectToBackend();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_connectToBackend, doc_QSensor_connectToBackend);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_isConnectedToBackend, "isConnectedToBackend(self) -> bool");

extern "C" {static PyObject *meth_QSensor_isConnectedToBackend(PyObject *, PyObject *);}
static PyObject *meth_QSensor_isConnectedToBackend(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isConnectedToBackend();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_isConnectedToBackend, doc_QSensor_isConnectedToBackend);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_isBusy, "isBusy(self) -> bool");

extern "C" {static PyObject *meth_QSensor_isBusy(PyObject *, PyObject *);}
static PyObject *meth_QSensor_isBusy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isBusy();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_isBusy, doc_QSensor_isBusy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_setActive, "setActive(self, active: bool)");

extern "C" {static PyObject *meth_QSensor_setActive(PyObject *, PyObject *);}
static PyObject *meth_QSensor_setActive(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QSensor, &sipCpp, &a0))
        {
            sipCpp->setActive(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_setActive, doc_QSensor_setActive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_isActive, "isActive(self) -> bool");

extern "C" {static PyObject *meth_QSensor_isActive(PyObject *, PyObject *);}
static PyObject *meth_QSensor_isActive(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isActive();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_isActive, doc_QSensor_isActive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_isAlwaysOn, "isAlwaysOn(self) -> bool");

extern "C" {static PyObject *meth_QSensor_isAlwaysOn(PyObject *, PyObject *);}
static PyObject *meth_QSensor_isAlwaysOn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAlwaysOn();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_isAlwaysOn, doc_QSensor_isAlwaysOn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_setAlwaysOn, "setAlwaysOn(self, alwaysOn: bool)");

extern "C" {static PyObject *meth_QSensor_setAlwaysOn(PyObject *, PyObject *);}
static PyObject *meth_QSensor_setAlwaysOn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QSensor, &sipCpp, &a0))
        {
            sipCpp->setAlwaysOn(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_setAlwaysOn, doc_QSensor_setAlwaysOn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_skipDuplicates, "skipDuplicates(self) -> bool");

extern "C" {static PyObject *meth_QSensor_skipDuplicates(PyObject *, PyObject *);}
static PyObject *meth_QSensor_skipDuplicates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->skipDuplicates();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_skipDuplicates, doc_QSensor_skipDuplicates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_setSkipDuplicates, "setSkipDuplicates(self, skipDuplicates: bool)");

extern "C" {static PyObject *meth_QSensor_setSkipDuplicates(PyObject *, PyObject *);}
static PyObject *meth_QSensor_setSkipDuplicates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QSensor, &sipCpp, &a0))
        {
            sipCpp->setSkipDuplicates(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_setSkipDuplicates, doc_QSensor_setSkipDuplicates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_availableDataRates, "availableDataRates(self) -> list[tuple[int, int]]");

extern "C" {static PyObject *meth_QSensor_availableDataRates(PyObject *, PyObject *);}
static PyObject *meth_QSensor_availableDataRates(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            ::qrangelist*sipRes;

            sipRes = new ::qrangelist(sipCpp->availableDataRates());

            return sipConvertFromNewType(sipRes, sipType_QList_0600QPair_1800_1800, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_availableDataRates, doc_QSensor_availableDataRates);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_dataRate, "dataRate(self) -> int");

extern "C" {static PyObject *meth_QSensor_dataRate(PyObject *, PyObject *);}
static PyObject *meth_QSensor_dataRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->dataRate();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_dataRate, doc_QSensor_dataRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_setDataRate, "setDataRate(self, rate: int)");

extern "C" {static PyObject *meth_QSensor_setDataRate(PyObject *, PyObject *);}
static PyObject *meth_QSensor_setDataRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSensor, &sipCpp, &a0))
        {
            sipCpp->setDataRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_setDataRate, doc_QSensor_setDataRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_outputRanges, "outputRanges(self) -> list[qoutputrange]");

extern "C" {static PyObject *meth_QSensor_outputRanges(PyObject *, PyObject *);}
static PyObject *meth_QSensor_outputRanges(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            ::qoutputrangelist*sipRes;

            sipRes = new ::qoutputrangelist(sipCpp->outputRanges());

            return sipConvertFromNewType(sipRes, sipType_QList_0100qoutputrange, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_outputRanges, doc_QSensor_outputRanges);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_outputRange, "outputRange(self) -> int");

extern "C" {static PyObject *meth_QSensor_outputRange(PyObject *, PyObject *);}
static PyObject *meth_QSensor_outputRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->outputRange();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_outputRange, doc_QSensor_outputRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_setOutputRange, "setOutputRange(self, index: int)");

extern "C" {static PyObject *meth_QSensor_setOutputRange(PyObject *, PyObject *);}
static PyObject *meth_QSensor_setOutputRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSensor, &sipCpp, &a0))
        {
            sipCpp->setOutputRange(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_setOutputRange, doc_QSensor_setOutputRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_description, "description(self) -> str");

extern "C" {static PyObject *meth_QSensor_description(PyObject *, PyObject *);}
static PyObject *meth_QSensor_description(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->description());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_description, doc_QSensor_description);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_error, "error(self) -> int");

extern "C" {static PyObject *meth_QSensor_error(PyObject *, PyObject *);}
static PyObject *meth_QSensor_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->error();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_error, doc_QSensor_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_addFilter, "addFilter(self, filter: Optional[QSensorFilter])");

extern "C" {static PyObject *meth_QSensor_addFilter(PyObject *, PyObject *);}
static PyObject *meth_QSensor_addFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSensorFilter* a0;
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QSensor, &sipCpp, sipType_QSensorFilter, &a0))
        {
            sipCpp->addFilter(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_addFilter, doc_QSensor_addFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_removeFilter, "removeFilter(self, filter: Optional[QSensorFilter])");

extern "C" {static PyObject *meth_QSensor_removeFilter(PyObject *, PyObject *);}
static PyObject *meth_QSensor_removeFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSensorFilter* a0;
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QSensor, &sipCpp, sipType_QSensorFilter, &a0))
        {
            sipCpp->removeFilter(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_removeFilter, doc_QSensor_removeFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_filters, "filters(self) -> list[QSensorFilter]");

extern "C" {static PyObject *meth_QSensor_filters(PyObject *, PyObject *);}
static PyObject *meth_QSensor_filters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            QList< ::QSensorFilter*>*sipRes;

            sipRes = new QList< ::QSensorFilter*>(sipCpp->filters());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QSensorFilter, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_filters, doc_QSensor_filters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_reading, "reading(self) -> Optional[QSensorReading]");

extern "C" {static PyObject *meth_QSensor_reading(PyObject *, PyObject *);}
static PyObject *meth_QSensor_reading(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            ::QSensorReading*sipRes;

            sipRes = sipCpp->reading();

            return sipConvertFromType(sipRes, sipType_QSensorReading, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_reading, doc_QSensor_reading);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_sensorTypes, "sensorTypes() -> list[QByteArray]");

extern "C" {static PyObject *meth_QSensor_sensorTypes(PyObject *, PyObject *);}
static PyObject *meth_QSensor_sensorTypes(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QByteArray>*sipRes;

            sipRes = new QList< ::QByteArray>(::QSensor::sensorTypes());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_sensorTypes, doc_QSensor_sensorTypes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_sensorsForType, "sensorsForType(type: Union[QByteArray, bytes, bytearray]) -> list[QByteArray]");

extern "C" {static PyObject *meth_QSensor_sensorsForType(PyObject *, PyObject *);}
static PyObject *meth_QSensor_sensorsForType(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QByteArray, &a0, &a0State))
        {
            QList< ::QByteArray>*sipRes;

            sipRes = new QList< ::QByteArray>(::QSensor::sensorsForType(*a0));
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            return sipConvertFromNewType(sipRes, sipType_QList_0100QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_sensorsForType, doc_QSensor_sensorsForType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_defaultSensorForType, "defaultSensorForType(type: Union[QByteArray, bytes, bytearray]) -> QByteArray");

extern "C" {static PyObject *meth_QSensor_defaultSensorForType(PyObject *, PyObject *);}
static PyObject *meth_QSensor_defaultSensorForType(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QByteArray, &a0, &a0State))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(::QSensor::defaultSensorForType(*a0));
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_defaultSensorForType, doc_QSensor_defaultSensorForType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_isFeatureSupported, "isFeatureSupported(self, feature: QSensor.Feature) -> bool");

extern "C" {static PyObject *meth_QSensor_isFeatureSupported(PyObject *, PyObject *);}
static PyObject *meth_QSensor_isFeatureSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSensor::Feature a0;
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSensor, &sipCpp, sipType_QSensor_Feature, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isFeatureSupported(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_isFeatureSupported, doc_QSensor_isFeatureSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_axesOrientationMode, "axesOrientationMode(self) -> QSensor.AxesOrientationMode");

extern "C" {static PyObject *meth_QSensor_axesOrientationMode(PyObject *, PyObject *);}
static PyObject *meth_QSensor_axesOrientationMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            ::QSensor::AxesOrientationMode sipRes;

            sipRes = sipCpp->axesOrientationMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSensor_AxesOrientationMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_axesOrientationMode, doc_QSensor_axesOrientationMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_setAxesOrientationMode, "setAxesOrientationMode(self, axesOrientationMode: QSensor.AxesOrientationMode)");

extern "C" {static PyObject *meth_QSensor_setAxesOrientationMode(PyObject *, PyObject *);}
static PyObject *meth_QSensor_setAxesOrientationMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSensor::AxesOrientationMode a0;
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSensor, &sipCpp, sipType_QSensor_AxesOrientationMode, &a0))
        {
            sipCpp->setAxesOrientationMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_setAxesOrientationMode, doc_QSensor_setAxesOrientationMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_currentOrientation, "currentOrientation(self) -> int");

extern "C" {static PyObject *meth_QSensor_currentOrientation(PyObject *, PyObject *);}
static PyObject *meth_QSensor_currentOrientation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->currentOrientation();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_currentOrientation, doc_QSensor_currentOrientation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_setCurrentOrientation, "setCurrentOrientation(self, currentOrientation: int)");

extern "C" {static PyObject *meth_QSensor_setCurrentOrientation(PyObject *, PyObject *);}
static PyObject *meth_QSensor_setCurrentOrientation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSensor, &sipCpp, &a0))
        {
            sipCpp->setCurrentOrientation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_setCurrentOrientation, doc_QSensor_setCurrentOrientation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_userOrientation, "userOrientation(self) -> int");

extern "C" {static PyObject *meth_QSensor_userOrientation(PyObject *, PyObject *);}
static PyObject *meth_QSensor_userOrientation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->userOrientation();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_userOrientation, doc_QSensor_userOrientation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_setUserOrientation, "setUserOrientation(self, userOrientation: int)");

extern "C" {static PyObject *meth_QSensor_setUserOrientation(PyObject *, PyObject *);}
static PyObject *meth_QSensor_setUserOrientation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSensor, &sipCpp, &a0))
        {
            sipCpp->setUserOrientation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_setUserOrientation, doc_QSensor_setUserOrientation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_maxBufferSize, "maxBufferSize(self) -> int");

extern "C" {static PyObject *meth_QSensor_maxBufferSize(PyObject *, PyObject *);}
static PyObject *meth_QSensor_maxBufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maxBufferSize();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_maxBufferSize, doc_QSensor_maxBufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_setMaxBufferSize, "setMaxBufferSize(self, maxBufferSize: int)");

extern "C" {static PyObject *meth_QSensor_setMaxBufferSize(PyObject *, PyObject *);}
static PyObject *meth_QSensor_setMaxBufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSensor, &sipCpp, &a0))
        {
            sipCpp->setMaxBufferSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_setMaxBufferSize, doc_QSensor_setMaxBufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_efficientBufferSize, "efficientBufferSize(self) -> int");

extern "C" {static PyObject *meth_QSensor_efficientBufferSize(PyObject *, PyObject *);}
static PyObject *meth_QSensor_efficientBufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->efficientBufferSize();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_efficientBufferSize, doc_QSensor_efficientBufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_setEfficientBufferSize, "setEfficientBufferSize(self, efficientBufferSize: int)");

extern "C" {static PyObject *meth_QSensor_setEfficientBufferSize(PyObject *, PyObject *);}
static PyObject *meth_QSensor_setEfficientBufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSensor, &sipCpp, &a0))
        {
            sipCpp->setEfficientBufferSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_setEfficientBufferSize, doc_QSensor_setEfficientBufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_bufferSize, "bufferSize(self) -> int");

extern "C" {static PyObject *meth_QSensor_bufferSize(PyObject *, PyObject *);}
static PyObject *meth_QSensor_bufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->bufferSize();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_bufferSize, doc_QSensor_bufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_setBufferSize, "setBufferSize(self, bufferSize: int)");

extern "C" {static PyObject *meth_QSensor_setBufferSize(PyObject *, PyObject *);}
static PyObject *meth_QSensor_setBufferSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSensor, &sipCpp, &a0))
        {
            sipCpp->setBufferSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_setBufferSize, doc_QSensor_setBufferSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_start, "start(self) -> bool");

extern "C" {static PyObject *meth_QSensor_start(PyObject *, PyObject *);}
static PyObject *meth_QSensor_start(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->start();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_start, doc_QSensor_start);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSensor_stop, "stop(self)");

extern "C" {static PyObject *meth_QSensor_stop(PyObject *, PyObject *);}
static PyObject *meth_QSensor_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSensor *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSensor, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSensor, sipName_stop, doc_QSensor_stop);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSensor(void *, const sipTypeDef *);}
static void *cast_QSensor(void *sipCppV, const sipTypeDef *targetType)
{
    ::QSensor *sipCpp = reinterpret_cast< ::QSensor *>(sipCppV);

    if (targetType == sipType_QSensor)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSensor(void *, int);}
static void release_QSensor(void *sipCppV, int)
{
    ::QSensor *sipCpp = reinterpret_cast< ::QSensor *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QSensor(sipSimpleWrapper *);}
static void dealloc_QSensor(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSensor *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSensor(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSensor(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSensor(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQSensor *sipCpp = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QByteArray, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQSensor(*a0, a1);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSensor[] = {{6, 0, 1}};


static PyMethodDef methods_QSensor[] = {
    {sipName_addFilter, meth_QSensor_addFilter, METH_VARARGS, doc_QSensor_addFilter},
    {sipName_availableDataRates, meth_QSensor_availableDataRates, METH_VARARGS, doc_QSensor_availableDataRates},
    {sipName_axesOrientationMode, meth_QSensor_axesOrientationMode, METH_VARARGS, doc_QSensor_axesOrientationMode},
    {sipName_bufferSize, meth_QSensor_bufferSize, METH_VARARGS, doc_QSensor_bufferSize},
    {sipName_connectToBackend, meth_QSensor_connectToBackend, METH_VARARGS, doc_QSensor_connectToBackend},
    {sipName_currentOrientation, meth_QSensor_currentOrientation, METH_VARARGS, doc_QSensor_currentOrientation},
    {sipName_dataRate, meth_QSensor_dataRate, METH_VARARGS, doc_QSensor_dataRate},
    {sipName_defaultSensorForType, meth_QSensor_defaultSensorForType, METH_VARARGS, doc_QSensor_defaultSensorForType},
    {sipName_description, meth_QSensor_description, METH_VARARGS, doc_QSensor_description},
    {sipName_efficientBufferSize, meth_QSensor_efficientBufferSize, METH_VARARGS, doc_QSensor_efficientBufferSize},
    {sipName_error, meth_QSensor_error, METH_VARARGS, doc_QSensor_error},
    {sipName_filters, meth_QSensor_filters, METH_VARARGS, doc_QSensor_filters},
    {sipName_identifier, meth_QSensor_identifier, METH_VARARGS, doc_QSensor_identifier},
    {sipName_isActive, meth_QSensor_isActive, METH_VARARGS, doc_QSensor_isActive},
    {sipName_isAlwaysOn, meth_QSensor_isAlwaysOn, METH_VARARGS, doc_QSensor_isAlwaysOn},
    {sipName_isBusy, meth_QSensor_isBusy, METH_VARARGS, doc_QSensor_isBusy},
    {sipName_isConnectedToBackend, meth_QSensor_isConnectedToBackend, METH_VARARGS, doc_QSensor_isConnectedToBackend},
    {sipName_isFeatureSupported, meth_QSensor_isFeatureSupported, METH_VARARGS, doc_QSensor_isFeatureSupported},
    {sipName_maxBufferSize, meth_QSensor_maxBufferSize, METH_VARARGS, doc_QSensor_maxBufferSize},
    {sipName_outputRange, meth_QSensor_outputRange, METH_VARARGS, doc_QSensor_outputRange},
    {sipName_outputRanges, meth_QSensor_outputRanges, METH_VARARGS, doc_QSensor_outputRanges},
    {sipName_reading, meth_QSensor_reading, METH_VARARGS, doc_QSensor_reading},
    {sipName_removeFilter, meth_QSensor_removeFilter, METH_VARARGS, doc_QSensor_removeFilter},
    {sipName_sensorTypes, meth_QSensor_sensorTypes, METH_VARARGS, doc_QSensor_sensorTypes},
    {sipName_sensorsForType, meth_QSensor_sensorsForType, METH_VARARGS, doc_QSensor_sensorsForType},
    {sipName_setActive, meth_QSensor_setActive, METH_VARARGS, doc_QSensor_setActive},
    {sipName_setAlwaysOn, meth_QSensor_setAlwaysOn, METH_VARARGS, doc_QSensor_setAlwaysOn},
    {sipName_setAxesOrientationMode, meth_QSensor_setAxesOrientationMode, METH_VARARGS, doc_QSensor_setAxesOrientationMode},
    {sipName_setBufferSize, meth_QSensor_setBufferSize, METH_VARARGS, doc_QSensor_setBufferSize},
    {sipName_setCurrentOrientation, meth_QSensor_setCurrentOrientation, METH_VARARGS, doc_QSensor_setCurrentOrientation},
    {sipName_setDataRate, meth_QSensor_setDataRate, METH_VARARGS, doc_QSensor_setDataRate},
    {sipName_setEfficientBufferSize, meth_QSensor_setEfficientBufferSize, METH_VARARGS, doc_QSensor_setEfficientBufferSize},
    {sipName_setIdentifier, meth_QSensor_setIdentifier, METH_VARARGS, doc_QSensor_setIdentifier},
    {sipName_setMaxBufferSize, meth_QSensor_setMaxBufferSize, METH_VARARGS, doc_QSensor_setMaxBufferSize},
    {sipName_setOutputRange, meth_QSensor_setOutputRange, METH_VARARGS, doc_QSensor_setOutputRange},
    {sipName_setSkipDuplicates, meth_QSensor_setSkipDuplicates, METH_VARARGS, doc_QSensor_setSkipDuplicates},
    {sipName_setUserOrientation, meth_QSensor_setUserOrientation, METH_VARARGS, doc_QSensor_setUserOrientation},
    {sipName_skipDuplicates, meth_QSensor_skipDuplicates, METH_VARARGS, doc_QSensor_skipDuplicates},
    {sipName_start, meth_QSensor_start, METH_VARARGS, doc_QSensor_start},
    {sipName_stop, meth_QSensor_stop, METH_VARARGS, doc_QSensor_stop},
    {sipName_type, meth_QSensor_type, METH_VARARGS, doc_QSensor_type},
    {sipName_userOrientation, meth_QSensor_userOrientation, METH_VARARGS, doc_QSensor_userOrientation}
};

static sipEnumMemberDef enummembers_QSensor[] = {
    {sipName_AccelerationMode, static_cast<int>(::QSensor::AccelerationMode), 58},
    {sipName_AlwaysOn, static_cast<int>(::QSensor::AlwaysOn), 58},
    {sipName_AutomaticOrientation, static_cast<int>(::QSensor::AutomaticOrientation), 57},
    {sipName_AxesOrientation, static_cast<int>(::QSensor::AxesOrientation), 58},
    {sipName_Buffering, static_cast<int>(::QSensor::Buffering), 58},
    {sipName_FieldOfView, static_cast<int>(::QSensor::FieldOfView), 58},
    {sipName_FixedOrientation, static_cast<int>(::QSensor::FixedOrientation), 57},
    {sipName_GeoValues, static_cast<int>(::QSensor::GeoValues), 58},
    {sipName_PressureSensorTemperature, static_cast<int>(::QSensor::PressureSensorTemperature), 58},
    {sipName_SkipDuplicates, static_cast<int>(::QSensor::SkipDuplicates), 58},
    {sipName_UserOrientation, static_cast<int>(::QSensor::UserOrientation), 57},
};

PyDoc_STRVAR(doc_QSensor, "\1QSensor(type: Union[QByteArray, bytes, bytearray], parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QSensor[] = {
    {"bufferSizeChanged(int)", "\1bufferSizeChanged(self, bufferSize: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"efficientBufferSizeChanged(int)", "\1efficientBufferSizeChanged(self, efficientBufferSize: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"maxBufferSizeChanged(int)", "\1maxBufferSizeChanged(self, maxBufferSize: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"userOrientationChanged(int)", "\1userOrientationChanged(self, userOrientation: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"currentOrientationChanged(int)", "\1currentOrientationChanged(self, currentOrientation: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"axesOrientationModeChanged(AxesOrientationMode)|(QSensor::AxesOrientationMode)", "\1axesOrientationModeChanged(self, axesOrientationMode: QSensor.AxesOrientationMode)", SIP_NULLPTR, SIP_NULLPTR},
    {"skipDuplicatesChanged(bool)", "\1skipDuplicatesChanged(self, skipDuplicates: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"dataRateChanged()", "\1dataRateChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"alwaysOnChanged()", "\1alwaysOnChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"availableSensorsChanged()", "\1availableSensorsChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"sensorError(int)", "\1sensorError(self, error: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"readingChanged()", "\1readingChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"activeChanged()", "\1activeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"busyChanged()", "\1busyChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QSensor = {
    &::QSensor::staticMetaObject,
    0,
    signals_QSensor,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtSensors_QSensor = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSensor,
        SIP_NULLPTR,
        &plugin_QSensor,
    },
    {
        sipNameNr_QSensor,
        {0, 0, 1},
        42, methods_QSensor,
        11, enummembers_QSensor,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSensor,
    -1,
    -1,
    supers_QSensor,
    SIP_NULLPTR,
    init_type_QSensor,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSensor,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QSensor,
    cast_QSensor,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QSensor),
};
