/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceicon.sip"
#include <qplaceicon.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceIcon.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceIcon.cpp"
#line 24 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceIcon.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacemanager.sip"
#include <qplacemanager.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceIcon.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceIcon.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceIcon.cpp"


PyDoc_STRVAR(doc_QPlaceIcon_url, "url(self, size: QSize = QSize()) -> QUrl");

extern "C" {static PyObject *meth_QPlaceIcon_url(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QPlaceIcon_url(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize& a0def = QSize();
        const ::QSize* a0 = &a0def;
        const ::QPlaceIcon *sipCpp;

        static const char *sipKwdList[] = {
            sipName_size,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QPlaceIcon, &sipCpp, sipType_QSize, &a0))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->url(*a0));

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceIcon, sipName_url, doc_QPlaceIcon_url);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceIcon_manager, "manager(self) -> Optional[QPlaceManager]");

extern "C" {static PyObject *meth_QPlaceIcon_manager(PyObject *, PyObject *);}
static PyObject *meth_QPlaceIcon_manager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceIcon, &sipCpp))
        {
            ::QPlaceManager*sipRes;

            sipRes = sipCpp->manager();

            return sipConvertFromType(sipRes, sipType_QPlaceManager, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceIcon, sipName_manager, doc_QPlaceIcon_manager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceIcon_setManager, "setManager(self, manager: Optional[QPlaceManager])");

extern "C" {static PyObject *meth_QPlaceIcon_setManager(PyObject *, PyObject *);}
static PyObject *meth_QPlaceIcon_setManager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPlaceManager* a0;
        ::QPlaceIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QPlaceIcon, &sipCpp, sipType_QPlaceManager, &a0))
        {
            sipCpp->setManager(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceIcon, sipName_setManager, doc_QPlaceIcon_setManager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceIcon_parameters, "parameters(self) -> dict[str, Any]");

extern "C" {static PyObject *meth_QPlaceIcon_parameters(PyObject *, PyObject *);}
static PyObject *meth_QPlaceIcon_parameters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceIcon, &sipCpp))
        {
            ::QVariantMap*sipRes;

            sipRes = new ::QVariantMap(sipCpp->parameters());

            return sipConvertFromNewType(sipRes, sipType_QVariantMap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceIcon, sipName_parameters, doc_QPlaceIcon_parameters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceIcon_setParameters, "setParameters(self, parameters: dict[str, Any])");

extern "C" {static PyObject *meth_QPlaceIcon_setParameters(PyObject *, PyObject *);}
static PyObject *meth_QPlaceIcon_setParameters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariantMap* a0;
        int a0State = 0;
        ::QPlaceIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceIcon, &sipCpp, sipType_QVariantMap, &a0, &a0State))
        {
            sipCpp->setParameters(*a0);
            sipReleaseType(const_cast< ::QVariantMap *>(a0), sipType_QVariantMap, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceIcon, sipName_setParameters, doc_QPlaceIcon_setParameters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceIcon_isEmpty, "isEmpty(self) -> bool");

extern "C" {static PyObject *meth_QPlaceIcon_isEmpty(PyObject *, PyObject *);}
static PyObject *meth_QPlaceIcon_isEmpty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceIcon *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceIcon, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEmpty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceIcon, sipName_isEmpty, doc_QPlaceIcon_isEmpty);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QPlaceIcon___ne__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceIcon___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceIcon *sipCpp = reinterpret_cast< ::QPlaceIcon *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceIcon));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceIcon* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceIcon, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceIcon::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, ne_slot, sipType_QPlaceIcon, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QPlaceIcon___eq__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceIcon___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceIcon *sipCpp = reinterpret_cast< ::QPlaceIcon *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceIcon));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceIcon* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceIcon, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceIcon::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, eq_slot, sipType_QPlaceIcon, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QPlaceIcon(void *, int);}
static void release_QPlaceIcon(void *sipCppV, int)
{
    delete reinterpret_cast< ::QPlaceIcon *>(sipCppV);
}


extern "C" {static void *array_QPlaceIcon(Py_ssize_t);}
static void *array_QPlaceIcon(Py_ssize_t sipNrElem)
{
    return new ::QPlaceIcon[sipNrElem];
}


extern "C" {static void array_delete_QPlaceIcon(void *);}
static void array_delete_QPlaceIcon(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPlaceIcon *>(sipCpp);
}


extern "C" {static void assign_QPlaceIcon(void *, Py_ssize_t, void *);}
static void assign_QPlaceIcon(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPlaceIcon *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPlaceIcon *>(sipSrc);
}


extern "C" {static void *copy_QPlaceIcon(const void *, Py_ssize_t);}
static void *copy_QPlaceIcon(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPlaceIcon(reinterpret_cast<const ::QPlaceIcon *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPlaceIcon(sipSimpleWrapper *);}
static void dealloc_QPlaceIcon(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPlaceIcon(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QPlaceIcon(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPlaceIcon(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QPlaceIcon *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QPlaceIcon();

            return sipCpp;
        }
    }

    {
        const ::QPlaceIcon* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPlaceIcon, &a0))
        {
            sipCpp = new ::QPlaceIcon(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QPlaceIcon[] = {
    {(void *)slot_QPlaceIcon___ne__, ne_slot},
    {(void *)slot_QPlaceIcon___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QPlaceIcon[] = {
    {sipName_isEmpty, meth_QPlaceIcon_isEmpty, METH_VARARGS, doc_QPlaceIcon_isEmpty},
    {sipName_manager, meth_QPlaceIcon_manager, METH_VARARGS, doc_QPlaceIcon_manager},
    {sipName_parameters, meth_QPlaceIcon_parameters, METH_VARARGS, doc_QPlaceIcon_parameters},
    {sipName_setManager, meth_QPlaceIcon_setManager, METH_VARARGS, doc_QPlaceIcon_setManager},
    {sipName_setParameters, meth_QPlaceIcon_setParameters, METH_VARARGS, doc_QPlaceIcon_setParameters},
    {sipName_url, SIP_MLMETH_CAST(meth_QPlaceIcon_url), METH_VARARGS|METH_KEYWORDS, doc_QPlaceIcon_url}
};


extern "C" {static PyObject *varget_QPlaceIcon_SingleUrl(void *, PyObject *, PyObject *);}
static PyObject *varget_QPlaceIcon_SingleUrl(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QPlaceIcon::SingleUrl);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}

sipVariableDef variables_QPlaceIcon[] = {
    {ClassVariable, sipName_SingleUrl, (PyMethodDef *)varget_QPlaceIcon_SingleUrl, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QPlaceIcon, "\1QPlaceIcon()\n"
"QPlaceIcon(other: QPlaceIcon)");


static pyqt5ClassPluginDef plugin_QPlaceIcon = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QPlaceIcon = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPlaceIcon,
        SIP_NULLPTR,
        &plugin_QPlaceIcon,
    },
    {
        sipNameNr_QPlaceIcon,
        {0, 0, 1},
        6, methods_QPlaceIcon,
        0, SIP_NULLPTR,
        1, variables_QPlaceIcon,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPlaceIcon,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QPlaceIcon,
    init_type_QPlaceIcon,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPlaceIcon,
    assign_QPlaceIcon,
    array_QPlaceIcon,
    copy_QPlaceIcon,
    release_QPlaceIcon,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPlaceIcon,
    sizeof (::QPlaceIcon),
};
