/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtXmlPatterns.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qxmlformatter.sip"
#include <qxmlformatter.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlFormatter.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qxmlquery.sip"
#include <qxmlquery.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlFormatter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlFormatter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlFormatter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qxmlname.sip"
#include <qxmlname.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlFormatter.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlFormatter.cpp"
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlFormatter.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qtextcodec.sip"
#include <qtextcodec.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlFormatter.cpp"


class sipQXmlFormatter : public ::QXmlFormatter
{
public:
    sipQXmlFormatter(const ::QXmlQuery&, ::QIODevice*);
    virtual ~sipQXmlFormatter();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void endOfSequence() SIP_OVERRIDE;
    void startOfSequence() SIP_OVERRIDE;
    void namespaceBinding(const ::QXmlName&) SIP_OVERRIDE;
    void atomicValue(const ::QVariant&) SIP_OVERRIDE;
    void processingInstruction(const ::QXmlName&, const ::QString&) SIP_OVERRIDE;
    void endDocument() SIP_OVERRIDE;
    void startDocument() SIP_OVERRIDE;
    void characters(const ::QStringRef&) SIP_OVERRIDE;
    void comment(const ::QString&) SIP_OVERRIDE;
    void attribute(const ::QXmlName&, const ::QStringRef&) SIP_OVERRIDE;
    void endElement() SIP_OVERRIDE;
    void startElement(const ::QXmlName&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQXmlFormatter(const sipQXmlFormatter &);
    sipQXmlFormatter &operator = (const sipQXmlFormatter &);

    char sipPyMethods[12];
};

sipQXmlFormatter::sipQXmlFormatter(const ::QXmlQuery& a0, ::QIODevice*a1): ::QXmlFormatter(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQXmlFormatter::~sipQXmlFormatter()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

void sipQXmlFormatter::endOfSequence()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_endOfSequence);

    if (!sipMeth)
    {
        ::QXmlFormatter::endOfSequence();
        return;
    }

    extern void sipVH_QtXmlPatterns_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtXmlPatterns_21(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQXmlFormatter::startOfSequence()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_startOfSequence);

    if (!sipMeth)
    {
        ::QXmlFormatter::startOfSequence();
        return;
    }

    extern void sipVH_QtXmlPatterns_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtXmlPatterns_21(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQXmlFormatter::namespaceBinding(const ::QXmlName& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_namespaceBinding);

    if (!sipMeth)
    {
        ::QXmlFormatter::namespaceBinding(a0);
        return;
    }

    extern void sipVH_QtXmlPatterns_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlName&);

    sipVH_QtXmlPatterns_20(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQXmlFormatter::atomicValue(const ::QVariant& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_atomicValue);

    if (!sipMeth)
    {
        ::QXmlFormatter::atomicValue(a0);
        return;
    }

    extern void sipVH_QtXmlPatterns_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QVariant&);

    sipVH_QtXmlPatterns_26(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQXmlFormatter::processingInstruction(const ::QXmlName& a0, const ::QString& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_processingInstruction);

    if (!sipMeth)
    {
        ::QXmlFormatter::processingInstruction(a0, a1);
        return;
    }

    extern void sipVH_QtXmlPatterns_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlName&, const ::QString&);

    sipVH_QtXmlPatterns_25(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQXmlFormatter::endDocument()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_endDocument);

    if (!sipMeth)
    {
        ::QXmlFormatter::endDocument();
        return;
    }

    extern void sipVH_QtXmlPatterns_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtXmlPatterns_21(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQXmlFormatter::startDocument()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_startDocument);

    if (!sipMeth)
    {
        ::QXmlFormatter::startDocument();
        return;
    }

    extern void sipVH_QtXmlPatterns_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtXmlPatterns_21(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQXmlFormatter::characters(const ::QStringRef& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_characters);

    if (!sipMeth)
    {
        ::QXmlFormatter::characters(a0);
        return;
    }

    extern void sipVH_QtXmlPatterns_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QStringRef&);

    sipVH_QtXmlPatterns_24(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQXmlFormatter::comment(const ::QString& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_comment);

    if (!sipMeth)
    {
        ::QXmlFormatter::comment(a0);
        return;
    }

    extern void sipVH_QtXmlPatterns_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    sipVH_QtXmlPatterns_23(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQXmlFormatter::attribute(const ::QXmlName& a0, const ::QStringRef& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_attribute);

    if (!sipMeth)
    {
        ::QXmlFormatter::attribute(a0, a1);
        return;
    }

    extern void sipVH_QtXmlPatterns_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlName&, const ::QStringRef&);

    sipVH_QtXmlPatterns_22(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQXmlFormatter::endElement()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_endElement);

    if (!sipMeth)
    {
        ::QXmlFormatter::endElement();
        return;
    }

    extern void sipVH_QtXmlPatterns_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtXmlPatterns_21(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQXmlFormatter::startElement(const ::QXmlName& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_startElement);

    if (!sipMeth)
    {
        ::QXmlFormatter::startElement(a0);
        return;
    }

    extern void sipVH_QtXmlPatterns_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QXmlName&);

    sipVH_QtXmlPatterns_20(sipGILState, sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QXmlFormatter_characters, "characters(self, value: str)");

extern "C" {static PyObject *meth_QXmlFormatter_characters(PyObject *, PyObject *);}
static PyObject *meth_QXmlFormatter_characters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QStringRef* a0;
        int a0State = 0;
        ::QXmlFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlFormatter, &sipCpp, sipType_QStringRef, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QXmlFormatter::characters(*a0) : sipCpp->characters(*a0));
            sipReleaseType(const_cast< ::QStringRef *>(a0), sipType_QStringRef, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlFormatter, sipName_characters, doc_QXmlFormatter_characters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlFormatter_comment, "comment(self, value: Optional[str])");

extern "C" {static PyObject *meth_QXmlFormatter_comment(PyObject *, PyObject *);}
static PyObject *meth_QXmlFormatter_comment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        ::QXmlFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlFormatter, &sipCpp, sipType_QString, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QXmlFormatter::comment(*a0) : sipCpp->comment(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlFormatter, sipName_comment, doc_QXmlFormatter_comment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlFormatter_startElement, "startElement(self, name: QXmlName)");

extern "C" {static PyObject *meth_QXmlFormatter_startElement(PyObject *, PyObject *);}
static PyObject *meth_QXmlFormatter_startElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QXmlName* a0;
        ::QXmlFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QXmlFormatter, &sipCpp, sipType_QXmlName, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QXmlFormatter::startElement(*a0) : sipCpp->startElement(*a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlFormatter, sipName_startElement, doc_QXmlFormatter_startElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlFormatter_endElement, "endElement(self)");

extern "C" {static PyObject *meth_QXmlFormatter_endElement(PyObject *, PyObject *);}
static PyObject *meth_QXmlFormatter_endElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QXmlFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlFormatter, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QXmlFormatter::endElement() : sipCpp->endElement());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlFormatter, sipName_endElement, doc_QXmlFormatter_endElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlFormatter_attribute, "attribute(self, name: QXmlName, value: str)");

extern "C" {static PyObject *meth_QXmlFormatter_attribute(PyObject *, PyObject *);}
static PyObject *meth_QXmlFormatter_attribute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QXmlName* a0;
        const ::QStringRef* a1;
        int a1State = 0;
        ::QXmlFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QXmlFormatter, &sipCpp, sipType_QXmlName, &a0, sipType_QStringRef, &a1, &a1State))
        {
            (sipSelfWasArg ? sipCpp->::QXmlFormatter::attribute(*a0, *a1) : sipCpp->attribute(*a0, *a1));
            sipReleaseType(const_cast< ::QStringRef *>(a1), sipType_QStringRef, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlFormatter, sipName_attribute, doc_QXmlFormatter_attribute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlFormatter_processingInstruction, "processingInstruction(self, name: QXmlName, value: Optional[str])");

extern "C" {static PyObject *meth_QXmlFormatter_processingInstruction(PyObject *, PyObject *);}
static PyObject *meth_QXmlFormatter_processingInstruction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QXmlName* a0;
        const ::QString* a1;
        int a1State = 0;
        ::QXmlFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J1", &sipSelf, sipType_QXmlFormatter, &sipCpp, sipType_QXmlName, &a0, sipType_QString, &a1, &a1State))
        {
            (sipSelfWasArg ? sipCpp->::QXmlFormatter::processingInstruction(*a0, *a1) : sipCpp->processingInstruction(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlFormatter, sipName_processingInstruction, doc_QXmlFormatter_processingInstruction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlFormatter_atomicValue, "atomicValue(self, value: Any)");

extern "C" {static PyObject *meth_QXmlFormatter_atomicValue(PyObject *, PyObject *);}
static PyObject *meth_QXmlFormatter_atomicValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QVariant* a0;
        int a0State = 0;
        ::QXmlFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QXmlFormatter, &sipCpp, sipType_QVariant, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QXmlFormatter::atomicValue(*a0) : sipCpp->atomicValue(*a0));
            sipReleaseType(const_cast< ::QVariant *>(a0), sipType_QVariant, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlFormatter, sipName_atomicValue, doc_QXmlFormatter_atomicValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlFormatter_startDocument, "startDocument(self)");

extern "C" {static PyObject *meth_QXmlFormatter_startDocument(PyObject *, PyObject *);}
static PyObject *meth_QXmlFormatter_startDocument(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QXmlFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlFormatter, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QXmlFormatter::startDocument() : sipCpp->startDocument());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlFormatter, sipName_startDocument, doc_QXmlFormatter_startDocument);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlFormatter_endDocument, "endDocument(self)");

extern "C" {static PyObject *meth_QXmlFormatter_endDocument(PyObject *, PyObject *);}
static PyObject *meth_QXmlFormatter_endDocument(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QXmlFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlFormatter, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QXmlFormatter::endDocument() : sipCpp->endDocument());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlFormatter, sipName_endDocument, doc_QXmlFormatter_endDocument);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlFormatter_startOfSequence, "startOfSequence(self)");

extern "C" {static PyObject *meth_QXmlFormatter_startOfSequence(PyObject *, PyObject *);}
static PyObject *meth_QXmlFormatter_startOfSequence(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QXmlFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlFormatter, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QXmlFormatter::startOfSequence() : sipCpp->startOfSequence());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlFormatter, sipName_startOfSequence, doc_QXmlFormatter_startOfSequence);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlFormatter_endOfSequence, "endOfSequence(self)");

extern "C" {static PyObject *meth_QXmlFormatter_endOfSequence(PyObject *, PyObject *);}
static PyObject *meth_QXmlFormatter_endOfSequence(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QXmlFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlFormatter, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QXmlFormatter::endOfSequence() : sipCpp->endOfSequence());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlFormatter, sipName_endOfSequence, doc_QXmlFormatter_endOfSequence);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlFormatter_indentationDepth, "indentationDepth(self) -> int");

extern "C" {static PyObject *meth_QXmlFormatter_indentationDepth(PyObject *, PyObject *);}
static PyObject *meth_QXmlFormatter_indentationDepth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlFormatter, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->indentationDepth();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlFormatter, sipName_indentationDepth, doc_QXmlFormatter_indentationDepth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlFormatter_setIndentationDepth, "setIndentationDepth(self, depth: int)");

extern "C" {static PyObject *meth_QXmlFormatter_setIndentationDepth(PyObject *, PyObject *);}
static PyObject *meth_QXmlFormatter_setIndentationDepth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QXmlFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QXmlFormatter, &sipCpp, &a0))
        {
            sipCpp->setIndentationDepth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlFormatter, sipName_setIndentationDepth, doc_QXmlFormatter_setIndentationDepth);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QXmlFormatter(void *, const sipTypeDef *);}
static void *cast_QXmlFormatter(void *sipCppV, const sipTypeDef *targetType)
{
    ::QXmlFormatter *sipCpp = reinterpret_cast< ::QXmlFormatter *>(sipCppV);

    if (targetType == sipType_QXmlFormatter)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QXmlSerializer)->ctd_cast(static_cast< ::QXmlSerializer *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QXmlFormatter(void *, int);}
static void release_QXmlFormatter(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQXmlFormatter *>(sipCppV);
    else
        delete reinterpret_cast< ::QXmlFormatter *>(sipCppV);
}


extern "C" {static void dealloc_QXmlFormatter(sipSimpleWrapper *);}
static void dealloc_QXmlFormatter(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQXmlFormatter *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QXmlFormatter(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QXmlFormatter(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QXmlFormatter(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQXmlFormatter *sipCpp = SIP_NULLPTR;

    {
        const ::QXmlQuery* a0;
        ::QIODevice* a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9J8", sipType_QXmlQuery, &a0, sipType_QIODevice, &a1))
        {
            sipCpp = new sipQXmlFormatter(*a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QXmlFormatter[] = {{21, 255, 1}};


static PyMethodDef methods_QXmlFormatter[] = {
    {sipName_atomicValue, meth_QXmlFormatter_atomicValue, METH_VARARGS, doc_QXmlFormatter_atomicValue},
    {sipName_attribute, meth_QXmlFormatter_attribute, METH_VARARGS, doc_QXmlFormatter_attribute},
    {sipName_characters, meth_QXmlFormatter_characters, METH_VARARGS, doc_QXmlFormatter_characters},
    {sipName_comment, meth_QXmlFormatter_comment, METH_VARARGS, doc_QXmlFormatter_comment},
    {sipName_endDocument, meth_QXmlFormatter_endDocument, METH_VARARGS, doc_QXmlFormatter_endDocument},
    {sipName_endElement, meth_QXmlFormatter_endElement, METH_VARARGS, doc_QXmlFormatter_endElement},
    {sipName_endOfSequence, meth_QXmlFormatter_endOfSequence, METH_VARARGS, doc_QXmlFormatter_endOfSequence},
    {sipName_indentationDepth, meth_QXmlFormatter_indentationDepth, METH_VARARGS, doc_QXmlFormatter_indentationDepth},
    {sipName_processingInstruction, meth_QXmlFormatter_processingInstruction, METH_VARARGS, doc_QXmlFormatter_processingInstruction},
    {sipName_setIndentationDepth, meth_QXmlFormatter_setIndentationDepth, METH_VARARGS, doc_QXmlFormatter_setIndentationDepth},
    {sipName_startDocument, meth_QXmlFormatter_startDocument, METH_VARARGS, doc_QXmlFormatter_startDocument},
    {sipName_startElement, meth_QXmlFormatter_startElement, METH_VARARGS, doc_QXmlFormatter_startElement},
    {sipName_startOfSequence, meth_QXmlFormatter_startOfSequence, METH_VARARGS, doc_QXmlFormatter_startOfSequence}
};

PyDoc_STRVAR(doc_QXmlFormatter, "\1QXmlFormatter(query: QXmlQuery, outputDevice: Optional[QIODevice])");


static pyqt5ClassPluginDef plugin_QXmlFormatter = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtXmlPatterns_QXmlFormatter = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QXmlFormatter,
        SIP_NULLPTR,
        &plugin_QXmlFormatter,
    },
    {
        sipNameNr_QXmlFormatter,
        {0, 0, 1},
        13, methods_QXmlFormatter,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QXmlFormatter,
    -1,
    -1,
    supers_QXmlFormatter,
    SIP_NULLPTR,
    init_type_QXmlFormatter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QXmlFormatter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QXmlFormatter,
    cast_QXmlFormatter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QXmlFormatter),
};
