/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKit.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebhistoryinterface.sip"
#include <qwebhistoryinterface.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistoryInterface.cpp"


class sipQWebHistoryInterface : public ::QWebHistoryInterface
{
public:
    sipQWebHistoryInterface(::QObject*);
    virtual ~sipQWebHistoryInterface();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void addHistoryEntry(const ::QString&) SIP_OVERRIDE;
    bool historyContains(const ::QString&) const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQWebHistoryInterface(const sipQWebHistoryInterface &);
    sipQWebHistoryInterface &operator = (const sipQWebHistoryInterface &);

    char sipPyMethods[9];
};

sipQWebHistoryInterface::sipQWebHistoryInterface(::QObject*a0): ::QWebHistoryInterface(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQWebHistoryInterface::~sipQWebHistoryInterface()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQWebHistoryInterface::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWebKit_qt_metaobject(sipPySelf, sipType_QWebHistoryInterface);

    return ::QWebHistoryInterface::metaObject();
}

int sipQWebHistoryInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QWebHistoryInterface::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWebKit_qt_metacall(sipPySelf, sipType_QWebHistoryInterface, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQWebHistoryInterface::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWebKit_qt_metacast(sipPySelf, sipType_QWebHistoryInterface, _clname, &sipCpp) ? sipCpp : ::QWebHistoryInterface::qt_metacast(_clname));
}

void sipQWebHistoryInterface::addHistoryEntry(const ::QString& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, sipName_QWebHistoryInterface, sipName_addHistoryEntry);

    if (!sipMeth)
        return;

    extern void sipVH_QtWebKit_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    sipVH_QtWebKit_7(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWebHistoryInterface::historyContains(const ::QString& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QWebHistoryInterface, sipName_historyContains);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtWebKit_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtWebKit_6(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWebHistoryInterface::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QWebHistoryInterface::event(a0);

    extern bool sipVH_QtWebKit_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWebKit_5(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWebHistoryInterface::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QWebHistoryInterface::eventFilter(a0, a1);

    extern bool sipVH_QtWebKit_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWebKit_4(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQWebHistoryInterface::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QWebHistoryInterface::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWebKit_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWebKit_3(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebHistoryInterface::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QWebHistoryInterface::childEvent(a0);
        return;
    }

    extern void sipVH_QtWebKit_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWebKit_2(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebHistoryInterface::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QWebHistoryInterface::customEvent(a0);
        return;
    }

    extern void sipVH_QtWebKit_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebKit_1(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebHistoryInterface::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QWebHistoryInterface::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWebKit_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebKit_0(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebHistoryInterface::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QWebHistoryInterface::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWebKit_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebKit_0(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QWebHistoryInterface_setDefaultInterface, "setDefaultInterface(defaultInterface: Optional[QWebHistoryInterface])");

extern "C" {static PyObject *meth_QWebHistoryInterface_setDefaultInterface(PyObject *, PyObject *);}
static PyObject *meth_QWebHistoryInterface_setDefaultInterface(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebHistoryInterface* a0;
        PyObject *a0Keep;

        if (sipParseArgs(&sipParseErr, sipArgs, "@J8", &a0Keep, sipType_QWebHistoryInterface, &a0))
        {
            ::QWebHistoryInterface::setDefaultInterface(a0);

            sipKeepReference(SIP_NULLPTR, -1, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistoryInterface, sipName_setDefaultInterface, doc_QWebHistoryInterface_setDefaultInterface);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistoryInterface_defaultInterface, "defaultInterface() -> Optional[QWebHistoryInterface]");

extern "C" {static PyObject *meth_QWebHistoryInterface_defaultInterface(PyObject *, PyObject *);}
static PyObject *meth_QWebHistoryInterface_defaultInterface(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QWebHistoryInterface*sipRes;

            sipRes = ::QWebHistoryInterface::defaultInterface();

            return sipConvertFromType(sipRes, sipType_QWebHistoryInterface, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistoryInterface, sipName_defaultInterface, doc_QWebHistoryInterface_defaultInterface);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistoryInterface_historyContains, "historyContains(self, url: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QWebHistoryInterface_historyContains(PyObject *, PyObject *);}
static PyObject *meth_QWebHistoryInterface_historyContains(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QWebHistoryInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebHistoryInterface, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QWebHistoryInterface, sipName_historyContains);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->historyContains(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistoryInterface, sipName_historyContains, doc_QWebHistoryInterface_historyContains);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistoryInterface_addHistoryEntry, "addHistoryEntry(self, url: Optional[str])");

extern "C" {static PyObject *meth_QWebHistoryInterface_addHistoryEntry(PyObject *, PyObject *);}
static PyObject *meth_QWebHistoryInterface_addHistoryEntry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebHistoryInterface *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebHistoryInterface, &sipCpp, sipType_QString, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QWebHistoryInterface, sipName_addHistoryEntry);
                return SIP_NULLPTR;
            }

            sipCpp->addHistoryEntry(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistoryInterface, sipName_addHistoryEntry, doc_QWebHistoryInterface_addHistoryEntry);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QWebHistoryInterface(void *, const sipTypeDef *);}
static void *cast_QWebHistoryInterface(void *sipCppV, const sipTypeDef *targetType)
{
    ::QWebHistoryInterface *sipCpp = reinterpret_cast< ::QWebHistoryInterface *>(sipCppV);

    if (targetType == sipType_QWebHistoryInterface)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebHistoryInterface(void *, int);}
static void release_QWebHistoryInterface(void *sipCppV, int)
{
    ::QWebHistoryInterface *sipCpp = reinterpret_cast< ::QWebHistoryInterface *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QWebHistoryInterface(sipSimpleWrapper *);}
static void dealloc_QWebHistoryInterface(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQWebHistoryInterface *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWebHistoryInterface(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QWebHistoryInterface(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWebHistoryInterface(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQWebHistoryInterface *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQWebHistoryInterface(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QWebHistoryInterface[] = {{5, 0, 1}};


static PyMethodDef methods_QWebHistoryInterface[] = {
    {sipName_addHistoryEntry, meth_QWebHistoryInterface_addHistoryEntry, METH_VARARGS, doc_QWebHistoryInterface_addHistoryEntry},
    {sipName_defaultInterface, meth_QWebHistoryInterface_defaultInterface, METH_VARARGS, doc_QWebHistoryInterface_defaultInterface},
    {sipName_historyContains, meth_QWebHistoryInterface_historyContains, METH_VARARGS, doc_QWebHistoryInterface_historyContains},
    {sipName_setDefaultInterface, meth_QWebHistoryInterface_setDefaultInterface, METH_VARARGS, doc_QWebHistoryInterface_setDefaultInterface}
};

PyDoc_STRVAR(doc_QWebHistoryInterface, "\1QWebHistoryInterface(parent: Optional[QObject] = None)");


static pyqt5ClassPluginDef plugin_QWebHistoryInterface = {
    &::QWebHistoryInterface::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKit_QWebHistoryInterface = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebHistoryInterface,
        SIP_NULLPTR,
        &plugin_QWebHistoryInterface,
    },
    {
        sipNameNr_QWebHistoryInterface,
        {0, 0, 1},
        4, methods_QWebHistoryInterface,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWebHistoryInterface,
    -1,
    -1,
    supers_QWebHistoryInterface,
    SIP_NULLPTR,
    init_type_QWebHistoryInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWebHistoryInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QWebHistoryInterface,
    cast_QWebHistoryInterface,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QWebHistoryInterface),
};
