/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtPrintSupportAPI_H
#define _QtPrintSupportAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QAbstractPrintDialog__PrintDialogOptions 0
#define sipName_QAbstractPrintDialog__PrintDialogOptions &sipStrings_QtPrintSupport[0]
#define sipNameNr_QAbstractPrintDialog__PrintDialogOption 41
#define sipName_QAbstractPrintDialog__PrintDialogOption &sipStrings_QtPrintSupport[41]
#define sipNameNr_QPrintEngine__PrintEnginePropertyKey 81
#define sipName_QPrintEngine__PrintEnginePropertyKey &sipStrings_QtPrintSupport[81]
#define sipNameNr_118 118
#define sipName_118 &sipStrings_QtPrintSupport[118]
#define sipNameNr_QAbstractPrintDialog__PrintRange 153
#define sipName_QAbstractPrintDialog__PrintRange &sipStrings_QtPrintSupport[153]
#define sipNameNr_186 186
#define sipName_186 &sipStrings_QtPrintSupport[186]
#define sipNameNr_QPrintPreviewWidget__ViewMode 216
#define sipName_QPrintPreviewWidget__ViewMode &sipStrings_QtPrintSupport[216]
#define sipNameNr_QPrintPreviewWidget__ZoomMode 246
#define sipName_QPrintPreviewWidget__ZoomMode &sipStrings_QtPrintSupport[246]
#define sipNameNr_276 276
#define sipName_276 &sipStrings_QtPrintSupport[276]
#define sipNameNr_PPK_SupportsMultipleCopies 304
#define sipName_PPK_SupportsMultipleCopies &sipStrings_QtPrintSupport[304]
#define sipNameNr_331 331
#define sipName_331 &sipStrings_QtPrintSupport[331]
#define sipNameNr_setPrinterSelectionOption 358
#define sipName_setPrinterSelectionOption &sipStrings_QtPrintSupport[358]
#define sipNameNr_PPK_SupportedResolutions 384
#define sipName_PPK_SupportedResolutions &sipStrings_QtPrintSupport[384]
#define sipNameNr_maximumPhysicalPageSize 409
#define sipName_maximumPhysicalPageSize &sipStrings_QtPrintSupport[409]
#define sipNameNr_minimumPhysicalPageSize 433
#define sipName_minimumPhysicalPageSize &sipStrings_QtPrintSupport[433]
#define sipNameNr_setFontEmbeddingEnabled 457
#define sipName_setFontEmbeddingEnabled &sipStrings_QtPrintSupport[457]
#define sipNameNr_setLandscapeOrientation 481
#define sipName_setLandscapeOrientation &sipStrings_QtPrintSupport[481]
#define sipNameNr_supportedSizesWithNames 505
#define sipName_supportedSizesWithNames &sipStrings_QtPrintSupport[505]
#define sipNameNr_supportsCustomPageSizes 529
#define sipName_supportsCustomPageSizes &sipStrings_QtPrintSupport[529]
#define sipNameNr_PrintEnginePropertyKey 95
#define sipName_PrintEnginePropertyKey &sipStrings_QtPrintSupport[95]
#define sipNameNr_QPrinter__OutputFormat 553
#define sipName_QPrinter__OutputFormat &sipStrings_QtPrintSupport[553]
#define sipNameNr_QPrinter__PrinterState 576
#define sipName_QPrinter__PrinterState &sipStrings_QtPrintSupport[576]
#define sipNameNr_printerSelectionOption 599
#define sipName_printerSelectionOption &sipStrings_QtPrintSupport[599]
#define sipNameNr_setDoubleSidedPrinting 622
#define sipName_setDoubleSidedPrinting &sipStrings_QtPrintSupport[622]
#define sipNameNr_setFacingPagesViewMode 645
#define sipName_setFacingPagesViewMode &sipStrings_QtPrintSupport[645]
#define sipNameNr_setPortraitOrientation 668
#define sipName_setPortraitOrientation &sipStrings_QtPrintSupport[668]
#define sipNameNr_supportsMultipleCopies 691
#define sipName_supportsMultipleCopies &sipStrings_QtPrintSupport[691]
#define sipNameNr_QPrinter__Orientation 714
#define sipName_QPrinter__Orientation &sipStrings_QtPrintSupport[714]
#define sipNameNr_QPrinter__PaperSource 736
#define sipName_QPrinter__PaperSource &sipStrings_QtPrintSupport[736]
#define sipNameNr_QPrinter__PrinterMode 758
#define sipName_QPrinter__PrinterMode &sipStrings_QtPrintSupport[758]
#define sipNameNr_availablePrinterNames 780
#define sipName_availablePrinterNames &sipStrings_QtPrintSupport[780]
#define sipNameNr_mouseDoubleClickEvent 802
#define sipName_mouseDoubleClickEvent &sipStrings_QtPrintSupport[802]
#define sipNameNr_setSinglePageViewMode 824
#define sipName_setSinglePageViewMode &sipStrings_QtPrintSupport[824]
#define sipNameNr_PyQt5_QtPrintSupport 846
#define sipName_PyQt5_QtPrintSupport &sipStrings_QtPrintSupport[846]
#define sipNameNr_QAbstractPrintDialog 867
#define sipName_QAbstractPrintDialog &sipStrings_QtPrintSupport[867]
#define sipNameNr_QPrinter__DuplexMode 888
#define sipName_QPrinter__DuplexMode &sipStrings_QtPrintSupport[888]
#define sipNameNr_QPrinter__PrintRange 909
#define sipName_QPrinter__PrintRange &sipStrings_QtPrintSupport[909]
#define sipNameNr_fontEmbeddingEnabled 930
#define sipName_fontEmbeddingEnabled &sipStrings_QtPrintSupport[930]
#define sipNameNr_supportedDuplexModes 951
#define sipName_supportedDuplexModes &sipStrings_QtPrintSupport[951]
#define sipNameNr_supportedResolutions 972
#define sipName_supportedResolutions &sipStrings_QtPrintSupport[972]
#define sipNameNr_PPK_CustomPaperSize 993
#define sipName_PPK_CustomPaperSize &sipStrings_QtPrintSupport[993]
#define sipNameNr_PPK_SelectionOption 1013
#define sipName_PPK_SelectionOption &sipStrings_QtPrintSupport[1013]
#define sipNameNr_PPK_WindowsPageSize 1033
#define sipName_PPK_WindowsPageSize &sipStrings_QtPrintSupport[1033]
#define sipNameNr_1053 1053
#define sipName_1053 &sipStrings_QtPrintSupport[1053]
#define sipNameNr_QPrintPreviewDialog 1073
#define sipName_QPrintPreviewDialog &sipStrings_QtPrintSupport[1073]
#define sipNameNr_QPrintPreviewWidget 1093
#define sipName_QPrintPreviewWidget &sipStrings_QtPrintSupport[1093]
#define sipNameNr_QPrinter__ColorMode 1113
#define sipName_QPrinter__ColorMode &sipStrings_QtPrintSupport[1113]
#define sipNameNr_QPrinter__PageOrder 1133
#define sipName_QPrinter__PageOrder &sipStrings_QtPrintSupport[1133]
#define sipNameNr_doubleSidedPrinting 1153
#define sipName_doubleSidedPrinting &sipStrings_QtPrintSupport[1153]
#define sipNameNr_setAllPagesViewMode 1173
#define sipName_setAllPagesViewMode &sipStrings_QtPrintSupport[1173]
#define sipNameNr_supportedColorModes 1193
#define sipName_supportedColorModes &sipStrings_QtPrintSupport[1193]
#define sipNameNr_supportedPaperSizes 1213
#define sipName_supportedPaperSizes &sipStrings_QtPrintSupport[1213]
#define sipNameNr_PPK_NumberOfCopies 1233
#define sipName_PPK_NumberOfCopies &sipStrings_QtPrintSupport[1233]
#define sipNameNr_PPK_OutputFileName 1252
#define sipName_PPK_OutputFileName &sipStrings_QtPrintSupport[1252]
#define sipNameNr_PPK_PrinterProgram 1271
#define sipName_PPK_PrinterProgram &sipStrings_QtPrintSupport[1271]
#define sipNameNr_PrintCollateCopies 1290
#define sipName_PrintCollateCopies &sipStrings_QtPrintSupport[1290]
#define sipNameNr_PrintDialogOptions 22
#define sipName_PrintDialogOptions &sipStrings_QtPrintSupport[22]
#define sipNameNr_defaultPrinterName 1309
#define sipName_defaultPrinterName &sipStrings_QtPrintSupport[1309]
#define sipNameNr_focusNextPrevChild 1328
#define sipName_focusNextPrevChild &sipStrings_QtPrintSupport[1328]
#define sipNameNr_supportedPageSizes 1347
#define sipName_supportedPageSizes &sipStrings_QtPrintSupport[1347]
#define sipNameNr_PPK_CollateCopies 1366
#define sipName_PPK_CollateCopies &sipStrings_QtPrintSupport[1366]
#define sipNameNr_PPK_FontEmbedding 1384
#define sipName_PPK_FontEmbedding &sipStrings_QtPrintSupport[1384]
#define sipNameNr_PrintDialogOption 63
#define sipName_PrintDialogOption &sipStrings_QtPrintSupport[63]
#define sipNameNr_PrintShowPageSize 1402
#define sipName_PrintShowPageSize &sipStrings_QtPrintSupport[1402]
#define sipNameNr_PrinterResolution 1420
#define sipName_PrinterResolution &sipStrings_QtPrintSupport[1420]
#define sipNameNr_availablePrinters 1438
#define sipName_availablePrinters &sipStrings_QtPrintSupport[1438]
#define sipNameNr_defaultDuplexMode 1456
#define sipName_defaultDuplexMode &sipStrings_QtPrintSupport[1456]
#define sipNameNr_hasHeightForWidth 1474
#define sipName_hasHeightForWidth &sipStrings_QtPrintSupport[1474]
#define sipNameNr_mouseReleaseEvent 1492
#define sipName_mouseReleaseEvent &sipStrings_QtPrintSupport[1492]
#define sipNameNr_setEnabledOptions 1510
#define sipName_setEnabledOptions &sipStrings_QtPrintSupport[1510]
#define sipNameNr_setOutputFileName 1528
#define sipName_setOutputFileName &sipStrings_QtPrintSupport[1528]
#define sipNameNr_sip_simplewrapper 1546
#define sipName_sip_simplewrapper &sipStrings_QtPrintSupport[1546]
#define sipNameNr_PPK_DocumentName 1564
#define sipName_PPK_DocumentName &sipStrings_QtPrintSupport[1564]
#define sipNameNr_PPK_PaperSources 1581
#define sipName_PPK_PaperSources &sipStrings_QtPrintSupport[1581]
#define sipNameNr_PPK_QPageMargins 1598
#define sipName_PPK_QPageMargins &sipStrings_QtPrintSupport[1598]
#define sipNameNr_PrintCurrentPage 1615
#define sipName_PrintCurrentPage &sipStrings_QtPrintSupport[1615]
#define sipNameNr_1632 1632
#define sipName_1632 &sipStrings_QtPrintSupport[1632]
#define sipNameNr_QPageSetupDialog 1649
#define sipName_QPageSetupDialog &sipStrings_QtPrintSupport[1649]
#define sipNameNr_ScreenResolution 1666
#define sipName_ScreenResolution &sipStrings_QtPrintSupport[1666]
#define sipNameNr_contextMenuEvent 1683
#define sipName_contextMenuEvent &sipStrings_QtPrintSupport[1683]
#define sipNameNr_defaultColorMode 1700
#define sipName_defaultColorMode &sipStrings_QtPrintSupport[1700]
#define sipNameNr_disconnectNotify 1717
#define sipName_disconnectNotify &sipStrings_QtPrintSupport[1717]
#define sipNameNr_inputMethodEvent 1734
#define sipName_inputMethodEvent &sipStrings_QtPrintSupport[1734]
#define sipNameNr_inputMethodQuery 1751
#define sipName_inputMethodQuery &sipStrings_QtPrintSupport[1751]
#define sipNameNr_setCollateCopies 1768
#define sipName_setCollateCopies &sipStrings_QtPrintSupport[1768]
#define sipNameNr_DuplexShortSide 1785
#define sipName_DuplexShortSide &sipStrings_QtPrintSupport[1785]
#define sipNameNr_FacingPagesView 1801
#define sipName_FacingPagesView &sipStrings_QtPrintSupport[1801]
#define sipNameNr_LastPaperSource 1817
#define sipName_LastPaperSource &sipStrings_QtPrintSupport[1817]
#define sipNameNr_PPK_Orientation 1833
#define sipName_PPK_Orientation &sipStrings_QtPrintSupport[1833]
#define sipNameNr_PPK_PageMargins 1849
#define sipName_PPK_PageMargins &sipStrings_QtPrintSupport[1849]
#define sipNameNr_PPK_PaperSource 1865
#define sipName_PPK_PaperSource &sipStrings_QtPrintSupport[1865]
#define sipNameNr_PPK_PrinterName 1881
#define sipName_PPK_PrinterName &sipStrings_QtPrintSupport[1881]
#define sipNameNr_PPK_QPageLayout 1897
#define sipName_PPK_QPageLayout &sipStrings_QtPrintSupport[1897]
#define sipNameNr_defaultPageSize 1913
#define sipName_defaultPageSize &sipStrings_QtPrintSupport[1913]
#define sipNameNr_keyReleaseEvent 1929
#define sipName_keyReleaseEvent &sipStrings_QtPrintSupport[1929]
#define sipNameNr_minimumSizeHint 1945
#define sipName_minimumSizeHint &sipStrings_QtPrintSupport[1945]
#define sipNameNr_mousePressEvent 1961
#define sipName_mousePressEvent &sipStrings_QtPrintSupport[1961]
#define sipNameNr_setOutputFormat 1977
#define sipName_setOutputFormat &sipStrings_QtPrintSupport[1977]
#define sipNameNr_setPrintProgram 1993
#define sipName_setPrintProgram &sipStrings_QtPrintSupport[1993]
#define sipNameNr_DuplexLongSide 2009
#define sipName_DuplexLongSide &sipStrings_QtPrintSupport[2009]
#define sipNameNr_EnvelopeManual 2024
#define sipName_EnvelopeManual &sipStrings_QtPrintSupport[2024]
#define sipNameNr_FirstPageFirst 2039
#define sipName_FirstPageFirst &sipStrings_QtPrintSupport[2039]
#define sipNameNr_HighResolution 2054
#define sipName_HighResolution &sipStrings_QtPrintSupport[2054]
#define sipNameNr_PPK_CustomBase 2069
#define sipName_PPK_CustomBase &sipStrings_QtPrintSupport[2069]
#define sipNameNr_PPK_Resolution 2084
#define sipName_PPK_Resolution &sipStrings_QtPrintSupport[2084]
#define sipNameNr_PrintPageRange 2099
#define sipName_PrintPageRange &sipStrings_QtPrintSupport[2099]
#define sipNameNr_PrintSelection 2114
#define sipName_PrintSelection &sipStrings_QtPrintSupport[2114]
#define sipNameNr_QPrinter__Unit 2129
#define sipName_QPrinter__Unit &sipStrings_QtPrintSupport[2129]
#define sipNameNr_SinglePageView 2144
#define sipName_SinglePageView &sipStrings_QtPrintSupport[2144]
#define sipNameNr_defaultPrinter 2159
#define sipName_defaultPrinter &sipStrings_QtPrintSupport[2159]
#define sipNameNr_dragEnterEvent 2174
#define sipName_dragEnterEvent &sipStrings_QtPrintSupport[2174]
#define sipNameNr_dragLeaveEvent 2189
#define sipName_dragLeaveEvent &sipStrings_QtPrintSupport[2189]
#define sipNameNr_enabledOptions 2204
#define sipName_enabledOptions &sipStrings_QtPrintSupport[2204]
#define sipNameNr_getPageMargins 2219
#define sipName_getPageMargins &sipStrings_QtPrintSupport[2219]
#define sipNameNr_heightForWidth 2234
#define sipName_heightForWidth &sipStrings_QtPrintSupport[2234]
#define sipNameNr_mouseMoveEvent 2249
#define sipName_mouseMoveEvent &sipStrings_QtPrintSupport[2249]
#define sipNameNr_outputFileName 2264
#define sipName_outputFileName &sipStrings_QtPrintSupport[2264]
#define sipNameNr_paintRequested 2279
#define sipName_paintRequested &sipStrings_QtPrintSupport[2279]
#define sipNameNr_previewChanged 2294
#define sipName_previewChanged &sipStrings_QtPrintSupport[2294]
#define sipNameNr_setCurrentPage 2309
#define sipName_setCurrentPage &sipStrings_QtPrintSupport[2309]
#define sipNameNr_setOrientation 2324
#define sipName_setOrientation &sipStrings_QtPrintSupport[2324]
#define sipNameNr_setPageMargins 2339
#define sipName_setPageMargins &sipStrings_QtPrintSupport[2339]
#define sipNameNr_setPaperSource 2354
#define sipName_setPaperSource &sipStrings_QtPrintSupport[2354]
#define sipNameNr_setPrinterName 2369
#define sipName_setPrinterName &sipStrings_QtPrintSupport[2369]
#define sipNameNr_LargeCapacity 2384
#define sipName_LargeCapacity &sipStrings_QtPrintSupport[2384]
#define sipNameNr_LastPageFirst 2398
#define sipName_LastPageFirst &sipStrings_QtPrintSupport[2398]
#define sipNameNr_MaxPageSource 2412
#define sipName_MaxPageSource &sipStrings_QtPrintSupport[2412]
#define sipNameNr_PPK_ColorMode 2426
#define sipName_PPK_ColorMode &sipStrings_QtPrintSupport[2426]
#define sipNameNr_PPK_CopyCount 2440
#define sipName_PPK_CopyCount &sipStrings_QtPrintSupport[2440]
#define sipNameNr_PPK_PageOrder 2454
#define sipName_PPK_PageOrder &sipStrings_QtPrintSupport[2454]
#define sipNameNr_PPK_PaperName 2468
#define sipName_PPK_PaperName &sipStrings_QtPrintSupport[2468]
#define sipNameNr_PPK_PaperRect 2482
#define sipName_PPK_PaperRect &sipStrings_QtPrintSupport[2482]
#define sipNameNr_PPK_PaperSize 2496
#define sipName_PPK_PaperSize &sipStrings_QtPrintSupport[2496]
#define sipNameNr_PPK_QPageSize 2510
#define sipName_PPK_QPageSize &sipStrings_QtPrintSupport[2510]
#define sipNameNr_collateCopies 2524
#define sipName_collateCopies &sipStrings_QtPrintSupport[2524]
#define sipNameNr_connectNotify 1720
#define sipName_connectNotify &sipStrings_QtPrintSupport[1720]
#define sipNameNr_dragMoveEvent 2538
#define sipName_dragMoveEvent &sipStrings_QtPrintSupport[2538]
#define sipNameNr_focusOutEvent 2552
#define sipName_focusOutEvent &sipStrings_QtPrintSupport[2552]
#define sipNameNr_keyPressEvent 2566
#define sipName_keyPressEvent &sipStrings_QtPrintSupport[2566]
#define sipNameNr_setOptionTabs 2580
#define sipName_setOptionTabs &sipStrings_QtPrintSupport[2580]
#define sipNameNr_setPageSizeMM 2594
#define sipName_setPageSizeMM &sipStrings_QtPrintSupport[2594]
#define sipNameNr_setPdfVersion 2608
#define sipName_setPdfVersion &sipStrings_QtPrintSupport[2608]
#define sipNameNr_setPrintRange 2622
#define sipName_setPrintRange &sipStrings_QtPrintSupport[2622]
#define sipNameNr_setResolution 2636
#define sipName_setResolution &sipStrings_QtPrintSupport[2636]
#define sipNameNr_setZoomFactor 2650
#define sipName_setZoomFactor &sipStrings_QtPrintSupport[2650]
#define sipNameNr_sharedPainter 2664
#define sipName_sharedPainter &sipStrings_QtPrintSupport[2664]
#define sipNameNr_updatePreview 2678
#define sipName_updatePreview &sipStrings_QtPrintSupport[2678]
#define sipNameNr_AllPagesView 2692
#define sipName_AllPagesView &sipStrings_QtPrintSupport[2692]
#define sipNameNr_CustomSource 2705
#define sipName_CustomSource &sipStrings_QtPrintSupport[2705]
#define sipNameNr_NativeFormat 2718
#define sipName_NativeFormat &sipStrings_QtPrintSupport[2718]
#define sipNameNr_OutputFormat 563
#define sipName_OutputFormat &sipStrings_QtPrintSupport[563]
#define sipNameNr_PPK_FullPage 2731
#define sipName_PPK_FullPage &sipStrings_QtPrintSupport[2731]
#define sipNameNr_PPK_PageRect 2744
#define sipName_PPK_PageRect &sipStrings_QtPrintSupport[2744]
#define sipNameNr_PPK_PageSize 2757
#define sipName_PPK_PageSize &sipStrings_QtPrintSupport[2757]
#define sipNameNr_PrinterState 586
#define sipName_PrinterState &sipStrings_QtPrintSupport[586]
#define sipNameNr_QPrintDialog 2770
#define sipName_QPrintDialog &sipStrings_QtPrintSupport[2770]
#define sipNameNr_QPrintEngine 2783
#define sipName_QPrintEngine &sipStrings_QtPrintSupport[2783]
#define sipNameNr_QPrinterInfo 2796
#define sipName_QPrinterInfo &sipStrings_QtPrintSupport[2796]
#define sipNameNr_focusInEvent 2809
#define sipName_focusInEvent &sipStrings_QtPrintSupport[2809]
#define sipNameNr_makeAndModel 2822
#define sipName_makeAndModel &sipStrings_QtPrintSupport[2822]
#define sipNameNr_outputFormat 2835
#define sipName_outputFormat &sipStrings_QtPrintSupport[2835]
#define sipNameNr_printProgram 2848
#define sipName_printProgram &sipStrings_QtPrintSupport[2848]
#define sipNameNr_printerState 2861
#define sipName_printerState &sipStrings_QtPrintSupport[2861]
#define sipNameNr_setColorMode 2874
#define sipName_setColorMode &sipStrings_QtPrintSupport[2874]
#define sipNameNr_setCopyCount 2887
#define sipName_setCopyCount &sipStrings_QtPrintSupport[2887]
#define sipNameNr_setPageOrder 2900
#define sipName_setPageOrder &sipStrings_QtPrintSupport[2900]
#define sipNameNr_setPaperName 2913
#define sipName_setPaperName &sipStrings_QtPrintSupport[2913]
#define sipNameNr_setPaperSize 2926
#define sipName_setPaperSize &sipStrings_QtPrintSupport[2926]
#define sipNameNr_CurrentPage 1620
#define sipName_CurrentPage &sipStrings_QtPrintSupport[1620]
#define sipNameNr_DevicePixel 2939
#define sipName_DevicePixel &sipStrings_QtPrintSupport[2939]
#define sipNameNr_LargeFormat 2951
#define sipName_LargeFormat &sipStrings_QtPrintSupport[2951]
#define sipNameNr_Orientation 493
#define sipName_Orientation &sipStrings_QtPrintSupport[493]
#define sipNameNr_PPK_Creator 2963
#define sipName_PPK_Creator &sipStrings_QtPrintSupport[2963]
#define sipNameNr_PaperSource 746
#define sipName_PaperSource &sipStrings_QtPrintSupport[746]
#define sipNameNr_PrintToFile 2975
#define sipName_PrintToFile &sipStrings_QtPrintSupport[2975]
#define sipNameNr_PrinterMode 768
#define sipName_PrinterMode &sipStrings_QtPrintSupport[768]
#define sipNameNr_SmallFormat 2987
#define sipName_SmallFormat &sipStrings_QtPrintSupport[2987]
#define sipNameNr_actionEvent 2999
#define sipName_actionEvent &sipStrings_QtPrintSupport[2999]
#define sipNameNr_changeEvent 3011
#define sipName_changeEvent &sipStrings_QtPrintSupport[3011]
#define sipNameNr_currentPage 3023
#define sipName_currentPage &sipStrings_QtPrintSupport[3023]
#define sipNameNr_customEvent 3035
#define sipName_customEvent &sipStrings_QtPrintSupport[3035]
#define sipNameNr_description 3047
#define sipName_description &sipStrings_QtPrintSupport[3047]
#define sipNameNr_eventFilter 3059
#define sipName_eventFilter &sipStrings_QtPrintSupport[3059]
#define sipNameNr_initPainter 3071
#define sipName_initPainter &sipStrings_QtPrintSupport[3071]
#define sipNameNr_nativeEvent 3083
#define sipName_nativeEvent &sipStrings_QtPrintSupport[3083]
#define sipNameNr_orientation 3095
#define sipName_orientation &sipStrings_QtPrintSupport[3095]
#define sipNameNr_paintEngine 3107
#define sipName_paintEngine &sipStrings_QtPrintSupport[3107]
#define sipNameNr_paperSource 3119
#define sipName_paperSource &sipStrings_QtPrintSupport[3119]
#define sipNameNr_printEngine 3131
#define sipName_printEngine &sipStrings_QtPrintSupport[3131]
#define sipNameNr_printerInfo 3143
#define sipName_printerInfo &sipStrings_QtPrintSupport[3143]
#define sipNameNr_printerName 3155
#define sipName_printerName &sipStrings_QtPrintSupport[3155]
#define sipNameNr_resizeEvent 3167
#define sipName_resizeEvent &sipStrings_QtPrintSupport[3167]
#define sipNameNr_setFullPage 3179
#define sipName_setFullPage &sipStrings_QtPrintSupport[3179]
#define sipNameNr_setPageSize 3191
#define sipName_setPageSize &sipStrings_QtPrintSupport[3191]
#define sipNameNr_setProperty 3203
#define sipName_setProperty &sipStrings_QtPrintSupport[3203]
#define sipNameNr_setViewMode 3215
#define sipName_setViewMode &sipStrings_QtPrintSupport[3215]
#define sipNameNr_setZoomMode 3227
#define sipName_setZoomMode &sipStrings_QtPrintSupport[3227]
#define sipNameNr_tabletEvent 3239
#define sipName_tabletEvent &sipStrings_QtPrintSupport[3239]
#define sipNameNr_CustomZoom 3251
#define sipName_CustomZoom &sipStrings_QtPrintSupport[3251]
#define sipNameNr_DuplexAuto 3262
#define sipName_DuplexAuto &sipStrings_QtPrintSupport[3262]
#define sipNameNr_DuplexMode 898
#define sipName_DuplexMode &sipStrings_QtPrintSupport[898]
#define sipNameNr_DuplexNone 3273
#define sipName_DuplexNone &sipStrings_QtPrintSupport[3273]
#define sipNameNr_FitToWidth 3284
#define sipName_FitToWidth &sipStrings_QtPrintSupport[3284]
#define sipNameNr_FormSource 3295
#define sipName_FormSource &sipStrings_QtPrintSupport[3295]
#define sipNameNr_Millimeter 3306
#define sipName_Millimeter &sipStrings_QtPrintSupport[3306]
#define sipNameNr_PPK_Duplex 3317
#define sipName_PPK_Duplex &sipStrings_QtPrintSupport[3317]
#define sipNameNr_PrintRange 175
#define sipName_PrintRange &sipStrings_QtPrintSupport[175]
#define sipNameNr___invert__ 3328
#define sipName___invert__ &sipStrings_QtPrintSupport[3328]
#define sipNameNr_childEvent 3339
#define sipName_childEvent &sipStrings_QtPrintSupport[3339]
#define sipNameNr_closeEvent 3350
#define sipName_closeEvent &sipStrings_QtPrintSupport[3350]
#define sipNameNr_enterEvent 3361
#define sipName_enterEvent &sipStrings_QtPrintSupport[3361]
#define sipNameNr_fitToWidth 3372
#define sipName_fitToWidth &sipStrings_QtPrintSupport[3372]
#define sipNameNr_leaveEvent 3383
#define sipName_leaveEvent &sipStrings_QtPrintSupport[3383]
#define sipNameNr_paintEvent 3394
#define sipName_paintEvent &sipStrings_QtPrintSupport[3394]
#define sipNameNr_pdfVersion 3405
#define sipName_pdfVersion &sipStrings_QtPrintSupport[3405]
#define sipNameNr_printRange 3416
#define sipName_printRange &sipStrings_QtPrintSupport[3416]
#define sipNameNr_resolution 3427
#define sipName_resolution &sipStrings_QtPrintSupport[3427]
#define sipNameNr_setCreator 3438
#define sipName_setCreator &sipStrings_QtPrintSupport[3438]
#define sipNameNr_setDocName 3449
#define sipName_setDocName &sipStrings_QtPrintSupport[3449]
#define sipNameNr_setEngines 3460
#define sipName_setEngines &sipStrings_QtPrintSupport[3460]
#define sipNameNr_setMargins 3471
#define sipName_setMargins &sipStrings_QtPrintSupport[3471]
#define sipNameNr_setOptions 3482
#define sipName_setOptions &sipStrings_QtPrintSupport[3482]
#define sipNameNr_setVisible 3493
#define sipName_setVisible &sipStrings_QtPrintSupport[3493]
#define sipNameNr_testOption 3504
#define sipName_testOption &sipStrings_QtPrintSupport[3504]
#define sipNameNr_timerEvent 3515
#define sipName_timerEvent &sipStrings_QtPrintSupport[3515]
#define sipNameNr_wheelEvent 3526
#define sipName_wheelEvent &sipStrings_QtPrintSupport[3526]
#define sipNameNr_zoomFactor 3537
#define sipName_zoomFactor &sipStrings_QtPrintSupport[3537]
#define sipNameNr_ColorMode 1123
#define sipName_ColorMode &sipStrings_QtPrintSupport[1123]
#define sipNameNr_FitInView 3548
#define sipName_FitInView &sipStrings_QtPrintSupport[3548]
#define sipNameNr_GrayScale 3558
#define sipName_GrayScale &sipStrings_QtPrintSupport[3558]
#define sipNameNr_Landscape 3568
#define sipName_Landscape &sipStrings_QtPrintSupport[3568]
#define sipNameNr_PageOrder 1143
#define sipName_PageOrder &sipStrings_QtPrintSupport[1143]
#define sipNameNr_PageRange 2104
#define sipName_PageRange &sipStrings_QtPrintSupport[2104]
#define sipNameNr_PdfFormat 3578
#define sipName_PdfFormat &sipStrings_QtPrintSupport[3578]
#define sipNameNr_Selection 2119
#define sipName_Selection &sipStrings_QtPrintSupport[2119]
#define sipNameNr___index__ 3588
#define sipName___index__ &sipStrings_QtPrintSupport[3588]
#define sipNameNr_colorMode 3598
#define sipName_colorMode &sipStrings_QtPrintSupport[3598]
#define sipNameNr_copyCount 3608
#define sipName_copyCount &sipStrings_QtPrintSupport[3608]
#define sipNameNr_dropEvent 3618
#define sipName_dropEvent &sipStrings_QtPrintSupport[3618]
#define sipNameNr_fitInView 3628
#define sipName_fitInView &sipStrings_QtPrintSupport[3628]
#define sipNameNr_hideEvent 3638
#define sipName_hideEvent &sipStrings_QtPrintSupport[3638]
#define sipNameNr_isDefault 3648
#define sipName_isDefault &sipStrings_QtPrintSupport[3648]
#define sipNameNr_moveEvent 3658
#define sipName_moveEvent &sipStrings_QtPrintSupport[3658]
#define sipNameNr_pageCount 3668
#define sipName_pageCount &sipStrings_QtPrintSupport[3668]
#define sipNameNr_pageOrder 3678
#define sipName_pageOrder &sipStrings_QtPrintSupport[3678]
#define sipNameNr_paperName 3688
#define sipName_paperName &sipStrings_QtPrintSupport[3688]
#define sipNameNr_paperRect 3698
#define sipName_paperRect &sipStrings_QtPrintSupport[3698]
#define sipNameNr_paperSize 3708
#define sipName_paperSize &sipStrings_QtPrintSupport[3708]
#define sipNameNr_setDuplex 3718
#define sipName_setDuplex &sipStrings_QtPrintSupport[3718]
#define sipNameNr_setFromTo 3728
#define sipName_setFromTo &sipStrings_QtPrintSupport[3728]
#define sipNameNr_setMinMax 3738
#define sipName_setMinMax &sipStrings_QtPrintSupport[3738]
#define sipNameNr_setOption 3748
#define sipName_setOption &sipStrings_QtPrintSupport[3748]
#define sipNameNr_showEvent 3758
#define sipName_showEvent &sipStrings_QtPrintSupport[3758]
#define sipNameNr_AllPages 3768
#define sipName_AllPages &sipStrings_QtPrintSupport[3768]
#define sipNameNr_Cassette 3777
#define sipName_Cassette &sipStrings_QtPrintSupport[3777]
#define sipNameNr_Envelope 3786
#define sipName_Envelope &sipStrings_QtPrintSupport[3786]
#define sipNameNr_Portrait 3795
#define sipName_Portrait &sipStrings_QtPrintSupport[3795]
#define sipNameNr_QPrinter 3804
#define sipName_QPrinter &sipStrings_QtPrintSupport[3804]
#define sipNameNr_ViewMode 237
#define sipName_ViewMode &sipStrings_QtPrintSupport[237]
#define sipNameNr_ZoomMode 267
#define sipName_ZoomMode &sipStrings_QtPrintSupport[267]
#define sipNameNr___bool__ 3813
#define sipName___bool__ &sipStrings_QtPrintSupport[3813]
#define sipNameNr___hash__ 3822
#define sipName___hash__ &sipStrings_QtPrintSupport[3822]
#define sipNameNr___iand__ 3831
#define sipName___iand__ &sipStrings_QtPrintSupport[3831]
#define sipNameNr___ixor__ 3840
#define sipName___ixor__ &sipStrings_QtPrintSupport[3840]
#define sipNameNr_accepted 3849
#define sipName_accepted &sipStrings_QtPrintSupport[3849]
#define sipNameNr_fromPage 3858
#define sipName_fromPage &sipStrings_QtPrintSupport[3858]
#define sipNameNr_fullPage 3867
#define sipName_fullPage &sipStrings_QtPrintSupport[3867]
#define sipNameNr_isRemote 3876
#define sipName_isRemote &sipStrings_QtPrintSupport[3876]
#define sipNameNr_location 3885
#define sipName_location &sipStrings_QtPrintSupport[3885]
#define sipNameNr_pageRect 3894
#define sipName_pageRect &sipStrings_QtPrintSupport[3894]
#define sipNameNr_property 3903
#define sipName_property &sipStrings_QtPrintSupport[3903]
#define sipNameNr_sizeHint 3912
#define sipName_sizeHint &sipStrings_QtPrintSupport[3912]
#define sipNameNr_viewMode 3921
#define sipName_viewMode &sipStrings_QtPrintSupport[3921]
#define sipNameNr_zoomMode 3930
#define sipName_zoomMode &sipStrings_QtPrintSupport[3930]
#define sipNameNr_Aborted 3939
#define sipName_Aborted &sipStrings_QtPrintSupport[3939]
#define sipNameNr_OnlyOne 3947
#define sipName_OnlyOne &sipStrings_QtPrintSupport[3947]
#define sipNameNr_Tractor 3955
#define sipName_Tractor &sipStrings_QtPrintSupport[3955]
#define sipNameNr___and__ 3963
#define sipName___and__ &sipStrings_QtPrintSupport[3963]
#define sipNameNr___int__ 3971
#define sipName___int__ &sipStrings_QtPrintSupport[3971]
#define sipNameNr___ior__ 3979
#define sipName___ior__ &sipStrings_QtPrintSupport[3979]
#define sipNameNr___xor__ 3987
#define sipName___xor__ &sipStrings_QtPrintSupport[3987]
#define sipNameNr_creator 3995
#define sipName_creator &sipStrings_QtPrintSupport[3995]
#define sipNameNr_devType 4003
#define sipName_devType &sipStrings_QtPrintSupport[4003]
#define sipNameNr_docName 4011
#define sipName_docName &sipStrings_QtPrintSupport[4011]
#define sipNameNr_isValid 4019
#define sipName_isValid &sipStrings_QtPrintSupport[4019]
#define sipNameNr_maxPage 4027
#define sipName_maxPage &sipStrings_QtPrintSupport[4027]
#define sipNameNr_minPage 4035
#define sipName_minPage &sipStrings_QtPrintSupport[4035]
#define sipNameNr_newPage 4043
#define sipName_newPage &sipStrings_QtPrintSupport[4043]
#define sipNameNr_options 4051
#define sipName_options &sipStrings_QtPrintSupport[4051]
#define sipNameNr_printer 4059
#define sipName_printer &sipStrings_QtPrintSupport[4059]
#define sipNameNr_zoomOut 4067
#define sipName_zoomOut &sipStrings_QtPrintSupport[4067]
#define sipNameNr_Active 4075
#define sipName_Active &sipStrings_QtPrintSupport[4075]
#define sipNameNr_Cicero 4082
#define sipName_Cicero &sipStrings_QtPrintSupport[4082]
#define sipNameNr_Manual 2032
#define sipName_Manual &sipStrings_QtPrintSupport[2032]
#define sipNameNr_Middle 4089
#define sipName_Middle &sipStrings_QtPrintSupport[4089]
#define sipNameNr___eq__ 4096
#define sipName___eq__ &sipStrings_QtPrintSupport[4096]
#define sipNameNr___ne__ 4103
#define sipName___ne__ &sipStrings_QtPrintSupport[4103]
#define sipNameNr___or__ 4110
#define sipName___or__ &sipStrings_QtPrintSupport[4110]
#define sipNameNr_accept 4117
#define sipName_accept &sipStrings_QtPrintSupport[4117]
#define sipNameNr_duplex 4124
#define sipName_duplex &sipStrings_QtPrintSupport[4124]
#define sipNameNr_factor 4131
#define sipName_factor &sipStrings_QtPrintSupport[4131]
#define sipNameNr_isNull 4138
#define sipName_isNull &sipStrings_QtPrintSupport[4138]
#define sipNameNr_metric 4145
#define sipName_metric &sipStrings_QtPrintSupport[4145]
#define sipNameNr_parent 4152
#define sipName_parent &sipStrings_QtPrintSupport[4152]
#define sipNameNr_print_ 4159
#define sipName_print_ &sipStrings_QtPrintSupport[4159]
#define sipNameNr_reject 4166
#define sipName_reject &sipStrings_QtPrintSupport[4166]
#define sipNameNr_toPage 4173
#define sipName_toPage &sipStrings_QtPrintSupport[4173]
#define sipNameNr_zoomIn 4180
#define sipName_zoomIn &sipStrings_QtPrintSupport[4180]
#define sipNameNr_Color 4187
#define sipName_Color &sipStrings_QtPrintSupport[4187]
#define sipNameNr_Didot 4193
#define sipName_Didot &sipStrings_QtPrintSupport[4193]
#define sipNameNr_Error 4199
#define sipName_Error &sipStrings_QtPrintSupport[4199]
#define sipNameNr_Lower 4205
#define sipName_Lower &sipStrings_QtPrintSupport[4205]
#define sipNameNr_None_ 4211
#define sipName_None_ &sipStrings_QtPrintSupport[4211]
#define sipNameNr_Point 4217
#define sipName_Point &sipStrings_QtPrintSupport[4217]
#define sipNameNr_Upper 4223
#define sipName_Upper &sipStrings_QtPrintSupport[4223]
#define sipNameNr_abort 4229
#define sipName_abort &sipStrings_QtPrintSupport[4229]
#define sipNameNr_event 4235
#define sipName_event &sipStrings_QtPrintSupport[4235]
#define sipNameNr_exec_ 4241
#define sipName_exec_ &sipStrings_QtPrintSupport[4241]
#define sipNameNr_flags 4247
#define sipName_flags &sipStrings_QtPrintSupport[4247]
#define sipNameNr_print 4253
#define sipName_print &sipStrings_QtPrintSupport[4253]
#define sipNameNr_state 4259
#define sipName_state &sipStrings_QtPrintSupport[4259]
#define sipNameNr_Auto 3268
#define sipName_Auto &sipStrings_QtPrintSupport[3268]
#define sipNameNr_Idle 4265
#define sipName_Idle &sipStrings_QtPrintSupport[4265]
#define sipNameNr_Inch 4270
#define sipName_Inch &sipStrings_QtPrintSupport[4270]
#define sipNameNr_Pica 4275
#define sipName_Pica &sipStrings_QtPrintSupport[4275]
#define sipNameNr_Unit 2139
#define sipName_Unit &sipStrings_QtPrintSupport[2139]
#define sipNameNr_done 4280
#define sipName_done &sipStrings_QtPrintSupport[4280]
#define sipNameNr_exec 4285
#define sipName_exec &sipStrings_QtPrintSupport[4285]
#define sipNameNr_mode 4290
#define sipName_mode &sipStrings_QtPrintSupport[4290]
#define sipNameNr_open 4295
#define sipName_open &sipStrings_QtPrintSupport[4295]
#define sipNameNr_on 78
#define sipName_on &sipStrings_QtPrintSupport[78]

#define sipMalloc                   sipAPI_QtPrintSupport->api_malloc
#define sipFree                     sipAPI_QtPrintSupport->api_free
#define sipBuildResult              sipAPI_QtPrintSupport->api_build_result
#define sipCallMethod               sipAPI_QtPrintSupport->api_call_method
#define sipCallProcedureMethod      sipAPI_QtPrintSupport->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtPrintSupport->api_call_error_handler
#define sipParseResultEx            sipAPI_QtPrintSupport->api_parse_result_ex
#define sipParseResult              sipAPI_QtPrintSupport->api_parse_result
#define sipParseArgs                sipAPI_QtPrintSupport->api_parse_args
#define sipParseKwdArgs             sipAPI_QtPrintSupport->api_parse_kwd_args
#define sipParsePair                sipAPI_QtPrintSupport->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtPrintSupport->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtPrintSupport->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtPrintSupport->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtPrintSupport->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtPrintSupport->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtPrintSupport->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtPrintSupport->api_add_exception
#define sipNoFunction               sipAPI_QtPrintSupport->api_no_function
#define sipNoMethod                 sipAPI_QtPrintSupport->api_no_method
#define sipAbstractMethod           sipAPI_QtPrintSupport->api_abstract_method
#define sipBadClass                 sipAPI_QtPrintSupport->api_bad_class
#define sipBadCatcherResult         sipAPI_QtPrintSupport->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtPrintSupport->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtPrintSupport->api_bad_operator_arg
#define sipTrace                    sipAPI_QtPrintSupport->api_trace
#define sipTransferBack             sipAPI_QtPrintSupport->api_transfer_back
#define sipTransferTo               sipAPI_QtPrintSupport->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtPrintSupport->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtPrintSupport->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtPrintSupport->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtPrintSupport->api_voidptr_type
#define sipGetPyObject              sipAPI_QtPrintSupport->api_get_pyobject
#define sipGetAddress               sipAPI_QtPrintSupport->api_get_address
#define sipGetMixinAddress          sipAPI_QtPrintSupport->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtPrintSupport->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtPrintSupport->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtPrintSupport->api_call_hook
#define sipEndThread                sipAPI_QtPrintSupport->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtPrintSupport->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtPrintSupport->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtPrintSupport->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtPrintSupport->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtPrintSupport->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtPrintSupport->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtPrintSupport->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtPrintSupport->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtPrintSupport->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtPrintSupport->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtPrintSupport->api_convert_to_bool
#define sipReleaseType              sipAPI_QtPrintSupport->api_release_type
#define sipConvertFromType          sipAPI_QtPrintSupport->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtPrintSupport->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtPrintSupport->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtPrintSupport->api_convert_from_enum
#define sipGetState                 sipAPI_QtPrintSupport->api_get_state
#define sipExportSymbol             sipAPI_QtPrintSupport->api_export_symbol
#define sipImportSymbol             sipAPI_QtPrintSupport->api_import_symbol
#define sipFindType                 sipAPI_QtPrintSupport->api_find_type
#define sipBytes_AsChar             sipAPI_QtPrintSupport->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtPrintSupport->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtPrintSupport->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtPrintSupport->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtPrintSupport->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtPrintSupport->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtPrintSupport->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtPrintSupport->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtPrintSupport->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtPrintSupport->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtPrintSupport->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtPrintSupport->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtPrintSupport->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtPrintSupport->api_get_reference
#define sipKeepReference            sipAPI_QtPrintSupport->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtPrintSupport->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtPrintSupport->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtPrintSupport->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtPrintSupport->api_type_scope
#define sipResolveTypedef           sipAPI_QtPrintSupport->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtPrintSupport->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtPrintSupport->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtPrintSupport->api_init_mixin
#define sipExportModule             sipAPI_QtPrintSupport->api_export_module
#define sipInitModule               sipAPI_QtPrintSupport->api_init_module
#define sipGetInterpreter           sipAPI_QtPrintSupport->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtPrintSupport->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtPrintSupport->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtPrintSupport->api_py_type_dict
#define sipPyTypeName               sipAPI_QtPrintSupport->api_py_type_name
#define sipGetCFunction             sipAPI_QtPrintSupport->api_get_c_function
#define sipGetMethod                sipAPI_QtPrintSupport->api_get_method
#define sipFromMethod               sipAPI_QtPrintSupport->api_from_method
#define sipGetDate                  sipAPI_QtPrintSupport->api_get_date
#define sipFromDate                 sipAPI_QtPrintSupport->api_from_date
#define sipGetDateTime              sipAPI_QtPrintSupport->api_get_datetime
#define sipFromDateTime             sipAPI_QtPrintSupport->api_from_datetime
#define sipGetTime                  sipAPI_QtPrintSupport->api_get_time
#define sipFromTime                 sipAPI_QtPrintSupport->api_from_time
#define sipIsUserType               sipAPI_QtPrintSupport->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtPrintSupport->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtPrintSupport->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtPrintSupport->api_unicode_write
#define sipUnicodeData              sipAPI_QtPrintSupport->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtPrintSupport->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtPrintSupport->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtPrintSupport->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtPrintSupport->api_is_derived_class
#define sipGetUserObject            sipAPI_QtPrintSupport->api_get_user_object
#define sipSetUserObject            sipAPI_QtPrintSupport->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtPrintSupport->api_register_event_handler
#define sipConvertToArray           sipAPI_QtPrintSupport->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtPrintSupport->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtPrintSupport->api_enable_gc
#define sipPrintObject              sipAPI_QtPrintSupport->api_print_object
#define sipLong_AsChar              sipAPI_QtPrintSupport->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtPrintSupport->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtPrintSupport->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtPrintSupport->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtPrintSupport->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtPrintSupport->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtPrintSupport->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtPrintSupport->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtPrintSupport->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtPrintSupport->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtPrintSupport->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtPrintSupport->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtPrintSupport->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtPrintSupport->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtPrintSupport->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtPrintSupport->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtPrintSupport->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtPrintSupport->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtPrintSupport->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtPrintSupport->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtPrintSupport->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtPrintSupport->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtPrintSupport->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtPrintSupport->api_connect_rx
#define sipConvertRx                sipAPI_QtPrintSupport->api_convert_rx
#define sipDisconnectRx             sipAPI_QtPrintSupport->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtPrintSupport->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtPrintSupport->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtPrintSupport->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtPrintSupport->api_same_slot
#define sipSaveSlot                 sipAPI_QtPrintSupport->api_save_slot
#define sipVisitSlot                sipAPI_QtPrintSupport->api_visit_slot
#define sipIsPyMethod               sipAPI_QtPrintSupport->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtPrintSupport[];

#define sipType_QAbstractPrintDialog sipExportedTypes_QtPrintSupport[0]

#define sipType_QAbstractPrintDialog_PrintDialogOption sipExportedTypes_QtPrintSupport[1]

#define sipType_QAbstractPrintDialog_PrintRange sipExportedTypes_QtPrintSupport[3]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QAbstractPrintDialog;

#define sipType_QAbstractPrintDialog_PrintDialogOptions sipExportedTypes_QtPrintSupport[2]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QAbstractPrintDialog_PrintDialogOptions;

#define sipType_QPageSetupDialog sipExportedTypes_QtPrintSupport[10]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QPageSetupDialog;

#define sipType_QPrintDialog sipExportedTypes_QtPrintSupport[11]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QPrintDialog;

#define sipType_QPrintEngine sipExportedTypes_QtPrintSupport[12]

#define sipType_QPrintEngine_PrintEnginePropertyKey sipExportedTypes_QtPrintSupport[13]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QPrintEngine;

#define sipType_QPrinter sipExportedTypes_QtPrintSupport[18]

#define sipType_QPrinter_DuplexMode sipExportedTypes_QtPrintSupport[20]

#define sipType_QPrinter_Unit sipExportedTypes_QtPrintSupport[28]

#define sipType_QPrinter_PrintRange sipExportedTypes_QtPrintSupport[25]

#define sipType_QPrinter_OutputFormat sipExportedTypes_QtPrintSupport[22]

#define sipType_QPrinter_PrinterState sipExportedTypes_QtPrintSupport[27]

#define sipType_QPrinter_PaperSource sipExportedTypes_QtPrintSupport[24]

#define sipType_QPrinter_ColorMode sipExportedTypes_QtPrintSupport[19]

#define sipType_QPrinter_PageOrder sipExportedTypes_QtPrintSupport[23]

#define sipType_QPrinter_Orientation sipExportedTypes_QtPrintSupport[21]

#define sipType_QPrinter_PrinterMode sipExportedTypes_QtPrintSupport[26]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QPrinter;

#define sipType_QPrinterInfo sipExportedTypes_QtPrintSupport[29]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QPrinterInfo;

#define sipType_QPrintPreviewDialog sipExportedTypes_QtPrintSupport[14]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QPrintPreviewDialog;

#define sipType_QPrintPreviewWidget sipExportedTypes_QtPrintSupport[15]

#define sipType_QPrintPreviewWidget_ZoomMode sipExportedTypes_QtPrintSupport[17]

#define sipType_QPrintPreviewWidget_ViewMode sipExportedTypes_QtPrintSupport[16]

extern sipClassTypeDef sipTypeDef_QtPrintSupport_QPrintPreviewWidget;

#define sipType_QList_0100QPageSize sipExportedTypes_QtPrintSupport[4]

extern sipMappedTypeDef sipTypeDef_QtPrintSupport_QList_0100QPageSize;

#define sipType_QList_0100QPrinterInfo sipExportedTypes_QtPrintSupport[9]

extern sipMappedTypeDef sipTypeDef_QtPrintSupport_QList_0100QPrinterInfo;

#define sipType_QList_0600QPair_0100QString_0100QSizeF sipExportedTypes_QtPrintSupport[6]

extern sipMappedTypeDef sipTypeDef_QtPrintSupport_QList_0600QPair_0100QString_0100QSizeF;

#define sipType_QList_0100QPrinter_ColorMode sipExportedTypes_QtPrintSupport[7]

extern sipMappedTypeDef sipTypeDef_QtPrintSupport_QList_0100QPrinter_ColorMode;

#define sipType_QList_0100QPrinter_DuplexMode sipExportedTypes_QtPrintSupport[8]

extern sipMappedTypeDef sipTypeDef_QtPrintSupport_QList_0100QPrinter_DuplexMode;

#define sipType_QList_0100QPagedPaintDevice_PageSize sipExportedTypes_QtPrintSupport[5]

extern sipMappedTypeDef sipTypeDef_QtPrintSupport_QList_0100QPagedPaintDevice_PageSize;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtPrintSupport;
extern sipExportedModuleDef sipModuleAPI_QtPrintSupport;
extern sipTypeDef *sipExportedTypes_QtPrintSupport[];

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtPrintSupport_QtCore[14].it_td

#define sipType_Qt_WindowFlags sipImportedTypes_QtPrintSupport_QtCore[15].it_td

#define sipType_QObject sipImportedTypes_QtPrintSupport_QtCore[5].it_td

#define sipType_QByteArray sipImportedTypes_QtPrintSupport_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtPrintSupport_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtPrintSupport_QtCore[12].it_td

#define sipType_QChildEvent sipImportedTypes_QtPrintSupport_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtPrintSupport_QtCore[4].it_td

#define sipType_QRect sipImportedTypes_QtPrintSupport_QtCore[6].it_td

#define sipType_QRectF sipImportedTypes_QtPrintSupport_QtCore[7].it_td

#define sipType_QSize sipImportedTypes_QtPrintSupport_QtCore[8].it_td

#define sipType_QSizeF sipImportedTypes_QtPrintSupport_QtCore[9].it_td

#define sipType_QVariant sipImportedTypes_QtPrintSupport_QtCore[13].it_td

#define sipType_QStringList sipImportedTypes_QtPrintSupport_QtCore[11].it_td

#define sipType_QList_1800 sipImportedTypes_QtPrintSupport_QtCore[3].it_td

#define sipType_QString sipImportedTypes_QtPrintSupport_QtCore[10].it_td
extern sipImportedTypeDef sipImportedTypes_QtPrintSupport_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtPrintSupport_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtPrintSupport_QtGui[18].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtPrintSupport_QtGui[19].it_td

#define sipType_QMouseEvent sipImportedTypes_QtPrintSupport_QtGui[11].it_td

#define sipType_QWheelEvent sipImportedTypes_QtPrintSupport_QtGui[26].it_td

#define sipType_QTabletEvent sipImportedTypes_QtPrintSupport_QtGui[25].it_td

#define sipType_QKeyEvent sipImportedTypes_QtPrintSupport_QtGui[10].it_td

#define sipType_QFocusEvent sipImportedTypes_QtPrintSupport_QtGui[7].it_td

#define sipType_QPaintEvent sipImportedTypes_QtPrintSupport_QtGui[21].it_td

#define sipType_QMoveEvent sipImportedTypes_QtPrintSupport_QtGui[12].it_td

#define sipType_QResizeEvent sipImportedTypes_QtPrintSupport_QtGui[23].it_td

#define sipType_QCloseEvent sipImportedTypes_QtPrintSupport_QtGui[1].it_td

#define sipType_QShowEvent sipImportedTypes_QtPrintSupport_QtGui[24].it_td

#define sipType_QHideEvent sipImportedTypes_QtPrintSupport_QtGui[8].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtPrintSupport_QtGui[2].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtPrintSupport_QtGui[9].it_td

#define sipType_QDropEvent sipImportedTypes_QtPrintSupport_QtGui[6].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtPrintSupport_QtGui[5].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtPrintSupport_QtGui[3].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtPrintSupport_QtGui[4].it_td

#define sipType_QActionEvent sipImportedTypes_QtPrintSupport_QtGui[0].it_td

#define sipType_QPagedPaintDevice sipImportedTypes_QtPrintSupport_QtGui[14].it_td

#define sipType_QPagedPaintDevice_PdfVersion sipImportedTypes_QtPrintSupport_QtGui[17].it_td

#define sipType_QPagedPaintDevice_PageSize sipImportedTypes_QtPrintSupport_QtGui[16].it_td

#define sipType_QPagedPaintDevice_Margins sipImportedTypes_QtPrintSupport_QtGui[15].it_td

#define sipType_QPageSize sipImportedTypes_QtPrintSupport_QtGui[13].it_td

#define sipType_QPainter sipImportedTypes_QtPrintSupport_QtGui[22].it_td

#define sipType_QPaintEngine sipImportedTypes_QtPrintSupport_QtGui[20].it_td
extern sipImportedTypeDef sipImportedTypes_QtPrintSupport_QtGui[];

#define sipType_QWidget sipImportedTypes_QtPrintSupport_QtWidgets[2].it_td

#define sipType_QDialog sipImportedTypes_QtPrintSupport_QtWidgets[0].it_td

#define sipType_QList_0101QWidget sipImportedTypes_QtPrintSupport_QtWidgets[1].it_td
extern sipImportedTypeDef sipImportedTypes_QtPrintSupport_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtPrintSupport_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtPrintSupport_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtPrintSupport_qt_metacast;
#line 160 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPrintSupport/qabstractprintdialog.sip"
// Imports from QtCore.
typedef sipErrorState (*pyqt5_qtprintsupport_get_connection_parts_t)(PyObject *, QObject *, const char *, bool, QObject **, QByteArray &);
extern pyqt5_qtprintsupport_get_connection_parts_t pyqt5_qtprintsupport_get_connection_parts;
#line 1080 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPrintSupport/sipAPIQtPrintSupport.h"

#endif
