/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerainfo.sip"
#include <qcamerainfo.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qpymultimedia_qlist.sip"
#include <qvideoframe.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qvideoframe.sip"
#include <qvideoframe.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameraviewfindersettings.sip"
#include <qcameraviewfindersettings.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 167 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qabstractvideosurface.sip"
#include <qabstractvideosurface.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameraimageprocessing.sip"
#include <qcameraimageprocessing.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerafocus.sip"
#include <qcamerafocus.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameraexposure.sip"
#include <qcameraexposure.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmultimedia.sip"
#include <qmultimedia.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaservice.sip"
#include <qmediaservice.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 106 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 112 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 115 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 118 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 121 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 124 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 127 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 130 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 133 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 136 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 139 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCamera.cpp"


class sipQCamera : public ::QCamera
{
public:
    sipQCamera(::QObject*);
    sipQCamera(const ::QByteArray&, ::QObject*);
    sipQCamera(const ::QCameraInfo&, ::QObject*);
    sipQCamera(::QCamera::Position, ::QObject*);
    virtual ~sipQCamera();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool isAvailable() const SIP_OVERRIDE;
    ::QMultimedia::AvailabilityStatus availability() const SIP_OVERRIDE;
    ::QMediaService* service() const SIP_OVERRIDE;
    bool bind(::QObject*) SIP_OVERRIDE;
    void unbind(::QObject*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQCamera(const sipQCamera &);
    sipQCamera &operator = (const sipQCamera &);

    char sipPyMethods[12];
};

sipQCamera::sipQCamera(::QObject*a0): ::QCamera(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCamera::sipQCamera(const ::QByteArray& a0, ::QObject*a1): ::QCamera(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCamera::sipQCamera(const ::QCameraInfo& a0, ::QObject*a1): ::QCamera(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCamera::sipQCamera(::QCamera::Position a0, ::QObject*a1): ::QCamera(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQCamera::~sipQCamera()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQCamera::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QCamera);

    return ::QCamera::metaObject();
}

int sipQCamera::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QCamera::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QCamera, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQCamera::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QCamera, _clname, &sipCpp) ? sipCpp : ::QCamera::qt_metacast(_clname));
}

void sipQCamera::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QCamera::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCamera::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QCamera::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCamera::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QCamera::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCamera::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QCamera::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCamera::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QCamera::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCamera::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QCamera::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQCamera::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QCamera::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQCamera::isAvailable() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isAvailable);

    if (!sipMeth)
        return ::QCamera::isAvailable();

    extern bool sipVH_QtMultimedia_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_16(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QMultimedia::AvailabilityStatus sipQCamera::availability() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_availability);

    if (!sipMeth)
        return ::QCamera::availability();

    extern ::QMultimedia::AvailabilityStatus sipVH_QtMultimedia_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_17(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QMediaService* sipQCamera::service() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_service);

    if (!sipMeth)
        return ::QCamera::service();

    extern ::QMediaService* sipVH_QtMultimedia_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_18(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQCamera::bind(::QObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_bind);

    if (!sipMeth)
        return ::QCamera::bind(a0);

    extern bool sipVH_QtMultimedia_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*);

    return sipVH_QtMultimedia_19(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQCamera::unbind(::QObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_unbind);

    if (!sipMeth)
    {
        ::QCamera::unbind(a0);
        return;
    }

    extern void sipVH_QtMultimedia_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*);

    sipVH_QtMultimedia_20(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QCamera_availableDevices, "availableDevices() -> list[QByteArray]");

extern "C" {static PyObject *meth_QCamera_availableDevices(PyObject *, PyObject *);}
static PyObject *meth_QCamera_availableDevices(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QByteArray>*sipRes;

            sipRes = new QList< ::QByteArray>(::QCamera::availableDevices());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_availableDevices, doc_QCamera_availableDevices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_deviceDescription, "deviceDescription(device: Union[QByteArray, bytes, bytearray]) -> str");

extern "C" {static PyObject *meth_QCamera_deviceDescription(PyObject *, PyObject *);}
static PyObject *meth_QCamera_deviceDescription(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QByteArray* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QByteArray, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QCamera::deviceDescription(*a0));
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_deviceDescription, doc_QCamera_deviceDescription);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_availability, "availability(self) -> QMultimedia.AvailabilityStatus");

extern "C" {static PyObject *meth_QCamera_availability(PyObject *, PyObject *);}
static PyObject *meth_QCamera_availability(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QMultimedia::AvailabilityStatus sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QCamera::availability() : sipCpp->availability());

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMultimedia_AvailabilityStatus);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_availability, doc_QCamera_availability);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_state, "state(self) -> QCamera.State");

extern "C" {static PyObject *meth_QCamera_state(PyObject *, PyObject *);}
static PyObject *meth_QCamera_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCamera::State sipRes;

            sipRes = sipCpp->state();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCamera_State);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_state, doc_QCamera_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_status, "status(self) -> QCamera.Status");

extern "C" {static PyObject *meth_QCamera_status(PyObject *, PyObject *);}
static PyObject *meth_QCamera_status(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCamera::Status sipRes;

            sipRes = sipCpp->status();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCamera_Status);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_status, doc_QCamera_status);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_captureMode, "captureMode(self) -> QCamera.CaptureModes");

extern "C" {static PyObject *meth_QCamera_captureMode(PyObject *, PyObject *);}
static PyObject *meth_QCamera_captureMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCamera::CaptureModes*sipRes;

            sipRes = new ::QCamera::CaptureModes(sipCpp->captureMode());

            return sipConvertFromNewType(sipRes, sipType_QCamera_CaptureModes, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_captureMode, doc_QCamera_captureMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_isCaptureModeSupported, "isCaptureModeSupported(self, mode: Union[QCamera.CaptureModes, QCamera.CaptureMode]) -> bool");

extern "C" {static PyObject *meth_QCamera_isCaptureModeSupported(PyObject *, PyObject *);}
static PyObject *meth_QCamera_isCaptureModeSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera::CaptureModes* a0;
        int a0State = 0;
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCamera_CaptureModes, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->isCaptureModeSupported(*a0);
            sipReleaseType(a0, sipType_QCamera_CaptureModes, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_isCaptureModeSupported, doc_QCamera_isCaptureModeSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_exposure, "exposure(self) -> Optional[QCameraExposure]");

extern "C" {static PyObject *meth_QCamera_exposure(PyObject *, PyObject *);}
static PyObject *meth_QCamera_exposure(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCameraExposure*sipRes;

            sipRes = sipCpp->exposure();

            return sipConvertFromType(sipRes, sipType_QCameraExposure, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_exposure, doc_QCamera_exposure);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_focus, "focus(self) -> Optional[QCameraFocus]");

extern "C" {static PyObject *meth_QCamera_focus(PyObject *, PyObject *);}
static PyObject *meth_QCamera_focus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCameraFocus*sipRes;

            sipRes = sipCpp->focus();

            return sipConvertFromType(sipRes, sipType_QCameraFocus, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_focus, doc_QCamera_focus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_imageProcessing, "imageProcessing(self) -> Optional[QCameraImageProcessing]");

extern "C" {static PyObject *meth_QCamera_imageProcessing(PyObject *, PyObject *);}
static PyObject *meth_QCamera_imageProcessing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCameraImageProcessing*sipRes;

            sipRes = sipCpp->imageProcessing();

            return sipConvertFromType(sipRes, sipType_QCameraImageProcessing, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_imageProcessing, doc_QCamera_imageProcessing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setViewfinder, "setViewfinder(self, viewfinder: Optional[QVideoWidget])\n"
"setViewfinder(self, viewfinder: Optional[QGraphicsVideoItem])\n"
"setViewfinder(self, surface: Optional[QAbstractVideoSurface])");

extern "C" {static PyObject *meth_QCamera_setViewfinder(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setViewfinder(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVideoWidget* a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QCamera, &sipCpp, sipType_QVideoWidget, &a0))
        {
            sipCpp->setViewfinder(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QGraphicsVideoItem* a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QCamera, &sipCpp, sipType_QGraphicsVideoItem, &a0))
        {
            sipCpp->setViewfinder(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QAbstractVideoSurface* a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QCamera, &sipCpp, sipType_QAbstractVideoSurface, &a0))
        {
            sipCpp->setViewfinder(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setViewfinder, doc_QCamera_setViewfinder);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_error, "error(self) -> QCamera.Error");

extern "C" {static PyObject *meth_QCamera_error(PyObject *, PyObject *);}
static PyObject *meth_QCamera_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCamera::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCamera_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_error, doc_QCamera_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QCamera_errorString(PyObject *, PyObject *);}
static PyObject *meth_QCamera_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_errorString, doc_QCamera_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_supportedLocks, "supportedLocks(self) -> QCamera.LockTypes");

extern "C" {static PyObject *meth_QCamera_supportedLocks(PyObject *, PyObject *);}
static PyObject *meth_QCamera_supportedLocks(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCamera::LockTypes*sipRes;

            sipRes = new ::QCamera::LockTypes(sipCpp->supportedLocks());

            return sipConvertFromNewType(sipRes, sipType_QCamera_LockTypes, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_supportedLocks, doc_QCamera_supportedLocks);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_requestedLocks, "requestedLocks(self) -> QCamera.LockTypes");

extern "C" {static PyObject *meth_QCamera_requestedLocks(PyObject *, PyObject *);}
static PyObject *meth_QCamera_requestedLocks(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCamera::LockTypes*sipRes;

            sipRes = new ::QCamera::LockTypes(sipCpp->requestedLocks());

            return sipConvertFromNewType(sipRes, sipType_QCamera_LockTypes, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_requestedLocks, doc_QCamera_requestedLocks);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_lockStatus, "lockStatus(self) -> QCamera.LockStatus\n"
"lockStatus(self, lock: QCamera.LockType) -> QCamera.LockStatus");

extern "C" {static PyObject *meth_QCamera_lockStatus(PyObject *, PyObject *);}
static PyObject *meth_QCamera_lockStatus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCamera::LockStatus sipRes;

            sipRes = sipCpp->lockStatus();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCamera_LockStatus);
        }
    }

    {
        ::QCamera::LockType a0;
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCamera_LockType, &a0))
        {
            ::QCamera::LockStatus sipRes;

            sipRes = sipCpp->lockStatus(a0);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCamera_LockStatus);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_lockStatus, doc_QCamera_lockStatus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setCaptureMode, "setCaptureMode(self, mode: Union[QCamera.CaptureModes, QCamera.CaptureMode])");

extern "C" {static PyObject *meth_QCamera_setCaptureMode(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setCaptureMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera::CaptureModes* a0;
        int a0State = 0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCamera_CaptureModes, &a0, &a0State))
        {
            sipCpp->setCaptureMode(*a0);
            sipReleaseType(a0, sipType_QCamera_CaptureModes, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setCaptureMode, doc_QCamera_setCaptureMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_load, "load(self)");

extern "C" {static PyObject *meth_QCamera_load(PyObject *, PyObject *);}
static PyObject *meth_QCamera_load(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            sipCpp->load();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_load, doc_QCamera_load);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_unload, "unload(self)");

extern "C" {static PyObject *meth_QCamera_unload(PyObject *, PyObject *);}
static PyObject *meth_QCamera_unload(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            sipCpp->unload();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_unload, doc_QCamera_unload);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_start, "start(self)");

extern "C" {static PyObject *meth_QCamera_start(PyObject *, PyObject *);}
static PyObject *meth_QCamera_start(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            sipCpp->start();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_start, doc_QCamera_start);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_stop, "stop(self)");

extern "C" {static PyObject *meth_QCamera_stop(PyObject *, PyObject *);}
static PyObject *meth_QCamera_stop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            sipCpp->stop();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_stop, doc_QCamera_stop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_searchAndLock, "searchAndLock(self)\n"
"searchAndLock(self, locks: Union[QCamera.LockTypes, QCamera.LockType])");

extern "C" {static PyObject *meth_QCamera_searchAndLock(PyObject *, PyObject *);}
static PyObject *meth_QCamera_searchAndLock(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            sipCpp->searchAndLock();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QCamera::LockTypes* a0;
        int a0State = 0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCamera_LockTypes, &a0, &a0State))
        {
            sipCpp->searchAndLock(*a0);
            sipReleaseType(a0, sipType_QCamera_LockTypes, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_searchAndLock, doc_QCamera_searchAndLock);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_unlock, "unlock(self)\n"
"unlock(self, locks: Union[QCamera.LockTypes, QCamera.LockType])");

extern "C" {static PyObject *meth_QCamera_unlock(PyObject *, PyObject *);}
static PyObject *meth_QCamera_unlock(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            sipCpp->unlock();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QCamera::LockTypes* a0;
        int a0State = 0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCamera_LockTypes, &a0, &a0State))
        {
            sipCpp->unlock(*a0);
            sipReleaseType(a0, sipType_QCamera_LockTypes, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_unlock, doc_QCamera_unlock);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_viewfinderSettings, "viewfinderSettings(self) -> QCameraViewfinderSettings");

extern "C" {static PyObject *meth_QCamera_viewfinderSettings(PyObject *, PyObject *);}
static PyObject *meth_QCamera_viewfinderSettings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCamera, &sipCpp))
        {
            ::QCameraViewfinderSettings*sipRes;

            sipRes = new ::QCameraViewfinderSettings(sipCpp->viewfinderSettings());

            return sipConvertFromNewType(sipRes, sipType_QCameraViewfinderSettings, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_viewfinderSettings, doc_QCamera_viewfinderSettings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_setViewfinderSettings, "setViewfinderSettings(self, settings: QCameraViewfinderSettings)");

extern "C" {static PyObject *meth_QCamera_setViewfinderSettings(PyObject *, PyObject *);}
static PyObject *meth_QCamera_setViewfinderSettings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraViewfinderSettings* a0;
        ::QCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCameraViewfinderSettings, &a0))
        {
            sipCpp->setViewfinderSettings(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_setViewfinderSettings, doc_QCamera_setViewfinderSettings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_supportedViewfinderSettings, "supportedViewfinderSettings(self, settings: QCameraViewfinderSettings = QCameraViewfinderSettings()) -> list[QCameraViewfinderSettings]");

extern "C" {static PyObject *meth_QCamera_supportedViewfinderSettings(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCamera_supportedViewfinderSettings(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraViewfinderSettings& a0def = QCameraViewfinderSettings();
        const ::QCameraViewfinderSettings* a0 = &a0def;
        const ::QCamera *sipCpp;

        static const char *sipKwdList[] = {
            sipName_settings,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCameraViewfinderSettings, &a0))
        {
            QList< ::QCameraViewfinderSettings>*sipRes;

            sipRes = new QList< ::QCameraViewfinderSettings>(sipCpp->supportedViewfinderSettings(*a0));

            return sipConvertFromNewType(sipRes, sipType_QList_0100QCameraViewfinderSettings, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_supportedViewfinderSettings, doc_QCamera_supportedViewfinderSettings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_supportedViewfinderResolutions, "supportedViewfinderResolutions(self, settings: QCameraViewfinderSettings = QCameraViewfinderSettings()) -> list[QSize]");

extern "C" {static PyObject *meth_QCamera_supportedViewfinderResolutions(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCamera_supportedViewfinderResolutions(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraViewfinderSettings& a0def = QCameraViewfinderSettings();
        const ::QCameraViewfinderSettings* a0 = &a0def;
        const ::QCamera *sipCpp;

        static const char *sipKwdList[] = {
            sipName_settings,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCameraViewfinderSettings, &a0))
        {
            QList< ::QSize>*sipRes;

            sipRes = new QList< ::QSize>(sipCpp->supportedViewfinderResolutions(*a0));

            return sipConvertFromNewType(sipRes, sipType_QList_0100QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_supportedViewfinderResolutions, doc_QCamera_supportedViewfinderResolutions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_supportedViewfinderFrameRateRanges, "supportedViewfinderFrameRateRanges(self, settings: QCameraViewfinderSettings = QCameraViewfinderSettings()) -> list[QCamera.FrameRateRange]");

extern "C" {static PyObject *meth_QCamera_supportedViewfinderFrameRateRanges(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCamera_supportedViewfinderFrameRateRanges(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraViewfinderSettings& a0def = QCameraViewfinderSettings();
        const ::QCameraViewfinderSettings* a0 = &a0def;
        const ::QCamera *sipCpp;

        static const char *sipKwdList[] = {
            sipName_settings,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCameraViewfinderSettings, &a0))
        {
            QList< ::QCamera::FrameRateRange>*sipRes;

            sipRes = new QList< ::QCamera::FrameRateRange>(sipCpp->supportedViewfinderFrameRateRanges(*a0));

            return sipConvertFromNewType(sipRes, sipType_QList_0100QCamera_FrameRateRange, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_supportedViewfinderFrameRateRanges, doc_QCamera_supportedViewfinderFrameRateRanges);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCamera_supportedViewfinderPixelFormats, "supportedViewfinderPixelFormats(self, settings: QCameraViewfinderSettings = QCameraViewfinderSettings()) -> list[QVideoFrame.PixelFormat]");

extern "C" {static PyObject *meth_QCamera_supportedViewfinderPixelFormats(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QCamera_supportedViewfinderPixelFormats(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraViewfinderSettings& a0def = QCameraViewfinderSettings();
        const ::QCameraViewfinderSettings* a0 = &a0def;
        const ::QCamera *sipCpp;

        static const char *sipKwdList[] = {
            sipName_settings,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QCamera, &sipCpp, sipType_QCameraViewfinderSettings, &a0))
        {
            ::QList< ::QVideoFrame::PixelFormat>*sipRes;

            sipRes = new ::QList< ::QVideoFrame::PixelFormat>(sipCpp->supportedViewfinderPixelFormats(*a0));

            return sipConvertFromNewType(sipRes, sipType_QList_0100QVideoFrame_PixelFormat, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCamera, sipName_supportedViewfinderPixelFormats, doc_QCamera_supportedViewfinderPixelFormats);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QCamera(void *, const sipTypeDef *);}
static void *cast_QCamera(void *sipCppV, const sipTypeDef *targetType)
{
    ::QCamera *sipCpp = reinterpret_cast< ::QCamera *>(sipCppV);

    if (targetType == sipType_QCamera)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaObject)->ctd_cast(static_cast< ::QMediaObject *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QCamera(void *, int);}
static void release_QCamera(void *sipCppV, int)
{
    ::QCamera *sipCpp = reinterpret_cast< ::QCamera *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QCamera(Py_ssize_t);}
static void *array_QCamera(Py_ssize_t sipNrElem)
{
    return new ::QCamera[sipNrElem];
}


extern "C" {static void array_delete_QCamera(void *);}
static void array_delete_QCamera(void *sipCpp)
{
    delete[] reinterpret_cast< ::QCamera *>(sipCpp);
}


extern "C" {static void dealloc_QCamera(sipSimpleWrapper *);}
static void dealloc_QCamera(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQCamera *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QCamera(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QCamera(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QCamera(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQCamera *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQCamera(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QByteArray* a0;
        int a0State = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QByteArray, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQCamera(*a0, a1);
            sipReleaseType(const_cast< ::QByteArray *>(a0), sipType_QByteArray, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QCameraInfo* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9|JH", sipType_QCameraInfo, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQCamera(*a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QCamera::Position a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "E|JH", sipType_QCamera_Position, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQCamera(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QCamera[] = {{108, 255, 1}};


static PyMethodDef methods_QCamera[] = {
    {sipName_availability, meth_QCamera_availability, METH_VARARGS, doc_QCamera_availability},
    {sipName_availableDevices, meth_QCamera_availableDevices, METH_VARARGS, doc_QCamera_availableDevices},
    {sipName_captureMode, meth_QCamera_captureMode, METH_VARARGS, doc_QCamera_captureMode},
    {sipName_deviceDescription, meth_QCamera_deviceDescription, METH_VARARGS, doc_QCamera_deviceDescription},
    {sipName_error, meth_QCamera_error, METH_VARARGS, doc_QCamera_error},
    {sipName_errorString, meth_QCamera_errorString, METH_VARARGS, doc_QCamera_errorString},
    {sipName_exposure, meth_QCamera_exposure, METH_VARARGS, doc_QCamera_exposure},
    {sipName_focus, meth_QCamera_focus, METH_VARARGS, doc_QCamera_focus},
    {sipName_imageProcessing, meth_QCamera_imageProcessing, METH_VARARGS, doc_QCamera_imageProcessing},
    {sipName_isCaptureModeSupported, meth_QCamera_isCaptureModeSupported, METH_VARARGS, doc_QCamera_isCaptureModeSupported},
    {sipName_load, meth_QCamera_load, METH_VARARGS, doc_QCamera_load},
    {sipName_lockStatus, meth_QCamera_lockStatus, METH_VARARGS, doc_QCamera_lockStatus},
    {sipName_requestedLocks, meth_QCamera_requestedLocks, METH_VARARGS, doc_QCamera_requestedLocks},
    {sipName_searchAndLock, meth_QCamera_searchAndLock, METH_VARARGS, doc_QCamera_searchAndLock},
    {sipName_setCaptureMode, meth_QCamera_setCaptureMode, METH_VARARGS, doc_QCamera_setCaptureMode},
    {sipName_setViewfinder, meth_QCamera_setViewfinder, METH_VARARGS, doc_QCamera_setViewfinder},
    {sipName_setViewfinderSettings, meth_QCamera_setViewfinderSettings, METH_VARARGS, doc_QCamera_setViewfinderSettings},
    {sipName_start, meth_QCamera_start, METH_VARARGS, doc_QCamera_start},
    {sipName_state, meth_QCamera_state, METH_VARARGS, doc_QCamera_state},
    {sipName_status, meth_QCamera_status, METH_VARARGS, doc_QCamera_status},
    {sipName_stop, meth_QCamera_stop, METH_VARARGS, doc_QCamera_stop},
    {sipName_supportedLocks, meth_QCamera_supportedLocks, METH_VARARGS, doc_QCamera_supportedLocks},
    {sipName_supportedViewfinderFrameRateRanges, SIP_MLMETH_CAST(meth_QCamera_supportedViewfinderFrameRateRanges), METH_VARARGS|METH_KEYWORDS, doc_QCamera_supportedViewfinderFrameRateRanges},
    {sipName_supportedViewfinderPixelFormats, SIP_MLMETH_CAST(meth_QCamera_supportedViewfinderPixelFormats), METH_VARARGS|METH_KEYWORDS, doc_QCamera_supportedViewfinderPixelFormats},
    {sipName_supportedViewfinderResolutions, SIP_MLMETH_CAST(meth_QCamera_supportedViewfinderResolutions), METH_VARARGS|METH_KEYWORDS, doc_QCamera_supportedViewfinderResolutions},
    {sipName_supportedViewfinderSettings, SIP_MLMETH_CAST(meth_QCamera_supportedViewfinderSettings), METH_VARARGS|METH_KEYWORDS, doc_QCamera_supportedViewfinderSettings},
    {sipName_unload, meth_QCamera_unload, METH_VARARGS, doc_QCamera_unload},
    {sipName_unlock, meth_QCamera_unlock, METH_VARARGS, doc_QCamera_unlock},
    {sipName_viewfinderSettings, meth_QCamera_viewfinderSettings, METH_VARARGS, doc_QCamera_viewfinderSettings}
};

static sipEnumMemberDef enummembers_QCamera[] = {
    {sipName_ActiveState, static_cast<int>(::QCamera::ActiveState), 40},
    {sipName_ActiveStatus, static_cast<int>(::QCamera::ActiveStatus), 41},
    {sipName_BackFace, static_cast<int>(::QCamera::BackFace), 39},
    {sipName_CameraError, static_cast<int>(::QCamera::CameraError), 33},
    {sipName_CaptureStillImage, static_cast<int>(::QCamera::CaptureStillImage), 31},
    {sipName_CaptureVideo, static_cast<int>(::QCamera::CaptureVideo), 31},
    {sipName_CaptureViewfinder, static_cast<int>(::QCamera::CaptureViewfinder), 31},
    {sipName_FrontFace, static_cast<int>(::QCamera::FrontFace), 39},
    {sipName_InvalidRequestError, static_cast<int>(::QCamera::InvalidRequestError), 33},
    {sipName_LoadedState, static_cast<int>(::QCamera::LoadedState), 40},
    {sipName_LoadedStatus, static_cast<int>(::QCamera::LoadedStatus), 41},
    {sipName_LoadingStatus, static_cast<int>(::QCamera::LoadingStatus), 41},
    {sipName_LockAcquired, static_cast<int>(::QCamera::LockAcquired), 35},
    {sipName_LockExposure, static_cast<int>(::QCamera::LockExposure), 37},
    {sipName_LockFailed, static_cast<int>(::QCamera::LockFailed), 35},
    {sipName_LockFocus, static_cast<int>(::QCamera::LockFocus), 37},
    {sipName_LockLost, static_cast<int>(::QCamera::LockLost), 35},
    {sipName_LockTemporaryLost, static_cast<int>(::QCamera::LockTemporaryLost), 35},
    {sipName_LockWhiteBalance, static_cast<int>(::QCamera::LockWhiteBalance), 37},
    {sipName_Locked, static_cast<int>(::QCamera::Locked), 36},
    {sipName_NoError, static_cast<int>(::QCamera::NoError), 33},
    {sipName_NoLock, static_cast<int>(::QCamera::NoLock), 37},
    {sipName_NotSupportedFeatureError, static_cast<int>(::QCamera::NotSupportedFeatureError), 33},
    {sipName_Searching, static_cast<int>(::QCamera::Searching), 36},
    {sipName_ServiceMissingError, static_cast<int>(::QCamera::ServiceMissingError), 33},
    {sipName_StandbyStatus, static_cast<int>(::QCamera::StandbyStatus), 41},
    {sipName_StartingStatus, static_cast<int>(::QCamera::StartingStatus), 41},
    {sipName_StoppingStatus, static_cast<int>(::QCamera::StoppingStatus), 41},
    {sipName_UnavailableStatus, static_cast<int>(::QCamera::UnavailableStatus), 41},
    {sipName_UnloadedState, static_cast<int>(::QCamera::UnloadedState), 40},
    {sipName_UnloadedStatus, static_cast<int>(::QCamera::UnloadedStatus), 41},
    {sipName_UnloadingStatus, static_cast<int>(::QCamera::UnloadingStatus), 41},
    {sipName_Unlocked, static_cast<int>(::QCamera::Unlocked), 36},
    {sipName_UnspecifiedPosition, static_cast<int>(::QCamera::UnspecifiedPosition), 39},
    {sipName_UserRequest, static_cast<int>(::QCamera::UserRequest), 35},
};

PyDoc_STRVAR(doc_QCamera, "\1QCamera(parent: Optional[QObject] = None)\n"
"QCamera(device: Union[QByteArray, bytes, bytearray], parent: Optional[QObject] = None)\n"
"QCamera(cameraInfo: QCameraInfo, parent: Optional[QObject] = None)\n"
"QCamera(position: QCamera.Position, parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QCamera[] = {
    {"errorOccurred(QCamera::Error)", "\1errorOccurred(self, a0: QCamera.Error)", SIP_NULLPTR, SIP_NULLPTR},
    {"lockStatusChanged(QCamera::LockStatus,QCamera::LockChangeReason)", "\1lockStatusChanged(self, a0: QCamera.LockStatus, a1: QCamera.LockChangeReason)", SIP_NULLPTR, SIP_NULLPTR},
    {"lockStatusChanged(QCamera::LockType,QCamera::LockStatus,QCamera::LockChangeReason)", "\1lockStatusChanged(self, a0: QCamera.LockType, a1: QCamera.LockStatus, a2: QCamera.LockChangeReason)", SIP_NULLPTR, SIP_NULLPTR},
    {"lockFailed()", "\1lockFailed(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"locked()", "\1locked(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"statusChanged(QCamera::Status)", "\1statusChanged(self, a0: QCamera.Status)", SIP_NULLPTR, SIP_NULLPTR},
    {"captureModeChanged(QCamera::CaptureModes)", "\1captureModeChanged(self, a0: Union[QCamera.CaptureModes, QCamera.CaptureMode])", SIP_NULLPTR, SIP_NULLPTR},
    {"stateChanged(QCamera::State)", "\1stateChanged(self, a0: QCamera.State)", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QCamera::Error)", "\1error(self, a0: QCamera.Error)", &methods_QCamera[4], SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QCamera = {
    &::QCamera::staticMetaObject,
    0,
    signals_QCamera,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QCamera = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCamera,
        SIP_NULLPTR,
        &plugin_QCamera,
    },
    {
        sipNameNr_QCamera,
        {0, 0, 1},
        29, methods_QCamera,
        35, enummembers_QCamera,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QCamera,
    -1,
    -1,
    supers_QCamera,
    SIP_NULLPTR,
    init_type_QCamera,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QCamera,
    SIP_NULLPTR,
    array_QCamera,
    SIP_NULLPTR,
    release_QCamera,
    cast_QCamera,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QCamera,
    sizeof (::QCamera),
};
