/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDesigner.h"

#line 25 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/qpydesignerpropertysheetextension.sip"
#include <qpydesignerpropertysheetextension.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQPyDesignerPropertySheetExtension.cpp"


class sipQPyDesignerPropertySheetExtension : public ::QPyDesignerPropertySheetExtension
{
public:
    sipQPyDesignerPropertySheetExtension(::QObject*);
    virtual ~sipQPyDesignerPropertySheetExtension();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    int count() const SIP_OVERRIDE;
    int indexOf(const ::QString&) const SIP_OVERRIDE;
    ::QString propertyName(int) const SIP_OVERRIDE;
    ::QString propertyGroup(int) const SIP_OVERRIDE;
    void setPropertyGroup(int, const ::QString&) SIP_OVERRIDE;
    bool hasReset(int) const SIP_OVERRIDE;
    bool reset(int) SIP_OVERRIDE;
    bool isVisible(int) const SIP_OVERRIDE;
    void setVisible(int, bool) SIP_OVERRIDE;
    bool isAttribute(int) const SIP_OVERRIDE;
    void setAttribute(int, bool) SIP_OVERRIDE;
    ::QVariant property(int) const SIP_OVERRIDE;
    void setProperty(int, const ::QVariant&) SIP_OVERRIDE;
    bool isChanged(int) const SIP_OVERRIDE;
    void setChanged(int, bool) SIP_OVERRIDE;
    bool isEnabled(int) const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPyDesignerPropertySheetExtension(const sipQPyDesignerPropertySheetExtension &);
    sipQPyDesignerPropertySheetExtension &operator = (const sipQPyDesignerPropertySheetExtension &);

    char sipPyMethods[23];
};

sipQPyDesignerPropertySheetExtension::sipQPyDesignerPropertySheetExtension(::QObject*a0): ::QPyDesignerPropertySheetExtension(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQPyDesignerPropertySheetExtension::~sipQPyDesignerPropertySheetExtension()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQPyDesignerPropertySheetExtension::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDesigner_qt_metaobject(sipPySelf, sipType_QPyDesignerPropertySheetExtension);

    return ::QPyDesignerPropertySheetExtension::metaObject();
}

int sipQPyDesignerPropertySheetExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QPyDesignerPropertySheetExtension::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDesigner_qt_metacall(sipPySelf, sipType_QPyDesignerPropertySheetExtension, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQPyDesignerPropertySheetExtension::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDesigner_qt_metacast(sipPySelf, sipType_QPyDesignerPropertySheetExtension, _clname, &sipCpp) ? sipCpp : ::QPyDesignerPropertySheetExtension::qt_metacast(_clname));
}

int sipQPyDesignerPropertySheetExtension::count() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QPyDesignerPropertySheetExtension, sipName_count);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtDesigner_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDesigner_28(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQPyDesignerPropertySheetExtension::indexOf(const ::QString& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QPyDesignerPropertySheetExtension, sipName_indexOf);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtDesigner_87(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    return sipVH_QtDesigner_87(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QString sipQPyDesignerPropertySheetExtension::propertyName(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QPyDesignerPropertySheetExtension, sipName_propertyName);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtDesigner_88(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_88(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QString sipQPyDesignerPropertySheetExtension::propertyGroup(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QPyDesignerPropertySheetExtension, sipName_propertyGroup);

    if (!sipMeth)
        return ::QString();

    extern ::QString sipVH_QtDesigner_88(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_88(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPyDesignerPropertySheetExtension::setPropertyGroup(int a0, const ::QString& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, sipName_QPyDesignerPropertySheetExtension, sipName_setPropertyGroup);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_89(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, const ::QString&);

    sipVH_QtDesigner_89(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQPyDesignerPropertySheetExtension::hasReset(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QPyDesignerPropertySheetExtension, sipName_hasReset);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_79(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_79(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPyDesignerPropertySheetExtension::reset(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, sipName_QPyDesignerPropertySheetExtension, sipName_reset);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_79(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_79(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPyDesignerPropertySheetExtension::isVisible(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QPyDesignerPropertySheetExtension, sipName_isVisible);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_79(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_79(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPyDesignerPropertySheetExtension::setVisible(int a0, bool a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, sipName_QPyDesignerPropertySheetExtension, sipName_setVisible);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_90(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, bool);

    sipVH_QtDesigner_90(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQPyDesignerPropertySheetExtension::isAttribute(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QPyDesignerPropertySheetExtension, sipName_isAttribute);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_79(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_79(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPyDesignerPropertySheetExtension::setAttribute(int a0, bool a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, sipName_QPyDesignerPropertySheetExtension, sipName_setAttribute);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_90(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, bool);

    sipVH_QtDesigner_90(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QVariant sipQPyDesignerPropertySheetExtension::property(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QPyDesignerPropertySheetExtension, sipName_property);

    if (!sipMeth)
        return ::QVariant();

    extern ::QVariant sipVH_QtDesigner_92(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_92(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPyDesignerPropertySheetExtension::setProperty(int a0, const ::QVariant& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, sipName_QPyDesignerPropertySheetExtension, sipName_setProperty);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_93(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, const ::QVariant&);

    sipVH_QtDesigner_93(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQPyDesignerPropertySheetExtension::isChanged(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QPyDesignerPropertySheetExtension, sipName_isChanged);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtDesigner_79(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_79(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPyDesignerPropertySheetExtension::setChanged(int a0, bool a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, sipName_QPyDesignerPropertySheetExtension, sipName_setChanged);

    if (!sipMeth)
        return;

    extern void sipVH_QtDesigner_90(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, bool);

    sipVH_QtDesigner_90(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQPyDesignerPropertySheetExtension::isEnabled(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[15]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isEnabled);

    if (!sipMeth)
        return ::QPyDesignerPropertySheetExtension::isEnabled(a0);

    extern bool sipVH_QtDesigner_79(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtDesigner_79(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPyDesignerPropertySheetExtension::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QPyDesignerPropertySheetExtension::event(a0);

    extern bool sipVH_QtDesigner_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDesigner_31(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQPyDesignerPropertySheetExtension::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QPyDesignerPropertySheetExtension::eventFilter(a0, a1);

    extern bool sipVH_QtDesigner_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDesigner_32(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQPyDesignerPropertySheetExtension::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QPyDesignerPropertySheetExtension::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDesigner_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDesigner_33(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPyDesignerPropertySheetExtension::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QPyDesignerPropertySheetExtension::childEvent(a0);
        return;
    }

    extern void sipVH_QtDesigner_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDesigner_34(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPyDesignerPropertySheetExtension::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QPyDesignerPropertySheetExtension::customEvent(a0);
        return;
    }

    extern void sipVH_QtDesigner_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDesigner_7(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPyDesignerPropertySheetExtension::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QPyDesignerPropertySheetExtension::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDesigner_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDesigner_35(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQPyDesignerPropertySheetExtension::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QPyDesignerPropertySheetExtension::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDesigner_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDesigner_35(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPyDesignerPropertySheetExtension(void *, const sipTypeDef *);}
static void *cast_QPyDesignerPropertySheetExtension(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPyDesignerPropertySheetExtension *sipCpp = reinterpret_cast< ::QPyDesignerPropertySheetExtension *>(sipCppV);

    if (targetType == sipType_QPyDesignerPropertySheetExtension)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    if (targetType == sipType_QDesignerPropertySheetExtension)
        return static_cast< ::QDesignerPropertySheetExtension *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPyDesignerPropertySheetExtension(void *, int);}
static void release_QPyDesignerPropertySheetExtension(void *sipCppV, int)
{
    ::QPyDesignerPropertySheetExtension *sipCpp = reinterpret_cast< ::QPyDesignerPropertySheetExtension *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QPyDesignerPropertySheetExtension(sipSimpleWrapper *);}
static void dealloc_QPyDesignerPropertySheetExtension(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPyDesignerPropertySheetExtension *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPyDesignerPropertySheetExtension(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPyDesignerPropertySheetExtension(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPyDesignerPropertySheetExtension(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQPyDesignerPropertySheetExtension *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQPyDesignerPropertySheetExtension(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPyDesignerPropertySheetExtension[] = {{7, 0, 0}, {20, 255, 1}};

PyDoc_STRVAR(doc_QPyDesignerPropertySheetExtension, "\1QPyDesignerPropertySheetExtension(parent: Optional[QObject])");


static pyqt5ClassPluginDef plugin_QPyDesignerPropertySheetExtension = {
    &::QPyDesignerPropertySheetExtension::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDesigner_QPyDesignerPropertySheetExtension = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPyDesignerPropertySheetExtension,
        SIP_NULLPTR,
        &plugin_QPyDesignerPropertySheetExtension,
    },
    {
        sipNameNr_QPyDesignerPropertySheetExtension,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPyDesignerPropertySheetExtension,
    -1,
    -1,
    supers_QPyDesignerPropertySheetExtension,
    SIP_NULLPTR,
    init_type_QPyDesignerPropertySheetExtension,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPyDesignerPropertySheetExtension,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QPyDesignerPropertySheetExtension,
    cast_QPyDesignerPropertySheetExtension,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QPyDesignerPropertySheetExtension),
};
