/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtHelp.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtHelp/qhelpfilterengine.sip"
#include <qhelpfilterengine.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"

#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 34 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qversionnumber.sip"
#include <qversionnumber.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtHelp/qhelpfilterdata.sip"
#include <qhelpfilterdata.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterEngine.cpp"


PyDoc_STRVAR(doc_QHelpFilterEngine_namespaceToComponent, "namespaceToComponent(self) -> dict[str, str]");

extern "C" {static PyObject *meth_QHelpFilterEngine_namespaceToComponent(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterEngine_namespaceToComponent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpFilterEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpFilterEngine, &sipCpp))
        {
            QMap< ::QString, ::QString>*sipRes;

            sipRes = new QMap< ::QString, ::QString>(sipCpp->namespaceToComponent());

            return sipConvertFromNewType(sipRes, sipType_QMap_0100QString_0100QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterEngine, sipName_namespaceToComponent, doc_QHelpFilterEngine_namespaceToComponent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpFilterEngine_namespaceToVersion, "namespaceToVersion(self) -> dict[str, QVersionNumber]");

extern "C" {static PyObject *meth_QHelpFilterEngine_namespaceToVersion(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterEngine_namespaceToVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpFilterEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpFilterEngine, &sipCpp))
        {
            QMap< ::QString, ::QVersionNumber>*sipRes;

            sipRes = new QMap< ::QString, ::QVersionNumber>(sipCpp->namespaceToVersion());

            return sipConvertFromNewType(sipRes, sipType_QMap_0100QString_0100QVersionNumber, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterEngine, sipName_namespaceToVersion, doc_QHelpFilterEngine_namespaceToVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpFilterEngine_filters, "filters(self) -> list[str]");

extern "C" {static PyObject *meth_QHelpFilterEngine_filters(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterEngine_filters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpFilterEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpFilterEngine, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->filters());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterEngine, sipName_filters, doc_QHelpFilterEngine_filters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpFilterEngine_activeFilter, "activeFilter(self) -> str");

extern "C" {static PyObject *meth_QHelpFilterEngine_activeFilter(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterEngine_activeFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpFilterEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpFilterEngine, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->activeFilter());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterEngine, sipName_activeFilter, doc_QHelpFilterEngine_activeFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpFilterEngine_setActiveFilter, "setActiveFilter(self, filterName: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QHelpFilterEngine_setActiveFilter(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterEngine_setActiveFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QHelpFilterEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpFilterEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->setActiveFilter(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterEngine, sipName_setActiveFilter, doc_QHelpFilterEngine_setActiveFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpFilterEngine_availableComponents, "availableComponents(self) -> list[str]");

extern "C" {static PyObject *meth_QHelpFilterEngine_availableComponents(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterEngine_availableComponents(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpFilterEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpFilterEngine, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->availableComponents());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterEngine, sipName_availableComponents, doc_QHelpFilterEngine_availableComponents);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpFilterEngine_filterData, "filterData(self, filterName: Optional[str]) -> QHelpFilterData");

extern "C" {static PyObject *meth_QHelpFilterEngine_filterData(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterEngine_filterData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QHelpFilterEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpFilterEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QHelpFilterData*sipRes;

            sipRes = new ::QHelpFilterData(sipCpp->filterData(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QHelpFilterData, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterEngine, sipName_filterData, doc_QHelpFilterEngine_filterData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpFilterEngine_setFilterData, "setFilterData(self, filterName: Optional[str], filterData: QHelpFilterData) -> bool");

extern "C" {static PyObject *meth_QHelpFilterEngine_setFilterData(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterEngine_setFilterData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QHelpFilterData* a1;
        ::QHelpFilterEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J9", &sipSelf, sipType_QHelpFilterEngine, &sipCpp, sipType_QString, &a0, &a0State, sipType_QHelpFilterData, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->setFilterData(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterEngine, sipName_setFilterData, doc_QHelpFilterEngine_setFilterData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpFilterEngine_removeFilter, "removeFilter(self, filterName: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QHelpFilterEngine_removeFilter(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterEngine_removeFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QHelpFilterEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpFilterEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->removeFilter(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterEngine, sipName_removeFilter, doc_QHelpFilterEngine_removeFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpFilterEngine_namespacesForFilter, "namespacesForFilter(self, filterName: Optional[str]) -> list[str]");

extern "C" {static PyObject *meth_QHelpFilterEngine_namespacesForFilter(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterEngine_namespacesForFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QHelpFilterEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpFilterEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->namespacesForFilter(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterEngine, sipName_namespacesForFilter, doc_QHelpFilterEngine_namespacesForFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpFilterEngine_availableVersions, "availableVersions(self) -> list[QVersionNumber]");

extern "C" {static PyObject *meth_QHelpFilterEngine_availableVersions(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterEngine_availableVersions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpFilterEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpFilterEngine, &sipCpp))
        {
            QList< ::QVersionNumber>*sipRes;

            sipRes = new QList< ::QVersionNumber>(sipCpp->availableVersions());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QVersionNumber, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterEngine, sipName_availableVersions, doc_QHelpFilterEngine_availableVersions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpFilterEngine_indices, "indices(self) -> list[str]\n"
"indices(self, filterName: Optional[str]) -> list[str]");

extern "C" {static PyObject *meth_QHelpFilterEngine_indices(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterEngine_indices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpFilterEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpFilterEngine, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->indices());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QHelpFilterEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpFilterEngine, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->indices(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterEngine, sipName_indices, doc_QHelpFilterEngine_indices);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QHelpFilterEngine(void *, const sipTypeDef *);}
static void *cast_QHelpFilterEngine(void *sipCppV, const sipTypeDef *targetType)
{
    ::QHelpFilterEngine *sipCpp = reinterpret_cast< ::QHelpFilterEngine *>(sipCppV);

    if (targetType == sipType_QHelpFilterEngine)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QHelpFilterEngine(void *, int);}
static void release_QHelpFilterEngine(void *, int)
{
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QHelpFilterEngine[] = {{16, 0, 1}};


static PyMethodDef methods_QHelpFilterEngine[] = {
    {sipName_activeFilter, meth_QHelpFilterEngine_activeFilter, METH_VARARGS, doc_QHelpFilterEngine_activeFilter},
    {sipName_availableComponents, meth_QHelpFilterEngine_availableComponents, METH_VARARGS, doc_QHelpFilterEngine_availableComponents},
    {sipName_availableVersions, meth_QHelpFilterEngine_availableVersions, METH_VARARGS, doc_QHelpFilterEngine_availableVersions},
    {sipName_filterData, meth_QHelpFilterEngine_filterData, METH_VARARGS, doc_QHelpFilterEngine_filterData},
    {sipName_filters, meth_QHelpFilterEngine_filters, METH_VARARGS, doc_QHelpFilterEngine_filters},
    {sipName_indices, meth_QHelpFilterEngine_indices, METH_VARARGS, doc_QHelpFilterEngine_indices},
    {sipName_namespaceToComponent, meth_QHelpFilterEngine_namespaceToComponent, METH_VARARGS, doc_QHelpFilterEngine_namespaceToComponent},
    {sipName_namespaceToVersion, meth_QHelpFilterEngine_namespaceToVersion, METH_VARARGS, doc_QHelpFilterEngine_namespaceToVersion},
    {sipName_namespacesForFilter, meth_QHelpFilterEngine_namespacesForFilter, METH_VARARGS, doc_QHelpFilterEngine_namespacesForFilter},
    {sipName_removeFilter, meth_QHelpFilterEngine_removeFilter, METH_VARARGS, doc_QHelpFilterEngine_removeFilter},
    {sipName_setActiveFilter, meth_QHelpFilterEngine_setActiveFilter, METH_VARARGS, doc_QHelpFilterEngine_setActiveFilter},
    {sipName_setFilterData, meth_QHelpFilterEngine_setFilterData, METH_VARARGS, doc_QHelpFilterEngine_setFilterData}
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QHelpFilterEngine[] = {
    {"filterActivated(QString)", "\1filterActivated(self, newFilter: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QHelpFilterEngine = {
    &::QHelpFilterEngine::staticMetaObject,
    0,
    signals_QHelpFilterEngine,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtHelp_QHelpFilterEngine = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QHelpFilterEngine,
        SIP_NULLPTR,
        &plugin_QHelpFilterEngine,
    },
    {
        sipNameNr_QHelpFilterEngine,
        {0, 0, 1},
        12, methods_QHelpFilterEngine,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QHelpFilterEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QHelpFilterEngine,
    cast_QHelpFilterEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
