/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtTextToSpeech.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtTextToSpeech/qvoice.sip"
#include <qvoice.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQVoice.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtTextToSpeech/sipQtTextToSpeechQVoice.cpp"


PyDoc_STRVAR(doc_QVoice_name, "name(self) -> str");

extern "C" {static PyObject *meth_QVoice_name(PyObject *, PyObject *);}
static PyObject *meth_QVoice_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVoice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVoice, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVoice, sipName_name, doc_QVoice_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVoice_gender, "gender(self) -> QVoice.Gender");

extern "C" {static PyObject *meth_QVoice_gender(PyObject *, PyObject *);}
static PyObject *meth_QVoice_gender(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVoice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVoice, &sipCpp))
        {
            ::QVoice::Gender sipRes;

            sipRes = sipCpp->gender();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QVoice_Gender);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVoice, sipName_gender, doc_QVoice_gender);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVoice_age, "age(self) -> QVoice.Age");

extern "C" {static PyObject *meth_QVoice_age(PyObject *, PyObject *);}
static PyObject *meth_QVoice_age(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVoice *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVoice, &sipCpp))
        {
            ::QVoice::Age sipRes;

            sipRes = sipCpp->age();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QVoice_Age);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVoice, sipName_age, doc_QVoice_age);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVoice_genderName, "genderName(gender: QVoice.Gender) -> str");

extern "C" {static PyObject *meth_QVoice_genderName(PyObject *, PyObject *);}
static PyObject *meth_QVoice_genderName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVoice::Gender a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "E", sipType_QVoice_Gender, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QVoice::genderName(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVoice, sipName_genderName, doc_QVoice_genderName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVoice_ageName, "ageName(age: QVoice.Age) -> str");

extern "C" {static PyObject *meth_QVoice_ageName(PyObject *, PyObject *);}
static PyObject *meth_QVoice_ageName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVoice::Age a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "E", sipType_QVoice_Age, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QVoice::ageName(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVoice, sipName_ageName, doc_QVoice_ageName);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QVoice___ne__(PyObject *, PyObject *);}
static PyObject *slot_QVoice___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QVoice *sipCpp = reinterpret_cast< ::QVoice *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QVoice));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVoice* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QVoice, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QVoice::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtTextToSpeech, ne_slot, sipType_QVoice, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QVoice___eq__(PyObject *, PyObject *);}
static PyObject *slot_QVoice___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QVoice *sipCpp = reinterpret_cast< ::QVoice *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QVoice));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVoice* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QVoice, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QVoice::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtTextToSpeech, eq_slot, sipType_QVoice, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QVoice(void *, int);}
static void release_QVoice(void *sipCppV, int)
{
    delete reinterpret_cast< ::QVoice *>(sipCppV);
}


extern "C" {static void *array_QVoice(Py_ssize_t);}
static void *array_QVoice(Py_ssize_t sipNrElem)
{
    return new ::QVoice[sipNrElem];
}


extern "C" {static void array_delete_QVoice(void *);}
static void array_delete_QVoice(void *sipCpp)
{
    delete[] reinterpret_cast< ::QVoice *>(sipCpp);
}


extern "C" {static void assign_QVoice(void *, Py_ssize_t, void *);}
static void assign_QVoice(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QVoice *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QVoice *>(sipSrc);
}


extern "C" {static void *copy_QVoice(const void *, Py_ssize_t);}
static void *copy_QVoice(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QVoice(reinterpret_cast<const ::QVoice *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QVoice(sipSimpleWrapper *);}
static void dealloc_QVoice(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QVoice(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QVoice(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QVoice(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QVoice *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QVoice();

            return sipCpp;
        }
    }

    {
        const ::QVoice* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QVoice, &a0))
        {
            sipCpp = new ::QVoice(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QVoice[] = {
    {(void *)slot_QVoice___ne__, ne_slot},
    {(void *)slot_QVoice___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QVoice[] = {
    {sipName_age, meth_QVoice_age, METH_VARARGS, doc_QVoice_age},
    {sipName_ageName, meth_QVoice_ageName, METH_VARARGS, doc_QVoice_ageName},
    {sipName_gender, meth_QVoice_gender, METH_VARARGS, doc_QVoice_gender},
    {sipName_genderName, meth_QVoice_genderName, METH_VARARGS, doc_QVoice_genderName},
    {sipName_name, meth_QVoice_name, METH_VARARGS, doc_QVoice_name}
};

static sipEnumMemberDef enummembers_QVoice[] = {
    {sipName_Adult, static_cast<int>(::QVoice::Adult), 5},
    {sipName_Child, static_cast<int>(::QVoice::Child), 5},
    {sipName_Female, static_cast<int>(::QVoice::Female), 6},
    {sipName_Male, static_cast<int>(::QVoice::Male), 6},
    {sipName_Other, static_cast<int>(::QVoice::Other), 5},
    {sipName_Senior, static_cast<int>(::QVoice::Senior), 5},
    {sipName_Teenager, static_cast<int>(::QVoice::Teenager), 5},
    {sipName_Unknown, static_cast<int>(::QVoice::Unknown), 6},
};

PyDoc_STRVAR(doc_QVoice, "\1QVoice()\n"
"QVoice(other: QVoice)");


static pyqt5ClassPluginDef plugin_QVoice = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtTextToSpeech_QVoice = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QVoice,
        SIP_NULLPTR,
        &plugin_QVoice,
    },
    {
        sipNameNr_QVoice,
        {0, 0, 1},
        5, methods_QVoice,
        8, enummembers_QVoice,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QVoice,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QVoice,
    init_type_QVoice,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QVoice,
    assign_QVoice,
    array_QVoice,
    copy_QVoice,
    release_QVoice,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QVoice,
    sizeof (::QVoice),
};
