/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaplaylist.sip"
#include <qmediaplaylist.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaobject.sip"
#include <qmediaobject.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediacontent.sip"
#include <qmediacontent.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qnetworkrequest.sip"
#include <qnetworkrequest.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaPlaylist.cpp"


class sipQMediaPlaylist : public ::QMediaPlaylist
{
public:
    sipQMediaPlaylist(::QObject*);
    virtual ~sipQMediaPlaylist();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QMediaObject* mediaObject() const SIP_OVERRIDE;
    bool setMediaObject(::QMediaObject*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQMediaPlaylist(const sipQMediaPlaylist &);
    sipQMediaPlaylist &operator = (const sipQMediaPlaylist &);

    char sipPyMethods[9];
};

sipQMediaPlaylist::sipQMediaPlaylist(::QObject*a0): ::QMediaPlaylist(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQMediaPlaylist::~sipQMediaPlaylist()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQMediaPlaylist::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QMediaPlaylist);

    return ::QMediaPlaylist::metaObject();
}

int sipQMediaPlaylist::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QMediaPlaylist::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QMediaPlaylist, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQMediaPlaylist::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QMediaPlaylist, _clname, &sipCpp) ? sipCpp : ::QMediaPlaylist::qt_metacast(_clname));
}

::QMediaObject* sipQMediaPlaylist::mediaObject() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_mediaObject);

    if (!sipMeth)
        return ::QMediaPlaylist::mediaObject();

    extern ::QMediaObject* sipVH_QtMultimedia_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_36(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQMediaPlaylist::setMediaObject(::QMediaObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_setMediaObject);

    if (!sipMeth)
        return ::QMediaPlaylist::setMediaObject(a0);

    extern bool sipVH_QtMultimedia_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMediaObject*);

    return sipVH_QtMultimedia_37(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQMediaPlaylist::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QMediaPlaylist::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQMediaPlaylist::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QMediaPlaylist::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQMediaPlaylist::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QMediaPlaylist::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlaylist::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QMediaPlaylist::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlaylist::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QMediaPlaylist::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlaylist::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QMediaPlaylist::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQMediaPlaylist::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QMediaPlaylist::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QMediaPlaylist_mediaObject, "mediaObject(self) -> Optional[QMediaObject]");

extern "C" {static PyObject *meth_QMediaPlaylist_mediaObject(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_mediaObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlaylist, &sipCpp))
        {
            ::QMediaObject*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QMediaPlaylist::mediaObject() : sipCpp->mediaObject());

            return sipConvertFromType(sipRes, sipType_QMediaObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_mediaObject, doc_QMediaPlaylist_mediaObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_playbackMode, "playbackMode(self) -> QMediaPlaylist.PlaybackMode");

extern "C" {static PyObject *meth_QMediaPlaylist_playbackMode(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_playbackMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlaylist, &sipCpp))
        {
            ::QMediaPlaylist::PlaybackMode sipRes;

            sipRes = sipCpp->playbackMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaPlaylist_PlaybackMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_playbackMode, doc_QMediaPlaylist_playbackMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_setPlaybackMode, "setPlaybackMode(self, mode: QMediaPlaylist.PlaybackMode)");

extern "C" {static PyObject *meth_QMediaPlaylist_setPlaybackMode(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_setPlaybackMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaPlaylist::PlaybackMode a0;
        ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QMediaPlaylist, &sipCpp, sipType_QMediaPlaylist_PlaybackMode, &a0))
        {
            sipCpp->setPlaybackMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_setPlaybackMode, doc_QMediaPlaylist_setPlaybackMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_currentIndex, "currentIndex(self) -> int");

extern "C" {static PyObject *meth_QMediaPlaylist_currentIndex(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_currentIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlaylist, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->currentIndex();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_currentIndex, doc_QMediaPlaylist_currentIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_currentMedia, "currentMedia(self) -> QMediaContent");

extern "C" {static PyObject *meth_QMediaPlaylist_currentMedia(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_currentMedia(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlaylist, &sipCpp))
        {
            ::QMediaContent*sipRes;

            sipRes = new ::QMediaContent(sipCpp->currentMedia());

            return sipConvertFromNewType(sipRes, sipType_QMediaContent, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_currentMedia, doc_QMediaPlaylist_currentMedia);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_nextIndex, "nextIndex(self, steps: int = 1) -> int");

extern "C" {static PyObject *meth_QMediaPlaylist_nextIndex(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_nextIndex(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = 1;
        const ::QMediaPlaylist *sipCpp;

        static const char *sipKwdList[] = {
            sipName_steps,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QMediaPlaylist, &sipCpp, &a0))
        {
            int sipRes;

            sipRes = sipCpp->nextIndex(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_nextIndex, doc_QMediaPlaylist_nextIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_previousIndex, "previousIndex(self, steps: int = 1) -> int");

extern "C" {static PyObject *meth_QMediaPlaylist_previousIndex(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_previousIndex(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = 1;
        const ::QMediaPlaylist *sipCpp;

        static const char *sipKwdList[] = {
            sipName_steps,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QMediaPlaylist, &sipCpp, &a0))
        {
            int sipRes;

            sipRes = sipCpp->previousIndex(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_previousIndex, doc_QMediaPlaylist_previousIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_media, "media(self, index: int) -> QMediaContent");

extern "C" {static PyObject *meth_QMediaPlaylist_media(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_media(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaPlaylist, &sipCpp, &a0))
        {
            ::QMediaContent*sipRes;

            sipRes = new ::QMediaContent(sipCpp->media(a0));

            return sipConvertFromNewType(sipRes, sipType_QMediaContent, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_media, doc_QMediaPlaylist_media);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_mediaCount, "mediaCount(self) -> int");

extern "C" {static PyObject *meth_QMediaPlaylist_mediaCount(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_mediaCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlaylist, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->mediaCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_mediaCount, doc_QMediaPlaylist_mediaCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_isEmpty, "isEmpty(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlaylist_isEmpty(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_isEmpty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlaylist, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEmpty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_isEmpty, doc_QMediaPlaylist_isEmpty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_isReadOnly, "isReadOnly(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlaylist_isReadOnly(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_isReadOnly(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlaylist, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isReadOnly();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_isReadOnly, doc_QMediaPlaylist_isReadOnly);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_addMedia, "addMedia(self, content: QMediaContent) -> bool\n"
"addMedia(self, items: Iterable[QMediaContent]) -> bool");

extern "C" {static PyObject *meth_QMediaPlaylist_addMedia(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_addMedia(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaContent* a0;
        ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QMediaPlaylist, &sipCpp, sipType_QMediaContent, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->addMedia(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const QList< ::QMediaContent>* a0;
        int a0State = 0;
        ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMediaPlaylist, &sipCpp, sipType_QList_0100QMediaContent, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->addMedia(*a0);
            sipReleaseType(const_cast<QList< ::QMediaContent> *>(a0), sipType_QList_0100QMediaContent, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_addMedia, doc_QMediaPlaylist_addMedia);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_insertMedia, "insertMedia(self, index: int, content: QMediaContent) -> bool\n"
"insertMedia(self, index: int, items: Iterable[QMediaContent]) -> bool");

extern "C" {static PyObject *meth_QMediaPlaylist_insertMedia(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_insertMedia(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QMediaContent* a1;
        ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ9", &sipSelf, sipType_QMediaPlaylist, &sipCpp, &a0, sipType_QMediaContent, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->insertMedia(a0, *a1);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        int a0;
        const QList< ::QMediaContent>* a1;
        int a1State = 0;
        ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QMediaPlaylist, &sipCpp, &a0, sipType_QList_0100QMediaContent, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->insertMedia(a0, *a1);
            sipReleaseType(const_cast<QList< ::QMediaContent> *>(a1), sipType_QList_0100QMediaContent, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_insertMedia, doc_QMediaPlaylist_insertMedia);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_removeMedia, "removeMedia(self, pos: int) -> bool\n"
"removeMedia(self, start: int, end: int) -> bool");

extern "C" {static PyObject *meth_QMediaPlaylist_removeMedia(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_removeMedia(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaPlaylist, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->removeMedia(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        int a0;
        int a1;
        ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QMediaPlaylist, &sipCpp, &a0, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->removeMedia(a0, a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_removeMedia, doc_QMediaPlaylist_removeMedia);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_clear, "clear(self) -> bool");

extern "C" {static PyObject *meth_QMediaPlaylist_clear(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlaylist, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->clear();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_clear, doc_QMediaPlaylist_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_load, "load(self, request: QNetworkRequest, format: Optional[str] = None)\n"
"load(self, location: QUrl, format: Optional[str] = None)\n"
"load(self, device: Optional[QIODevice], format: Optional[str] = None)");

extern "C" {static PyObject *meth_QMediaPlaylist_load(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_load(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QNetworkRequest* a0;
        const char* a1 = 0;
        PyObject *a1Keep = 0;
        ::QMediaPlaylist *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|AA", &sipSelf, sipType_QMediaPlaylist, &sipCpp, sipType_QNetworkRequest, &a0, &a1Keep, &a1))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->load(*a0, a1);
            Py_END_ALLOW_THREADS
            Py_XDECREF(a1Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QUrl* a0;
        const char* a1 = 0;
        PyObject *a1Keep = 0;
        ::QMediaPlaylist *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|AA", &sipSelf, sipType_QMediaPlaylist, &sipCpp, sipType_QUrl, &a0, &a1Keep, &a1))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->load(*a0, a1);
            Py_END_ALLOW_THREADS
            Py_XDECREF(a1Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QIODevice* a0;
        const char* a1 = 0;
        PyObject *a1Keep = 0;
        ::QMediaPlaylist *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|AA", &sipSelf, sipType_QMediaPlaylist, &sipCpp, sipType_QIODevice, &a0, &a1Keep, &a1))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->load(a0, a1);
            Py_END_ALLOW_THREADS
            Py_XDECREF(a1Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_load, doc_QMediaPlaylist_load);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_save, "save(self, location: QUrl, format: Optional[str] = None) -> bool\n"
"save(self, device: Optional[QIODevice], format: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QMediaPlaylist_save(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_save(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        const char* a1 = 0;
        PyObject *a1Keep = 0;
        ::QMediaPlaylist *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|AA", &sipSelf, sipType_QMediaPlaylist, &sipCpp, sipType_QUrl, &a0, &a1Keep, &a1))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->save(*a0, a1);
            Py_END_ALLOW_THREADS
            Py_XDECREF(a1Keep);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        ::QIODevice* a0;
        const char* a1;
        PyObject *a1Keep;
        ::QMediaPlaylist *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ8AA", &sipSelf, sipType_QMediaPlaylist, &sipCpp, sipType_QIODevice, &a0, &a1Keep, &a1))
        {
            bool sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = sipCpp->save(a0, a1);
            Py_END_ALLOW_THREADS
            Py_DECREF(a1Keep);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_save, doc_QMediaPlaylist_save);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_error, "error(self) -> QMediaPlaylist.Error");

extern "C" {static PyObject *meth_QMediaPlaylist_error(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlaylist, &sipCpp))
        {
            ::QMediaPlaylist::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMediaPlaylist_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_error, doc_QMediaPlaylist_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QMediaPlaylist_errorString(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlaylist, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_errorString, doc_QMediaPlaylist_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_moveMedia, "moveMedia(self, from_: int, to: int) -> bool");

extern "C" {static PyObject *meth_QMediaPlaylist_moveMedia(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_moveMedia(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QMediaPlaylist, &sipCpp, &a0, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->moveMedia(a0, a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_moveMedia, doc_QMediaPlaylist_moveMedia);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_shuffle, "shuffle(self)");

extern "C" {static PyObject *meth_QMediaPlaylist_shuffle(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_shuffle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlaylist, &sipCpp))
        {
            sipCpp->shuffle();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_shuffle, doc_QMediaPlaylist_shuffle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_next, "next(self)");

extern "C" {static PyObject *meth_QMediaPlaylist_next(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_next(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlaylist, &sipCpp))
        {
            sipCpp->next();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_next, doc_QMediaPlaylist_next);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_previous, "previous(self)");

extern "C" {static PyObject *meth_QMediaPlaylist_previous(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_previous(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaPlaylist, &sipCpp))
        {
            sipCpp->previous();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_previous, doc_QMediaPlaylist_previous);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_setCurrentIndex, "setCurrentIndex(self, index: int)");

extern "C" {static PyObject *meth_QMediaPlaylist_setCurrentIndex(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_setCurrentIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaPlaylist, &sipCpp, &a0))
        {
            sipCpp->setCurrentIndex(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_setCurrentIndex, doc_QMediaPlaylist_setCurrentIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaPlaylist_setMediaObject, "setMediaObject(self, object: Optional[QMediaObject]) -> bool");

extern "C" {static PyObject *meth_QMediaPlaylist_setMediaObject(PyObject *, PyObject *);}
static PyObject *meth_QMediaPlaylist_setMediaObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMediaObject* a0;
        ::QMediaPlaylist *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QMediaPlaylist, &sipCpp, sipType_QMediaObject, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QMediaPlaylist::setMediaObject(a0) : sipCpp->setMediaObject(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaPlaylist, sipName_setMediaObject, doc_QMediaPlaylist_setMediaObject);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QMediaPlaylist(void *, const sipTypeDef *);}
static void *cast_QMediaPlaylist(void *sipCppV, const sipTypeDef *targetType)
{
    ::QMediaPlaylist *sipCpp = reinterpret_cast< ::QMediaPlaylist *>(sipCppV);

    if (targetType == sipType_QMediaPlaylist)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    if (targetType == sipType_QMediaBindableInterface)
        return static_cast< ::QMediaBindableInterface *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QMediaPlaylist(void *, int);}
static void release_QMediaPlaylist(void *sipCppV, int)
{
    ::QMediaPlaylist *sipCpp = reinterpret_cast< ::QMediaPlaylist *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QMediaPlaylist(Py_ssize_t);}
static void *array_QMediaPlaylist(Py_ssize_t sipNrElem)
{
    return new ::QMediaPlaylist[sipNrElem];
}


extern "C" {static void array_delete_QMediaPlaylist(void *);}
static void array_delete_QMediaPlaylist(void *sipCpp)
{
    delete[] reinterpret_cast< ::QMediaPlaylist *>(sipCpp);
}


extern "C" {static void dealloc_QMediaPlaylist(sipSimpleWrapper *);}
static void dealloc_QMediaPlaylist(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQMediaPlaylist *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QMediaPlaylist(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QMediaPlaylist(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QMediaPlaylist(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQMediaPlaylist *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQMediaPlaylist(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QMediaPlaylist[] = {{9, 0, 0}, {101, 255, 1}};


static PyMethodDef methods_QMediaPlaylist[] = {
    {sipName_addMedia, meth_QMediaPlaylist_addMedia, METH_VARARGS, doc_QMediaPlaylist_addMedia},
    {sipName_clear, meth_QMediaPlaylist_clear, METH_VARARGS, doc_QMediaPlaylist_clear},
    {sipName_currentIndex, meth_QMediaPlaylist_currentIndex, METH_VARARGS, doc_QMediaPlaylist_currentIndex},
    {sipName_currentMedia, meth_QMediaPlaylist_currentMedia, METH_VARARGS, doc_QMediaPlaylist_currentMedia},
    {sipName_error, meth_QMediaPlaylist_error, METH_VARARGS, doc_QMediaPlaylist_error},
    {sipName_errorString, meth_QMediaPlaylist_errorString, METH_VARARGS, doc_QMediaPlaylist_errorString},
    {sipName_insertMedia, meth_QMediaPlaylist_insertMedia, METH_VARARGS, doc_QMediaPlaylist_insertMedia},
    {sipName_isEmpty, meth_QMediaPlaylist_isEmpty, METH_VARARGS, doc_QMediaPlaylist_isEmpty},
    {sipName_isReadOnly, meth_QMediaPlaylist_isReadOnly, METH_VARARGS, doc_QMediaPlaylist_isReadOnly},
    {sipName_load, SIP_MLMETH_CAST(meth_QMediaPlaylist_load), METH_VARARGS|METH_KEYWORDS, doc_QMediaPlaylist_load},
    {sipName_media, meth_QMediaPlaylist_media, METH_VARARGS, doc_QMediaPlaylist_media},
    {sipName_mediaCount, meth_QMediaPlaylist_mediaCount, METH_VARARGS, doc_QMediaPlaylist_mediaCount},
    {sipName_mediaObject, meth_QMediaPlaylist_mediaObject, METH_VARARGS, doc_QMediaPlaylist_mediaObject},
    {sipName_moveMedia, meth_QMediaPlaylist_moveMedia, METH_VARARGS, doc_QMediaPlaylist_moveMedia},
    {sipName_next, meth_QMediaPlaylist_next, METH_VARARGS, doc_QMediaPlaylist_next},
    {sipName_nextIndex, SIP_MLMETH_CAST(meth_QMediaPlaylist_nextIndex), METH_VARARGS|METH_KEYWORDS, doc_QMediaPlaylist_nextIndex},
    {sipName_playbackMode, meth_QMediaPlaylist_playbackMode, METH_VARARGS, doc_QMediaPlaylist_playbackMode},
    {sipName_previous, meth_QMediaPlaylist_previous, METH_VARARGS, doc_QMediaPlaylist_previous},
    {sipName_previousIndex, SIP_MLMETH_CAST(meth_QMediaPlaylist_previousIndex), METH_VARARGS|METH_KEYWORDS, doc_QMediaPlaylist_previousIndex},
    {sipName_removeMedia, meth_QMediaPlaylist_removeMedia, METH_VARARGS, doc_QMediaPlaylist_removeMedia},
    {sipName_save, SIP_MLMETH_CAST(meth_QMediaPlaylist_save), METH_VARARGS|METH_KEYWORDS, doc_QMediaPlaylist_save},
    {sipName_setCurrentIndex, meth_QMediaPlaylist_setCurrentIndex, METH_VARARGS, doc_QMediaPlaylist_setCurrentIndex},
    {sipName_setMediaObject, meth_QMediaPlaylist_setMediaObject, METH_VARARGS, doc_QMediaPlaylist_setMediaObject},
    {sipName_setPlaybackMode, meth_QMediaPlaylist_setPlaybackMode, METH_VARARGS, doc_QMediaPlaylist_setPlaybackMode},
    {sipName_shuffle, meth_QMediaPlaylist_shuffle, METH_VARARGS, doc_QMediaPlaylist_shuffle}
};

static sipEnumMemberDef enummembers_QMediaPlaylist[] = {
    {sipName_AccessDeniedError, static_cast<int>(::QMediaPlaylist::AccessDeniedError), 117},
    {sipName_CurrentItemInLoop, static_cast<int>(::QMediaPlaylist::CurrentItemInLoop), 118},
    {sipName_CurrentItemOnce, static_cast<int>(::QMediaPlaylist::CurrentItemOnce), 118},
    {sipName_FormatError, static_cast<int>(::QMediaPlaylist::FormatError), 117},
    {sipName_FormatNotSupportedError, static_cast<int>(::QMediaPlaylist::FormatNotSupportedError), 117},
    {sipName_Loop, static_cast<int>(::QMediaPlaylist::Loop), 118},
    {sipName_NetworkError, static_cast<int>(::QMediaPlaylist::NetworkError), 117},
    {sipName_NoError, static_cast<int>(::QMediaPlaylist::NoError), 117},
    {sipName_Random, static_cast<int>(::QMediaPlaylist::Random), 118},
    {sipName_Sequential, static_cast<int>(::QMediaPlaylist::Sequential), 118},
};

PyDoc_STRVAR(doc_QMediaPlaylist, "\1QMediaPlaylist(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QMediaPlaylist[] = {
    {"loadFailed()", "\1loadFailed(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"loaded()", "\1loaded(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"mediaChanged(int,int)", "\1mediaChanged(self, start: int, end: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"mediaRemoved(int,int)", "\1mediaRemoved(self, start: int, end: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"mediaAboutToBeRemoved(int,int)", "\1mediaAboutToBeRemoved(self, start: int, end: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"mediaInserted(int,int)", "\1mediaInserted(self, start: int, end: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"mediaAboutToBeInserted(int,int)", "\1mediaAboutToBeInserted(self, start: int, end: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"currentMediaChanged(QMediaContent)", "\1currentMediaChanged(self, a0: QMediaContent)", SIP_NULLPTR, SIP_NULLPTR},
    {"playbackModeChanged(QMediaPlaylist::PlaybackMode)", "\1playbackModeChanged(self, mode: QMediaPlaylist.PlaybackMode)", SIP_NULLPTR, SIP_NULLPTR},
    {"currentIndexChanged(int)", "\1currentIndexChanged(self, index: int)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QMediaPlaylist = {
    &::QMediaPlaylist::staticMetaObject,
    0,
    signals_QMediaPlaylist,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QMediaPlaylist = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QMediaPlaylist,
        SIP_NULLPTR,
        &plugin_QMediaPlaylist,
    },
    {
        sipNameNr_QMediaPlaylist,
        {0, 0, 1},
        25, methods_QMediaPlaylist,
        10, enummembers_QMediaPlaylist,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QMediaPlaylist,
    -1,
    -1,
    supers_QMediaPlaylist,
    SIP_NULLPTR,
    init_type_QMediaPlaylist,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QMediaPlaylist,
    SIP_NULLPTR,
    array_QMediaPlaylist,
    SIP_NULLPTR,
    release_QMediaPlaylist,
    cast_QMediaPlaylist,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QMediaPlaylist,
    sizeof (::QMediaPlaylist),
};
