/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaresource.sip"
#include <qmediaresource.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaResource.cpp"

#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaResource.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaResource.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qnetworkrequest.sip"
#include <qnetworkrequest.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaResource.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaResource.cpp"


PyDoc_STRVAR(doc_QMediaResource_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QMediaResource_isNull(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaResource, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_isNull, doc_QMediaResource_isNull);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_url, "url(self) -> QUrl");

extern "C" {static PyObject *meth_QMediaResource_url(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_url(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaResource, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->url());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_url, doc_QMediaResource_url);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_request, "request(self) -> QNetworkRequest");

extern "C" {static PyObject *meth_QMediaResource_request(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_request(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaResource, &sipCpp))
        {
            ::QNetworkRequest*sipRes;

            sipRes = new ::QNetworkRequest(sipCpp->request());

            return sipConvertFromNewType(sipRes, sipType_QNetworkRequest, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_request, doc_QMediaResource_request);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_mimeType, "mimeType(self) -> str");

extern "C" {static PyObject *meth_QMediaResource_mimeType(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_mimeType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaResource, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->mimeType());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_mimeType, doc_QMediaResource_mimeType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_language, "language(self) -> str");

extern "C" {static PyObject *meth_QMediaResource_language(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_language(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaResource, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->language());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_language, doc_QMediaResource_language);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_setLanguage, "setLanguage(self, language: Optional[str])");

extern "C" {static PyObject *meth_QMediaResource_setLanguage(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_setLanguage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMediaResource, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setLanguage(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_setLanguage, doc_QMediaResource_setLanguage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_audioCodec, "audioCodec(self) -> str");

extern "C" {static PyObject *meth_QMediaResource_audioCodec(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_audioCodec(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaResource, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->audioCodec());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_audioCodec, doc_QMediaResource_audioCodec);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_setAudioCodec, "setAudioCodec(self, codec: Optional[str])");

extern "C" {static PyObject *meth_QMediaResource_setAudioCodec(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_setAudioCodec(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMediaResource, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setAudioCodec(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_setAudioCodec, doc_QMediaResource_setAudioCodec);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_videoCodec, "videoCodec(self) -> str");

extern "C" {static PyObject *meth_QMediaResource_videoCodec(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_videoCodec(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaResource, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->videoCodec());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_videoCodec, doc_QMediaResource_videoCodec);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_setVideoCodec, "setVideoCodec(self, codec: Optional[str])");

extern "C" {static PyObject *meth_QMediaResource_setVideoCodec(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_setVideoCodec(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QMediaResource, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setVideoCodec(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_setVideoCodec, doc_QMediaResource_setVideoCodec);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_dataSize, "dataSize(self) -> int");

extern "C" {static PyObject *meth_QMediaResource_dataSize(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_dataSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaResource, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->dataSize();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_dataSize, doc_QMediaResource_dataSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_setDataSize, "setDataSize(self, size: int)");

extern "C" {static PyObject *meth_QMediaResource_setDataSize(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_setDataSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qint64 a0;
        ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bn", &sipSelf, sipType_QMediaResource, &sipCpp, &a0))
        {
            sipCpp->setDataSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_setDataSize, doc_QMediaResource_setDataSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_audioBitRate, "audioBitRate(self) -> int");

extern "C" {static PyObject *meth_QMediaResource_audioBitRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_audioBitRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaResource, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->audioBitRate();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_audioBitRate, doc_QMediaResource_audioBitRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_setAudioBitRate, "setAudioBitRate(self, rate: int)");

extern "C" {static PyObject *meth_QMediaResource_setAudioBitRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_setAudioBitRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaResource, &sipCpp, &a0))
        {
            sipCpp->setAudioBitRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_setAudioBitRate, doc_QMediaResource_setAudioBitRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_sampleRate, "sampleRate(self) -> int");

extern "C" {static PyObject *meth_QMediaResource_sampleRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_sampleRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaResource, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->sampleRate();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_sampleRate, doc_QMediaResource_sampleRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_setSampleRate, "setSampleRate(self, frequency: int)");

extern "C" {static PyObject *meth_QMediaResource_setSampleRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_setSampleRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaResource, &sipCpp, &a0))
        {
            sipCpp->setSampleRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_setSampleRate, doc_QMediaResource_setSampleRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_channelCount, "channelCount(self) -> int");

extern "C" {static PyObject *meth_QMediaResource_channelCount(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_channelCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaResource, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->channelCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_channelCount, doc_QMediaResource_channelCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_setChannelCount, "setChannelCount(self, channels: int)");

extern "C" {static PyObject *meth_QMediaResource_setChannelCount(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_setChannelCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaResource, &sipCpp, &a0))
        {
            sipCpp->setChannelCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_setChannelCount, doc_QMediaResource_setChannelCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_videoBitRate, "videoBitRate(self) -> int");

extern "C" {static PyObject *meth_QMediaResource_videoBitRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_videoBitRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaResource, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->videoBitRate();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_videoBitRate, doc_QMediaResource_videoBitRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_setVideoBitRate, "setVideoBitRate(self, rate: int)");

extern "C" {static PyObject *meth_QMediaResource_setVideoBitRate(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_setVideoBitRate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QMediaResource, &sipCpp, &a0))
        {
            sipCpp->setVideoBitRate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_setVideoBitRate, doc_QMediaResource_setVideoBitRate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_resolution, "resolution(self) -> QSize");

extern "C" {static PyObject *meth_QMediaResource_resolution(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_resolution(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QMediaResource, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->resolution());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_resolution, doc_QMediaResource_resolution);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QMediaResource_setResolution, "setResolution(self, resolution: QSize)\n"
"setResolution(self, width: int, height: int)");

extern "C" {static PyObject *meth_QMediaResource_setResolution(PyObject *, PyObject *);}
static PyObject *meth_QMediaResource_setResolution(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QMediaResource, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setResolution(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        int a1;
        ::QMediaResource *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QMediaResource, &sipCpp, &a0, &a1))
        {
            sipCpp->setResolution(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QMediaResource, sipName_setResolution, doc_QMediaResource_setResolution);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QMediaResource___ne__(PyObject *, PyObject *);}
static PyObject *slot_QMediaResource___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QMediaResource *sipCpp = reinterpret_cast< ::QMediaResource *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QMediaResource));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaResource* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QMediaResource, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QMediaResource::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, ne_slot, sipType_QMediaResource, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QMediaResource___eq__(PyObject *, PyObject *);}
static PyObject *slot_QMediaResource___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QMediaResource *sipCpp = reinterpret_cast< ::QMediaResource *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QMediaResource));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QMediaResource* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QMediaResource, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QMediaResource::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, eq_slot, sipType_QMediaResource, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QMediaResource(void *, int);}
static void release_QMediaResource(void *sipCppV, int)
{
    delete reinterpret_cast< ::QMediaResource *>(sipCppV);
}


extern "C" {static void *array_QMediaResource(Py_ssize_t);}
static void *array_QMediaResource(Py_ssize_t sipNrElem)
{
    return new ::QMediaResource[sipNrElem];
}


extern "C" {static void array_delete_QMediaResource(void *);}
static void array_delete_QMediaResource(void *sipCpp)
{
    delete[] reinterpret_cast< ::QMediaResource *>(sipCpp);
}


extern "C" {static void assign_QMediaResource(void *, Py_ssize_t, void *);}
static void assign_QMediaResource(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QMediaResource *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QMediaResource *>(sipSrc);
}


extern "C" {static void *copy_QMediaResource(const void *, Py_ssize_t);}
static void *copy_QMediaResource(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QMediaResource(reinterpret_cast<const ::QMediaResource *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QMediaResource(sipSimpleWrapper *);}
static void dealloc_QMediaResource(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QMediaResource(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QMediaResource(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QMediaResource(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QMediaResource *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QMediaResource();

            return sipCpp;
        }
    }

    {
        const ::QUrl* a0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mimeType,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9|J1", sipType_QUrl, &a0, sipType_QString, &a1, &a1State))
        {
            sipCpp = new ::QMediaResource(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipCpp;
        }
    }

    {
        const ::QNetworkRequest* a0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_mimeType,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9|J1", sipType_QNetworkRequest, &a0, sipType_QString, &a1, &a1State))
        {
            sipCpp = new ::QMediaResource(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipCpp;
        }
    }

    {
        const ::QMediaResource* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QMediaResource, &a0))
        {
            sipCpp = new ::QMediaResource(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QMediaResource[] = {
    {(void *)slot_QMediaResource___ne__, ne_slot},
    {(void *)slot_QMediaResource___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QMediaResource[] = {
    {sipName_audioBitRate, meth_QMediaResource_audioBitRate, METH_VARARGS, doc_QMediaResource_audioBitRate},
    {sipName_audioCodec, meth_QMediaResource_audioCodec, METH_VARARGS, doc_QMediaResource_audioCodec},
    {sipName_channelCount, meth_QMediaResource_channelCount, METH_VARARGS, doc_QMediaResource_channelCount},
    {sipName_dataSize, meth_QMediaResource_dataSize, METH_VARARGS, doc_QMediaResource_dataSize},
    {sipName_isNull, meth_QMediaResource_isNull, METH_VARARGS, doc_QMediaResource_isNull},
    {sipName_language, meth_QMediaResource_language, METH_VARARGS, doc_QMediaResource_language},
    {sipName_mimeType, meth_QMediaResource_mimeType, METH_VARARGS, doc_QMediaResource_mimeType},
    {sipName_request, meth_QMediaResource_request, METH_VARARGS, doc_QMediaResource_request},
    {sipName_resolution, meth_QMediaResource_resolution, METH_VARARGS, doc_QMediaResource_resolution},
    {sipName_sampleRate, meth_QMediaResource_sampleRate, METH_VARARGS, doc_QMediaResource_sampleRate},
    {sipName_setAudioBitRate, meth_QMediaResource_setAudioBitRate, METH_VARARGS, doc_QMediaResource_setAudioBitRate},
    {sipName_setAudioCodec, meth_QMediaResource_setAudioCodec, METH_VARARGS, doc_QMediaResource_setAudioCodec},
    {sipName_setChannelCount, meth_QMediaResource_setChannelCount, METH_VARARGS, doc_QMediaResource_setChannelCount},
    {sipName_setDataSize, meth_QMediaResource_setDataSize, METH_VARARGS, doc_QMediaResource_setDataSize},
    {sipName_setLanguage, meth_QMediaResource_setLanguage, METH_VARARGS, doc_QMediaResource_setLanguage},
    {sipName_setResolution, meth_QMediaResource_setResolution, METH_VARARGS, doc_QMediaResource_setResolution},
    {sipName_setSampleRate, meth_QMediaResource_setSampleRate, METH_VARARGS, doc_QMediaResource_setSampleRate},
    {sipName_setVideoBitRate, meth_QMediaResource_setVideoBitRate, METH_VARARGS, doc_QMediaResource_setVideoBitRate},
    {sipName_setVideoCodec, meth_QMediaResource_setVideoCodec, METH_VARARGS, doc_QMediaResource_setVideoCodec},
    {sipName_url, meth_QMediaResource_url, METH_VARARGS, doc_QMediaResource_url},
    {sipName_videoBitRate, meth_QMediaResource_videoBitRate, METH_VARARGS, doc_QMediaResource_videoBitRate},
    {sipName_videoCodec, meth_QMediaResource_videoCodec, METH_VARARGS, doc_QMediaResource_videoCodec}
};

PyDoc_STRVAR(doc_QMediaResource, "\1QMediaResource()\n"
"QMediaResource(url: QUrl, mimeType: Optional[str] = '')\n"
"QMediaResource(request: QNetworkRequest, mimeType: Optional[str] = '')\n"
"QMediaResource(other: QMediaResource)");


static pyqt5ClassPluginDef plugin_QMediaResource = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QMediaResource = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QMediaResource,
        SIP_NULLPTR,
        &plugin_QMediaResource,
    },
    {
        sipNameNr_QMediaResource,
        {0, 0, 1},
        22, methods_QMediaResource,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QMediaResource,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QMediaResource,
    init_type_QMediaResource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QMediaResource,
    assign_QMediaResource,
    array_QMediaResource,
    copy_QMediaResource,
    release_QMediaResource,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QMediaResource,
    sizeof (::QMediaResource),
};
