/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoroutingmanagerengine.sip"
#include <qgeoroutingmanagerengine.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"

#line 24 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoroutereply.sip"
#include <qgeoroutereply.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoroute.sip"
#include <qgeoroute.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeocoordinate.sip"
#include <qgeocoordinate.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRoutingManagerEngine.cpp"


class sipQGeoRoutingManagerEngine : public ::QGeoRoutingManagerEngine
{
public:
    sipQGeoRoutingManagerEngine(const ::QVariantMap&, ::QObject*);
    virtual ~sipQGeoRoutingManagerEngine();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QGeoRouteReply* updateRoute(const ::QGeoRoute&, const ::QGeoCoordinate&) SIP_OVERRIDE;
    ::QGeoRouteReply* calculateRoute(const ::QGeoRouteRequest&) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQGeoRoutingManagerEngine(const sipQGeoRoutingManagerEngine &);
    sipQGeoRoutingManagerEngine &operator = (const sipQGeoRoutingManagerEngine &);

    char sipPyMethods[9];
};

sipQGeoRoutingManagerEngine::sipQGeoRoutingManagerEngine(const ::QVariantMap& a0, ::QObject*a1): ::QGeoRoutingManagerEngine(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGeoRoutingManagerEngine::~sipQGeoRoutingManagerEngine()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQGeoRoutingManagerEngine::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtLocation_qt_metaobject(sipPySelf, sipType_QGeoRoutingManagerEngine);

    return ::QGeoRoutingManagerEngine::metaObject();
}

int sipQGeoRoutingManagerEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QGeoRoutingManagerEngine::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtLocation_qt_metacall(sipPySelf, sipType_QGeoRoutingManagerEngine, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQGeoRoutingManagerEngine::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtLocation_qt_metacast(sipPySelf, sipType_QGeoRoutingManagerEngine, _clname, &sipCpp) ? sipCpp : ::QGeoRoutingManagerEngine::qt_metacast(_clname));
}

::QGeoRouteReply* sipQGeoRoutingManagerEngine::updateRoute(const ::QGeoRoute& a0, const ::QGeoCoordinate& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_updateRoute);

    if (!sipMeth)
        return ::QGeoRoutingManagerEngine::updateRoute(a0, a1);

    extern ::QGeoRouteReply* sipVH_QtLocation_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGeoRoute&, const ::QGeoCoordinate&);

    return sipVH_QtLocation_11(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QGeoRouteReply* sipQGeoRoutingManagerEngine::calculateRoute(const ::QGeoRouteRequest& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, sipName_QGeoRoutingManagerEngine, sipName_calculateRoute);

    if (!sipMeth)
        return 0;

    extern ::QGeoRouteReply* sipVH_QtLocation_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QGeoRouteRequest&);

    return sipVH_QtLocation_10(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGeoRoutingManagerEngine::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QGeoRoutingManagerEngine::event(a0);

    extern bool sipVH_QtLocation_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtLocation_5(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGeoRoutingManagerEngine::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QGeoRoutingManagerEngine::eventFilter(a0, a1);

    extern bool sipVH_QtLocation_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtLocation_4(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQGeoRoutingManagerEngine::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QGeoRoutingManagerEngine::timerEvent(a0);
        return;
    }

    extern void sipVH_QtLocation_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtLocation_3(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoRoutingManagerEngine::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QGeoRoutingManagerEngine::childEvent(a0);
        return;
    }

    extern void sipVH_QtLocation_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtLocation_2(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoRoutingManagerEngine::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QGeoRoutingManagerEngine::customEvent(a0);
        return;
    }

    extern void sipVH_QtLocation_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtLocation_1(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoRoutingManagerEngine::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QGeoRoutingManagerEngine::connectNotify(a0);
        return;
    }

    extern void sipVH_QtLocation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtLocation_0(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGeoRoutingManagerEngine::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QGeoRoutingManagerEngine::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtLocation_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtLocation_0(sipGILState, sipImportedVirtErrorHandlers_QtLocation_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_managerName, "managerName(self) -> str");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_managerName(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_managerName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->managerName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_managerName, doc_QGeoRoutingManagerEngine_managerName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_managerVersion, "managerVersion(self) -> int");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_managerVersion(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_managerVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->managerVersion();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_managerVersion, doc_QGeoRoutingManagerEngine_managerVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_calculateRoute, "calculateRoute(self, request: QGeoRouteRequest) -> Optional[QGeoRouteReply]");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_calculateRoute(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_calculateRoute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QGeoRouteRequest* a0;
        ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp, sipType_QGeoRouteRequest, &a0))
        {
            ::QGeoRouteReply*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QGeoRoutingManagerEngine, sipName_calculateRoute);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->calculateRoute(*a0);

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_calculateRoute, doc_QGeoRoutingManagerEngine_calculateRoute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_updateRoute, "updateRoute(self, route: QGeoRoute, position: QGeoCoordinate) -> Optional[QGeoRouteReply]");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_updateRoute(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_updateRoute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QGeoRoute* a0;
        const ::QGeoCoordinate* a1;
        ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp, sipType_QGeoRoute, &a0, sipType_QGeoCoordinate, &a1))
        {
            ::QGeoRouteReply*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QGeoRoutingManagerEngine::updateRoute(*a0, *a1) : sipCpp->updateRoute(*a0, *a1));

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_updateRoute, doc_QGeoRoutingManagerEngine_updateRoute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_supportedTravelModes, "supportedTravelModes(self) -> QGeoRouteRequest.TravelModes");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_supportedTravelModes(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_supportedTravelModes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp))
        {
            ::QGeoRouteRequest::TravelModes*sipRes;

            sipRes = new ::QGeoRouteRequest::TravelModes(sipCpp->supportedTravelModes());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_TravelModes, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_supportedTravelModes, doc_QGeoRoutingManagerEngine_supportedTravelModes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_supportedFeatureTypes, "supportedFeatureTypes(self) -> QGeoRouteRequest.FeatureTypes");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_supportedFeatureTypes(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_supportedFeatureTypes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp))
        {
            ::QGeoRouteRequest::FeatureTypes*sipRes;

            sipRes = new ::QGeoRouteRequest::FeatureTypes(sipCpp->supportedFeatureTypes());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_FeatureTypes, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_supportedFeatureTypes, doc_QGeoRoutingManagerEngine_supportedFeatureTypes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_supportedFeatureWeights, "supportedFeatureWeights(self) -> QGeoRouteRequest.FeatureWeights");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_supportedFeatureWeights(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_supportedFeatureWeights(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp))
        {
            ::QGeoRouteRequest::FeatureWeights*sipRes;

            sipRes = new ::QGeoRouteRequest::FeatureWeights(sipCpp->supportedFeatureWeights());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_FeatureWeights, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_supportedFeatureWeights, doc_QGeoRoutingManagerEngine_supportedFeatureWeights);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_supportedRouteOptimizations, "supportedRouteOptimizations(self) -> QGeoRouteRequest.RouteOptimizations");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_supportedRouteOptimizations(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_supportedRouteOptimizations(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp))
        {
            ::QGeoRouteRequest::RouteOptimizations*sipRes;

            sipRes = new ::QGeoRouteRequest::RouteOptimizations(sipCpp->supportedRouteOptimizations());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_RouteOptimizations, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_supportedRouteOptimizations, doc_QGeoRoutingManagerEngine_supportedRouteOptimizations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_supportedSegmentDetails, "supportedSegmentDetails(self) -> QGeoRouteRequest.SegmentDetails");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_supportedSegmentDetails(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_supportedSegmentDetails(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp))
        {
            ::QGeoRouteRequest::SegmentDetails*sipRes;

            sipRes = new ::QGeoRouteRequest::SegmentDetails(sipCpp->supportedSegmentDetails());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_SegmentDetails, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_supportedSegmentDetails, doc_QGeoRoutingManagerEngine_supportedSegmentDetails);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_supportedManeuverDetails, "supportedManeuverDetails(self) -> QGeoRouteRequest.ManeuverDetails");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_supportedManeuverDetails(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_supportedManeuverDetails(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp))
        {
            ::QGeoRouteRequest::ManeuverDetails*sipRes;

            sipRes = new ::QGeoRouteRequest::ManeuverDetails(sipCpp->supportedManeuverDetails());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_ManeuverDetails, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_supportedManeuverDetails, doc_QGeoRoutingManagerEngine_supportedManeuverDetails);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_setLocale, "setLocale(self, locale: QLocale)");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_setLocale(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_setLocale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale* a0;
        ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp, sipType_QLocale, &a0))
        {
            sipCpp->setLocale(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_setLocale, doc_QGeoRoutingManagerEngine_setLocale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_locale, "locale(self) -> QLocale");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_locale(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_locale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp))
        {
            ::QLocale*sipRes;

            sipRes = new ::QLocale(sipCpp->locale());

            return sipConvertFromNewType(sipRes, sipType_QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_locale, doc_QGeoRoutingManagerEngine_locale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_setMeasurementSystem, "setMeasurementSystem(self, system: QLocale.MeasurementSystem)");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_setMeasurementSystem(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_setMeasurementSystem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::MeasurementSystem a0;
        ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp, sipType_QLocale_MeasurementSystem, &a0))
        {
            sipCpp->setMeasurementSystem(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_setMeasurementSystem, doc_QGeoRoutingManagerEngine_setMeasurementSystem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_measurementSystem, "measurementSystem(self) -> QLocale.MeasurementSystem");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_measurementSystem(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_measurementSystem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp))
        {
            ::QLocale::MeasurementSystem sipRes;

            sipRes = sipCpp->measurementSystem();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocale_MeasurementSystem);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_measurementSystem, doc_QGeoRoutingManagerEngine_measurementSystem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_setSupportedTravelModes, "setSupportedTravelModes(self, travelModes: Union[QGeoRouteRequest.TravelModes, QGeoRouteRequest.TravelMode])");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_setSupportedTravelModes(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_setSupportedTravelModes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::TravelModes* a0;
        int a0State = 0;
        ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp, sipType_QGeoRouteRequest_TravelModes, &a0, &a0State))
        {
            sipCpp->setSupportedTravelModes(*a0);
            sipReleaseType(a0, sipType_QGeoRouteRequest_TravelModes, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_setSupportedTravelModes, doc_QGeoRoutingManagerEngine_setSupportedTravelModes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_setSupportedFeatureTypes, "setSupportedFeatureTypes(self, featureTypes: Union[QGeoRouteRequest.FeatureTypes, QGeoRouteRequest.FeatureType])");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_setSupportedFeatureTypes(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_setSupportedFeatureTypes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::FeatureTypes* a0;
        int a0State = 0;
        ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp, sipType_QGeoRouteRequest_FeatureTypes, &a0, &a0State))
        {
            sipCpp->setSupportedFeatureTypes(*a0);
            sipReleaseType(a0, sipType_QGeoRouteRequest_FeatureTypes, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_setSupportedFeatureTypes, doc_QGeoRoutingManagerEngine_setSupportedFeatureTypes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_setSupportedFeatureWeights, "setSupportedFeatureWeights(self, featureWeights: Union[QGeoRouteRequest.FeatureWeights, QGeoRouteRequest.FeatureWeight])");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_setSupportedFeatureWeights(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_setSupportedFeatureWeights(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::FeatureWeights* a0;
        int a0State = 0;
        ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp, sipType_QGeoRouteRequest_FeatureWeights, &a0, &a0State))
        {
            sipCpp->setSupportedFeatureWeights(*a0);
            sipReleaseType(a0, sipType_QGeoRouteRequest_FeatureWeights, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_setSupportedFeatureWeights, doc_QGeoRoutingManagerEngine_setSupportedFeatureWeights);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_setSupportedRouteOptimizations, "setSupportedRouteOptimizations(self, optimizations: Union[QGeoRouteRequest.RouteOptimizations, QGeoRouteRequest.RouteOptimization])");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_setSupportedRouteOptimizations(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_setSupportedRouteOptimizations(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::RouteOptimizations* a0;
        int a0State = 0;
        ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp, sipType_QGeoRouteRequest_RouteOptimizations, &a0, &a0State))
        {
            sipCpp->setSupportedRouteOptimizations(*a0);
            sipReleaseType(a0, sipType_QGeoRouteRequest_RouteOptimizations, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_setSupportedRouteOptimizations, doc_QGeoRoutingManagerEngine_setSupportedRouteOptimizations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_setSupportedSegmentDetails, "setSupportedSegmentDetails(self, segmentDetails: Union[QGeoRouteRequest.SegmentDetails, QGeoRouteRequest.SegmentDetail])");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_setSupportedSegmentDetails(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_setSupportedSegmentDetails(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::SegmentDetails* a0;
        int a0State = 0;
        ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp, sipType_QGeoRouteRequest_SegmentDetails, &a0, &a0State))
        {
            sipCpp->setSupportedSegmentDetails(*a0);
            sipReleaseType(a0, sipType_QGeoRouteRequest_SegmentDetails, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_setSupportedSegmentDetails, doc_QGeoRoutingManagerEngine_setSupportedSegmentDetails);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRoutingManagerEngine_setSupportedManeuverDetails, "setSupportedManeuverDetails(self, maneuverDetails: Union[QGeoRouteRequest.ManeuverDetails, QGeoRouteRequest.ManeuverDetail])");

extern "C" {static PyObject *meth_QGeoRoutingManagerEngine_setSupportedManeuverDetails(PyObject *, PyObject *);}
static PyObject *meth_QGeoRoutingManagerEngine_setSupportedManeuverDetails(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::ManeuverDetails* a0;
        int a0State = 0;
        ::QGeoRoutingManagerEngine *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QGeoRoutingManagerEngine, &sipCpp, sipType_QGeoRouteRequest_ManeuverDetails, &a0, &a0State))
        {
            sipCpp->setSupportedManeuverDetails(*a0);
            sipReleaseType(a0, sipType_QGeoRouteRequest_ManeuverDetails, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_setSupportedManeuverDetails, doc_QGeoRoutingManagerEngine_setSupportedManeuverDetails);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGeoRoutingManagerEngine(void *, const sipTypeDef *);}
static void *cast_QGeoRoutingManagerEngine(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGeoRoutingManagerEngine *sipCpp = reinterpret_cast< ::QGeoRoutingManagerEngine *>(sipCppV);

    if (targetType == sipType_QGeoRoutingManagerEngine)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoRoutingManagerEngine(void *, int);}
static void release_QGeoRoutingManagerEngine(void *sipCppV, int)
{
    ::QGeoRoutingManagerEngine *sipCpp = reinterpret_cast< ::QGeoRoutingManagerEngine *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QGeoRoutingManagerEngine(sipSimpleWrapper *);}
static void dealloc_QGeoRoutingManagerEngine(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQGeoRoutingManagerEngine *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoRoutingManagerEngine(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QGeoRoutingManagerEngine(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoRoutingManagerEngine(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQGeoRoutingManagerEngine *sipCpp = SIP_NULLPTR;

    {
        const ::QVariantMap* a0;
        int a0State = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QVariantMap, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQGeoRoutingManagerEngine(*a0, a1);
            sipReleaseType(const_cast< ::QVariantMap *>(a0), sipType_QVariantMap, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGeoRoutingManagerEngine[] = {{7, 0, 1}};


static PyMethodDef methods_QGeoRoutingManagerEngine[] = {
    {sipName_calculateRoute, meth_QGeoRoutingManagerEngine_calculateRoute, METH_VARARGS, doc_QGeoRoutingManagerEngine_calculateRoute},
    {sipName_locale, meth_QGeoRoutingManagerEngine_locale, METH_VARARGS, doc_QGeoRoutingManagerEngine_locale},
    {sipName_managerName, meth_QGeoRoutingManagerEngine_managerName, METH_VARARGS, doc_QGeoRoutingManagerEngine_managerName},
    {sipName_managerVersion, meth_QGeoRoutingManagerEngine_managerVersion, METH_VARARGS, doc_QGeoRoutingManagerEngine_managerVersion},
    {sipName_measurementSystem, meth_QGeoRoutingManagerEngine_measurementSystem, METH_VARARGS, doc_QGeoRoutingManagerEngine_measurementSystem},
    {sipName_setLocale, meth_QGeoRoutingManagerEngine_setLocale, METH_VARARGS, doc_QGeoRoutingManagerEngine_setLocale},
    {sipName_setMeasurementSystem, meth_QGeoRoutingManagerEngine_setMeasurementSystem, METH_VARARGS, doc_QGeoRoutingManagerEngine_setMeasurementSystem},
    {sipName_setSupportedFeatureTypes, meth_QGeoRoutingManagerEngine_setSupportedFeatureTypes, METH_VARARGS, doc_QGeoRoutingManagerEngine_setSupportedFeatureTypes},
    {sipName_setSupportedFeatureWeights, meth_QGeoRoutingManagerEngine_setSupportedFeatureWeights, METH_VARARGS, doc_QGeoRoutingManagerEngine_setSupportedFeatureWeights},
    {sipName_setSupportedManeuverDetails, meth_QGeoRoutingManagerEngine_setSupportedManeuverDetails, METH_VARARGS, doc_QGeoRoutingManagerEngine_setSupportedManeuverDetails},
    {sipName_setSupportedRouteOptimizations, meth_QGeoRoutingManagerEngine_setSupportedRouteOptimizations, METH_VARARGS, doc_QGeoRoutingManagerEngine_setSupportedRouteOptimizations},
    {sipName_setSupportedSegmentDetails, meth_QGeoRoutingManagerEngine_setSupportedSegmentDetails, METH_VARARGS, doc_QGeoRoutingManagerEngine_setSupportedSegmentDetails},
    {sipName_setSupportedTravelModes, meth_QGeoRoutingManagerEngine_setSupportedTravelModes, METH_VARARGS, doc_QGeoRoutingManagerEngine_setSupportedTravelModes},
    {sipName_supportedFeatureTypes, meth_QGeoRoutingManagerEngine_supportedFeatureTypes, METH_VARARGS, doc_QGeoRoutingManagerEngine_supportedFeatureTypes},
    {sipName_supportedFeatureWeights, meth_QGeoRoutingManagerEngine_supportedFeatureWeights, METH_VARARGS, doc_QGeoRoutingManagerEngine_supportedFeatureWeights},
    {sipName_supportedManeuverDetails, meth_QGeoRoutingManagerEngine_supportedManeuverDetails, METH_VARARGS, doc_QGeoRoutingManagerEngine_supportedManeuverDetails},
    {sipName_supportedRouteOptimizations, meth_QGeoRoutingManagerEngine_supportedRouteOptimizations, METH_VARARGS, doc_QGeoRoutingManagerEngine_supportedRouteOptimizations},
    {sipName_supportedSegmentDetails, meth_QGeoRoutingManagerEngine_supportedSegmentDetails, METH_VARARGS, doc_QGeoRoutingManagerEngine_supportedSegmentDetails},
    {sipName_supportedTravelModes, meth_QGeoRoutingManagerEngine_supportedTravelModes, METH_VARARGS, doc_QGeoRoutingManagerEngine_supportedTravelModes},
    {sipName_updateRoute, meth_QGeoRoutingManagerEngine_updateRoute, METH_VARARGS, doc_QGeoRoutingManagerEngine_updateRoute}
};

PyDoc_STRVAR(doc_QGeoRoutingManagerEngine, "\1QGeoRoutingManagerEngine(parameters: dict[str, Any], parent: Optional[QObject] = None)");


extern "C" {static int emit_QGeoRoutingManagerEngine_error(void *, PyObject *);}

static int emit_QGeoRoutingManagerEngine_error(void *sipCppV, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    ::QGeoRoutingManagerEngine *sipCpp = reinterpret_cast< ::QGeoRoutingManagerEngine *>(sipCppV);

    {
        ::QGeoRouteReply* a0;
        ::QGeoRouteReply::Error a1;
        ::QString a2def = QString();
        ::QString* a2 = &a2def;
        int a2State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8E|J1", sipType_QGeoRouteReply, &a0, sipType_QGeoRouteReply_Error, &a1, sipType_QString, &a2, &a2State))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->error(a0, a1, *a2);
            Py_END_ALLOW_THREADS

            sipReleaseType(a2, sipType_QString, a2State);

            return 0;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRoutingManagerEngine, sipName_error, SIP_NULLPTR);

    return -1;
}


/* Define this type's signals. */
static const pyqt5QtSignal signals_QGeoRoutingManagerEngine[] = {
    {"error(QGeoRouteReply*,QGeoRouteReply::Error,QString)", "\1error(self, reply: Optional[QGeoRouteReply], error: QGeoRouteReply.Error, errorString: Optional[str] = '')", SIP_NULLPTR, emit_QGeoRoutingManagerEngine_error},
    {"finished(QGeoRouteReply*)", "\1finished(self, reply: Optional[QGeoRouteReply])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QGeoRoutingManagerEngine = {
    &::QGeoRoutingManagerEngine::staticMetaObject,
    0,
    signals_QGeoRoutingManagerEngine,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QGeoRoutingManagerEngine = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoRoutingManagerEngine,
        SIP_NULLPTR,
        &plugin_QGeoRoutingManagerEngine,
    },
    {
        sipNameNr_QGeoRoutingManagerEngine,
        {0, 0, 1},
        20, methods_QGeoRoutingManagerEngine,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoRoutingManagerEngine,
    -1,
    -1,
    supers_QGeoRoutingManagerEngine,
    SIP_NULLPTR,
    init_type_QGeoRoutingManagerEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoRoutingManagerEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QGeoRoutingManagerEngine,
    cast_QGeoRoutingManagerEngine,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QGeoRoutingManagerEngine),
};
