/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQml.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtQml/qqmlparserstatus.sip"
#include <qqmlparserstatus.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtQml/sipQtQmlQQmlParserStatus.cpp"



class sipQQmlParserStatus : public ::QQmlParserStatus
{
public:
    sipQQmlParserStatus();
    sipQQmlParserStatus(const ::QQmlParserStatus&);
    virtual ~sipQQmlParserStatus();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void componentComplete() SIP_OVERRIDE;
    void classBegin() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQQmlParserStatus(const sipQQmlParserStatus &);
    sipQQmlParserStatus &operator = (const sipQQmlParserStatus &);

    char sipPyMethods[2];
};

sipQQmlParserStatus::sipQQmlParserStatus(): ::QQmlParserStatus(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlParserStatus::sipQQmlParserStatus(const ::QQmlParserStatus& a0): ::QQmlParserStatus(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQQmlParserStatus::~sipQQmlParserStatus()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

void sipQQmlParserStatus::componentComplete()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, sipName_QQmlParserStatus, sipName_componentComplete);

    if (!sipMeth)
        return;

    extern void sipVH_QtQml_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQml_8(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQQmlParserStatus::classBegin()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, sipName_QQmlParserStatus, sipName_classBegin);

    if (!sipMeth)
        return;

    extern void sipVH_QtQml_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtQml_8(sipGILState, sipImportedVirtErrorHandlers_QtQml_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QQmlParserStatus_classBegin, "classBegin(self)");

extern "C" {static PyObject *meth_QQmlParserStatus_classBegin(PyObject *, PyObject *);}
static PyObject *meth_QQmlParserStatus_classBegin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QQmlParserStatus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlParserStatus, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QQmlParserStatus, sipName_classBegin);
                return SIP_NULLPTR;
            }

            sipCpp->classBegin();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlParserStatus, sipName_classBegin, doc_QQmlParserStatus_classBegin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QQmlParserStatus_componentComplete, "componentComplete(self)");

extern "C" {static PyObject *meth_QQmlParserStatus_componentComplete(PyObject *, PyObject *);}
static PyObject *meth_QQmlParserStatus_componentComplete(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QQmlParserStatus *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QQmlParserStatus, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QQmlParserStatus, sipName_componentComplete);
                return SIP_NULLPTR;
            }

            sipCpp->componentComplete();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QQmlParserStatus, sipName_componentComplete, doc_QQmlParserStatus_componentComplete);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QQmlParserStatus(void *, int);}
static void release_QQmlParserStatus(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQQmlParserStatus *>(sipCppV);
    else
        delete reinterpret_cast< ::QQmlParserStatus *>(sipCppV);
}


extern "C" {static int mixin_QQmlParserStatus(PyObject *, PyObject *, PyObject *);}
static int mixin_QQmlParserStatus(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    return sipInitMixin(sipSelf, sipArgs, sipKwds, (sipClassTypeDef *)&sipTypeDef_QtQml_QQmlParserStatus);
}


extern "C" {static void dealloc_QQmlParserStatus(sipSimpleWrapper *);}
static void dealloc_QQmlParserStatus(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQQmlParserStatus *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QQmlParserStatus(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QQmlParserStatus(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QQmlParserStatus(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQQmlParserStatus *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQQmlParserStatus();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QQmlParserStatus* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QQmlParserStatus, &a0))
        {
            sipCpp = new sipQQmlParserStatus(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QQmlParserStatus[] = {
    {sipName_classBegin, meth_QQmlParserStatus_classBegin, METH_VARARGS, doc_QQmlParserStatus_classBegin},
    {sipName_componentComplete, meth_QQmlParserStatus_componentComplete, METH_VARARGS, doc_QQmlParserStatus_componentComplete}
};

PyDoc_STRVAR(doc_QQmlParserStatus, "\1QQmlParserStatus()\n"
"QQmlParserStatus(a0: QQmlParserStatus)");


static pyqt5ClassPluginDef plugin_QQmlParserStatus = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    "org.qt-project.Qt.QQmlParserStatus"
};


sipClassTypeDef sipTypeDef_QtQml_QQmlParserStatus = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QQmlParserStatus,
        SIP_NULLPTR,
        &plugin_QQmlParserStatus,
    },
    {
        sipNameNr_QQmlParserStatus,
        {0, 0, 1},
        2, methods_QQmlParserStatus,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QQmlParserStatus,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QQmlParserStatus,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QQmlParserStatus,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QQmlParserStatus,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    mixin_QQmlParserStatus,
    SIP_NULLPTR,
    sizeof (::QQmlParserStatus),
};
