/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtXmlPatterns.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qabstractxmlnodemodel.sip"
#include <qabstractxmlnodemodel.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlNodeModelIndex.cpp"

#line 76 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qabstractxmlnodemodel.sip"
#include <qabstractxmlnodemodel.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlNodeModelIndex.cpp"


PyDoc_STRVAR(doc_QXmlNodeModelIndex_data, "data(self) -> int");

extern "C" {static PyObject *meth_QXmlNodeModelIndex_data(PyObject *, PyObject *);}
static PyObject *meth_QXmlNodeModelIndex_data(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlNodeModelIndex *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlNodeModelIndex, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->data();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlNodeModelIndex, sipName_data, doc_QXmlNodeModelIndex_data);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlNodeModelIndex_internalPointer, "internalPointer(self) -> Any");

extern "C" {static PyObject *meth_QXmlNodeModelIndex_internalPointer(PyObject *, PyObject *);}
static PyObject *meth_QXmlNodeModelIndex_internalPointer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlNodeModelIndex *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlNodeModelIndex, &sipCpp))
        {
            PyObject * sipRes = SIP_NULLPTR;

#line 56 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qabstractxmlnodemodel.sip"
        sipRes = reinterpret_cast<PyObject *>(sipCpp->internalPointer());
        
        if (!sipRes)
            sipRes = Py_None;
        
        Py_INCREF(sipRes);
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlNodeModelIndex.cpp"

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlNodeModelIndex, sipName_internalPointer, doc_QXmlNodeModelIndex_internalPointer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlNodeModelIndex_model, "model(self) -> Optional[QAbstractXmlNodeModel]");

extern "C" {static PyObject *meth_QXmlNodeModelIndex_model(PyObject *, PyObject *);}
static PyObject *meth_QXmlNodeModelIndex_model(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlNodeModelIndex *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlNodeModelIndex, &sipCpp))
        {
            const ::QAbstractXmlNodeModel*sipRes;

            sipRes = sipCpp->model();

            return sipConvertFromType(const_cast< ::QAbstractXmlNodeModel *>(sipRes), sipType_QAbstractXmlNodeModel, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlNodeModelIndex, sipName_model, doc_QXmlNodeModelIndex_model);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlNodeModelIndex_additionalData, "additionalData(self) -> int");

extern "C" {static PyObject *meth_QXmlNodeModelIndex_additionalData(PyObject *, PyObject *);}
static PyObject *meth_QXmlNodeModelIndex_additionalData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlNodeModelIndex *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlNodeModelIndex, &sipCpp))
        {
            ::qint64 sipRes;

            sipRes = sipCpp->additionalData();

            return PyLong_FromLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlNodeModelIndex, sipName_additionalData, doc_QXmlNodeModelIndex_additionalData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QXmlNodeModelIndex_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QXmlNodeModelIndex_isNull(PyObject *, PyObject *);}
static PyObject *meth_QXmlNodeModelIndex_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlNodeModelIndex *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QXmlNodeModelIndex, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QXmlNodeModelIndex, sipName_isNull, doc_QXmlNodeModelIndex_isNull);

    return SIP_NULLPTR;
}


extern "C" {static long slot_QXmlNodeModelIndex___hash__(PyObject *);}
static long slot_QXmlNodeModelIndex___hash__(PyObject *sipSelf)
{
    ::QXmlNodeModelIndex *sipCpp = reinterpret_cast< ::QXmlNodeModelIndex *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QXmlNodeModelIndex));

    if (!sipCpp)
        return 0L;


    {
        {
            long sipRes = 0;

#line 69 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXmlPatterns/qabstractxmlnodemodel.sip"
        sipRes = qHash(*sipCpp);
#line 188 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXmlPatterns/sipQtXmlPatternsQXmlNodeModelIndex.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QXmlNodeModelIndex___ne__(PyObject *, PyObject *);}
static PyObject *slot_QXmlNodeModelIndex___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QXmlNodeModelIndex *sipCpp = reinterpret_cast< ::QXmlNodeModelIndex *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QXmlNodeModelIndex));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlNodeModelIndex* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QXmlNodeModelIndex, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QXmlNodeModelIndex::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtXmlPatterns, ne_slot, sipType_QXmlNodeModelIndex, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QXmlNodeModelIndex___eq__(PyObject *, PyObject *);}
static PyObject *slot_QXmlNodeModelIndex___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QXmlNodeModelIndex *sipCpp = reinterpret_cast< ::QXmlNodeModelIndex *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QXmlNodeModelIndex));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QXmlNodeModelIndex* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QXmlNodeModelIndex, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QXmlNodeModelIndex::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtXmlPatterns, eq_slot, sipType_QXmlNodeModelIndex, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QXmlNodeModelIndex(void *, int);}
static void release_QXmlNodeModelIndex(void *sipCppV, int)
{
    delete reinterpret_cast< ::QXmlNodeModelIndex *>(sipCppV);
}


extern "C" {static void *array_QXmlNodeModelIndex(Py_ssize_t);}
static void *array_QXmlNodeModelIndex(Py_ssize_t sipNrElem)
{
    return new ::QXmlNodeModelIndex[sipNrElem];
}


extern "C" {static void array_delete_QXmlNodeModelIndex(void *);}
static void array_delete_QXmlNodeModelIndex(void *sipCpp)
{
    delete[] reinterpret_cast< ::QXmlNodeModelIndex *>(sipCpp);
}


extern "C" {static void assign_QXmlNodeModelIndex(void *, Py_ssize_t, void *);}
static void assign_QXmlNodeModelIndex(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QXmlNodeModelIndex *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QXmlNodeModelIndex *>(sipSrc);
}


extern "C" {static void *copy_QXmlNodeModelIndex(const void *, Py_ssize_t);}
static void *copy_QXmlNodeModelIndex(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QXmlNodeModelIndex(reinterpret_cast<const ::QXmlNodeModelIndex *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QXmlNodeModelIndex(sipSimpleWrapper *);}
static void dealloc_QXmlNodeModelIndex(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QXmlNodeModelIndex(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QXmlNodeModelIndex(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QXmlNodeModelIndex(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QXmlNodeModelIndex *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QXmlNodeModelIndex();

            return sipCpp;
        }
    }

    {
        const ::QXmlNodeModelIndex* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QXmlNodeModelIndex, &a0))
        {
            sipCpp = new ::QXmlNodeModelIndex(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QXmlNodeModelIndex[] = {
    {(void *)slot_QXmlNodeModelIndex___hash__, hash_slot},
    {(void *)slot_QXmlNodeModelIndex___ne__, ne_slot},
    {(void *)slot_QXmlNodeModelIndex___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QXmlNodeModelIndex[] = {
    {sipName_additionalData, meth_QXmlNodeModelIndex_additionalData, METH_VARARGS, doc_QXmlNodeModelIndex_additionalData},
    {sipName_data, meth_QXmlNodeModelIndex_data, METH_VARARGS, doc_QXmlNodeModelIndex_data},
    {sipName_internalPointer, meth_QXmlNodeModelIndex_internalPointer, METH_VARARGS, doc_QXmlNodeModelIndex_internalPointer},
    {sipName_isNull, meth_QXmlNodeModelIndex_isNull, METH_VARARGS, doc_QXmlNodeModelIndex_isNull},
    {sipName_model, meth_QXmlNodeModelIndex_model, METH_VARARGS, doc_QXmlNodeModelIndex_model}
};

static sipEnumMemberDef enummembers_QXmlNodeModelIndex[] = {
    {sipName_Attribute, static_cast<int>(::QXmlNodeModelIndex::Attribute), 15},
    {sipName_Comment, static_cast<int>(::QXmlNodeModelIndex::Comment), 15},
    {sipName_Document, static_cast<int>(::QXmlNodeModelIndex::Document), 15},
    {sipName_Element, static_cast<int>(::QXmlNodeModelIndex::Element), 15},
    {sipName_Follows, static_cast<int>(::QXmlNodeModelIndex::Follows), 14},
    {sipName_Is, static_cast<int>(::QXmlNodeModelIndex::Is), 14},
    {sipName_Namespace, static_cast<int>(::QXmlNodeModelIndex::Namespace), 15},
    {sipName_Precedes, static_cast<int>(::QXmlNodeModelIndex::Precedes), 14},
    {sipName_ProcessingInstruction, static_cast<int>(::QXmlNodeModelIndex::ProcessingInstruction), 15},
    {sipName_Text, static_cast<int>(::QXmlNodeModelIndex::Text), 15},
};

PyDoc_STRVAR(doc_QXmlNodeModelIndex, "\1QXmlNodeModelIndex()\n"
"QXmlNodeModelIndex(other: QXmlNodeModelIndex)");


static pyqt5ClassPluginDef plugin_QXmlNodeModelIndex = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtXmlPatterns_QXmlNodeModelIndex = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QXmlNodeModelIndex,
        SIP_NULLPTR,
        &plugin_QXmlNodeModelIndex,
    },
    {
        sipNameNr_QXmlNodeModelIndex,
        {0, 0, 1},
        5, methods_QXmlNodeModelIndex,
        10, enummembers_QXmlNodeModelIndex,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QXmlNodeModelIndex,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QXmlNodeModelIndex,
    init_type_QXmlNodeModelIndex,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QXmlNodeModelIndex,
    assign_QXmlNodeModelIndex,
    array_QXmlNodeModelIndex,
    copy_QXmlNodeModelIndex,
    release_QXmlNodeModelIndex,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QXmlNodeModelIndex,
    sizeof (::QXmlNodeModelIndex),
};
