/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtHelpAPI_H
#define _QtHelpAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_horizontalScrollbarValueChanged 0
#define sipName_horizontalScrollbarValueChanged &sipStrings_QtHelp[0]
#define sipNameNr_verticalScrollbarValueChanged 32
#define sipName_verticalScrollbarValueChanged &sipStrings_QtHelp[32]
#define sipNameNr_62 62
#define sipName_62 &sipStrings_QtHelp[62]
#define sipNameNr_QHelpSearchQuery__FieldName 91
#define sipName_QHelpSearchQuery__FieldName &sipStrings_QtHelp[91]
#define sipNameNr_readersAboutToBeInvalidated 119
#define sipName_readersAboutToBeInvalidated &sipStrings_QtHelp[119]
#define sipNameNr_147 147
#define sipName_147 &sipStrings_QtHelp[147]
#define sipNameNr_QHelpFilterSettingsWidget 174
#define sipName_QHelpFilterSettingsWidget &sipStrings_QtHelp[174]
#define sipNameNr_horizontalScrollbarAction 200
#define sipName_horizontalScrollbarAction &sipStrings_QtHelp[200]
#define sipNameNr_registeredDocumentations 226
#define sipName_registeredDocumentations &sipStrings_QtHelp[226]
#define sipNameNr_visualRegionForSelection 251
#define sipName_visualRegionForSelection &sipStrings_QtHelp[251]
#define sipNameNr_QHelpSearchResultWidget 276
#define sipName_QHelpSearchResultWidget &sipStrings_QtHelp[276]
#define sipNameNr_300 300
#define sipName_300 &sipStrings_QtHelp[300]
#define sipNameNr_contentsCreationStarted 324
#define sipName_contentsCreationStarted &sipStrings_QtHelp[324]
#define sipNameNr_unregisterDocumentation 348
#define sipName_unregisterDocumentation &sipStrings_QtHelp[348]
#define sipNameNr_verticalScrollbarAction 372
#define sipName_verticalScrollbarAction &sipStrings_QtHelp[372]
#define sipNameNr_QHelpSearchQueryWidget 396
#define sipName_QHelpSearchQueryWidget &sipStrings_QtHelp[396]
#define sipNameNr_collapseExtendedSearch 419
#define sipName_collapseExtendedSearch &sipStrings_QtHelp[419]
#define sipNameNr_documentsForIdentifier 442
#define sipName_documentsForIdentifier &sipStrings_QtHelp[442]
#define sipNameNr_fromCompressedHelpFile 465
#define sipName_fromCompressedHelpFile &sipStrings_QtHelp[465]
#define sipNameNr_setAvailableComponents 488
#define sipName_setAvailableComponents &sipStrings_QtHelp[488]
#define sipNameNr_updateEditorGeometries 511
#define sipName_updateEditorGeometries &sipStrings_QtHelp[511]
#define sipNameNr_534 534
#define sipName_534 &sipStrings_QtHelp[534]
#define sipNameNr_556 556
#define sipName_556 &sipStrings_QtHelp[556]
#define sipNameNr_documentationFileName 578
#define sipName_documentationFileName &sipStrings_QtHelp[578]
#define sipNameNr_mouseDoubleClickEvent 600
#define sipName_mouseDoubleClickEvent &sipStrings_QtHelp[600]
#define sipNameNr_registerDocumentation 350
#define sipName_registerDocumentation &sipStrings_QtHelp[350]
#define sipNameNr_currentFilterChanged 622
#define sipName_currentFilterChanged &sipStrings_QtHelp[622]
#define sipNameNr_expandExtendedSearch 643
#define sipName_expandExtendedSearch &sipStrings_QtHelp[643]
#define sipNameNr_indexCreationStarted 664
#define sipName_indexCreationStarted &sipStrings_QtHelp[664]
#define sipNameNr_namespaceToComponent 685
#define sipName_namespaceToComponent &sipStrings_QtHelp[685]
#define sipNameNr_reindexDocumentation 706
#define sipName_reindexDocumentation &sipStrings_QtHelp[706]
#define sipNameNr_rowsAboutToBeRemoved 727
#define sipName_rowsAboutToBeRemoved &sipStrings_QtHelp[727]
#define sipNameNr_setAvailableVersions 748
#define sipName_setAvailableVersions &sipStrings_QtHelp[748]
#define sipNameNr_supportedDragActions 769
#define sipName_supportedDragActions &sipStrings_QtHelp[769]
#define sipNameNr_supportedDropActions 790
#define sipName_supportedDropActions &sipStrings_QtHelp[790]
#define sipNameNr_QCompressedHelpInfo 811
#define sipName_QCompressedHelpInfo &sipStrings_QtHelp[811]
#define sipNameNr_activateCurrentItem 831
#define sipName_activateCurrentItem &sipStrings_QtHelp[831]
#define sipNameNr_availableComponents 851
#define sipName_availableComponents &sipStrings_QtHelp[851]
#define sipNameNr_documentsForKeyword 871
#define sipName_documentsForKeyword &sipStrings_QtHelp[871]
#define sipNameNr_filterAttributeSets 891
#define sipName_filterAttributeSets &sipStrings_QtHelp[891]
#define sipNameNr_namespacesForFilter 911
#define sipName_namespacesForFilter &sipStrings_QtHelp[911]
#define sipNameNr_setUsesFilterEngine 931
#define sipName_setUsesFilterEngine &sipStrings_QtHelp[931]
#define sipNameNr_QHelpContentWidget 951
#define sipName_QHelpContentWidget &sipStrings_QtHelp[951]
#define sipNameNr_970 970
#define sipName_970 &sipStrings_QtHelp[970]
#define sipNameNr_989 989
#define sipName_989 &sipStrings_QtHelp[989]
#define sipNameNr_copyCollectionFile 1008
#define sipName_copyCollectionFile &sipStrings_QtHelp[1008]
#define sipNameNr_documentsActivated 1027
#define sipName_documentsActivated &sipStrings_QtHelp[1027]
#define sipNameNr_focusNextPrevChild 1046
#define sipName_focusNextPrevChild &sipStrings_QtHelp[1046]
#define sipNameNr_isCreatingContents 1065
#define sipName_isCreatingContents &sipStrings_QtHelp[1065]
#define sipNameNr_linksForIdentifier 1084
#define sipName_linksForIdentifier &sipStrings_QtHelp[1084]
#define sipNameNr_namespaceToVersion 1103
#define sipName_namespaceToVersion &sipStrings_QtHelp[1103]
#define sipNameNr_removeCustomFilter 1122
#define sipName_removeCustomFilter &sipStrings_QtHelp[1122]
#define sipNameNr_QHelpContentModel 1141
#define sipName_QHelpContentModel &sipStrings_QtHelp[1141]
#define sipNameNr_QHelpFilterEngine 1159
#define sipName_QHelpFilterEngine &sipStrings_QtHelp[1159]
#define sipNameNr_QHelpSearchEngine 1177
#define sipName_QHelpSearchEngine &sipStrings_QtHelp[1177]
#define sipNameNr_QHelpSearchResult 1195
#define sipName_QHelpSearchResult &sipStrings_QtHelp[1195]
#define sipNameNr_availableVersions 1213
#define sipName_availableVersions &sipStrings_QtHelp[1213]
#define sipNameNr_documentActivated 1231
#define sipName_documentActivated &sipStrings_QtHelp[1231]
#define sipNameNr_hasHeightForWidth 1249
#define sipName_hasHeightForWidth &sipStrings_QtHelp[1249]
#define sipNameNr_mouseReleaseEvent 1267
#define sipName_mouseReleaseEvent &sipStrings_QtHelp[1267]
#define sipNameNr_removeCustomValue 1285
#define sipName_removeCustomValue &sipStrings_QtHelp[1285]
#define sipNameNr_searchResultCount 1303
#define sipName_searchResultCount &sipStrings_QtHelp[1303]
#define sipNameNr_searchingFinished 1321
#define sipName_searchingFinished &sipStrings_QtHelp[1321]
#define sipNameNr_setAutoSaveFilter 1339
#define sipName_setAutoSaveFilter &sipStrings_QtHelp[1339]
#define sipNameNr_setCollectionFile 1357
#define sipName_setCollectionFile &sipStrings_QtHelp[1357]
#define sipNameNr_setSelectionModel 1375
#define sipName_setSelectionModel &sipStrings_QtHelp[1375]
#define sipNameNr_sip_simplewrapper 1393
#define sipName_sip_simplewrapper &sipStrings_QtHelp[1393]
#define sipNameNr_sizeHintForColumn 1411
#define sipName_sizeHintForColumn &sipStrings_QtHelp[1411]
#define sipNameNr_QHelpContentItem 1429
#define sipName_QHelpContentItem &sipStrings_QtHelp[1429]
#define sipNameNr_QHelpIndexWidget 1446
#define sipName_QHelpIndexWidget &sipStrings_QtHelp[1446]
#define sipNameNr_QHelpSearchQuery 1463
#define sipName_QHelpSearchQuery &sipStrings_QtHelp[1463]
#define sipNameNr_1480 1480
#define sipName_1480 &sipStrings_QtHelp[1480]
#define sipNameNr_contextMenuEvent 1497
#define sipName_contextMenuEvent &sipStrings_QtHelp[1497]
#define sipNameNr_disconnectNotify 1514
#define sipName_disconnectNotify &sipStrings_QtHelp[1514]
#define sipNameNr_filterAttributes 1531
#define sipName_filterAttributes &sipStrings_QtHelp[1531]
#define sipNameNr_horizontalOffset 1548
#define sipName_horizontalOffset &sipStrings_QtHelp[1548]
#define sipNameNr_indexingFinished 1565
#define sipName_indexingFinished &sipStrings_QtHelp[1565]
#define sipNameNr_inputMethodEvent 1582
#define sipName_inputMethodEvent &sipStrings_QtHelp[1582]
#define sipNameNr_inputMethodQuery 1599
#define sipName_inputMethodQuery &sipStrings_QtHelp[1599]
#define sipNameNr_scrollContentsBy 1616
#define sipName_scrollContentsBy &sipStrings_QtHelp[1616]
#define sipNameNr_searchingStarted 1633
#define sipName_searchingStarted &sipStrings_QtHelp[1633]
#define sipNameNr_selectionChanged 1650
#define sipName_selectionChanged &sipStrings_QtHelp[1650]
#define sipNameNr_selectionCommand 1667
#define sipName_selectionCommand &sipStrings_QtHelp[1667]
#define sipNameNr_setCurrentFilter 1684
#define sipName_setCurrentFilter &sipStrings_QtHelp[1684]
#define sipNameNr_updateEditorData 1701
#define sipName_updateEditorData &sipStrings_QtHelp[1701]
#define sipNameNr_updateGeometries 1718
#define sipName_updateGeometries &sipStrings_QtHelp[1718]
#define sipNameNr_usesFilterEngine 1735
#define sipName_usesFilterEngine &sipStrings_QtHelp[1735]
#define sipNameNr_viewportSizeHint 1752
#define sipName_viewportSizeHint &sipStrings_QtHelp[1752]
#define sipNameNr_QHelpEngineCore 1769
#define sipName_QHelpEngineCore &sipStrings_QtHelp[1769]
#define sipNameNr_QHelpFilterData 1785
#define sipName_QHelpFilterData &sipStrings_QtHelp[1785]
#define sipNameNr_QHelpIndexModel 1801
#define sipName_QHelpIndexModel &sipStrings_QtHelp[1801]
#define sipNameNr_addCustomFilter 1817
#define sipName_addCustomFilter &sipStrings_QtHelp[1817]
#define sipNameNr_canDropMimeData 1833
#define sipName_canDropMimeData &sipStrings_QtHelp[1833]
#define sipNameNr_cancelSearching 1849
#define sipName_cancelSearching &sipStrings_QtHelp[1849]
#define sipNameNr_contentsCreated 1865
#define sipName_contentsCreated &sipStrings_QtHelp[1865]
#define sipNameNr_editorDestroyed 1881
#define sipName_editorDestroyed &sipStrings_QtHelp[1881]
#define sipNameNr_extensionFilter 1897
#define sipName_extensionFilter &sipStrings_QtHelp[1897]
#define sipNameNr_filterActivated 1913
#define sipName_filterActivated &sipStrings_QtHelp[1913]
#define sipNameNr_indexingStarted 1929
#define sipName_indexingStarted &sipStrings_QtHelp[1929]
#define sipNameNr_isCreatingIndex 1945
#define sipName_isCreatingIndex &sipStrings_QtHelp[1945]
#define sipNameNr_keyReleaseEvent 1961
#define sipName_keyReleaseEvent &sipStrings_QtHelp[1961]
#define sipNameNr_linksForKeyword 1977
#define sipName_linksForKeyword &sipStrings_QtHelp[1977]
#define sipNameNr_minimumSizeHint 1993
#define sipName_minimumSizeHint &sipStrings_QtHelp[1993]
#define sipNameNr_mousePressEvent 2009
#define sipName_mousePressEvent &sipStrings_QtHelp[2009]
#define sipNameNr_requestShowLink 2025
#define sipName_requestShowLink &sipStrings_QtHelp[2025]
#define sipNameNr_selectedIndexes 2041
#define sipName_selectedIndexes &sipStrings_QtHelp[2041]
#define sipNameNr_setActiveFilter 2057
#define sipName_setActiveFilter &sipStrings_QtHelp[2057]
#define sipNameNr_autoSaveFilter 2073
#define sipName_autoSaveFilter &sipStrings_QtHelp[2073]
#define sipNameNr_cancelIndexing 2088
#define sipName_cancelIndexing &sipStrings_QtHelp[2088]
#define sipNameNr_collectionFile 2103
#define sipName_collectionFile &sipStrings_QtHelp[2103]
#define sipNameNr_createContents 2118
#define sipName_createContents &sipStrings_QtHelp[2118]
#define sipNameNr_currentChanged 2133
#define sipName_currentChanged &sipStrings_QtHelp[2133]
#define sipNameNr_dragEnterEvent 2148
#define sipName_dragEnterEvent &sipStrings_QtHelp[2148]
#define sipNameNr_dragLeaveEvent 2163
#define sipName_dragLeaveEvent &sipStrings_QtHelp[2163]
#define sipNameNr_heightForWidth 2178
#define sipName_heightForWidth &sipStrings_QtHelp[2178]
#define sipNameNr_keyboardSearch 2193
#define sipName_keyboardSearch &sipStrings_QtHelp[2193]
#define sipNameNr_linksActivated 2208
#define sipName_linksActivated &sipStrings_QtHelp[2208]
#define sipNameNr_mouseMoveEvent 2223
#define sipName_mouseMoveEvent &sipStrings_QtHelp[2223]
#define sipNameNr_setCompactMode 2238
#define sipName_setCompactMode &sipStrings_QtHelp[2238]
#define sipNameNr_setCustomValue 2253
#define sipName_setCustomValue &sipStrings_QtHelp[2253]
#define sipNameNr_setSearchInput 2268
#define sipName_setSearchInput &sipStrings_QtHelp[2268]
#define sipNameNr_sizeHintForRow 2283
#define sipName_sizeHintForRow &sipStrings_QtHelp[2283]
#define sipNameNr_verticalOffset 2298
#define sipName_verticalOffset &sipStrings_QtHelp[2298]
#define sipNameNr_applySettings 2313
#define sipName_applySettings &sipStrings_QtHelp[2313]
#define sipNameNr_childPosition 2327
#define sipName_childPosition &sipStrings_QtHelp[2327]
#define sipNameNr_connectNotify 1517
#define sipName_connectNotify &sipStrings_QtHelp[1517]
#define sipNameNr_contentItemAt 2341
#define sipName_contentItemAt &sipStrings_QtHelp[2341]
#define sipNameNr_contentWidget 2355
#define sipName_contentWidget &sipStrings_QtHelp[2355]
#define sipNameNr_currentFilter 2369
#define sipName_currentFilter &sipStrings_QtHelp[2369]
#define sipNameNr_customFilters 2383
#define sipName_customFilters &sipStrings_QtHelp[2383]
#define sipNameNr_dragMoveEvent 2397
#define sipName_dragMoveEvent &sipStrings_QtHelp[2397]
#define sipNameNr_filterIndices 2411
#define sipName_filterIndices &sipStrings_QtHelp[2411]
#define sipNameNr_focusOutEvent 2425
#define sipName_focusOutEvent &sipStrings_QtHelp[2425]
#define sipNameNr_insertColumns 2439
#define sipName_insertColumns &sipStrings_QtHelp[2439]
#define sipNameNr_isCompactMode 2453
#define sipName_isCompactMode &sipStrings_QtHelp[2453]
#define sipNameNr_isIndexHidden 2467
#define sipName_isIndexHidden &sipStrings_QtHelp[2467]
#define sipNameNr_keyPressEvent 2481
#define sipName_keyPressEvent &sipStrings_QtHelp[2481]
#define sipNameNr_linkActivated 2495
#define sipName_linkActivated &sipStrings_QtHelp[2495]
#define sipNameNr_namespaceName 2509
#define sipName_namespaceName &sipStrings_QtHelp[2509]
#define sipNameNr_removeColumns 2523
#define sipName_removeColumns &sipStrings_QtHelp[2523]
#define sipNameNr_searchResults 2537
#define sipName_searchResults &sipStrings_QtHelp[2537]
#define sipNameNr_setComponents 2551
#define sipName_setComponents &sipStrings_QtHelp[2551]
#define sipNameNr_setFilterData 2565
#define sipName_setFilterData &sipStrings_QtHelp[2565]
#define sipNameNr_setHeaderData 2579
#define sipName_setHeaderData &sipStrings_QtHelp[2579]
#define sipNameNr_setupFinished 2593
#define sipName_setupFinished &sipStrings_QtHelp[2593]
#define sipNameNr_setupViewport 2607
#define sipName_setupViewport &sipStrings_QtHelp[2607]
#define sipNameNr_sharedPainter 2621
#define sipName_sharedPainter &sipStrings_QtHelp[2621]
#define sipNameNr_viewportEvent 2635
#define sipName_viewportEvent &sipStrings_QtHelp[2635]
#define sipNameNr_PyQt5_QtHelp 2649
#define sipName_PyQt5_QtHelp &sipStrings_QtHelp[2649]
#define sipNameNr_activeFilter 2662
#define sipName_activeFilter &sipStrings_QtHelp[2662]
#define sipNameNr_canFetchMore 2675
#define sipName_canFetchMore &sipStrings_QtHelp[2675]
#define sipNameNr_contentModel 2688
#define sipName_contentModel &sipStrings_QtHelp[2688]
#define sipNameNr_defaultValue 2701
#define sipName_defaultValue &sipStrings_QtHelp[2701]
#define sipNameNr_drawBranches 2714
#define sipName_drawBranches &sipStrings_QtHelp[2714]
#define sipNameNr_dropMimeData 2727
#define sipName_dropMimeData &sipStrings_QtHelp[2727]
#define sipNameNr_filterEngine 2740
#define sipName_filterEngine &sipStrings_QtHelp[2740]
#define sipNameNr_focusInEvent 2753
#define sipName_focusInEvent &sipStrings_QtHelp[2753]
#define sipNameNr_indexCreated 2766
#define sipName_indexCreated &sipStrings_QtHelp[2766]
#define sipNameNr_readSettings 2779
#define sipName_readSettings &sipStrings_QtHelp[2779]
#define sipNameNr_removeFilter 2792
#define sipName_removeFilter &sipStrings_QtHelp[2792]
#define sipNameNr_resultWidget 2805
#define sipName_resultWidget &sipStrings_QtHelp[2805]
#define sipNameNr_rowsInserted 2818
#define sipName_rowsInserted &sipStrings_QtHelp[2818]
#define sipNameNr_searchEngine 2831
#define sipName_searchEngine &sipStrings_QtHelp[2831]
#define sipNameNr_setRootIndex 2844
#define sipName_setRootIndex &sipStrings_QtHelp[2844]
#define sipNameNr_setSelection 2857
#define sipName_setSelection &sipStrings_QtHelp[2857]
#define sipNameNr_setupStarted 2870
#define sipName_setupStarted &sipStrings_QtHelp[2870]
#define sipNameNr_QHelpEngine 2883
#define sipName_QHelpEngine &sipStrings_QtHelp[2883]
#define sipNameNr_actionEvent 2895
#define sipName_actionEvent &sipStrings_QtHelp[2895]
#define sipNameNr_changeEvent 2907
#define sipName_changeEvent &sipStrings_QtHelp[2907]
#define sipNameNr_closeEditor 2919
#define sipName_closeEditor &sipStrings_QtHelp[2919]
#define sipNameNr_columnCount 2931
#define sipName_columnCount &sipStrings_QtHelp[2931]
#define sipNameNr_createIndex 2943
#define sipName_createIndex &sipStrings_QtHelp[2943]
#define sipNameNr_customEvent 2955
#define sipName_customEvent &sipStrings_QtHelp[2955]
#define sipNameNr_customValue 2967
#define sipName_customValue &sipStrings_QtHelp[2967]
#define sipNameNr_dataChanged 2979
#define sipName_dataChanged &sipStrings_QtHelp[2979]
#define sipNameNr_eventFilter 2991
#define sipName_eventFilter &sipStrings_QtHelp[2991]
#define sipNameNr_hasChildren 3003
#define sipName_hasChildren &sipStrings_QtHelp[3003]
#define sipNameNr_indexWidget 3015
#define sipName_indexWidget &sipStrings_QtHelp[3015]
#define sipNameNr_initPainter 3027
#define sipName_initPainter &sipStrings_QtHelp[3027]
#define sipNameNr_moveColumns 2525
#define sipName_moveColumns &sipStrings_QtHelp[2525]
#define sipNameNr_nativeEvent 3039
#define sipName_nativeEvent &sipStrings_QtHelp[3039]
#define sipNameNr_paintEngine 3051
#define sipName_paintEngine &sipStrings_QtHelp[3051]
#define sipNameNr_queryWidget 3063
#define sipName_queryWidget &sipStrings_QtHelp[3063]
#define sipNameNr_resizeEvent 3075
#define sipName_resizeEvent &sipStrings_QtHelp[3075]
#define sipNameNr_searchInput 3087
#define sipName_searchInput &sipStrings_QtHelp[3087]
#define sipNameNr_setItemData 3099
#define sipName_setItemData &sipStrings_QtHelp[3099]
#define sipNameNr_setVersions 3111
#define sipName_setVersions &sipStrings_QtHelp[3111]
#define sipNameNr_tabletEvent 3123
#define sipName_tabletEvent &sipStrings_QtHelp[3123]
#define sipNameNr_viewOptions 3135
#define sipName_viewOptions &sipStrings_QtHelp[3135]
#define sipNameNr_childCount 3147
#define sipName_childCount &sipStrings_QtHelp[3147]
#define sipNameNr_childEvent 3158
#define sipName_childEvent &sipStrings_QtHelp[3158]
#define sipNameNr_closeEvent 3169
#define sipName_closeEvent &sipStrings_QtHelp[3169]
#define sipNameNr_commitData 3180
#define sipName_commitData &sipStrings_QtHelp[3180]
#define sipNameNr_components 3191
#define sipName_components &sipStrings_QtHelp[3191]
#define sipNameNr_enterEvent 3202
#define sipName_enterEvent &sipStrings_QtHelp[3202]
#define sipNameNr_filterData 3213
#define sipName_filterData &sipStrings_QtHelp[3213]
#define sipNameNr_headerData 3224
#define sipName_headerData &sipStrings_QtHelp[3224]
#define sipNameNr_helpEngine 3235
#define sipName_helpEngine &sipStrings_QtHelp[3235]
#define sipNameNr_indexModel 3246
#define sipName_indexModel &sipStrings_QtHelp[3246]
#define sipNameNr_insertRows 3257
#define sipName_insertRows &sipStrings_QtHelp[3257]
#define sipNameNr_leaveEvent 3268
#define sipName_leaveEvent &sipStrings_QtHelp[3268]
#define sipNameNr_moveCursor 3279
#define sipName_moveCursor &sipStrings_QtHelp[3279]
#define sipNameNr_paintEvent 3290
#define sipName_paintEvent &sipStrings_QtHelp[3290]
#define sipNameNr_removeRows 3301
#define sipName_removeRows &sipStrings_QtHelp[3301]
#define sipNameNr_setVisible 3312
#define sipName_setVisible &sipStrings_QtHelp[3312]
#define sipNameNr_timerEvent 3323
#define sipName_timerEvent &sipStrings_QtHelp[3323]
#define sipNameNr_visualRect 3334
#define sipName_visualRect &sipStrings_QtHelp[3334]
#define sipNameNr_wheelEvent 3345
#define sipName_wheelEvent &sipStrings_QtHelp[3345]
#define sipNameNr_FieldName 109
#define sipName_FieldName &sipStrings_QtHelp[109]
#define sipNameNr_QHelpLink 3356
#define sipName_QHelpLink &sipStrings_QtHelp[3356]
#define sipNameNr_component 3366
#define sipName_component &sipStrings_QtHelp[3366]
#define sipNameNr_dropEvent 3376
#define sipName_dropEvent &sipStrings_QtHelp[3376]
#define sipNameNr_fetchMore 3386
#define sipName_fetchMore &sipStrings_QtHelp[3386]
#define sipNameNr_hideEvent 3396
#define sipName_hideEvent &sipStrings_QtHelp[3396]
#define sipNameNr_mimeTypes 3406
#define sipName_mimeTypes &sipStrings_QtHelp[3406]
#define sipNameNr_moveEvent 3416
#define sipName_moveEvent &sipStrings_QtHelp[3416]
#define sipNameNr_roleNames 3426
#define sipName_roleNames &sipStrings_QtHelp[3426]
#define sipNameNr_selectAll 3436
#define sipName_selectAll &sipStrings_QtHelp[3436]
#define sipNameNr_setupData 3446
#define sipName_setupData &sipStrings_QtHelp[3446]
#define sipNameNr_showEvent 3456
#define sipName_showEvent &sipStrings_QtHelp[3456]
#define sipNameNr_startDrag 3466
#define sipName_startDrag &sipStrings_QtHelp[3466]
#define sipNameNr_fileData 3476
#define sipName_fileData &sipStrings_QtHelp[3476]
#define sipNameNr_findFile 3485
#define sipName_findFile &sipStrings_QtHelp[3485]
#define sipNameNr_hitCount 3494
#define sipName_hitCount &sipStrings_QtHelp[3494]
#define sipNameNr_itemData 3503
#define sipName_itemData &sipStrings_QtHelp[3503]
#define sipNameNr_metaData 3512
#define sipName_metaData &sipStrings_QtHelp[3512]
#define sipNameNr_mimeData 3521
#define sipName_mimeData &sipStrings_QtHelp[3521]
#define sipNameNr_moveRows 3303
#define sipName_moveRows &sipStrings_QtHelp[3303]
#define sipNameNr_rowCount 3530
#define sipName_rowCount &sipStrings_QtHelp[3530]
#define sipNameNr_scrollTo 3539
#define sipName_scrollTo &sipStrings_QtHelp[3539]
#define sipNameNr_setModel 3548
#define sipName_setModel &sipStrings_QtHelp[3548]
#define sipNameNr_setQuery 3557
#define sipName_setQuery &sipStrings_QtHelp[3557]
#define sipNameNr_sizeHint 3566
#define sipName_sizeHint &sipStrings_QtHelp[3566]
#define sipNameNr_versions 3575
#define sipName_versions &sipStrings_QtHelp[3575]
#define sipNameNr_wildcard 3584
#define sipName_wildcard &sipStrings_QtHelp[3584]
#define sipNameNr_ATLEAST 3593
#define sipName_ATLEAST &sipStrings_QtHelp[3593]
#define sipNameNr_DEFAULT 3601
#define sipName_DEFAULT &sipStrings_QtHelp[3601]
#define sipNameNr_WITHOUT 3609
#define sipName_WITHOUT &sipStrings_QtHelp[3609]
#define sipNameNr_devType 3617
#define sipName_devType &sipStrings_QtHelp[3617]
#define sipNameNr_drawRow 3625
#define sipName_drawRow &sipStrings_QtHelp[3625]
#define sipNameNr_filters 3633
#define sipName_filters &sipStrings_QtHelp[3633]
#define sipNameNr_indexAt 3641
#define sipName_indexAt &sipStrings_QtHelp[3641]
#define sipNameNr_indexOf 3649
#define sipName_indexOf &sipStrings_QtHelp[3649]
#define sipNameNr_indices 3657
#define sipName_indices &sipStrings_QtHelp[3657]
#define sipNameNr_setData 3665
#define sipName_setData &sipStrings_QtHelp[3665]
#define sipNameNr_sibling 3673
#define sipName_sibling &sipStrings_QtHelp[3673]
#define sipNameNr_snippet 3681
#define sipName_snippet &sipStrings_QtHelp[3681]
#define sipNameNr_version 3689
#define sipName_version &sipStrings_QtHelp[3689]
#define sipNameNr_warning 3697
#define sipName_warning &sipStrings_QtHelp[3697]
#define sipNameNr_PHRASE 3705
#define sipName_PHRASE &sipStrings_QtHelp[3705]
#define sipNameNr___eq__ 3712
#define sipName___eq__ &sipStrings_QtHelp[3712]
#define sipNameNr___ne__ 3719
#define sipName___ne__ &sipStrings_QtHelp[3719]
#define sipNameNr_filter 3726
#define sipName_filter &sipStrings_QtHelp[3726]
#define sipNameNr_isNull 3733
#define sipName_isNull &sipStrings_QtHelp[3733]
#define sipNameNr_linkAt 3740
#define sipName_linkAt &sipStrings_QtHelp[3740]
#define sipNameNr_metric 3747
#define sipName_metric &sipStrings_QtHelp[3747]
#define sipNameNr_parent 3754
#define sipName_parent &sipStrings_QtHelp[3754]
#define sipNameNr_revert 3761
#define sipName_revert &sipStrings_QtHelp[3761]
#define sipNameNr_search 3768
#define sipName_search &sipStrings_QtHelp[3768]
#define sipNameNr_submit 3775
#define sipName_submit &sipStrings_QtHelp[3775]
#define sipNameNr_FUZZY 3782
#define sipName_FUZZY &sipStrings_QtHelp[3782]
#define sipNameNr_buddy 3788
#define sipName_buddy &sipStrings_QtHelp[3788]
#define sipNameNr_child 3794
#define sipName_child &sipStrings_QtHelp[3794]
#define sipNameNr_error 3800
#define sipName_error &sipStrings_QtHelp[3800]
#define sipNameNr_event 3806
#define sipName_event &sipStrings_QtHelp[3806]
#define sipNameNr_files 3812
#define sipName_files &sipStrings_QtHelp[3812]
#define sipNameNr_flags 3818
#define sipName_flags &sipStrings_QtHelp[3818]
#define sipNameNr_index 3824
#define sipName_index &sipStrings_QtHelp[3824]
#define sipNameNr_match 3830
#define sipName_match &sipStrings_QtHelp[3830]
#define sipNameNr_query 3836
#define sipName_query &sipStrings_QtHelp[3836]
#define sipNameNr_reset 3842
#define sipName_reset &sipStrings_QtHelp[3842]
#define sipNameNr_title 3848
#define sipName_title &sipStrings_QtHelp[3848]
#define sipNameNr_data 3854
#define sipName_data &sipStrings_QtHelp[3854]
#define sipNameNr_edit 3859
#define sipName_edit &sipStrings_QtHelp[3859]
#define sipNameNr_hits 3864
#define sipName_hits &sipStrings_QtHelp[3864]
#define sipNameNr_sort 3869
#define sipName_sort &sipStrings_QtHelp[3869]
#define sipNameNr_span 3874
#define sipName_span &sipStrings_QtHelp[3874]
#define sipNameNr_swap 3879
#define sipName_swap &sipStrings_QtHelp[3879]
#define sipNameNr_ALL 3884
#define sipName_ALL &sipStrings_QtHelp[3884]
#define sipNameNr_row 3888
#define sipName_row &sipStrings_QtHelp[3888]
#define sipNameNr_url 3892
#define sipName_url &sipStrings_QtHelp[3892]

#define sipMalloc                   sipAPI_QtHelp->api_malloc
#define sipFree                     sipAPI_QtHelp->api_free
#define sipBuildResult              sipAPI_QtHelp->api_build_result
#define sipCallMethod               sipAPI_QtHelp->api_call_method
#define sipCallProcedureMethod      sipAPI_QtHelp->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtHelp->api_call_error_handler
#define sipParseResultEx            sipAPI_QtHelp->api_parse_result_ex
#define sipParseResult              sipAPI_QtHelp->api_parse_result
#define sipParseArgs                sipAPI_QtHelp->api_parse_args
#define sipParseKwdArgs             sipAPI_QtHelp->api_parse_kwd_args
#define sipParsePair                sipAPI_QtHelp->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtHelp->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtHelp->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtHelp->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtHelp->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtHelp->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtHelp->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtHelp->api_add_exception
#define sipNoFunction               sipAPI_QtHelp->api_no_function
#define sipNoMethod                 sipAPI_QtHelp->api_no_method
#define sipAbstractMethod           sipAPI_QtHelp->api_abstract_method
#define sipBadClass                 sipAPI_QtHelp->api_bad_class
#define sipBadCatcherResult         sipAPI_QtHelp->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtHelp->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtHelp->api_bad_operator_arg
#define sipTrace                    sipAPI_QtHelp->api_trace
#define sipTransferBack             sipAPI_QtHelp->api_transfer_back
#define sipTransferTo               sipAPI_QtHelp->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtHelp->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtHelp->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtHelp->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtHelp->api_voidptr_type
#define sipGetPyObject              sipAPI_QtHelp->api_get_pyobject
#define sipGetAddress               sipAPI_QtHelp->api_get_address
#define sipGetMixinAddress          sipAPI_QtHelp->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtHelp->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtHelp->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtHelp->api_call_hook
#define sipEndThread                sipAPI_QtHelp->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtHelp->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtHelp->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtHelp->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtHelp->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtHelp->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtHelp->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtHelp->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtHelp->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtHelp->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtHelp->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtHelp->api_convert_to_bool
#define sipReleaseType              sipAPI_QtHelp->api_release_type
#define sipConvertFromType          sipAPI_QtHelp->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtHelp->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtHelp->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtHelp->api_convert_from_enum
#define sipGetState                 sipAPI_QtHelp->api_get_state
#define sipExportSymbol             sipAPI_QtHelp->api_export_symbol
#define sipImportSymbol             sipAPI_QtHelp->api_import_symbol
#define sipFindType                 sipAPI_QtHelp->api_find_type
#define sipBytes_AsChar             sipAPI_QtHelp->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtHelp->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtHelp->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtHelp->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtHelp->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtHelp->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtHelp->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtHelp->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtHelp->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtHelp->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtHelp->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtHelp->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtHelp->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtHelp->api_get_reference
#define sipKeepReference            sipAPI_QtHelp->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtHelp->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtHelp->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtHelp->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtHelp->api_type_scope
#define sipResolveTypedef           sipAPI_QtHelp->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtHelp->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtHelp->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtHelp->api_init_mixin
#define sipExportModule             sipAPI_QtHelp->api_export_module
#define sipInitModule               sipAPI_QtHelp->api_init_module
#define sipGetInterpreter           sipAPI_QtHelp->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtHelp->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtHelp->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtHelp->api_py_type_dict
#define sipPyTypeName               sipAPI_QtHelp->api_py_type_name
#define sipGetCFunction             sipAPI_QtHelp->api_get_c_function
#define sipGetMethod                sipAPI_QtHelp->api_get_method
#define sipFromMethod               sipAPI_QtHelp->api_from_method
#define sipGetDate                  sipAPI_QtHelp->api_get_date
#define sipFromDate                 sipAPI_QtHelp->api_from_date
#define sipGetDateTime              sipAPI_QtHelp->api_get_datetime
#define sipFromDateTime             sipAPI_QtHelp->api_from_datetime
#define sipGetTime                  sipAPI_QtHelp->api_get_time
#define sipFromTime                 sipAPI_QtHelp->api_from_time
#define sipIsUserType               sipAPI_QtHelp->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtHelp->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtHelp->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtHelp->api_unicode_write
#define sipUnicodeData              sipAPI_QtHelp->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtHelp->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtHelp->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtHelp->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtHelp->api_is_derived_class
#define sipGetUserObject            sipAPI_QtHelp->api_get_user_object
#define sipSetUserObject            sipAPI_QtHelp->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtHelp->api_register_event_handler
#define sipConvertToArray           sipAPI_QtHelp->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtHelp->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtHelp->api_enable_gc
#define sipPrintObject              sipAPI_QtHelp->api_print_object
#define sipLong_AsChar              sipAPI_QtHelp->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtHelp->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtHelp->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtHelp->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtHelp->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtHelp->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtHelp->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtHelp->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtHelp->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtHelp->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtHelp->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtHelp->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtHelp->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtHelp->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtHelp->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtHelp->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtHelp->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtHelp->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtHelp->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtHelp->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtHelp->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtHelp->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtHelp->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtHelp->api_connect_rx
#define sipConvertRx                sipAPI_QtHelp->api_convert_rx
#define sipDisconnectRx             sipAPI_QtHelp->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtHelp->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtHelp->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtHelp->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtHelp->api_same_slot
#define sipSaveSlot                 sipAPI_QtHelp->api_save_slot
#define sipVisitSlot                sipAPI_QtHelp->api_visit_slot
#define sipIsPyMethod               sipAPI_QtHelp->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtHelp[];

#define sipType_QCompressedHelpInfo sipExportedTypes_QtHelp[0]

extern sipClassTypeDef sipTypeDef_QtHelp_QCompressedHelpInfo;

#define sipType_QHelpContentItem sipExportedTypes_QtHelp[1]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpContentItem;

#define sipType_QHelpContentModel sipExportedTypes_QtHelp[2]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpContentModel;

#define sipType_QHelpContentWidget sipExportedTypes_QtHelp[3]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpContentWidget;

#define sipType_QHelpEngineCore sipExportedTypes_QtHelp[5]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpEngineCore;

#define sipType_QHelpEngine sipExportedTypes_QtHelp[4]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpEngine;

#define sipType_QHelpFilterData sipExportedTypes_QtHelp[6]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpFilterData;

#define sipType_QHelpFilterEngine sipExportedTypes_QtHelp[7]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpFilterEngine;

#define sipType_QHelpFilterSettingsWidget sipExportedTypes_QtHelp[8]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpFilterSettingsWidget;

#define sipType_QHelpIndexModel sipExportedTypes_QtHelp[9]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpIndexModel;

#define sipType_QHelpIndexWidget sipExportedTypes_QtHelp[10]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpIndexWidget;

#define sipType_QHelpLink sipExportedTypes_QtHelp[11]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpLink;

#define sipType_QHelpSearchQuery sipExportedTypes_QtHelp[13]

#define sipType_QHelpSearchQuery_FieldName sipExportedTypes_QtHelp[14]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpSearchQuery;

#define sipType_QHelpSearchEngine sipExportedTypes_QtHelp[12]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpSearchEngine;

#define sipType_QHelpSearchResult sipExportedTypes_QtHelp[16]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpSearchResult;

#define sipType_QHelpSearchQueryWidget sipExportedTypes_QtHelp[15]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpSearchQueryWidget;

#define sipType_QHelpSearchResultWidget sipExportedTypes_QtHelp[17]

extern sipClassTypeDef sipTypeDef_QtHelp_QHelpSearchResultWidget;

#define sipType_QVector_0100QHelpSearchResult sipExportedTypes_QtHelp[25]

extern sipMappedTypeDef sipTypeDef_QtHelp_QVector_0100QHelpSearchResult;

#define sipType_QList_0100QHelpSearchQuery sipExportedTypes_QtHelp[19]

extern sipMappedTypeDef sipTypeDef_QtHelp_QList_0100QHelpSearchQuery;

#define sipType_QMap_0100QString_0100QVersionNumber sipExportedTypes_QtHelp[24]

extern sipMappedTypeDef sipTypeDef_QtHelp_QMap_0100QString_0100QVersionNumber;

#define sipType_QMap_0100QString_0100QString sipExportedTypes_QtHelp[22]

extern sipMappedTypeDef sipTypeDef_QtHelp_QMap_0100QString_0100QString;

#define sipType_QList_0100QVersionNumber sipExportedTypes_QtHelp[21]

extern sipMappedTypeDef sipTypeDef_QtHelp_QList_0100QVersionNumber;

#define sipType_QList_0100QHelpLink sipExportedTypes_QtHelp[18]

extern sipMappedTypeDef sipTypeDef_QtHelp_QList_0100QHelpLink;

#define sipType_QMap_0100QString_0100QUrl sipExportedTypes_QtHelp[23]

extern sipMappedTypeDef sipTypeDef_QtHelp_QMap_0100QString_0100QUrl;

#define sipType_QList_0100QStringList sipExportedTypes_QtHelp[20]

extern sipMappedTypeDef sipTypeDef_QtHelp_QList_0100QStringList;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtHelp;
extern sipExportedModuleDef sipModuleAPI_QtHelp;
extern sipTypeDef *sipExportedTypes_QtHelp[];

#define sipType_Qt_DropAction sipImportedTypes_QtHelp_QtCore[28].it_td

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtHelp_QtCore[30].it_td

#define sipType_Qt_SortOrder sipImportedTypes_QtHelp_QtCore[35].it_td

#define sipType_Qt_Orientation sipImportedTypes_QtHelp_QtCore[34].it_td

#define sipType_Qt_KeyboardModifiers sipImportedTypes_QtHelp_QtCore[32].it_td

#define sipType_Qt_DropActions sipImportedTypes_QtHelp_QtCore[29].it_td

#define sipType_Qt_ItemFlags sipImportedTypes_QtHelp_QtCore[31].it_td

#define sipType_Qt_MatchFlags sipImportedTypes_QtHelp_QtCore[33].it_td

#define sipType_QObject sipImportedTypes_QtHelp_QtCore[16].it_td

#define sipType_QModelIndex sipImportedTypes_QtHelp_QtCore[15].it_td

#define sipType_QAbstractItemModel sipImportedTypes_QtHelp_QtCore[0].it_td

#define sipType_QAbstractListModel sipImportedTypes_QtHelp_QtCore[1].it_td

#define sipType_QByteArray sipImportedTypes_QtHelp_QtCore[2].it_td

#define sipType_QEvent sipImportedTypes_QtHelp_QtCore[4].it_td

#define sipType_QTimerEvent sipImportedTypes_QtHelp_QtCore[23].it_td

#define sipType_QChildEvent sipImportedTypes_QtHelp_QtCore[3].it_td

#define sipType_QItemSelectionModel sipImportedTypes_QtHelp_QtCore[7].it_td

#define sipType_QItemSelectionModel_SelectionFlags sipImportedTypes_QtHelp_QtCore[8].it_td

#define sipType_QItemSelection sipImportedTypes_QtHelp_QtCore[6].it_td

#define sipType_QMetaMethod sipImportedTypes_QtHelp_QtCore[13].it_td

#define sipType_QMimeData sipImportedTypes_QtHelp_QtCore[14].it_td

#define sipType_QPoint sipImportedTypes_QtHelp_QtCore[17].it_td

#define sipType_QRect sipImportedTypes_QtHelp_QtCore[18].it_td

#define sipType_QSize sipImportedTypes_QtHelp_QtCore[19].it_td

#define sipType_QStringListModel sipImportedTypes_QtHelp_QtCore[22].it_td

#define sipType_QUrl sipImportedTypes_QtHelp_QtCore[24].it_td

#define sipType_QVariant sipImportedTypes_QtHelp_QtCore[25].it_td

#define sipType_QVersionNumber sipImportedTypes_QtHelp_QtCore[27].it_td

#define sipType_QList_0600QPair_0100QString_0100QString sipImportedTypes_QtHelp_QtCore[10].it_td

#define sipType_QList_0100QUrl sipImportedTypes_QtHelp_QtCore[11].it_td

#define sipType_QHash_1800_0100QByteArray sipImportedTypes_QtHelp_QtCore[5].it_td

#define sipType_QMap_1800_0100QVariant sipImportedTypes_QtHelp_QtCore[12].it_td

#define sipType_QList_0100QModelIndex sipImportedTypes_QtHelp_QtCore[9].it_td

#define sipType_QVector_1800 sipImportedTypes_QtHelp_QtCore[26].it_td

#define sipType_QStringList sipImportedTypes_QtHelp_QtCore[21].it_td

#define sipType_QString sipImportedTypes_QtHelp_QtCore[20].it_td
extern sipImportedTypeDef sipImportedTypes_QtHelp_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtHelp_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtHelp_QtGui[13].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtHelp_QtGui[14].it_td

#define sipType_QMouseEvent sipImportedTypes_QtHelp_QtGui[11].it_td

#define sipType_QWheelEvent sipImportedTypes_QtHelp_QtGui[22].it_td

#define sipType_QTabletEvent sipImportedTypes_QtHelp_QtGui[21].it_td

#define sipType_QKeyEvent sipImportedTypes_QtHelp_QtGui[10].it_td

#define sipType_QFocusEvent sipImportedTypes_QtHelp_QtGui[7].it_td

#define sipType_QPaintEvent sipImportedTypes_QtHelp_QtGui[16].it_td

#define sipType_QMoveEvent sipImportedTypes_QtHelp_QtGui[12].it_td

#define sipType_QResizeEvent sipImportedTypes_QtHelp_QtGui[19].it_td

#define sipType_QCloseEvent sipImportedTypes_QtHelp_QtGui[1].it_td

#define sipType_QShowEvent sipImportedTypes_QtHelp_QtGui[20].it_td

#define sipType_QHideEvent sipImportedTypes_QtHelp_QtGui[8].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtHelp_QtGui[2].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtHelp_QtGui[9].it_td

#define sipType_QDropEvent sipImportedTypes_QtHelp_QtGui[6].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtHelp_QtGui[5].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtHelp_QtGui[3].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtHelp_QtGui[4].it_td

#define sipType_QActionEvent sipImportedTypes_QtHelp_QtGui[0].it_td

#define sipType_QPainter sipImportedTypes_QtHelp_QtGui[17].it_td

#define sipType_QPaintEngine sipImportedTypes_QtHelp_QtGui[15].it_td

#define sipType_QRegion sipImportedTypes_QtHelp_QtGui[18].it_td
extern sipImportedTypeDef sipImportedTypes_QtHelp_QtGui[];

#define sipType_QWidget sipImportedTypes_QtHelp_QtWidgets[10].it_td

#define sipType_QAbstractItemDelegate_EndEditHint sipImportedTypes_QtHelp_QtWidgets[0].it_td

#define sipType_QFrame sipImportedTypes_QtHelp_QtWidgets[6].it_td

#define sipType_QAbstractScrollArea sipImportedTypes_QtHelp_QtWidgets[5].it_td

#define sipType_QAbstractItemView sipImportedTypes_QtHelp_QtWidgets[1].it_td

#define sipType_QAbstractItemView_CursorAction sipImportedTypes_QtHelp_QtWidgets[2].it_td

#define sipType_QAbstractItemView_ScrollHint sipImportedTypes_QtHelp_QtWidgets[4].it_td

#define sipType_QAbstractItemView_EditTrigger sipImportedTypes_QtHelp_QtWidgets[3].it_td

#define sipType_QListView sipImportedTypes_QtHelp_QtWidgets[7].it_td

#define sipType_QStyleOptionViewItem sipImportedTypes_QtHelp_QtWidgets[8].it_td

#define sipType_QTreeView sipImportedTypes_QtHelp_QtWidgets[9].it_td
extern sipImportedTypeDef sipImportedTypes_QtHelp_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtHelp_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtHelp_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtHelp_qt_metacast;

#endif
