/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacemanager.sip"
#include <qplacemanager.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecategory.sip"
#include <qplacecategory.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacereply.sip"
#include <qplacereply.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacematchreply.sip"
#include <qplacematchreply.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacematchrequest.sip"
#include <qplacematchrequest.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplace.sip"
#include <qplace.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceidreply.sip"
#include <qplaceidreply.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesearchsuggestionreply.sip"
#include <qplacesearchsuggestionreply.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesearchrequest.sip"
#include <qplacesearchrequest.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesearchreply.sip"
#include <qplacesearchreply.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecontentreply.sip"
#include <qplacecontentreply.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecontentrequest.sip"
#include <qplacecontentrequest.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacedetailsreply.sip"
#include <qplacedetailsreply.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 122 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 125 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 128 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 131 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceManager.cpp"


PyDoc_STRVAR(doc_QPlaceManager_managerName, "managerName(self) -> str");

extern "C" {static PyObject *meth_QPlaceManager_managerName(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_managerName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceManager, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->managerName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_managerName, doc_QPlaceManager_managerName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_managerVersion, "managerVersion(self) -> int");

extern "C" {static PyObject *meth_QPlaceManager_managerVersion(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_managerVersion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceManager, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->managerVersion();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_managerVersion, doc_QPlaceManager_managerVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_getPlaceDetails, "getPlaceDetails(self, placeId: Optional[str]) -> Optional[QPlaceDetailsReply]");

extern "C" {static PyObject *meth_QPlaceManager_getPlaceDetails(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_getPlaceDetails(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QPlaceDetailsReply*sipRes;

            sipRes = sipCpp->getPlaceDetails(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromType(sipRes, sipType_QPlaceDetailsReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_getPlaceDetails, doc_QPlaceManager_getPlaceDetails);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_getPlaceContent, "getPlaceContent(self, request: QPlaceContentRequest) -> Optional[QPlaceContentReply]");

extern "C" {static PyObject *meth_QPlaceManager_getPlaceContent(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_getPlaceContent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceContentRequest* a0;
        const ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QPlaceContentRequest, &a0))
        {
            ::QPlaceContentReply*sipRes;

            sipRes = sipCpp->getPlaceContent(*a0);

            return sipConvertFromType(sipRes, sipType_QPlaceContentReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_getPlaceContent, doc_QPlaceManager_getPlaceContent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_search, "search(self, query: QPlaceSearchRequest) -> Optional[QPlaceSearchReply]");

extern "C" {static PyObject *meth_QPlaceManager_search(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_search(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchRequest* a0;
        const ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QPlaceSearchRequest, &a0))
        {
            ::QPlaceSearchReply*sipRes;

            sipRes = sipCpp->search(*a0);

            return sipConvertFromType(sipRes, sipType_QPlaceSearchReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_search, doc_QPlaceManager_search);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_searchSuggestions, "searchSuggestions(self, request: QPlaceSearchRequest) -> Optional[QPlaceSearchSuggestionReply]");

extern "C" {static PyObject *meth_QPlaceManager_searchSuggestions(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_searchSuggestions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceSearchRequest* a0;
        const ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QPlaceSearchRequest, &a0))
        {
            ::QPlaceSearchSuggestionReply*sipRes;

            sipRes = sipCpp->searchSuggestions(*a0);

            return sipConvertFromType(sipRes, sipType_QPlaceSearchSuggestionReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_searchSuggestions, doc_QPlaceManager_searchSuggestions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_savePlace, "savePlace(self, place: QPlace) -> Optional[QPlaceIdReply]");

extern "C" {static PyObject *meth_QPlaceManager_savePlace(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_savePlace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlace* a0;
        ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QPlace, &a0))
        {
            ::QPlaceIdReply*sipRes;

            sipRes = sipCpp->savePlace(*a0);

            return sipConvertFromType(sipRes, sipType_QPlaceIdReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_savePlace, doc_QPlaceManager_savePlace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_removePlace, "removePlace(self, placeId: Optional[str]) -> Optional[QPlaceIdReply]");

extern "C" {static PyObject *meth_QPlaceManager_removePlace(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_removePlace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QPlaceIdReply*sipRes;

            sipRes = sipCpp->removePlace(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromType(sipRes, sipType_QPlaceIdReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_removePlace, doc_QPlaceManager_removePlace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_saveCategory, "saveCategory(self, category: QPlaceCategory, parentId: Optional[str] = '') -> Optional[QPlaceIdReply]");

extern "C" {static PyObject *meth_QPlaceManager_saveCategory(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_saveCategory(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceCategory* a0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        ::QPlaceManager *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parentId,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|J1", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QPlaceCategory, &a0, sipType_QString, &a1, &a1State))
        {
            ::QPlaceIdReply*sipRes;

            sipRes = sipCpp->saveCategory(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromType(sipRes, sipType_QPlaceIdReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_saveCategory, doc_QPlaceManager_saveCategory);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_removeCategory, "removeCategory(self, categoryId: Optional[str]) -> Optional[QPlaceIdReply]");

extern "C" {static PyObject *meth_QPlaceManager_removeCategory(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_removeCategory(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QPlaceIdReply*sipRes;

            sipRes = sipCpp->removeCategory(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromType(sipRes, sipType_QPlaceIdReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_removeCategory, doc_QPlaceManager_removeCategory);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_initializeCategories, "initializeCategories(self) -> Optional[QPlaceReply]");

extern "C" {static PyObject *meth_QPlaceManager_initializeCategories(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_initializeCategories(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceManager, &sipCpp))
        {
            ::QPlaceReply*sipRes;

            sipRes = sipCpp->initializeCategories();

            return sipConvertFromType(sipRes, sipType_QPlaceReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_initializeCategories, doc_QPlaceManager_initializeCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_parentCategoryId, "parentCategoryId(self, categoryId: Optional[str]) -> str");

extern "C" {static PyObject *meth_QPlaceManager_parentCategoryId(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_parentCategoryId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->parentCategoryId(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_parentCategoryId, doc_QPlaceManager_parentCategoryId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_childCategoryIds, "childCategoryIds(self, parentId: Optional[str] = '') -> list[str]");

extern "C" {static PyObject *meth_QPlaceManager_childCategoryIds(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_childCategoryIds(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString& a0def = QString();
        const ::QString* a0 = &a0def;
        int a0State = 0;
        const ::QPlaceManager *sipCpp;

        static const char *sipKwdList[] = {
            sipName_parentId,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->childCategoryIds(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_childCategoryIds, doc_QPlaceManager_childCategoryIds);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_category, "category(self, categoryId: Optional[str]) -> QPlaceCategory");

extern "C" {static PyObject *meth_QPlaceManager_category(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_category(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QPlaceCategory*sipRes;

            sipRes = new ::QPlaceCategory(sipCpp->category(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QPlaceCategory, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_category, doc_QPlaceManager_category);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_childCategories, "childCategories(self, parentId: Optional[str] = '') -> list[QPlaceCategory]");

extern "C" {static PyObject *meth_QPlaceManager_childCategories(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_childCategories(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString& a0def = QString();
        const ::QString* a0 = &a0def;
        int a0State = 0;
        const ::QPlaceManager *sipCpp;

        static const char *sipKwdList[] = {
            sipName_parentId,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QString, &a0, &a0State))
        {
            QList< ::QPlaceCategory>*sipRes;

            sipRes = new QList< ::QPlaceCategory>(sipCpp->childCategories(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QList_0100QPlaceCategory, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_childCategories, doc_QPlaceManager_childCategories);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_locales, "locales(self) -> list[QLocale]");

extern "C" {static PyObject *meth_QPlaceManager_locales(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_locales(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceManager, &sipCpp))
        {
            QList< ::QLocale>*sipRes;

            sipRes = new QList< ::QLocale>(sipCpp->locales());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_locales, doc_QPlaceManager_locales);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_setLocale, "setLocale(self, locale: QLocale)");

extern "C" {static PyObject *meth_QPlaceManager_setLocale(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_setLocale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale* a0;
        ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QLocale, &a0))
        {
            sipCpp->setLocale(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_setLocale, doc_QPlaceManager_setLocale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_setLocales, "setLocales(self, locale: Iterable[QLocale])");

extern "C" {static PyObject *meth_QPlaceManager_setLocales(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_setLocales(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QLocale>* a0;
        int a0State = 0;
        ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QList_0100QLocale, &a0, &a0State))
        {
            sipCpp->setLocales(*a0);
            sipReleaseType(const_cast<QList< ::QLocale> *>(a0), sipType_QList_0100QLocale, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_setLocales, doc_QPlaceManager_setLocales);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_compatiblePlace, "compatiblePlace(self, place: QPlace) -> QPlace");

extern "C" {static PyObject *meth_QPlaceManager_compatiblePlace(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_compatiblePlace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlace* a0;
        ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QPlace, &a0))
        {
            ::QPlace*sipRes;

            sipRes = new ::QPlace(sipCpp->compatiblePlace(*a0));

            return sipConvertFromNewType(sipRes, sipType_QPlace, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_compatiblePlace, doc_QPlaceManager_compatiblePlace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceManager_matchingPlaces, "matchingPlaces(self, request: QPlaceMatchRequest) -> Optional[QPlaceMatchReply]");

extern "C" {static PyObject *meth_QPlaceManager_matchingPlaces(PyObject *, PyObject *);}
static PyObject *meth_QPlaceManager_matchingPlaces(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceMatchRequest* a0;
        const ::QPlaceManager *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceManager, &sipCpp, sipType_QPlaceMatchRequest, &a0))
        {
            ::QPlaceMatchReply*sipRes;

            sipRes = sipCpp->matchingPlaces(*a0);

            return sipConvertFromType(sipRes, sipType_QPlaceMatchReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_matchingPlaces, doc_QPlaceManager_matchingPlaces);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QPlaceManager(void *, const sipTypeDef *);}
static void *cast_QPlaceManager(void *sipCppV, const sipTypeDef *targetType)
{
    ::QPlaceManager *sipCpp = reinterpret_cast< ::QPlaceManager *>(sipCppV);

    if (targetType == sipType_QPlaceManager)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QPlaceManager(void *, int);}
static void release_QPlaceManager(void *sipCppV, int)
{
    ::QPlaceManager *sipCpp = reinterpret_cast< ::QPlaceManager *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QPlaceManager(sipSimpleWrapper *);}
static void dealloc_QPlaceManager(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPlaceManager(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QPlaceManager[] = {{7, 0, 1}};


static PyMethodDef methods_QPlaceManager[] = {
    {sipName_category, meth_QPlaceManager_category, METH_VARARGS, doc_QPlaceManager_category},
    {sipName_childCategories, SIP_MLMETH_CAST(meth_QPlaceManager_childCategories), METH_VARARGS|METH_KEYWORDS, doc_QPlaceManager_childCategories},
    {sipName_childCategoryIds, SIP_MLMETH_CAST(meth_QPlaceManager_childCategoryIds), METH_VARARGS|METH_KEYWORDS, doc_QPlaceManager_childCategoryIds},
    {sipName_compatiblePlace, meth_QPlaceManager_compatiblePlace, METH_VARARGS, doc_QPlaceManager_compatiblePlace},
    {sipName_getPlaceContent, meth_QPlaceManager_getPlaceContent, METH_VARARGS, doc_QPlaceManager_getPlaceContent},
    {sipName_getPlaceDetails, meth_QPlaceManager_getPlaceDetails, METH_VARARGS, doc_QPlaceManager_getPlaceDetails},
    {sipName_initializeCategories, meth_QPlaceManager_initializeCategories, METH_VARARGS, doc_QPlaceManager_initializeCategories},
    {sipName_locales, meth_QPlaceManager_locales, METH_VARARGS, doc_QPlaceManager_locales},
    {sipName_managerName, meth_QPlaceManager_managerName, METH_VARARGS, doc_QPlaceManager_managerName},
    {sipName_managerVersion, meth_QPlaceManager_managerVersion, METH_VARARGS, doc_QPlaceManager_managerVersion},
    {sipName_matchingPlaces, meth_QPlaceManager_matchingPlaces, METH_VARARGS, doc_QPlaceManager_matchingPlaces},
    {sipName_parentCategoryId, meth_QPlaceManager_parentCategoryId, METH_VARARGS, doc_QPlaceManager_parentCategoryId},
    {sipName_removeCategory, meth_QPlaceManager_removeCategory, METH_VARARGS, doc_QPlaceManager_removeCategory},
    {sipName_removePlace, meth_QPlaceManager_removePlace, METH_VARARGS, doc_QPlaceManager_removePlace},
    {sipName_saveCategory, SIP_MLMETH_CAST(meth_QPlaceManager_saveCategory), METH_VARARGS|METH_KEYWORDS, doc_QPlaceManager_saveCategory},
    {sipName_savePlace, meth_QPlaceManager_savePlace, METH_VARARGS, doc_QPlaceManager_savePlace},
    {sipName_search, meth_QPlaceManager_search, METH_VARARGS, doc_QPlaceManager_search},
    {sipName_searchSuggestions, meth_QPlaceManager_searchSuggestions, METH_VARARGS, doc_QPlaceManager_searchSuggestions},
    {sipName_setLocale, meth_QPlaceManager_setLocale, METH_VARARGS, doc_QPlaceManager_setLocale},
    {sipName_setLocales, meth_QPlaceManager_setLocales, METH_VARARGS, doc_QPlaceManager_setLocales}
};


extern "C" {static int emit_QPlaceManager_error(void *, PyObject *);}

static int emit_QPlaceManager_error(void *sipCppV, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    ::QPlaceManager *sipCpp = reinterpret_cast< ::QPlaceManager *>(sipCppV);

    {
        ::QPlaceReply* a0;
        ::QPlaceReply::Error a1;
        const ::QString& a2def = QString();
        const ::QString* a2 = &a2def;
        int a2State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8E|J1", sipType_QPlaceReply, &a0, sipType_QPlaceReply_Error, &a1, sipType_QString, &a2, &a2State))
        {
            Py_BEGIN_ALLOW_THREADS
            sipCpp->error(a0, a1, *a2);
            Py_END_ALLOW_THREADS

            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);

            return 0;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceManager, sipName_error, SIP_NULLPTR);

    return -1;
}


/* Define this type's signals. */
static const pyqt5QtSignal signals_QPlaceManager[] = {
    {"dataChanged()", "\1dataChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"categoryRemoved(QString,QString)", "\1categoryRemoved(self, categoryId: Optional[str], parentId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"categoryUpdated(QPlaceCategory,QString)", "\1categoryUpdated(self, category: QPlaceCategory, parentId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"categoryAdded(QPlaceCategory,QString)", "\1categoryAdded(self, category: QPlaceCategory, parentId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"placeRemoved(QString)", "\1placeRemoved(self, placeId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"placeUpdated(QString)", "\1placeUpdated(self, placeId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"placeAdded(QString)", "\1placeAdded(self, placeId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QPlaceReply*,QPlaceReply::Error,QString)", "\1error(self, a0: Optional[QPlaceReply], error: QPlaceReply.Error, errorString: Optional[str] = '')", SIP_NULLPTR, emit_QPlaceManager_error},
    {"finished(QPlaceReply*)", "\1finished(self, reply: Optional[QPlaceReply])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QPlaceManager = {
    &::QPlaceManager::staticMetaObject,
    0,
    signals_QPlaceManager,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QPlaceManager = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPlaceManager,
        SIP_NULLPTR,
        &plugin_QPlaceManager,
    },
    {
        sipNameNr_QPlaceManager,
        {0, 0, 1},
        20, methods_QPlaceManager,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QPlaceManager,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPlaceManager,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QPlaceManager,
    cast_QPlaceManager,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
