/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qundoview.sip"
#include <qundoview.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qundostack.sip"
#include <qundostack.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qundogroup.sip"
#include <qundogroup.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 169 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qitemselectionmodel.sip"
#include <qitemselectionmodel.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 67 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qitemselectionmodel.sip"
#include <qitemselectionmodel.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qabstractitemview.sip"
#include <qabstractitemview.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 398 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 579 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 253 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 570 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 619 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 592 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 99 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 425 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 102 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 105 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 205 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 108 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 442 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 114 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qlistview.sip"
#include <qlistview.h>
#line 117 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 120 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 123 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 509 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 126 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 129 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qabstractitemdelegate.sip"
#include <qabstractitemdelegate.h>
#line 132 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 363 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 135 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 384 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 138 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 608 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 141 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qabstractitemview.sip"
#include <qabstractitemview.h>
#line 144 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 67 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qitemselectionmodel.sip"
#include <qitemselectionmodel.h>
#line 147 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 150 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qabstractscrollarea.sip"
#include <qabstractscrollarea.h>
#line 153 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 156 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qscrollbar.sip"
#include <qscrollbar.h>
#line 159 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 482 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 162 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 165 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 208 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 168 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 171 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qframe.sip"
#include <qframe.h>
#line 174 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 177 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 180 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 183 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 186 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 189 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 192 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 198 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 201 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 204 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 207 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 210 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 213 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 216 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 219 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 222 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 471 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 225 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 460 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 228 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 675 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 231 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 302 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 234 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 438 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 237 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 412 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 243 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 246 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 249 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 255 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 258 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 261 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 264 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 267 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 270 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 273 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 278 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 281 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 284 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 287 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 290 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 293 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 296 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 299 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 302 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 305 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQUndoView.cpp"


class sipQUndoView : public ::QUndoView
{
public:
    sipQUndoView(::QWidget*);
    sipQUndoView(::QUndoStack*, ::QWidget*);
    sipQUndoView(::QUndoGroup*, ::QWidget*);
    virtual ~sipQUndoView();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QStyleOptionViewItem viewOptions() const SIP_OVERRIDE;
    void startDrag(::Qt::DropActions) SIP_OVERRIDE;
    ::QItemSelectionModel::SelectionFlags selectionCommand(const ::QModelIndex&, const ::QEvent*) const SIP_OVERRIDE;
    bool edit(const ::QModelIndex&, ::QAbstractItemView::EditTrigger, ::QEvent*) SIP_OVERRIDE;
    ::QModelIndexList selectedIndexes() const SIP_OVERRIDE;
    ::QRegion visualRegionForSelection(const ::QItemSelection&) const SIP_OVERRIDE;
    void setSelection(const ::QRect&, ::QItemSelectionModel::SelectionFlags) SIP_OVERRIDE;
    bool isIndexHidden(const ::QModelIndex&) const SIP_OVERRIDE;
    int verticalOffset() const SIP_OVERRIDE;
    int horizontalOffset() const SIP_OVERRIDE;
    ::QModelIndex moveCursor(::QAbstractItemView::CursorAction, ::Qt::KeyboardModifiers) SIP_OVERRIDE;
    void editorDestroyed(::QObject*) SIP_OVERRIDE;
    void commitData(::QWidget*) SIP_OVERRIDE;
    void closeEditor(::QWidget*, ::QAbstractItemDelegate::EndEditHint) SIP_OVERRIDE;
    void horizontalScrollbarValueChanged(int) SIP_OVERRIDE;
    void verticalScrollbarValueChanged(int) SIP_OVERRIDE;
    void horizontalScrollbarAction(int) SIP_OVERRIDE;
    void verticalScrollbarAction(int) SIP_OVERRIDE;
    void updateGeometries() SIP_OVERRIDE;
    void updateEditorGeometries() SIP_OVERRIDE;
    void updateEditorData() SIP_OVERRIDE;
    void currentChanged(const ::QModelIndex&, const ::QModelIndex&) SIP_OVERRIDE;
    void selectionChanged(const ::QItemSelection&, const ::QItemSelection&) SIP_OVERRIDE;
    void rowsAboutToBeRemoved(const ::QModelIndex&, int, int) SIP_OVERRIDE;
    void rowsInserted(const ::QModelIndex&, int, int) SIP_OVERRIDE;
    void dataChanged(const ::QModelIndex&, const ::QModelIndex&, const ::QVector<int>&) SIP_OVERRIDE;
    void selectAll() SIP_OVERRIDE;
    void setRootIndex(const ::QModelIndex&) SIP_OVERRIDE;
    void reset() SIP_OVERRIDE;
    int sizeHintForColumn(int) const SIP_OVERRIDE;
    int sizeHintForRow(int) const SIP_OVERRIDE;
    ::QModelIndex indexAt(const ::QPoint&) const SIP_OVERRIDE;
    void scrollTo(const ::QModelIndex&, ::QAbstractItemView::ScrollHint) SIP_OVERRIDE;
    ::QRect visualRect(const ::QModelIndex&) const SIP_OVERRIDE;
    void keyboardSearch(const ::QString&) SIP_OVERRIDE;
    void setSelectionModel(::QItemSelectionModel*) SIP_OVERRIDE;
    void setModel(::QAbstractItemModel*) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void enterEvent(::QEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, long*) SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    void initPainter(::QPainter*) const SIP_OVERRIDE;
    ::QSize viewportSizeHint() const SIP_OVERRIDE;
    bool viewportEvent(::QEvent*) SIP_OVERRIDE;
    void scrollContentsBy(int, int) SIP_OVERRIDE;
    void setupViewport(::QWidget*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQUndoView(const sipQUndoView &);
    sipQUndoView &operator = (const sipQUndoView &);

    char sipPyMethods[87];
};

sipQUndoView::sipQUndoView(::QWidget*a0): ::QUndoView(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQUndoView::sipQUndoView(::QUndoStack*a0, ::QWidget*a1): ::QUndoView(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQUndoView::sipQUndoView(::QUndoGroup*a0, ::QWidget*a1): ::QUndoView(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQUndoView::~sipQUndoView()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQUndoView::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QUndoView);

    return ::QUndoView::metaObject();
}

int sipQUndoView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QUndoView::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QUndoView, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQUndoView::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QUndoView, _clname, &sipCpp) ? sipCpp : ::QUndoView::qt_metacast(_clname));
}

::QStyleOptionViewItem sipQUndoView::viewOptions() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_viewOptions);

    if (!sipMeth)
        return ::QUndoView::viewOptions();

    extern ::QStyleOptionViewItem sipVH_QtWidgets_70(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_70(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQUndoView::startDrag(::Qt::DropActions a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_startDrag);

    if (!sipMeth)
    {
        ::QUndoView::startDrag(a0);
        return;
    }

    extern void sipVH_QtWidgets_69(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::DropActions);

    sipVH_QtWidgets_69(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QItemSelectionModel::SelectionFlags sipQUndoView::selectionCommand(const ::QModelIndex& a0, const ::QEvent*a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_selectionCommand);

    if (!sipMeth)
        return ::QUndoView::selectionCommand(a0, a1);

    extern ::QItemSelectionModel::SelectionFlags sipVH_QtWidgets_68(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const ::QEvent*);

    return sipVH_QtWidgets_68(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQUndoView::edit(const ::QModelIndex& a0, ::QAbstractItemView::EditTrigger a1, ::QEvent*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_edit);

    if (!sipMeth)
        return ::QUndoView::edit(a0, a1, a2);

    extern bool sipVH_QtWidgets_67(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, ::QAbstractItemView::EditTrigger, ::QEvent*);

    return sipVH_QtWidgets_67(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QModelIndexList sipQUndoView::selectedIndexes() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_selectedIndexes);

    if (!sipMeth)
        return ::QUndoView::selectedIndexes();

    extern ::QModelIndexList sipVH_QtWidgets_66(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_66(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QRegion sipQUndoView::visualRegionForSelection(const ::QItemSelection& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_visualRegionForSelection);

    if (!sipMeth)
        return ::QUndoView::visualRegionForSelection(a0);

    extern ::QRegion sipVH_QtWidgets_65(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QItemSelection&);

    return sipVH_QtWidgets_65(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::setSelection(const ::QRect& a0, ::QItemSelectionModel::SelectionFlags a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_setSelection);

    if (!sipMeth)
    {
        ::QUndoView::setSelection(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_64(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QRect&, ::QItemSelectionModel::SelectionFlags);

    sipVH_QtWidgets_64(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQUndoView::isIndexHidden(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isIndexHidden);

    if (!sipMeth)
        return ::QUndoView::isIndexHidden(a0);

    extern bool sipVH_QtWidgets_63(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtWidgets_63(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQUndoView::verticalOffset() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_verticalOffset);

    if (!sipMeth)
        return ::QUndoView::verticalOffset();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQUndoView::horizontalOffset() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_horizontalOffset);

    if (!sipMeth)
        return ::QUndoView::horizontalOffset();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QModelIndex sipQUndoView::moveCursor(::QAbstractItemView::CursorAction a0, ::Qt::KeyboardModifiers a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_moveCursor);

    if (!sipMeth)
        return ::QUndoView::moveCursor(a0, a1);

    extern ::QModelIndex sipVH_QtWidgets_62(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QAbstractItemView::CursorAction, ::Qt::KeyboardModifiers);

    return sipVH_QtWidgets_62(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQUndoView::editorDestroyed(::QObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_editorDestroyed);

    if (!sipMeth)
    {
        ::QUndoView::editorDestroyed(a0);
        return;
    }

    extern void sipVH_QtWidgets_61(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*);

    sipVH_QtWidgets_61(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::commitData(::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_commitData);

    if (!sipMeth)
    {
        ::QUndoView::commitData(a0);
        return;
    }

    extern void sipVH_QtWidgets_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*);

    sipVH_QtWidgets_47(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::closeEditor(::QWidget*a0, ::QAbstractItemDelegate::EndEditHint a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_closeEditor);

    if (!sipMeth)
    {
        ::QUndoView::closeEditor(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_60(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*, ::QAbstractItemDelegate::EndEditHint);

    sipVH_QtWidgets_60(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQUndoView::horizontalScrollbarValueChanged(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_horizontalScrollbarValueChanged);

    if (!sipMeth)
    {
        ::QUndoView::horizontalScrollbarValueChanged(a0);
        return;
    }

    extern void sipVH_QtWidgets_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_59(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::verticalScrollbarValueChanged(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_verticalScrollbarValueChanged);

    if (!sipMeth)
    {
        ::QUndoView::verticalScrollbarValueChanged(a0);
        return;
    }

    extern void sipVH_QtWidgets_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_59(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::horizontalScrollbarAction(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_horizontalScrollbarAction);

    if (!sipMeth)
    {
        ::QUndoView::horizontalScrollbarAction(a0);
        return;
    }

    extern void sipVH_QtWidgets_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_59(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::verticalScrollbarAction(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_verticalScrollbarAction);

    if (!sipMeth)
    {
        ::QUndoView::verticalScrollbarAction(a0);
        return;
    }

    extern void sipVH_QtWidgets_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_59(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::updateGeometries()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_updateGeometries);

    if (!sipMeth)
    {
        ::QUndoView::updateGeometries();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQUndoView::updateEditorGeometries()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_updateEditorGeometries);

    if (!sipMeth)
    {
        ::QUndoView::updateEditorGeometries();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQUndoView::updateEditorData()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_updateEditorData);

    if (!sipMeth)
    {
        ::QUndoView::updateEditorData();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQUndoView::currentChanged(const ::QModelIndex& a0, const ::QModelIndex& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_currentChanged);

    if (!sipMeth)
    {
        ::QUndoView::currentChanged(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_58(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const ::QModelIndex&);

    sipVH_QtWidgets_58(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQUndoView::selectionChanged(const ::QItemSelection& a0, const ::QItemSelection& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_selectionChanged);

    if (!sipMeth)
    {
        ::QUndoView::selectionChanged(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_57(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QItemSelection&, const ::QItemSelection&);

    sipVH_QtWidgets_57(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQUndoView::rowsAboutToBeRemoved(const ::QModelIndex& a0, int a1, int a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_rowsAboutToBeRemoved);

    if (!sipMeth)
    {
        ::QUndoView::rowsAboutToBeRemoved(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_56(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, int);

    sipVH_QtWidgets_56(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQUndoView::rowsInserted(const ::QModelIndex& a0, int a1, int a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_rowsInserted);

    if (!sipMeth)
    {
        ::QUndoView::rowsInserted(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_56(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, int);

    sipVH_QtWidgets_56(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQUndoView::dataChanged(const ::QModelIndex& a0, const ::QModelIndex& a1, const ::QVector<int>& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_dataChanged);

    if (!sipMeth)
    {
        ::QUndoView::dataChanged(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_55(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const ::QModelIndex&, const ::QVector<int>&);

    sipVH_QtWidgets_55(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQUndoView::selectAll()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_selectAll);

    if (!sipMeth)
    {
        ::QUndoView::selectAll();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQUndoView::setRootIndex(const ::QModelIndex& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_setRootIndex);

    if (!sipMeth)
    {
        ::QUndoView::setRootIndex(a0);
        return;
    }

    extern void sipVH_QtWidgets_54(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    sipVH_QtWidgets_54(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::reset()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_reset);

    if (!sipMeth)
    {
        ::QUndoView::reset();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQUndoView::sizeHintForColumn(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[29]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHintForColumn);

    if (!sipMeth)
        return ::QUndoView::sizeHintForColumn(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQUndoView::sizeHintForRow(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[30]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHintForRow);

    if (!sipMeth)
        return ::QUndoView::sizeHintForRow(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QModelIndex sipQUndoView::indexAt(const ::QPoint& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[31]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_indexAt);

    if (!sipMeth)
        return ::QUndoView::indexAt(a0);

    extern ::QModelIndex sipVH_QtWidgets_53(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPoint&);

    return sipVH_QtWidgets_53(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::scrollTo(const ::QModelIndex& a0, ::QAbstractItemView::ScrollHint a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_scrollTo);

    if (!sipMeth)
    {
        ::QUndoView::scrollTo(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_52(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, ::QAbstractItemView::ScrollHint);

    sipVH_QtWidgets_52(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QRect sipQUndoView::visualRect(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[33]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_visualRect);

    if (!sipMeth)
        return ::QUndoView::visualRect(a0);

    extern ::QRect sipVH_QtWidgets_51(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtWidgets_51(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::keyboardSearch(const ::QString& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_keyboardSearch);

    if (!sipMeth)
    {
        ::QUndoView::keyboardSearch(a0);
        return;
    }

    extern void sipVH_QtWidgets_50(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    sipVH_QtWidgets_50(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::setSelectionModel(::QItemSelectionModel*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_setSelectionModel);

    if (!sipMeth)
    {
        ::QUndoView::setSelectionModel(a0);
        return;
    }

    extern void sipVH_QtWidgets_49(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QItemSelectionModel*);

    sipVH_QtWidgets_49(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::setModel(::QAbstractItemModel*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_setModel);

    if (!sipMeth)
    {
        ::QUndoView::setModel(a0);
        return;
    }

    extern void sipVH_QtWidgets_48(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QAbstractItemModel*);

    sipVH_QtWidgets_48(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QUndoView::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[38], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QUndoView::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QUndoView::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QUndoView::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[41], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QUndoView::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQUndoView::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[42], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QUndoView::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQUndoView::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[43], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QUndoView::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQUndoView::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[44]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QUndoView::metric(a0);

    extern int sipVH_QtWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPaintEngine* sipQUndoView::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[45]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QUndoView::paintEngine();

    extern ::QPaintEngine* sipVH_QtWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQUndoView::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[46]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QUndoView::devType();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQUndoView::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[47], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QUndoView::setVisible(a0);
        return;
    }

    extern void sipVH_QtWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQUndoView::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[48]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QUndoView::sizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQUndoView::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[49]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QUndoView::minimumSizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQUndoView::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[50]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QUndoView::heightForWidth(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[51], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QUndoView::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[52], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QUndoView::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[53], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QUndoView::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[54], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QUndoView::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[55], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QUndoView::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[56], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QUndoView::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[57], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QUndoView::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[58], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QUndoView::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[59], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QUndoView::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::enterEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[60], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QUndoView::enterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[61], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QUndoView::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[62], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QUndoView::paintEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[63], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QUndoView::moveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[64], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QUndoView::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[65], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QUndoView::closeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[66], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QUndoView::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtWidgets_20(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[67], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QUndoView::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[68], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QUndoView::actionEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[69], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QUndoView::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[70], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QUndoView::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[71], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QUndoView::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[72], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QUndoView::dropEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[73], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QUndoView::showEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[74], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QUndoView::hideEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[75], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QUndoView::changeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[76], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QUndoView::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQUndoView::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[77]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QUndoView::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQUndoView::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[78], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QUndoView::focusNextPrevChild(a0);

    extern bool sipVH_QtWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQUndoView::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[79]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QUndoView::hasHeightForWidth();

    extern bool sipVH_QtWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQUndoView::nativeEvent(const ::QByteArray& a0, void*a1, long*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[80], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QUndoView::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, long*);

    return sipVH_QtWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPainter* sipQUndoView::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[81]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QUndoView::sharedPainter();

    extern ::QPainter* sipVH_QtWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQUndoView::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[82]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QUndoView::initPainter(a0);
        return;
    }

    extern void sipVH_QtWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQUndoView::viewportSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[83]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_viewportSizeHint);

    if (!sipMeth)
        return ::QUndoView::viewportSizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQUndoView::viewportEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[84], &sipPySelf, SIP_NULLPTR, sipName_viewportEvent);

    if (!sipMeth)
        return ::QUndoView::viewportEvent(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQUndoView::scrollContentsBy(int a0, int a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[85], &sipPySelf, SIP_NULLPTR, sipName_scrollContentsBy);

    if (!sipMeth)
    {
        ::QUndoView::scrollContentsBy(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_46(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int);

    sipVH_QtWidgets_46(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQUndoView::setupViewport(::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[86], &sipPySelf, SIP_NULLPTR, sipName_setupViewport);

    if (!sipMeth)
    {
        ::QUndoView::setupViewport(a0);
        return;
    }

    extern void sipVH_QtWidgets_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*);

    sipVH_QtWidgets_47(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QUndoView_stack, "stack(self) -> Optional[QUndoStack]");

extern "C" {static PyObject *meth_QUndoView_stack(PyObject *, PyObject *);}
static PyObject *meth_QUndoView_stack(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUndoView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUndoView, &sipCpp))
        {
            ::QUndoStack*sipRes;

            sipRes = sipCpp->stack();

            return sipConvertFromType(sipRes, sipType_QUndoStack, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUndoView, sipName_stack, doc_QUndoView_stack);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUndoView_group, "group(self) -> Optional[QUndoGroup]");

extern "C" {static PyObject *meth_QUndoView_group(PyObject *, PyObject *);}
static PyObject *meth_QUndoView_group(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUndoView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUndoView, &sipCpp))
        {
            ::QUndoGroup*sipRes;

            sipRes = sipCpp->group();

            return sipConvertFromType(sipRes, sipType_QUndoGroup, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUndoView, sipName_group, doc_QUndoView_group);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUndoView_setEmptyLabel, "setEmptyLabel(self, label: Optional[str])");

extern "C" {static PyObject *meth_QUndoView_setEmptyLabel(PyObject *, PyObject *);}
static PyObject *meth_QUndoView_setEmptyLabel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QUndoView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QUndoView, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setEmptyLabel(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUndoView, sipName_setEmptyLabel, doc_QUndoView_setEmptyLabel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUndoView_emptyLabel, "emptyLabel(self) -> str");

extern "C" {static PyObject *meth_QUndoView_emptyLabel(PyObject *, PyObject *);}
static PyObject *meth_QUndoView_emptyLabel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUndoView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUndoView, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->emptyLabel());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUndoView, sipName_emptyLabel, doc_QUndoView_emptyLabel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUndoView_setCleanIcon, "setCleanIcon(self, icon: QIcon)");

extern "C" {static PyObject *meth_QUndoView_setCleanIcon(PyObject *, PyObject *);}
static PyObject *meth_QUndoView_setCleanIcon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QIcon* a0;
        ::QUndoView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QUndoView, &sipCpp, sipType_QIcon, &a0))
        {
            sipCpp->setCleanIcon(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUndoView, sipName_setCleanIcon, doc_QUndoView_setCleanIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUndoView_cleanIcon, "cleanIcon(self) -> QIcon");

extern "C" {static PyObject *meth_QUndoView_cleanIcon(PyObject *, PyObject *);}
static PyObject *meth_QUndoView_cleanIcon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUndoView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QUndoView, &sipCpp))
        {
            ::QIcon*sipRes;

            sipRes = new ::QIcon(sipCpp->cleanIcon());

            return sipConvertFromNewType(sipRes, sipType_QIcon, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QUndoView, sipName_cleanIcon, doc_QUndoView_cleanIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUndoView_setStack, "setStack(self, stack: Optional[QUndoStack])");

extern "C" {static PyObject *meth_QUndoView_setStack(PyObject *, PyObject *);}
static PyObject *meth_QUndoView_setStack(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QUndoStack* a0;
        PyObject *a0Keep;
        ::QUndoView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QUndoView, &sipCpp, &a0Keep, sipType_QUndoStack, &a0))
        {
            sipCpp->setStack(a0);

            sipKeepReference(sipSelf, -55, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUndoView, sipName_setStack, doc_QUndoView_setStack);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QUndoView_setGroup, "setGroup(self, group: Optional[QUndoGroup])");

extern "C" {static PyObject *meth_QUndoView_setGroup(PyObject *, PyObject *);}
static PyObject *meth_QUndoView_setGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QUndoGroup* a0;
        PyObject *a0Keep;
        ::QUndoView *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QUndoView, &sipCpp, &a0Keep, sipType_QUndoGroup, &a0))
        {
            sipCpp->setGroup(a0);

            sipKeepReference(sipSelf, -56, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QUndoView, sipName_setGroup, doc_QUndoView_setGroup);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QUndoView(void *, const sipTypeDef *);}
static void *cast_QUndoView(void *sipCppV, const sipTypeDef *targetType)
{
    ::QUndoView *sipCpp = reinterpret_cast< ::QUndoView *>(sipCppV);

    if (targetType == sipType_QUndoView)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QListView)->ctd_cast(static_cast< ::QListView *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QUndoView(void *, int);}
static void release_QUndoView(void *sipCppV, int)
{
    ::QUndoView *sipCpp = reinterpret_cast< ::QUndoView *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QUndoView(Py_ssize_t);}
static void *array_QUndoView(Py_ssize_t sipNrElem)
{
    return new ::QUndoView[sipNrElem];
}


extern "C" {static void array_delete_QUndoView(void *);}
static void array_delete_QUndoView(void *sipCpp)
{
    delete[] reinterpret_cast< ::QUndoView *>(sipCpp);
}


extern "C" {static void dealloc_QUndoView(sipSimpleWrapper *);}
static void dealloc_QUndoView(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQUndoView *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QUndoView(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QUndoView(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QUndoView(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQUndoView *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QWidget, &a0, sipOwner))
        {
            sipCpp = new sipQUndoView(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QUndoStack* a0;
        ::QWidget* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|JH", sipType_QUndoStack, &a0, sipType_QWidget, &a1, sipOwner))
        {
            sipCpp = new sipQUndoView(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QUndoGroup* a0;
        ::QWidget* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|JH", sipType_QUndoGroup, &a0, sipType_QWidget, &a1, sipOwner))
        {
            sipCpp = new sipQUndoView(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QUndoView[] = {{216, 255, 1}};


static PyMethodDef methods_QUndoView[] = {
    {sipName_cleanIcon, meth_QUndoView_cleanIcon, METH_VARARGS, doc_QUndoView_cleanIcon},
    {sipName_emptyLabel, meth_QUndoView_emptyLabel, METH_VARARGS, doc_QUndoView_emptyLabel},
    {sipName_group, meth_QUndoView_group, METH_VARARGS, doc_QUndoView_group},
    {sipName_setCleanIcon, meth_QUndoView_setCleanIcon, METH_VARARGS, doc_QUndoView_setCleanIcon},
    {sipName_setEmptyLabel, meth_QUndoView_setEmptyLabel, METH_VARARGS, doc_QUndoView_setEmptyLabel},
    {sipName_setGroup, meth_QUndoView_setGroup, METH_VARARGS, doc_QUndoView_setGroup},
    {sipName_setStack, meth_QUndoView_setStack, METH_VARARGS, doc_QUndoView_setStack},
    {sipName_stack, meth_QUndoView_stack, METH_VARARGS, doc_QUndoView_stack}
};

PyDoc_STRVAR(doc_QUndoView, "\1QUndoView(parent: Optional[QWidget] = None)\n"
"QUndoView(stack: Optional[QUndoStack], parent: Optional[QWidget] = None)\n"
"QUndoView(group: Optional[QUndoGroup], parent: Optional[QWidget] = None)");


static pyqt5ClassPluginDef plugin_QUndoView = {
    &::QUndoView::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QUndoView = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QUndoView,
        SIP_NULLPTR,
        &plugin_QUndoView,
    },
    {
        sipNameNr_QUndoView,
        {0, 0, 1},
        8, methods_QUndoView,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QUndoView,
    -1,
    -1,
    supers_QUndoView,
    SIP_NULLPTR,
    init_type_QUndoView,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QUndoView,
    SIP_NULLPTR,
    array_QUndoView,
    SIP_NULLPTR,
    release_QUndoView,
    cast_QUndoView,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QUndoView,
    sizeof (::QUndoView),
};
