/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef __QOpenGLFunctions_4_1_CoreAPI_H
#define __QOpenGLFunctions_4_1_CoreAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_PyQt5__QOpenGLFunctions_4_1_Core 0
#define sipName_PyQt5__QOpenGLFunctions_4_1_Core &sipStrings__QOpenGLFunctions_4_1_Core[0]
#define sipNameNr_glRenderbufferStorageMultisample 33
#define sipName_glRenderbufferStorageMultisample &sipStrings__QOpenGLFunctions_4_1_Core[33]
#define sipNameNr_glDrawTransformFeedbackStream 66
#define sipName_glDrawTransformFeedbackStream &sipStrings__QOpenGLFunctions_4_1_Core[66]
#define sipNameNr_glDisableVertexAttribArray 96
#define sipName_glDisableVertexAttribArray &sipStrings__QOpenGLFunctions_4_1_Core[96]
#define sipNameNr_QOpenGLFunctions_4_1_Core 7
#define sipName_QOpenGLFunctions_4_1_Core &sipStrings__QOpenGLFunctions_4_1_Core[7]
#define sipNameNr_glCompressedTexSubImage1D 123
#define sipName_glCompressedTexSubImage1D &sipStrings__QOpenGLFunctions_4_1_Core[123]
#define sipNameNr_glCompressedTexSubImage2D 149
#define sipName_glCompressedTexSubImage2D &sipStrings__QOpenGLFunctions_4_1_Core[149]
#define sipNameNr_glCompressedTexSubImage3D 175
#define sipName_glCompressedTexSubImage3D &sipStrings__QOpenGLFunctions_4_1_Core[175]
#define sipNameNr_glEnableVertexAttribArray 201
#define sipName_glEnableVertexAttribArray &sipStrings__QOpenGLFunctions_4_1_Core[201]
#define sipNameNr_glFramebufferRenderbuffer 227
#define sipName_glFramebufferRenderbuffer &sipStrings__QOpenGLFunctions_4_1_Core[227]
#define sipNameNr_glFramebufferTextureLayer 253
#define sipName_glFramebufferTextureLayer &sipStrings__QOpenGLFunctions_4_1_Core[253]
#define sipNameNr_glResumeTransformFeedback 279
#define sipName_glResumeTransformFeedback &sipStrings__QOpenGLFunctions_4_1_Core[279]
#define sipNameNr_glValidateProgramPipeline 305
#define sipName_glValidateProgramPipeline &sipStrings__QOpenGLFunctions_4_1_Core[305]
#define sipNameNr_initializeOpenGLFunctions 331
#define sipName_initializeOpenGLFunctions &sipStrings__QOpenGLFunctions_4_1_Core[331]
#define sipNameNr_glBeginConditionalRender 357
#define sipName_glBeginConditionalRender &sipStrings__QOpenGLFunctions_4_1_Core[357]
#define sipNameNr_glBeginTransformFeedback 382
#define sipName_glBeginTransformFeedback &sipStrings__QOpenGLFunctions_4_1_Core[382]
#define sipNameNr_glBlendEquationSeparatei 407
#define sipName_glBlendEquationSeparatei &sipStrings__QOpenGLFunctions_4_1_Core[407]
#define sipNameNr_glCheckFramebufferStatus 432
#define sipName_glCheckFramebufferStatus &sipStrings__QOpenGLFunctions_4_1_Core[432]
#define sipNameNr_glGetTexLevelParameterfv 457
#define sipName_glGetTexLevelParameterfv &sipStrings__QOpenGLFunctions_4_1_Core[457]
#define sipNameNr_glGetTexLevelParameteriv 482
#define sipName_glGetTexLevelParameteriv &sipStrings__QOpenGLFunctions_4_1_Core[482]
#define sipNameNr_glPauseTransformFeedback 507
#define sipName_glPauseTransformFeedback &sipStrings__QOpenGLFunctions_4_1_Core[507]
#define sipNameNr_glBindTransformFeedback 532
#define sipName_glBindTransformFeedback &sipStrings__QOpenGLFunctions_4_1_Core[532]
#define sipNameNr_glBlendEquationSeparate 556
#define sipName_glBlendEquationSeparate &sipStrings__QOpenGLFunctions_4_1_Core[556]
#define sipNameNr_glDrawTransformFeedback 580
#define sipName_glDrawTransformFeedback &sipStrings__QOpenGLFunctions_4_1_Core[580]
#define sipNameNr_glPrimitiveRestartIndex 604
#define sipName_glPrimitiveRestartIndex &sipStrings__QOpenGLFunctions_4_1_Core[604]
#define sipNameNr_glReleaseShaderCompiler 628
#define sipName_glReleaseShaderCompiler &sipStrings__QOpenGLFunctions_4_1_Core[628]
#define sipNameNr_glTexImage2DMultisample 652
#define sipName_glTexImage2DMultisample &sipStrings__QOpenGLFunctions_4_1_Core[652]
#define sipNameNr_glTexImage3DMultisample 676
#define sipName_glTexImage3DMultisample &sipStrings__QOpenGLFunctions_4_1_Core[676]
#define sipNameNr_glCompressedTexImage1D 700
#define sipName_glCompressedTexImage1D &sipStrings__QOpenGLFunctions_4_1_Core[700]
#define sipNameNr_glCompressedTexImage2D 723
#define sipName_glCompressedTexImage2D &sipStrings__QOpenGLFunctions_4_1_Core[723]
#define sipNameNr_glCompressedTexImage3D 746
#define sipName_glCompressedTexImage3D &sipStrings__QOpenGLFunctions_4_1_Core[746]
#define sipNameNr_glEndConditionalRender 769
#define sipName_glEndConditionalRender &sipStrings__QOpenGLFunctions_4_1_Core[769]
#define sipNameNr_glEndTransformFeedback 792
#define sipName_glEndTransformFeedback &sipStrings__QOpenGLFunctions_4_1_Core[792]
#define sipNameNr_glFramebufferTexture1D 815
#define sipName_glFramebufferTexture1D &sipStrings__QOpenGLFunctions_4_1_Core[815]
#define sipNameNr_glFramebufferTexture2D 838
#define sipName_glFramebufferTexture2D &sipStrings__QOpenGLFunctions_4_1_Core[838]
#define sipNameNr_glFramebufferTexture3D 861
#define sipName_glFramebufferTexture3D &sipStrings__QOpenGLFunctions_4_1_Core[861]
#define sipNameNr_glGetBufferParameteriv 884
#define sipName_glGetBufferParameteriv &sipStrings__QOpenGLFunctions_4_1_Core[884]
#define sipNameNr_glActiveShaderProgram 907
#define sipName_glActiveShaderProgram &sipStrings__QOpenGLFunctions_4_1_Core[907]
#define sipNameNr_glBindProgramPipeline 929
#define sipName_glBindProgramPipeline &sipStrings__QOpenGLFunctions_4_1_Core[929]
#define sipNameNr_glDrawArraysInstanced 951
#define sipName_glDrawArraysInstanced &sipStrings__QOpenGLFunctions_4_1_Core[951]
#define sipNameNr_glIsTransformFeedback 973
#define sipName_glIsTransformFeedback &sipStrings__QOpenGLFunctions_4_1_Core[973]
#define sipNameNr_glRenderbufferStorage 995
#define sipName_glRenderbufferStorage &sipStrings__QOpenGLFunctions_4_1_Core[995]
#define sipNameNr_glStencilFuncSeparate 1017
#define sipName_glStencilFuncSeparate &sipStrings__QOpenGLFunctions_4_1_Core[1017]
#define sipNameNr_glStencilMaskSeparate 1039
#define sipName_glStencilMaskSeparate &sipStrings__QOpenGLFunctions_4_1_Core[1039]
#define sipNameNr_glUniformBlockBinding 1061
#define sipName_glUniformBlockBinding &sipStrings__QOpenGLFunctions_4_1_Core[1061]
#define sipNameNr_glVertexAttribDivisor 1083
#define sipName_glVertexAttribDivisor &sipStrings__QOpenGLFunctions_4_1_Core[1083]
#define sipNameNr_glVertexAttribPointer 1105
#define sipName_glVertexAttribPointer &sipStrings__QOpenGLFunctions_4_1_Core[1105]
#define sipNameNr_glBindAttribLocation 1127
#define sipName_glBindAttribLocation &sipStrings__QOpenGLFunctions_4_1_Core[1127]
#define sipNameNr_glBlendFuncSeparatei 1148
#define sipName_glBlendFuncSeparatei &sipStrings__QOpenGLFunctions_4_1_Core[1148]
#define sipNameNr_glFramebufferTexture 1169
#define sipName_glFramebufferTexture &sipStrings__QOpenGLFunctions_4_1_Core[1169]
#define sipNameNr_glGetAttachedShaders 1190
#define sipName_glGetAttachedShaders &sipStrings__QOpenGLFunctions_4_1_Core[1190]
#define sipNameNr_glGetUniformLocation 1211
#define sipName_glGetUniformLocation &sipStrings__QOpenGLFunctions_4_1_Core[1211]
#define sipNameNr_glSecondaryColorP3ui 1232
#define sipName_glSecondaryColorP3ui &sipStrings__QOpenGLFunctions_4_1_Core[1232]
#define sipNameNr_glBeginQueryIndexed 1253
#define sipName_glBeginQueryIndexed &sipStrings__QOpenGLFunctions_4_1_Core[1253]
#define sipNameNr_glBlendFuncSeparate 1273
#define sipName_glBlendFuncSeparate &sipStrings__QOpenGLFunctions_4_1_Core[1273]
#define sipNameNr_glCopyTexSubImage1D 1293
#define sipName_glCopyTexSubImage1D &sipStrings__QOpenGLFunctions_4_1_Core[1293]
#define sipNameNr_glCopyTexSubImage2D 1313
#define sipName_glCopyTexSubImage2D &sipStrings__QOpenGLFunctions_4_1_Core[1313]
#define sipNameNr_glCopyTexSubImage3D 1333
#define sipName_glCopyTexSubImage3D &sipStrings__QOpenGLFunctions_4_1_Core[1333]
#define sipNameNr_glDepthRangeIndexed 1353
#define sipName_glDepthRangeIndexed &sipStrings__QOpenGLFunctions_4_1_Core[1353]
#define sipNameNr_glDrawRangeElements 1373
#define sipName_glDrawRangeElements &sipStrings__QOpenGLFunctions_4_1_Core[1373]
#define sipNameNr_glGetAttribLocation 1393
#define sipName_glGetAttribLocation &sipStrings__QOpenGLFunctions_4_1_Core[1393]
#define sipNameNr_glGetProgramInfoLog 1413
#define sipName_glGetProgramInfoLog &sipStrings__QOpenGLFunctions_4_1_Core[1413]
#define sipNameNr_glGetTexParameterfv 1433
#define sipName_glGetTexParameterfv &sipStrings__QOpenGLFunctions_4_1_Core[1433]
#define sipNameNr_glGetTexParameteriv 1453
#define sipName_glGetTexParameteriv &sipStrings__QOpenGLFunctions_4_1_Core[1453]
#define sipNameNr_glGetVertexAttribdv 1473
#define sipName_glGetVertexAttribdv &sipStrings__QOpenGLFunctions_4_1_Core[1473]
#define sipNameNr_glGetVertexAttribfv 1493
#define sipName_glGetVertexAttribfv &sipStrings__QOpenGLFunctions_4_1_Core[1493]
#define sipNameNr_glGetVertexAttribiv 1513
#define sipName_glGetVertexAttribiv &sipStrings__QOpenGLFunctions_4_1_Core[1513]
#define sipNameNr_glIsProgramPipeline 1533
#define sipName_glIsProgramPipeline &sipStrings__QOpenGLFunctions_4_1_Core[1533]
#define sipNameNr_glMultiTexCoordP1ui 1553
#define sipName_glMultiTexCoordP1ui &sipStrings__QOpenGLFunctions_4_1_Core[1553]
#define sipNameNr_glMultiTexCoordP2ui 1573
#define sipName_glMultiTexCoordP2ui &sipStrings__QOpenGLFunctions_4_1_Core[1573]
#define sipNameNr_glMultiTexCoordP3ui 1593
#define sipName_glMultiTexCoordP3ui &sipStrings__QOpenGLFunctions_4_1_Core[1593]
#define sipNameNr_glMultiTexCoordP4ui 1613
#define sipName_glMultiTexCoordP4ui &sipStrings__QOpenGLFunctions_4_1_Core[1613]
#define sipNameNr_glProgramParameteri 1633
#define sipName_glProgramParameteri &sipStrings__QOpenGLFunctions_4_1_Core[1633]
#define sipNameNr_glProgramUniform1ui 1653
#define sipName_glProgramUniform1ui &sipStrings__QOpenGLFunctions_4_1_Core[1653]
#define sipNameNr_glProgramUniform2ui 1673
#define sipName_glProgramUniform2ui &sipStrings__QOpenGLFunctions_4_1_Core[1673]
#define sipNameNr_glProgramUniform3ui 1693
#define sipName_glProgramUniform3ui &sipStrings__QOpenGLFunctions_4_1_Core[1693]
#define sipNameNr_glProgramUniform4ui 1713
#define sipName_glProgramUniform4ui &sipStrings__QOpenGLFunctions_4_1_Core[1713]
#define sipNameNr_glSamplerParameterf 1733
#define sipName_glSamplerParameterf &sipStrings__QOpenGLFunctions_4_1_Core[1733]
#define sipNameNr_glSamplerParameteri 1753
#define sipName_glSamplerParameteri &sipStrings__QOpenGLFunctions_4_1_Core[1753]
#define sipNameNr_glStencilOpSeparate 1773
#define sipName_glStencilOpSeparate &sipStrings__QOpenGLFunctions_4_1_Core[1773]
#define sipNameNr_glBindRenderbuffer 1793
#define sipName_glBindRenderbuffer &sipStrings__QOpenGLFunctions_4_1_Core[1793]
#define sipNameNr_glGetActiveUniform 1812
#define sipName_glGetActiveUniform &sipStrings__QOpenGLFunctions_4_1_Core[1812]
#define sipNameNr_glGetShaderInfoLog 1831
#define sipName_glGetShaderInfoLog &sipStrings__QOpenGLFunctions_4_1_Core[1831]
#define sipNameNr_glMinSampleShading 1850
#define sipName_glMinSampleShading &sipStrings__QOpenGLFunctions_4_1_Core[1850]
#define sipNameNr_glPointParameterfv 1869
#define sipName_glPointParameterfv &sipStrings__QOpenGLFunctions_4_1_Core[1869]
#define sipNameNr_glPointParameteriv 1888
#define sipName_glPointParameteriv &sipStrings__QOpenGLFunctions_4_1_Core[1888]
#define sipNameNr_glProgramUniform1d 1907
#define sipName_glProgramUniform1d &sipStrings__QOpenGLFunctions_4_1_Core[1907]
#define sipNameNr_glProgramUniform1f 1926
#define sipName_glProgramUniform1f &sipStrings__QOpenGLFunctions_4_1_Core[1926]
#define sipNameNr_glProgramUniform1i 1945
#define sipName_glProgramUniform1i &sipStrings__QOpenGLFunctions_4_1_Core[1945]
#define sipNameNr_glProgramUniform2d 1964
#define sipName_glProgramUniform2d &sipStrings__QOpenGLFunctions_4_1_Core[1964]
#define sipNameNr_glProgramUniform2f 1983
#define sipName_glProgramUniform2f &sipStrings__QOpenGLFunctions_4_1_Core[1983]
#define sipNameNr_glProgramUniform2i 2002
#define sipName_glProgramUniform2i &sipStrings__QOpenGLFunctions_4_1_Core[2002]
#define sipNameNr_glProgramUniform3d 2021
#define sipName_glProgramUniform3d &sipStrings__QOpenGLFunctions_4_1_Core[2021]
#define sipNameNr_glProgramUniform3f 2040
#define sipName_glProgramUniform3f &sipStrings__QOpenGLFunctions_4_1_Core[2040]
#define sipNameNr_glProgramUniform3i 2059
#define sipName_glProgramUniform3i &sipStrings__QOpenGLFunctions_4_1_Core[2059]
#define sipNameNr_glProgramUniform4d 2078
#define sipName_glProgramUniform4d &sipStrings__QOpenGLFunctions_4_1_Core[2078]
#define sipNameNr_glProgramUniform4f 2097
#define sipName_glProgramUniform4f &sipStrings__QOpenGLFunctions_4_1_Core[2097]
#define sipNameNr_glProgramUniform4i 2116
#define sipName_glProgramUniform4i &sipStrings__QOpenGLFunctions_4_1_Core[2116]
#define sipNameNr_glUniformMatrix2fv 2135
#define sipName_glUniformMatrix2fv &sipStrings__QOpenGLFunctions_4_1_Core[2135]
#define sipNameNr_glUniformMatrix3fv 2154
#define sipName_glUniformMatrix3fv &sipStrings__QOpenGLFunctions_4_1_Core[2154]
#define sipNameNr_glUniformMatrix4fv 2173
#define sipName_glUniformMatrix4fv &sipStrings__QOpenGLFunctions_4_1_Core[2173]
#define sipNameNr_glUseProgramStages 2192
#define sipName_glUseProgramStages &sipStrings__QOpenGLFunctions_4_1_Core[2192]
#define sipNameNr_glVertexAttribP1ui 2211
#define sipName_glVertexAttribP1ui &sipStrings__QOpenGLFunctions_4_1_Core[2211]
#define sipNameNr_glVertexAttribP2ui 2230
#define sipName_glVertexAttribP2ui &sipStrings__QOpenGLFunctions_4_1_Core[2230]
#define sipNameNr_glVertexAttribP3ui 2249
#define sipName_glVertexAttribP3ui &sipStrings__QOpenGLFunctions_4_1_Core[2249]
#define sipNameNr_glVertexAttribP4ui 2268
#define sipName_glVertexAttribP4ui &sipStrings__QOpenGLFunctions_4_1_Core[2268]
#define sipNameNr_glViewportIndexedf 2287
#define sipName_glViewportIndexedf &sipStrings__QOpenGLFunctions_4_1_Core[2287]
#define sipNameNr_glBindFramebuffer 2306
#define sipName_glBindFramebuffer &sipStrings__QOpenGLFunctions_4_1_Core[2306]
#define sipNameNr_glBindVertexArray 2324
#define sipName_glBindVertexArray &sipStrings__QOpenGLFunctions_4_1_Core[2324]
#define sipNameNr_glBlitFramebuffer 2342
#define sipName_glBlitFramebuffer &sipStrings__QOpenGLFunctions_4_1_Core[2342]
#define sipNameNr_glEndQueryIndexed 2360
#define sipName_glEndQueryIndexed &sipStrings__QOpenGLFunctions_4_1_Core[2360]
#define sipNameNr_glGetActiveAttrib 2378
#define sipName_glGetActiveAttrib &sipStrings__QOpenGLFunctions_4_1_Core[2378]
#define sipNameNr_glGetShaderSource 2396
#define sipName_glGetShaderSource &sipStrings__QOpenGLFunctions_4_1_Core[2396]
#define sipNameNr_glPatchParameteri 2414
#define sipName_glPatchParameteri &sipStrings__QOpenGLFunctions_4_1_Core[2414]
#define sipNameNr_glPointParameterf 2432
#define sipName_glPointParameterf &sipStrings__QOpenGLFunctions_4_1_Core[2432]
#define sipNameNr_glPointParameteri 2450
#define sipName_glPointParameteri &sipStrings__QOpenGLFunctions_4_1_Core[2450]
#define sipNameNr_glProvokingVertex 2468
#define sipName_glProvokingVertex &sipStrings__QOpenGLFunctions_4_1_Core[2468]
#define sipNameNr_glValidateProgram 2486
#define sipName_glValidateProgram &sipStrings__QOpenGLFunctions_4_1_Core[2486]
#define sipNameNr_glVertexAttribL1d 2504
#define sipName_glVertexAttribL1d &sipStrings__QOpenGLFunctions_4_1_Core[2504]
#define sipNameNr_glVertexAttribL2d 2522
#define sipName_glVertexAttribL2d &sipStrings__QOpenGLFunctions_4_1_Core[2522]
#define sipNameNr_glVertexAttribL3d 2540
#define sipName_glVertexAttribL3d &sipStrings__QOpenGLFunctions_4_1_Core[2540]
#define sipNameNr_glVertexAttribL4d 2558
#define sipName_glVertexAttribL4d &sipStrings__QOpenGLFunctions_4_1_Core[2558]
#define sipNameNr_glBindBufferBase 2576
#define sipName_glBindBufferBase &sipStrings__QOpenGLFunctions_4_1_Core[2576]
#define sipNameNr_glBlendEquationi 2593
#define sipName_glBlendEquationi &sipStrings__QOpenGLFunctions_4_1_Core[2593]
#define sipNameNr_glCopyTexImage1D 2610
#define sipName_glCopyTexImage1D &sipStrings__QOpenGLFunctions_4_1_Core[2610]
#define sipNameNr_glCopyTexImage2D 2627
#define sipName_glCopyTexImage2D &sipStrings__QOpenGLFunctions_4_1_Core[2627]
#define sipNameNr_glDeleteTextures 2644
#define sipName_glDeleteTextures &sipStrings__QOpenGLFunctions_4_1_Core[2644]
#define sipNameNr_glGenerateMipmap 2661
#define sipName_glGenerateMipmap &sipStrings__QOpenGLFunctions_4_1_Core[2661]
#define sipNameNr_glIsRenderbuffer 2678
#define sipName_glIsRenderbuffer &sipStrings__QOpenGLFunctions_4_1_Core[2678]
#define sipNameNr_glSampleCoverage 2695
#define sipName_glSampleCoverage &sipStrings__QOpenGLFunctions_4_1_Core[2695]
#define sipNameNr_glScissorIndexed 2712
#define sipName_glScissorIndexed &sipStrings__QOpenGLFunctions_4_1_Core[2712]
#define sipNameNr_glTexParameterfv 2729
#define sipName_glTexParameterfv &sipStrings__QOpenGLFunctions_4_1_Core[2729]
#define sipNameNr_glTexParameteriv 2746
#define sipName_glTexParameteriv &sipStrings__QOpenGLFunctions_4_1_Core[2746]
#define sipNameNr_glActiveTexture 2763
#define sipName_glActiveTexture &sipStrings__QOpenGLFunctions_4_1_Core[2763]
#define sipNameNr_glBlendEquation 2779
#define sipName_glBlendEquation &sipStrings__QOpenGLFunctions_4_1_Core[2779]
#define sipNameNr_glBufferSubData 2795
#define sipName_glBufferSubData &sipStrings__QOpenGLFunctions_4_1_Core[2795]
#define sipNameNr_glClearBufferfi 2811
#define sipName_glClearBufferfi &sipStrings__QOpenGLFunctions_4_1_Core[2811]
#define sipNameNr_glCompileShader 2827
#define sipName_glCompileShader &sipStrings__QOpenGLFunctions_4_1_Core[2827]
#define sipNameNr_glCreateProgram 2843
#define sipName_glCreateProgram &sipStrings__QOpenGLFunctions_4_1_Core[2843]
#define sipNameNr_glDeleteBuffers 2859
#define sipName_glDeleteBuffers &sipStrings__QOpenGLFunctions_4_1_Core[2859]
#define sipNameNr_glDeleteProgram 2875
#define sipName_glDeleteProgram &sipStrings__QOpenGLFunctions_4_1_Core[2875]
#define sipNameNr_glDeleteQueries 2891
#define sipName_glDeleteQueries &sipStrings__QOpenGLFunctions_4_1_Core[2891]
#define sipNameNr_glIsFramebuffer 2907
#define sipName_glIsFramebuffer &sipStrings__QOpenGLFunctions_4_1_Core[2907]
#define sipNameNr_glIsVertexArray 2923
#define sipName_glIsVertexArray &sipStrings__QOpenGLFunctions_4_1_Core[2923]
#define sipNameNr_glPolygonOffset 2939
#define sipName_glPolygonOffset &sipStrings__QOpenGLFunctions_4_1_Core[2939]
#define sipNameNr_glTexParameterf 2955
#define sipName_glTexParameterf &sipStrings__QOpenGLFunctions_4_1_Core[2955]
#define sipNameNr_glTexParameteri 2971
#define sipName_glTexParameteri &sipStrings__QOpenGLFunctions_4_1_Core[2971]
#define sipNameNr_glTexSubImage1D 2987
#define sipName_glTexSubImage1D &sipStrings__QOpenGLFunctions_4_1_Core[2987]
#define sipNameNr_glTexSubImage2D 3003
#define sipName_glTexSubImage2D &sipStrings__QOpenGLFunctions_4_1_Core[3003]
#define sipNameNr_glTexSubImage3D 3019
#define sipName_glTexSubImage3D &sipStrings__QOpenGLFunctions_4_1_Core[3019]
#define sipNameNr_glAttachShader 3035
#define sipName_glAttachShader &sipStrings__QOpenGLFunctions_4_1_Core[3035]
#define sipNameNr_glClearStencil 3050
#define sipName_glClearStencil &sipStrings__QOpenGLFunctions_4_1_Core[3050]
#define sipNameNr_glCreateShader 3065
#define sipName_glCreateShader &sipStrings__QOpenGLFunctions_4_1_Core[3065]
#define sipNameNr_glDeleteShader 3080
#define sipName_glDeleteShader &sipStrings__QOpenGLFunctions_4_1_Core[3080]
#define sipNameNr_glDetachShader 3095
#define sipName_glDetachShader &sipStrings__QOpenGLFunctions_4_1_Core[3095]
#define sipNameNr_glDrawElements 3110
#define sipName_glDrawElements &sipStrings__QOpenGLFunctions_4_1_Core[3110]
#define sipNameNr_glGetProgramiv 3125
#define sipName_glGetProgramiv &sipStrings__QOpenGLFunctions_4_1_Core[3125]
#define sipNameNr_glQueryCounter 3140
#define sipName_glQueryCounter &sipStrings__QOpenGLFunctions_4_1_Core[3140]
#define sipNameNr_glTexCoordP1ui 3155
#define sipName_glTexCoordP1ui &sipStrings__QOpenGLFunctions_4_1_Core[3155]
#define sipNameNr_glTexCoordP2ui 3170
#define sipName_glTexCoordP2ui &sipStrings__QOpenGLFunctions_4_1_Core[3170]
#define sipNameNr_glTexCoordP3ui 3185
#define sipName_glTexCoordP3ui &sipStrings__QOpenGLFunctions_4_1_Core[3185]
#define sipNameNr_glTexCoordP4ui 3200
#define sipName_glTexCoordP4ui &sipStrings__QOpenGLFunctions_4_1_Core[3200]
#define sipNameNr_glBindSampler 3215
#define sipName_glBindSampler &sipStrings__QOpenGLFunctions_4_1_Core[3215]
#define sipNameNr_glBindTexture 3229
#define sipName_glBindTexture &sipStrings__QOpenGLFunctions_4_1_Core[3229]
#define sipNameNr_glClearDepthf 3243
#define sipName_glClearDepthf &sipStrings__QOpenGLFunctions_4_1_Core[3243]
#define sipNameNr_glDepthRangef 3257
#define sipName_glDepthRangef &sipStrings__QOpenGLFunctions_4_1_Core[3257]
#define sipNameNr_glDrawBuffers 3271
#define sipName_glDrawBuffers &sipStrings__QOpenGLFunctions_4_1_Core[3271]
#define sipNameNr_glGenTextures 3285
#define sipName_glGenTextures &sipStrings__QOpenGLFunctions_4_1_Core[3285]
#define sipNameNr_glGetBooleanv 3299
#define sipName_glGetBooleanv &sipStrings__QOpenGLFunctions_4_1_Core[3299]
#define sipNameNr_glGetIntegerv 3313
#define sipName_glGetIntegerv &sipStrings__QOpenGLFunctions_4_1_Core[3313]
#define sipNameNr_glGetShaderiv 3327
#define sipName_glGetShaderiv &sipStrings__QOpenGLFunctions_4_1_Core[3327]
#define sipNameNr_glLinkProgram 3341
#define sipName_glLinkProgram &sipStrings__QOpenGLFunctions_4_1_Core[3341]
#define sipNameNr_glPixelStoref 3355
#define sipName_glPixelStoref &sipStrings__QOpenGLFunctions_4_1_Core[3355]
#define sipNameNr_glPixelStorei 3369
#define sipName_glPixelStorei &sipStrings__QOpenGLFunctions_4_1_Core[3369]
#define sipNameNr_glPolygonMode 3383
#define sipName_glPolygonMode &sipStrings__QOpenGLFunctions_4_1_Core[3383]
#define sipNameNr_glSampleMaski 3397
#define sipName_glSampleMaski &sipStrings__QOpenGLFunctions_4_1_Core[3397]
#define sipNameNr_glStencilFunc 3411
#define sipName_glStencilFunc &sipStrings__QOpenGLFunctions_4_1_Core[3411]
#define sipNameNr_glStencilMask 3425
#define sipName_glStencilMask &sipStrings__QOpenGLFunctions_4_1_Core[3425]
#define sipNameNr_glUnmapBuffer 3439
#define sipName_glUnmapBuffer &sipStrings__QOpenGLFunctions_4_1_Core[3439]
#define sipNameNr_glBeginQuery 3453
#define sipName_glBeginQuery &sipStrings__QOpenGLFunctions_4_1_Core[3453]
#define sipNameNr_glBindBuffer 3466
#define sipName_glBindBuffer &sipStrings__QOpenGLFunctions_4_1_Core[3466]
#define sipNameNr_glBlendColor 3479
#define sipName_glBlendColor &sipStrings__QOpenGLFunctions_4_1_Core[3479]
#define sipNameNr_glBlendFunci 3492
#define sipName_glBlendFunci &sipStrings__QOpenGLFunctions_4_1_Core[3492]
#define sipNameNr_glBufferData 3505
#define sipName_glBufferData &sipStrings__QOpenGLFunctions_4_1_Core[3505]
#define sipNameNr_glClampColor 3518
#define sipName_glClampColor &sipStrings__QOpenGLFunctions_4_1_Core[3518]
#define sipNameNr_glClearColor 3531
#define sipName_glClearColor &sipStrings__QOpenGLFunctions_4_1_Core[3531]
#define sipNameNr_glClearDepth 3544
#define sipName_glClearDepth &sipStrings__QOpenGLFunctions_4_1_Core[3544]
#define sipNameNr_glColorMaski 3557
#define sipName_glColorMaski &sipStrings__QOpenGLFunctions_4_1_Core[3557]
#define sipNameNr_glDepthRange 3570
#define sipName_glDepthRange &sipStrings__QOpenGLFunctions_4_1_Core[3570]
#define sipNameNr_glDrawArrays 3583
#define sipName_glDrawArrays &sipStrings__QOpenGLFunctions_4_1_Core[3583]
#define sipNameNr_glDrawBuffer 3596
#define sipName_glDrawBuffer &sipStrings__QOpenGLFunctions_4_1_Core[3596]
#define sipNameNr_glGenBuffers 3609
#define sipName_glGenBuffers &sipStrings__QOpenGLFunctions_4_1_Core[3609]
#define sipNameNr_glGenQueries 3622
#define sipName_glGenQueries &sipStrings__QOpenGLFunctions_4_1_Core[3622]
#define sipNameNr_glGetDoublev 3635
#define sipName_glGetDoublev &sipStrings__QOpenGLFunctions_4_1_Core[3635]
#define sipNameNr_glGetQueryiv 3648
#define sipName_glGetQueryiv &sipStrings__QOpenGLFunctions_4_1_Core[3648]
#define sipNameNr_glIsEnabledi 3661
#define sipName_glIsEnabledi &sipStrings__QOpenGLFunctions_4_1_Core[3661]
#define sipNameNr_glNormalP3ui 3674
#define sipName_glNormalP3ui &sipStrings__QOpenGLFunctions_4_1_Core[3674]
#define sipNameNr_glReadBuffer 3687
#define sipName_glReadBuffer &sipStrings__QOpenGLFunctions_4_1_Core[3687]
#define sipNameNr_glReadPixels 3700
#define sipName_glReadPixels &sipStrings__QOpenGLFunctions_4_1_Core[3700]
#define sipNameNr_glTexImage1D 3713
#define sipName_glTexImage1D &sipStrings__QOpenGLFunctions_4_1_Core[3713]
#define sipNameNr_glTexImage2D 3726
#define sipName_glTexImage2D &sipStrings__QOpenGLFunctions_4_1_Core[3726]
#define sipNameNr_glTexImage3D 3739
#define sipName_glTexImage3D &sipStrings__QOpenGLFunctions_4_1_Core[3739]
#define sipNameNr_glUniform1fv 3752
#define sipName_glUniform1fv &sipStrings__QOpenGLFunctions_4_1_Core[3752]
#define sipNameNr_glUniform1iv 3765
#define sipName_glUniform1iv &sipStrings__QOpenGLFunctions_4_1_Core[3765]
#define sipNameNr_glUniform1ui 3778
#define sipName_glUniform1ui &sipStrings__QOpenGLFunctions_4_1_Core[3778]
#define sipNameNr_glUniform2fv 3791
#define sipName_glUniform2fv &sipStrings__QOpenGLFunctions_4_1_Core[3791]
#define sipNameNr_glUniform2iv 3804
#define sipName_glUniform2iv &sipStrings__QOpenGLFunctions_4_1_Core[3804]
#define sipNameNr_glUniform2ui 3817
#define sipName_glUniform2ui &sipStrings__QOpenGLFunctions_4_1_Core[3817]
#define sipNameNr_glUniform3fv 3830
#define sipName_glUniform3fv &sipStrings__QOpenGLFunctions_4_1_Core[3830]
#define sipNameNr_glUniform3iv 3843
#define sipName_glUniform3iv &sipStrings__QOpenGLFunctions_4_1_Core[3843]
#define sipNameNr_glUniform3ui 3856
#define sipName_glUniform3ui &sipStrings__QOpenGLFunctions_4_1_Core[3856]
#define sipNameNr_glUniform4fv 3869
#define sipName_glUniform4fv &sipStrings__QOpenGLFunctions_4_1_Core[3869]
#define sipNameNr_glUniform4iv 3882
#define sipName_glUniform4iv &sipStrings__QOpenGLFunctions_4_1_Core[3882]
#define sipNameNr_glUniform4ui 3895
#define sipName_glUniform4ui &sipStrings__QOpenGLFunctions_4_1_Core[3895]
#define sipNameNr_glUseProgram 3908
#define sipName_glUseProgram &sipStrings__QOpenGLFunctions_4_1_Core[3908]
#define sipNameNr_glVertexP2ui 3921
#define sipName_glVertexP2ui &sipStrings__QOpenGLFunctions_4_1_Core[3921]
#define sipNameNr_glVertexP3ui 3934
#define sipName_glVertexP3ui &sipStrings__QOpenGLFunctions_4_1_Core[3934]
#define sipNameNr_glVertexP4ui 3947
#define sipName_glVertexP4ui &sipStrings__QOpenGLFunctions_4_1_Core[3947]
#define sipNameNr_glBlendFunc 3960
#define sipName_glBlendFunc &sipStrings__QOpenGLFunctions_4_1_Core[3960]
#define sipNameNr_glColorMask 3972
#define sipName_glColorMask &sipStrings__QOpenGLFunctions_4_1_Core[3972]
#define sipNameNr_glColorP3ui 3984
#define sipName_glColorP3ui &sipStrings__QOpenGLFunctions_4_1_Core[3984]
#define sipNameNr_glColorP4ui 3996
#define sipName_glColorP4ui &sipStrings__QOpenGLFunctions_4_1_Core[3996]
#define sipNameNr_glDepthFunc 4008
#define sipName_glDepthFunc &sipStrings__QOpenGLFunctions_4_1_Core[4008]
#define sipNameNr_glDepthMask 4020
#define sipName_glDepthMask &sipStrings__QOpenGLFunctions_4_1_Core[4020]
#define sipNameNr_glFrontFace 4032
#define sipName_glFrontFace &sipStrings__QOpenGLFunctions_4_1_Core[4032]
#define sipNameNr_glGetFloatv 4044
#define sipName_glGetFloatv &sipStrings__QOpenGLFunctions_4_1_Core[4044]
#define sipNameNr_glGetString 4056
#define sipName_glGetString &sipStrings__QOpenGLFunctions_4_1_Core[4056]
#define sipNameNr_glIsEnabled 4068
#define sipName_glIsEnabled &sipStrings__QOpenGLFunctions_4_1_Core[4068]
#define sipNameNr_glIsProgram 4080
#define sipName_glIsProgram &sipStrings__QOpenGLFunctions_4_1_Core[4080]
#define sipNameNr_glIsSampler 4092
#define sipName_glIsSampler &sipStrings__QOpenGLFunctions_4_1_Core[4092]
#define sipNameNr_glIsTexture 4104
#define sipName_glIsTexture &sipStrings__QOpenGLFunctions_4_1_Core[4104]
#define sipNameNr_glLineWidth 4116
#define sipName_glLineWidth &sipStrings__QOpenGLFunctions_4_1_Core[4116]
#define sipNameNr_glPointSize 4128
#define sipName_glPointSize &sipStrings__QOpenGLFunctions_4_1_Core[4128]
#define sipNameNr_glStencilOp 4140
#define sipName_glStencilOp &sipStrings__QOpenGLFunctions_4_1_Core[4140]
#define sipNameNr_glTexBuffer 4152
#define sipName_glTexBuffer &sipStrings__QOpenGLFunctions_4_1_Core[4152]
#define sipNameNr_glUniform1d 4164
#define sipName_glUniform1d &sipStrings__QOpenGLFunctions_4_1_Core[4164]
#define sipNameNr_glUniform1f 4176
#define sipName_glUniform1f &sipStrings__QOpenGLFunctions_4_1_Core[4176]
#define sipNameNr_glUniform1i 4188
#define sipName_glUniform1i &sipStrings__QOpenGLFunctions_4_1_Core[4188]
#define sipNameNr_glUniform2d 4200
#define sipName_glUniform2d &sipStrings__QOpenGLFunctions_4_1_Core[4200]
#define sipNameNr_glUniform2f 4212
#define sipName_glUniform2f &sipStrings__QOpenGLFunctions_4_1_Core[4212]
#define sipNameNr_glUniform2i 4224
#define sipName_glUniform2i &sipStrings__QOpenGLFunctions_4_1_Core[4224]
#define sipNameNr_glUniform3d 4236
#define sipName_glUniform3d &sipStrings__QOpenGLFunctions_4_1_Core[4236]
#define sipNameNr_glUniform3f 4248
#define sipName_glUniform3f &sipStrings__QOpenGLFunctions_4_1_Core[4248]
#define sipNameNr_glUniform3i 4260
#define sipName_glUniform3i &sipStrings__QOpenGLFunctions_4_1_Core[4260]
#define sipNameNr_glUniform4d 4272
#define sipName_glUniform4d &sipStrings__QOpenGLFunctions_4_1_Core[4272]
#define sipNameNr_glUniform4f 4284
#define sipName_glUniform4f &sipStrings__QOpenGLFunctions_4_1_Core[4284]
#define sipNameNr_glUniform4i 4296
#define sipName_glUniform4i &sipStrings__QOpenGLFunctions_4_1_Core[4296]
#define sipNameNr_glCullFace 4308
#define sipName_glCullFace &sipStrings__QOpenGLFunctions_4_1_Core[4308]
#define sipNameNr_glDisablei 4319
#define sipName_glDisablei &sipStrings__QOpenGLFunctions_4_1_Core[4319]
#define sipNameNr_glEndQuery 4330
#define sipName_glEndQuery &sipStrings__QOpenGLFunctions_4_1_Core[4330]
#define sipNameNr_glGetError 4341
#define sipName_glGetError &sipStrings__QOpenGLFunctions_4_1_Core[4341]
#define sipNameNr_glIndexubv 4352
#define sipName_glIndexubv &sipStrings__QOpenGLFunctions_4_1_Core[4352]
#define sipNameNr_glIsBuffer 4363
#define sipName_glIsBuffer &sipStrings__QOpenGLFunctions_4_1_Core[4363]
#define sipNameNr_glIsShader 4374
#define sipName_glIsShader &sipStrings__QOpenGLFunctions_4_1_Core[4374]
#define sipNameNr_glViewport 4385
#define sipName_glViewport &sipStrings__QOpenGLFunctions_4_1_Core[4385]
#define sipNameNr_glDisable 4396
#define sipName_glDisable &sipStrings__QOpenGLFunctions_4_1_Core[4396]
#define sipNameNr_glEnablei 4406
#define sipName_glEnablei &sipStrings__QOpenGLFunctions_4_1_Core[4406]
#define sipNameNr_glIndexub 4416
#define sipName_glIndexub &sipStrings__QOpenGLFunctions_4_1_Core[4416]
#define sipNameNr_glIsQuery 4426
#define sipName_glIsQuery &sipStrings__QOpenGLFunctions_4_1_Core[4426]
#define sipNameNr_glLogicOp 4436
#define sipName_glLogicOp &sipStrings__QOpenGLFunctions_4_1_Core[4436]
#define sipNameNr_glScissor 4446
#define sipName_glScissor &sipStrings__QOpenGLFunctions_4_1_Core[4446]
#define sipNameNr_glEnable 4456
#define sipName_glEnable &sipStrings__QOpenGLFunctions_4_1_Core[4456]
#define sipNameNr_glFinish 4465
#define sipName_glFinish &sipStrings__QOpenGLFunctions_4_1_Core[4465]
#define sipNameNr_glClear 4474
#define sipName_glClear &sipStrings__QOpenGLFunctions_4_1_Core[4474]
#define sipNameNr_glFlush 4482
#define sipName_glFlush &sipStrings__QOpenGLFunctions_4_1_Core[4482]
#define sipNameNr_glHint 4490
#define sipName_glHint &sipStrings__QOpenGLFunctions_4_1_Core[4490]

#define sipMalloc                   sipAPI__QOpenGLFunctions_4_1_Core->api_malloc
#define sipFree                     sipAPI__QOpenGLFunctions_4_1_Core->api_free
#define sipBuildResult              sipAPI__QOpenGLFunctions_4_1_Core->api_build_result
#define sipCallMethod               sipAPI__QOpenGLFunctions_4_1_Core->api_call_method
#define sipCallProcedureMethod      sipAPI__QOpenGLFunctions_4_1_Core->api_call_procedure_method
#define sipCallErrorHandler         sipAPI__QOpenGLFunctions_4_1_Core->api_call_error_handler
#define sipParseResultEx            sipAPI__QOpenGLFunctions_4_1_Core->api_parse_result_ex
#define sipParseResult              sipAPI__QOpenGLFunctions_4_1_Core->api_parse_result
#define sipParseArgs                sipAPI__QOpenGLFunctions_4_1_Core->api_parse_args
#define sipParseKwdArgs             sipAPI__QOpenGLFunctions_4_1_Core->api_parse_kwd_args
#define sipParsePair                sipAPI__QOpenGLFunctions_4_1_Core->api_parse_pair
#define sipInstanceDestroyed        sipAPI__QOpenGLFunctions_4_1_Core->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI__QOpenGLFunctions_4_1_Core->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI__QOpenGLFunctions_4_1_Core->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI__QOpenGLFunctions_4_1_Core->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI__QOpenGLFunctions_4_1_Core->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI__QOpenGLFunctions_4_1_Core->api_convert_to_void_ptr
#define sipAddException             sipAPI__QOpenGLFunctions_4_1_Core->api_add_exception
#define sipNoFunction               sipAPI__QOpenGLFunctions_4_1_Core->api_no_function
#define sipNoMethod                 sipAPI__QOpenGLFunctions_4_1_Core->api_no_method
#define sipAbstractMethod           sipAPI__QOpenGLFunctions_4_1_Core->api_abstract_method
#define sipBadClass                 sipAPI__QOpenGLFunctions_4_1_Core->api_bad_class
#define sipBadCatcherResult         sipAPI__QOpenGLFunctions_4_1_Core->api_bad_catcher_result
#define sipBadCallableArg           sipAPI__QOpenGLFunctions_4_1_Core->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI__QOpenGLFunctions_4_1_Core->api_bad_operator_arg
#define sipTrace                    sipAPI__QOpenGLFunctions_4_1_Core->api_trace
#define sipTransferBack             sipAPI__QOpenGLFunctions_4_1_Core->api_transfer_back
#define sipTransferTo               sipAPI__QOpenGLFunctions_4_1_Core->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI__QOpenGLFunctions_4_1_Core->api_simplewrapper_type
#define sipWrapper_Type             sipAPI__QOpenGLFunctions_4_1_Core->api_wrapper_type
#define sipWrapperType_Type         sipAPI__QOpenGLFunctions_4_1_Core->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI__QOpenGLFunctions_4_1_Core->api_voidptr_type
#define sipGetPyObject              sipAPI__QOpenGLFunctions_4_1_Core->api_get_pyobject
#define sipGetAddress               sipAPI__QOpenGLFunctions_4_1_Core->api_get_address
#define sipGetMixinAddress          sipAPI__QOpenGLFunctions_4_1_Core->api_get_mixin_address
#define sipGetCppPtr                sipAPI__QOpenGLFunctions_4_1_Core->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI__QOpenGLFunctions_4_1_Core->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI__QOpenGLFunctions_4_1_Core->api_call_hook
#define sipEndThread                sipAPI__QOpenGLFunctions_4_1_Core->api_end_thread
#define sipRaiseUnknownException    sipAPI__QOpenGLFunctions_4_1_Core->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI__QOpenGLFunctions_4_1_Core->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI__QOpenGLFunctions_4_1_Core->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI__QOpenGLFunctions_4_1_Core->api_add_type_instance
#define sipPySlotExtend             sipAPI__QOpenGLFunctions_4_1_Core->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI__QOpenGLFunctions_4_1_Core->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI__QOpenGLFunctions_4_1_Core->api_can_convert_to_type
#define sipConvertToType            sipAPI__QOpenGLFunctions_4_1_Core->api_convert_to_type
#define sipForceConvertToType       sipAPI__QOpenGLFunctions_4_1_Core->api_force_convert_to_type
#define sipConvertToEnum            sipAPI__QOpenGLFunctions_4_1_Core->api_convert_to_enum
#define sipConvertToBool            sipAPI__QOpenGLFunctions_4_1_Core->api_convert_to_bool
#define sipReleaseType              sipAPI__QOpenGLFunctions_4_1_Core->api_release_type
#define sipConvertFromType          sipAPI__QOpenGLFunctions_4_1_Core->api_convert_from_type
#define sipConvertFromNewType       sipAPI__QOpenGLFunctions_4_1_Core->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI__QOpenGLFunctions_4_1_Core->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI__QOpenGLFunctions_4_1_Core->api_convert_from_enum
#define sipGetState                 sipAPI__QOpenGLFunctions_4_1_Core->api_get_state
#define sipExportSymbol             sipAPI__QOpenGLFunctions_4_1_Core->api_export_symbol
#define sipImportSymbol             sipAPI__QOpenGLFunctions_4_1_Core->api_import_symbol
#define sipFindType                 sipAPI__QOpenGLFunctions_4_1_Core->api_find_type
#define sipBytes_AsChar             sipAPI__QOpenGLFunctions_4_1_Core->api_bytes_as_char
#define sipBytes_AsString           sipAPI__QOpenGLFunctions_4_1_Core->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI__QOpenGLFunctions_4_1_Core->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI__QOpenGLFunctions_4_1_Core->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI__QOpenGLFunctions_4_1_Core->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI__QOpenGLFunctions_4_1_Core->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI__QOpenGLFunctions_4_1_Core->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI__QOpenGLFunctions_4_1_Core->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI__QOpenGLFunctions_4_1_Core->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI__QOpenGLFunctions_4_1_Core->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI__QOpenGLFunctions_4_1_Core->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI__QOpenGLFunctions_4_1_Core->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI__QOpenGLFunctions_4_1_Core->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI__QOpenGLFunctions_4_1_Core->api_get_reference
#define sipKeepReference            sipAPI__QOpenGLFunctions_4_1_Core->api_keep_reference
#define sipRegisterProxyResolver    sipAPI__QOpenGLFunctions_4_1_Core->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI__QOpenGLFunctions_4_1_Core->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI__QOpenGLFunctions_4_1_Core->api_type_from_py_type_object
#define sipTypeScope                sipAPI__QOpenGLFunctions_4_1_Core->api_type_scope
#define sipResolveTypedef           sipAPI__QOpenGLFunctions_4_1_Core->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI__QOpenGLFunctions_4_1_Core->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI__QOpenGLFunctions_4_1_Core->api_enable_autoconversion
#define sipInitMixin                sipAPI__QOpenGLFunctions_4_1_Core->api_init_mixin
#define sipExportModule             sipAPI__QOpenGLFunctions_4_1_Core->api_export_module
#define sipInitModule               sipAPI__QOpenGLFunctions_4_1_Core->api_init_module
#define sipGetInterpreter           sipAPI__QOpenGLFunctions_4_1_Core->api_get_interpreter
#define sipSetTypeUserData          sipAPI__QOpenGLFunctions_4_1_Core->api_set_type_user_data
#define sipGetTypeUserData          sipAPI__QOpenGLFunctions_4_1_Core->api_get_type_user_data
#define sipPyTypeDict               sipAPI__QOpenGLFunctions_4_1_Core->api_py_type_dict
#define sipPyTypeName               sipAPI__QOpenGLFunctions_4_1_Core->api_py_type_name
#define sipGetCFunction             sipAPI__QOpenGLFunctions_4_1_Core->api_get_c_function
#define sipGetMethod                sipAPI__QOpenGLFunctions_4_1_Core->api_get_method
#define sipFromMethod               sipAPI__QOpenGLFunctions_4_1_Core->api_from_method
#define sipGetDate                  sipAPI__QOpenGLFunctions_4_1_Core->api_get_date
#define sipFromDate                 sipAPI__QOpenGLFunctions_4_1_Core->api_from_date
#define sipGetDateTime              sipAPI__QOpenGLFunctions_4_1_Core->api_get_datetime
#define sipFromDateTime             sipAPI__QOpenGLFunctions_4_1_Core->api_from_datetime
#define sipGetTime                  sipAPI__QOpenGLFunctions_4_1_Core->api_get_time
#define sipFromTime                 sipAPI__QOpenGLFunctions_4_1_Core->api_from_time
#define sipIsUserType               sipAPI__QOpenGLFunctions_4_1_Core->api_is_user_type
#define sipCheckPluginForType       sipAPI__QOpenGLFunctions_4_1_Core->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI__QOpenGLFunctions_4_1_Core->api_unicode_new
#define sipUnicodeWrite             sipAPI__QOpenGLFunctions_4_1_Core->api_unicode_write
#define sipUnicodeData              sipAPI__QOpenGLFunctions_4_1_Core->api_unicode_data
#define sipGetBufferInfo            sipAPI__QOpenGLFunctions_4_1_Core->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI__QOpenGLFunctions_4_1_Core->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI__QOpenGLFunctions_4_1_Core->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI__QOpenGLFunctions_4_1_Core->api_is_derived_class
#define sipGetUserObject            sipAPI__QOpenGLFunctions_4_1_Core->api_get_user_object
#define sipSetUserObject            sipAPI__QOpenGLFunctions_4_1_Core->api_set_user_object
#define sipRegisterEventHandler     sipAPI__QOpenGLFunctions_4_1_Core->api_register_event_handler
#define sipConvertToArray           sipAPI__QOpenGLFunctions_4_1_Core->api_convert_to_array
#define sipConvertToTypedArray      sipAPI__QOpenGLFunctions_4_1_Core->api_convert_to_typed_array
#define sipEnableGC                 sipAPI__QOpenGLFunctions_4_1_Core->api_enable_gc
#define sipPrintObject              sipAPI__QOpenGLFunctions_4_1_Core->api_print_object
#define sipLong_AsChar              sipAPI__QOpenGLFunctions_4_1_Core->api_long_as_char
#define sipLong_AsSignedChar        sipAPI__QOpenGLFunctions_4_1_Core->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI__QOpenGLFunctions_4_1_Core->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI__QOpenGLFunctions_4_1_Core->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI__QOpenGLFunctions_4_1_Core->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI__QOpenGLFunctions_4_1_Core->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI__QOpenGLFunctions_4_1_Core->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI__QOpenGLFunctions_4_1_Core->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI__QOpenGLFunctions_4_1_Core->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI__QOpenGLFunctions_4_1_Core->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI__QOpenGLFunctions_4_1_Core->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI__QOpenGLFunctions_4_1_Core->api_long_as_size_t
#define sipVisitWrappers            sipAPI__QOpenGLFunctions_4_1_Core->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI__QOpenGLFunctions_4_1_Core->api_register_exit_notifier
#define sipDeprecated               sipAPI__QOpenGLFunctions_4_1_Core->api_deprecated
#define sipPyTypeDictRef            sipAPI__QOpenGLFunctions_4_1_Core->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI__QOpenGLFunctions_4_1_Core->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI__QOpenGLFunctions_4_1_Core->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI__QOpenGLFunctions_4_1_Core->api_get_frame
#define sipSetDestroyOnExit         sipAPI__QOpenGLFunctions_4_1_Core->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI__QOpenGLFunctions_4_1_Core->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI__QOpenGLFunctions_4_1_Core->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI__QOpenGLFunctions_4_1_Core->api_clear_any_slot_reference
#define sipConnectRx                sipAPI__QOpenGLFunctions_4_1_Core->api_connect_rx
#define sipConvertRx                sipAPI__QOpenGLFunctions_4_1_Core->api_convert_rx
#define sipDisconnectRx             sipAPI__QOpenGLFunctions_4_1_Core->api_disconnect_rx
#define sipFreeSipslot              sipAPI__QOpenGLFunctions_4_1_Core->api_free_sipslot
#define sipInvokeSlot               sipAPI__QOpenGLFunctions_4_1_Core->api_invoke_slot
#define sipInvokeSlotEx             sipAPI__QOpenGLFunctions_4_1_Core->api_invoke_slot_ex
#define sipSameSlot                 sipAPI__QOpenGLFunctions_4_1_Core->api_same_slot
#define sipSaveSlot                 sipAPI__QOpenGLFunctions_4_1_Core->api_save_slot
#define sipVisitSlot                sipAPI__QOpenGLFunctions_4_1_Core->api_visit_slot
#define sipIsPyMethod               sipAPI__QOpenGLFunctions_4_1_Core->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings__QOpenGLFunctions_4_1_Core[];

#define sipType_QOpenGLFunctions_4_1_Core sipExportedTypes__QOpenGLFunctions_4_1_Core[0]

extern sipClassTypeDef sipTypeDef__QOpenGLFunctions_4_1_Core_QOpenGLFunctions_4_1_Core;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI__QOpenGLFunctions_4_1_Core;
extern sipExportedModuleDef sipModuleAPI__QOpenGLFunctions_4_1_Core;
extern sipTypeDef *sipExportedTypes__QOpenGLFunctions_4_1_Core[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers__QOpenGLFunctions_4_1_Core_QtCore[];

#define sipType_QAbstractOpenGLFunctions sipImportedTypes__QOpenGLFunctions_4_1_Core_QtGui[0].it_td
extern sipImportedTypeDef sipImportedTypes__QOpenGLFunctions_4_1_Core_QtGui[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip__QOpenGLFunctions_4_1_Core_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip__QOpenGLFunctions_4_1_Core_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip__QOpenGLFunctions_4_1_Core_qt_metacast;
#line 1102 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_4_1_Core/qopenglfunctions_4_1_core.sip"
#include <qopengl.h>

// Imports from QtGui.
typedef const GLvoid *(*qpyopengl_value_array_t)(sipErrorState *, PyObject *, GLenum, PyObject *);
extern qpyopengl_value_array_t qpyopengl_value_array;

typedef const GLvoid *(*qpyopengl_value_array_cached_t)(sipErrorState *, PyObject *, GLenum, PyObject *, const char *, GLuint);
extern qpyopengl_value_array_cached_t qpyopengl_value_array_cached;

typedef GLint (*qpyopengl_get_t)(GLenum, GLenum *);
extern qpyopengl_get_t qpyopengl_get;

typedef PyObject *(*qpyopengl_from_GLint_t)(int *, const GLint *, Py_ssize_t);
extern qpyopengl_from_GLint_t qpyopengl_from_GLint;

typedef PyObject *(*qpyopengl_from_GLuint_t)(int *, const GLuint *, Py_ssize_t);
extern qpyopengl_from_GLuint_t qpyopengl_from_GLuint;

typedef PyObject *(*qpyopengl_from_GLboolean_t)(int *, const GLboolean *, Py_ssize_t);
extern qpyopengl_from_GLboolean_t qpyopengl_from_GLboolean;

typedef PyObject *(*qpyopengl_from_GLfloat_t)(int *, const GLfloat *, Py_ssize_t);
extern qpyopengl_from_GLfloat_t qpyopengl_from_GLfloat;

typedef PyObject *(*qpyopengl_from_GLdouble_t)(int *, const GLdouble *, Py_ssize_t);
extern qpyopengl_from_GLdouble_t qpyopengl_from_GLdouble;
#line 795 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_4_1_Core/sipAPI_QOpenGLFunctions_4_1_Core.h"

#endif
