/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtHelp.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtHelp/qhelpfilterdata.sip"
#include <qhelpfilterdata.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterData.cpp"

#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterData.cpp"
#line 34 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qversionnumber.sip"
#include <qversionnumber.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterData.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpFilterData.cpp"


PyDoc_STRVAR(doc_QHelpFilterData_swap, "swap(self, other: QHelpFilterData)");

extern "C" {static PyObject *meth_QHelpFilterData_swap(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterData_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHelpFilterData* a0;
        ::QHelpFilterData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QHelpFilterData, &sipCpp, sipType_QHelpFilterData, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterData, sipName_swap, doc_QHelpFilterData_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpFilterData_setComponents, "setComponents(self, components: Iterable[Optional[str]])");

extern "C" {static PyObject *meth_QHelpFilterData_setComponents(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterData_setComponents(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QHelpFilterData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpFilterData, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setComponents(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterData, sipName_setComponents, doc_QHelpFilterData_setComponents);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpFilterData_setVersions, "setVersions(self, versions: Iterable[QVersionNumber])");

extern "C" {static PyObject *meth_QHelpFilterData_setVersions(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterData_setVersions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QVersionNumber>* a0;
        int a0State = 0;
        ::QHelpFilterData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpFilterData, &sipCpp, sipType_QList_0100QVersionNumber, &a0, &a0State))
        {
            sipCpp->setVersions(*a0);
            sipReleaseType(const_cast<QList< ::QVersionNumber> *>(a0), sipType_QList_0100QVersionNumber, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterData, sipName_setVersions, doc_QHelpFilterData_setVersions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpFilterData_components, "components(self) -> list[str]");

extern "C" {static PyObject *meth_QHelpFilterData_components(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterData_components(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpFilterData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpFilterData, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->components());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterData, sipName_components, doc_QHelpFilterData_components);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpFilterData_versions, "versions(self) -> list[QVersionNumber]");

extern "C" {static PyObject *meth_QHelpFilterData_versions(PyObject *, PyObject *);}
static PyObject *meth_QHelpFilterData_versions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpFilterData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpFilterData, &sipCpp))
        {
            QList< ::QVersionNumber>*sipRes;

            sipRes = new QList< ::QVersionNumber>(sipCpp->versions());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QVersionNumber, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpFilterData, sipName_versions, doc_QHelpFilterData_versions);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QHelpFilterData___ne__(PyObject *, PyObject *);}
static PyObject *slot_QHelpFilterData___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QHelpFilterData *sipCpp = reinterpret_cast< ::QHelpFilterData *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QHelpFilterData));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpFilterData* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QHelpFilterData, &a0))
        {
            bool sipRes;

            sipRes = !sipCpp->::QHelpFilterData::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtHelp, ne_slot, sipType_QHelpFilterData, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QHelpFilterData___eq__(PyObject *, PyObject *);}
static PyObject *slot_QHelpFilterData___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QHelpFilterData *sipCpp = reinterpret_cast< ::QHelpFilterData *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QHelpFilterData));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpFilterData* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QHelpFilterData, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QHelpFilterData::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtHelp, eq_slot, sipType_QHelpFilterData, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QHelpFilterData(void *, int);}
static void release_QHelpFilterData(void *sipCppV, int)
{
    delete reinterpret_cast< ::QHelpFilterData *>(sipCppV);
}


extern "C" {static void *array_QHelpFilterData(Py_ssize_t);}
static void *array_QHelpFilterData(Py_ssize_t sipNrElem)
{
    return new ::QHelpFilterData[sipNrElem];
}


extern "C" {static void array_delete_QHelpFilterData(void *);}
static void array_delete_QHelpFilterData(void *sipCpp)
{
    delete[] reinterpret_cast< ::QHelpFilterData *>(sipCpp);
}


extern "C" {static void assign_QHelpFilterData(void *, Py_ssize_t, void *);}
static void assign_QHelpFilterData(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QHelpFilterData *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QHelpFilterData *>(sipSrc);
}


extern "C" {static void *copy_QHelpFilterData(const void *, Py_ssize_t);}
static void *copy_QHelpFilterData(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QHelpFilterData(reinterpret_cast<const ::QHelpFilterData *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QHelpFilterData(sipSimpleWrapper *);}
static void dealloc_QHelpFilterData(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QHelpFilterData(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QHelpFilterData(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QHelpFilterData(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QHelpFilterData *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QHelpFilterData();

            return sipCpp;
        }
    }

    {
        const ::QHelpFilterData* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QHelpFilterData, &a0))
        {
            sipCpp = new ::QHelpFilterData(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QHelpFilterData[] = {
    {(void *)slot_QHelpFilterData___ne__, ne_slot},
    {(void *)slot_QHelpFilterData___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QHelpFilterData[] = {
    {sipName_components, meth_QHelpFilterData_components, METH_VARARGS, doc_QHelpFilterData_components},
    {sipName_setComponents, meth_QHelpFilterData_setComponents, METH_VARARGS, doc_QHelpFilterData_setComponents},
    {sipName_setVersions, meth_QHelpFilterData_setVersions, METH_VARARGS, doc_QHelpFilterData_setVersions},
    {sipName_swap, meth_QHelpFilterData_swap, METH_VARARGS, doc_QHelpFilterData_swap},
    {sipName_versions, meth_QHelpFilterData_versions, METH_VARARGS, doc_QHelpFilterData_versions}
};

PyDoc_STRVAR(doc_QHelpFilterData, "\1QHelpFilterData()\n"
"QHelpFilterData(other: QHelpFilterData)");


static pyqt5ClassPluginDef plugin_QHelpFilterData = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtHelp_QHelpFilterData = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QHelpFilterData,
        SIP_NULLPTR,
        &plugin_QHelpFilterData,
    },
    {
        sipNameNr_QHelpFilterData,
        {0, 0, 1},
        5, methods_QHelpFilterData,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QHelpFilterData,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QHelpFilterData,
    init_type_QHelpFilterData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QHelpFilterData,
    assign_QHelpFilterData,
    array_QHelpFilterData,
    copy_QHelpFilterData,
    release_QHelpFilterData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QHelpFilterData,
    sizeof (::QHelpFilterData),
};
