/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacecategory.sip"
#include <qplacecategory.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceCategory.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplaceicon.sip"
#include <qplaceicon.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceCategory.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qlocation.sip"
#include <qlocation.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceCategory.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceCategory.cpp"


class sipQPlaceCategory : public ::QPlaceCategory
{
public:
    sipQPlaceCategory();
    sipQPlaceCategory(const ::QPlaceCategory&);
    ~sipQPlaceCategory();

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQPlaceCategory(const sipQPlaceCategory &);
    sipQPlaceCategory &operator = (const sipQPlaceCategory &);
};

sipQPlaceCategory::sipQPlaceCategory(): ::QPlaceCategory(), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceCategory::sipQPlaceCategory(const ::QPlaceCategory& a0): ::QPlaceCategory(a0), sipPySelf(SIP_NULLPTR)
{
}

sipQPlaceCategory::~sipQPlaceCategory()
{
    sipInstanceDestroyedEx(&sipPySelf);
}


PyDoc_STRVAR(doc_QPlaceCategory_categoryId, "categoryId(self) -> str");

extern "C" {static PyObject *meth_QPlaceCategory_categoryId(PyObject *, PyObject *);}
static PyObject *meth_QPlaceCategory_categoryId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceCategory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceCategory, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->categoryId());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceCategory, sipName_categoryId, doc_QPlaceCategory_categoryId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceCategory_setCategoryId, "setCategoryId(self, identifier: Optional[str])");

extern "C" {static PyObject *meth_QPlaceCategory_setCategoryId(PyObject *, PyObject *);}
static PyObject *meth_QPlaceCategory_setCategoryId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceCategory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceCategory, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCategoryId(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceCategory, sipName_setCategoryId, doc_QPlaceCategory_setCategoryId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceCategory_name, "name(self) -> str");

extern "C" {static PyObject *meth_QPlaceCategory_name(PyObject *, PyObject *);}
static PyObject *meth_QPlaceCategory_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceCategory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceCategory, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceCategory, sipName_name, doc_QPlaceCategory_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceCategory_setName, "setName(self, name: Optional[str])");

extern "C" {static PyObject *meth_QPlaceCategory_setName(PyObject *, PyObject *);}
static PyObject *meth_QPlaceCategory_setName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QPlaceCategory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceCategory, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceCategory, sipName_setName, doc_QPlaceCategory_setName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceCategory_visibility, "visibility(self) -> QLocation.Visibility");

extern "C" {static PyObject *meth_QPlaceCategory_visibility(PyObject *, PyObject *);}
static PyObject *meth_QPlaceCategory_visibility(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceCategory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceCategory, &sipCpp))
        {
            ::QLocation::Visibility sipRes;

            sipRes = sipCpp->visibility();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocation_Visibility);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceCategory, sipName_visibility, doc_QPlaceCategory_visibility);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceCategory_setVisibility, "setVisibility(self, visibility: QLocation.Visibility)");

extern "C" {static PyObject *meth_QPlaceCategory_setVisibility(PyObject *, PyObject *);}
static PyObject *meth_QPlaceCategory_setVisibility(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocation::Visibility a0;
        ::QPlaceCategory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QPlaceCategory, &sipCpp, sipType_QLocation_Visibility, &a0))
        {
            sipCpp->setVisibility(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceCategory, sipName_setVisibility, doc_QPlaceCategory_setVisibility);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceCategory_icon, "icon(self) -> QPlaceIcon");

extern "C" {static PyObject *meth_QPlaceCategory_icon(PyObject *, PyObject *);}
static PyObject *meth_QPlaceCategory_icon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceCategory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceCategory, &sipCpp))
        {
            ::QPlaceIcon*sipRes;

            sipRes = new ::QPlaceIcon(sipCpp->icon());

            return sipConvertFromNewType(sipRes, sipType_QPlaceIcon, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceCategory, sipName_icon, doc_QPlaceCategory_icon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceCategory_setIcon, "setIcon(self, icon: QPlaceIcon)");

extern "C" {static PyObject *meth_QPlaceCategory_setIcon(PyObject *, PyObject *);}
static PyObject *meth_QPlaceCategory_setIcon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceIcon* a0;
        ::QPlaceCategory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPlaceCategory, &sipCpp, sipType_QPlaceIcon, &a0))
        {
            sipCpp->setIcon(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceCategory, sipName_setIcon, doc_QPlaceCategory_setIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceCategory_isEmpty, "isEmpty(self) -> bool");

extern "C" {static PyObject *meth_QPlaceCategory_isEmpty(PyObject *, PyObject *);}
static PyObject *meth_QPlaceCategory_isEmpty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceCategory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceCategory, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEmpty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceCategory, sipName_isEmpty, doc_QPlaceCategory_isEmpty);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QPlaceCategory___ne__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceCategory___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceCategory *sipCpp = reinterpret_cast< ::QPlaceCategory *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceCategory));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceCategory* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceCategory, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceCategory::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, ne_slot, sipType_QPlaceCategory, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QPlaceCategory___eq__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceCategory___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceCategory *sipCpp = reinterpret_cast< ::QPlaceCategory *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceCategory));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceCategory* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceCategory, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceCategory::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, eq_slot, sipType_QPlaceCategory, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QPlaceCategory(void *, int);}
static void release_QPlaceCategory(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQPlaceCategory *>(sipCppV);
    else
        delete reinterpret_cast< ::QPlaceCategory *>(sipCppV);
}


extern "C" {static void *array_QPlaceCategory(Py_ssize_t);}
static void *array_QPlaceCategory(Py_ssize_t sipNrElem)
{
    return new ::QPlaceCategory[sipNrElem];
}


extern "C" {static void array_delete_QPlaceCategory(void *);}
static void array_delete_QPlaceCategory(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPlaceCategory *>(sipCpp);
}


extern "C" {static void assign_QPlaceCategory(void *, Py_ssize_t, void *);}
static void assign_QPlaceCategory(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPlaceCategory *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPlaceCategory *>(sipSrc);
}


extern "C" {static void *copy_QPlaceCategory(const void *, Py_ssize_t);}
static void *copy_QPlaceCategory(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPlaceCategory(reinterpret_cast<const ::QPlaceCategory *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPlaceCategory(sipSimpleWrapper *);}
static void dealloc_QPlaceCategory(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQPlaceCategory *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPlaceCategory(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QPlaceCategory(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPlaceCategory(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQPlaceCategory *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQPlaceCategory();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QPlaceCategory* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPlaceCategory, &a0))
        {
            sipCpp = new sipQPlaceCategory(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QPlaceCategory[] = {
    {(void *)slot_QPlaceCategory___ne__, ne_slot},
    {(void *)slot_QPlaceCategory___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QPlaceCategory[] = {
    {sipName_categoryId, meth_QPlaceCategory_categoryId, METH_VARARGS, doc_QPlaceCategory_categoryId},
    {sipName_icon, meth_QPlaceCategory_icon, METH_VARARGS, doc_QPlaceCategory_icon},
    {sipName_isEmpty, meth_QPlaceCategory_isEmpty, METH_VARARGS, doc_QPlaceCategory_isEmpty},
    {sipName_name, meth_QPlaceCategory_name, METH_VARARGS, doc_QPlaceCategory_name},
    {sipName_setCategoryId, meth_QPlaceCategory_setCategoryId, METH_VARARGS, doc_QPlaceCategory_setCategoryId},
    {sipName_setIcon, meth_QPlaceCategory_setIcon, METH_VARARGS, doc_QPlaceCategory_setIcon},
    {sipName_setName, meth_QPlaceCategory_setName, METH_VARARGS, doc_QPlaceCategory_setName},
    {sipName_setVisibility, meth_QPlaceCategory_setVisibility, METH_VARARGS, doc_QPlaceCategory_setVisibility},
    {sipName_visibility, meth_QPlaceCategory_visibility, METH_VARARGS, doc_QPlaceCategory_visibility}
};

PyDoc_STRVAR(doc_QPlaceCategory, "\1QPlaceCategory()\n"
"QPlaceCategory(other: QPlaceCategory)");


static pyqt5ClassPluginDef plugin_QPlaceCategory = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QPlaceCategory = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPlaceCategory,
        SIP_NULLPTR,
        &plugin_QPlaceCategory,
    },
    {
        sipNameNr_QPlaceCategory,
        {0, 0, 1},
        9, methods_QPlaceCategory,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPlaceCategory,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QPlaceCategory,
    init_type_QPlaceCategory,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPlaceCategory,
    assign_QPlaceCategory,
    array_QPlaceCategory,
    copy_QPlaceCategory,
    release_QPlaceCategory,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPlaceCategory,
    sizeof (::QPlaceCategory),
};
