/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRouteRequest.cpp"

#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRouteRequest.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeocoordinate.sip"
#include <qgeocoordinate.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRouteRequest.cpp"
#line 360 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qdatetime.sip"
#include <qdatetime.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRouteRequest.cpp"
#line 24 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRouteRequest.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRouteRequest.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRouteRequest.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRouteRequest.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeorouterequest.sip"
#include <qgeorouterequest.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRouteRequest.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRouteRequest.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeorectangle.sip"
#include <qgeorectangle.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoRouteRequest.cpp"


PyDoc_STRVAR(doc_QGeoRouteRequest_setWaypoints, "setWaypoints(self, waypoints: Iterable[QGeoCoordinate])");

extern "C" {static PyObject *meth_QGeoRouteRequest_setWaypoints(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_setWaypoints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QGeoCoordinate>* a0;
        int a0State = 0;
        ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoRouteRequest, &sipCpp, sipType_QList_0100QGeoCoordinate, &a0, &a0State))
        {
            sipCpp->setWaypoints(*a0);
            sipReleaseType(const_cast<QList< ::QGeoCoordinate> *>(a0), sipType_QList_0100QGeoCoordinate, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_setWaypoints, doc_QGeoRouteRequest_setWaypoints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_waypoints, "waypoints(self) -> list[QGeoCoordinate]");

extern "C" {static PyObject *meth_QGeoRouteRequest_waypoints(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_waypoints(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRouteRequest, &sipCpp))
        {
            QList< ::QGeoCoordinate>*sipRes;

            sipRes = new QList< ::QGeoCoordinate>(sipCpp->waypoints());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QGeoCoordinate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_waypoints, doc_QGeoRouteRequest_waypoints);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_setExcludeAreas, "setExcludeAreas(self, areas: Iterable[QGeoRectangle])");

extern "C" {static PyObject *meth_QGeoRouteRequest_setExcludeAreas(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_setExcludeAreas(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QGeoRectangle>* a0;
        int a0State = 0;
        ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoRouteRequest, &sipCpp, sipType_QList_0100QGeoRectangle, &a0, &a0State))
        {
            sipCpp->setExcludeAreas(*a0);
            sipReleaseType(const_cast<QList< ::QGeoRectangle> *>(a0), sipType_QList_0100QGeoRectangle, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_setExcludeAreas, doc_QGeoRouteRequest_setExcludeAreas);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_excludeAreas, "excludeAreas(self) -> list[QGeoRectangle]");

extern "C" {static PyObject *meth_QGeoRouteRequest_excludeAreas(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_excludeAreas(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRouteRequest, &sipCpp))
        {
            QList< ::QGeoRectangle>*sipRes;

            sipRes = new QList< ::QGeoRectangle>(sipCpp->excludeAreas());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QGeoRectangle, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_excludeAreas, doc_QGeoRouteRequest_excludeAreas);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_setNumberAlternativeRoutes, "setNumberAlternativeRoutes(self, alternatives: int)");

extern "C" {static PyObject *meth_QGeoRouteRequest_setNumberAlternativeRoutes(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_setNumberAlternativeRoutes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QGeoRouteRequest, &sipCpp, &a0))
        {
            sipCpp->setNumberAlternativeRoutes(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_setNumberAlternativeRoutes, doc_QGeoRouteRequest_setNumberAlternativeRoutes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_numberAlternativeRoutes, "numberAlternativeRoutes(self) -> int");

extern "C" {static PyObject *meth_QGeoRouteRequest_numberAlternativeRoutes(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_numberAlternativeRoutes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRouteRequest, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->numberAlternativeRoutes();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_numberAlternativeRoutes, doc_QGeoRouteRequest_numberAlternativeRoutes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_setTravelModes, "setTravelModes(self, travelModes: Union[QGeoRouteRequest.TravelModes, QGeoRouteRequest.TravelMode])");

extern "C" {static PyObject *meth_QGeoRouteRequest_setTravelModes(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_setTravelModes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::TravelModes* a0;
        int a0State = 0;
        ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoRouteRequest, &sipCpp, sipType_QGeoRouteRequest_TravelModes, &a0, &a0State))
        {
            sipCpp->setTravelModes(*a0);
            sipReleaseType(a0, sipType_QGeoRouteRequest_TravelModes, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_setTravelModes, doc_QGeoRouteRequest_setTravelModes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_travelModes, "travelModes(self) -> QGeoRouteRequest.TravelModes");

extern "C" {static PyObject *meth_QGeoRouteRequest_travelModes(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_travelModes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRouteRequest, &sipCpp))
        {
            ::QGeoRouteRequest::TravelModes*sipRes;

            sipRes = new ::QGeoRouteRequest::TravelModes(sipCpp->travelModes());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_TravelModes, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_travelModes, doc_QGeoRouteRequest_travelModes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_setFeatureWeight, "setFeatureWeight(self, featureType: QGeoRouteRequest.FeatureType, featureWeight: QGeoRouteRequest.FeatureWeight)");

extern "C" {static PyObject *meth_QGeoRouteRequest_setFeatureWeight(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_setFeatureWeight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::FeatureType a0;
        ::QGeoRouteRequest::FeatureWeight a1;
        ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEE", &sipSelf, sipType_QGeoRouteRequest, &sipCpp, sipType_QGeoRouteRequest_FeatureType, &a0, sipType_QGeoRouteRequest_FeatureWeight, &a1))
        {
            sipCpp->setFeatureWeight(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_setFeatureWeight, doc_QGeoRouteRequest_setFeatureWeight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_featureWeight, "featureWeight(self, featureType: QGeoRouteRequest.FeatureType) -> QGeoRouteRequest.FeatureWeight");

extern "C" {static PyObject *meth_QGeoRouteRequest_featureWeight(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_featureWeight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::FeatureType a0;
        const ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGeoRouteRequest, &sipCpp, sipType_QGeoRouteRequest_FeatureType, &a0))
        {
            ::QGeoRouteRequest::FeatureWeight sipRes;

            sipRes = sipCpp->featureWeight(a0);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoRouteRequest_FeatureWeight);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_featureWeight, doc_QGeoRouteRequest_featureWeight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_featureTypes, "featureTypes(self) -> list[QGeoRouteRequest.FeatureType]");

extern "C" {static PyObject *meth_QGeoRouteRequest_featureTypes(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_featureTypes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRouteRequest, &sipCpp))
        {
            QList< ::QGeoRouteRequest::FeatureType>*sipRes;

            sipRes = new QList< ::QGeoRouteRequest::FeatureType>(sipCpp->featureTypes());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QGeoRouteRequest_FeatureType, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_featureTypes, doc_QGeoRouteRequest_featureTypes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_setRouteOptimization, "setRouteOptimization(self, optimization: Union[QGeoRouteRequest.RouteOptimizations, QGeoRouteRequest.RouteOptimization])");

extern "C" {static PyObject *meth_QGeoRouteRequest_setRouteOptimization(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_setRouteOptimization(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::RouteOptimizations* a0;
        int a0State = 0;
        ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoRouteRequest, &sipCpp, sipType_QGeoRouteRequest_RouteOptimizations, &a0, &a0State))
        {
            sipCpp->setRouteOptimization(*a0);
            sipReleaseType(a0, sipType_QGeoRouteRequest_RouteOptimizations, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_setRouteOptimization, doc_QGeoRouteRequest_setRouteOptimization);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_routeOptimization, "routeOptimization(self) -> QGeoRouteRequest.RouteOptimizations");

extern "C" {static PyObject *meth_QGeoRouteRequest_routeOptimization(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_routeOptimization(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRouteRequest, &sipCpp))
        {
            ::QGeoRouteRequest::RouteOptimizations*sipRes;

            sipRes = new ::QGeoRouteRequest::RouteOptimizations(sipCpp->routeOptimization());

            return sipConvertFromNewType(sipRes, sipType_QGeoRouteRequest_RouteOptimizations, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_routeOptimization, doc_QGeoRouteRequest_routeOptimization);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_setSegmentDetail, "setSegmentDetail(self, segmentDetail: QGeoRouteRequest.SegmentDetail)");

extern "C" {static PyObject *meth_QGeoRouteRequest_setSegmentDetail(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_setSegmentDetail(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::SegmentDetail a0;
        ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGeoRouteRequest, &sipCpp, sipType_QGeoRouteRequest_SegmentDetail, &a0))
        {
            sipCpp->setSegmentDetail(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_setSegmentDetail, doc_QGeoRouteRequest_setSegmentDetail);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_segmentDetail, "segmentDetail(self) -> QGeoRouteRequest.SegmentDetail");

extern "C" {static PyObject *meth_QGeoRouteRequest_segmentDetail(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_segmentDetail(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRouteRequest, &sipCpp))
        {
            ::QGeoRouteRequest::SegmentDetail sipRes;

            sipRes = sipCpp->segmentDetail();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoRouteRequest_SegmentDetail);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_segmentDetail, doc_QGeoRouteRequest_segmentDetail);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_setManeuverDetail, "setManeuverDetail(self, maneuverDetail: QGeoRouteRequest.ManeuverDetail)");

extern "C" {static PyObject *meth_QGeoRouteRequest_setManeuverDetail(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_setManeuverDetail(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRouteRequest::ManeuverDetail a0;
        ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QGeoRouteRequest, &sipCpp, sipType_QGeoRouteRequest_ManeuverDetail, &a0))
        {
            sipCpp->setManeuverDetail(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_setManeuverDetail, doc_QGeoRouteRequest_setManeuverDetail);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_maneuverDetail, "maneuverDetail(self) -> QGeoRouteRequest.ManeuverDetail");

extern "C" {static PyObject *meth_QGeoRouteRequest_maneuverDetail(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_maneuverDetail(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRouteRequest, &sipCpp))
        {
            ::QGeoRouteRequest::ManeuverDetail sipRes;

            sipRes = sipCpp->maneuverDetail();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QGeoRouteRequest_ManeuverDetail);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_maneuverDetail, doc_QGeoRouteRequest_maneuverDetail);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_setWaypointsMetadata, "setWaypointsMetadata(self, waypointMetadata: Iterable[dict[str, Any]])");

extern "C" {static PyObject *meth_QGeoRouteRequest_setWaypointsMetadata(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_setWaypointsMetadata(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QVariantMap>* a0;
        int a0State = 0;
        ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoRouteRequest, &sipCpp, sipType_QList_0100QVariantMap, &a0, &a0State))
        {
            sipCpp->setWaypointsMetadata(*a0);
            sipReleaseType(const_cast<QList< ::QVariantMap> *>(a0), sipType_QList_0100QVariantMap, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_setWaypointsMetadata, doc_QGeoRouteRequest_setWaypointsMetadata);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_waypointsMetadata, "waypointsMetadata(self) -> list[dict[str, Any]]");

extern "C" {static PyObject *meth_QGeoRouteRequest_waypointsMetadata(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_waypointsMetadata(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRouteRequest, &sipCpp))
        {
            QList< ::QVariantMap>*sipRes;

            sipRes = new QList< ::QVariantMap>(sipCpp->waypointsMetadata());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QVariantMap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_waypointsMetadata, doc_QGeoRouteRequest_waypointsMetadata);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_setExtraParameters, "setExtraParameters(self, extraParameters: dict[str, Any])");

extern "C" {static PyObject *meth_QGeoRouteRequest_setExtraParameters(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_setExtraParameters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariantMap* a0;
        int a0State = 0;
        ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoRouteRequest, &sipCpp, sipType_QVariantMap, &a0, &a0State))
        {
            sipCpp->setExtraParameters(*a0);
            sipReleaseType(const_cast< ::QVariantMap *>(a0), sipType_QVariantMap, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_setExtraParameters, doc_QGeoRouteRequest_setExtraParameters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_extraParameters, "extraParameters(self) -> dict[str, Any]");

extern "C" {static PyObject *meth_QGeoRouteRequest_extraParameters(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_extraParameters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRouteRequest, &sipCpp))
        {
            ::QVariantMap*sipRes;

            sipRes = new ::QVariantMap(sipCpp->extraParameters());

            return sipConvertFromNewType(sipRes, sipType_QVariantMap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_extraParameters, doc_QGeoRouteRequest_extraParameters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_setDepartureTime, "setDepartureTime(self, departureTime: Union[QDateTime, datetime.datetime])");

extern "C" {static PyObject *meth_QGeoRouteRequest_setDepartureTime(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_setDepartureTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDateTime* a0;
        int a0State = 0;
        ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoRouteRequest, &sipCpp, sipType_QDateTime, &a0, &a0State))
        {
            sipCpp->setDepartureTime(*a0);
            sipReleaseType(const_cast< ::QDateTime *>(a0), sipType_QDateTime, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_setDepartureTime, doc_QGeoRouteRequest_setDepartureTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRouteRequest_departureTime, "departureTime(self) -> QDateTime");

extern "C" {static PyObject *meth_QGeoRouteRequest_departureTime(PyObject *, PyObject *);}
static PyObject *meth_QGeoRouteRequest_departureTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRouteRequest, &sipCpp))
        {
            ::QDateTime*sipRes;

            sipRes = new ::QDateTime(sipCpp->departureTime());

            return sipConvertFromNewType(sipRes, sipType_QDateTime, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRouteRequest, sipName_departureTime, doc_QGeoRouteRequest_departureTime);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QGeoRouteRequest___ne__(PyObject *, PyObject *);}
static PyObject *slot_QGeoRouteRequest___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoRouteRequest *sipCpp = reinterpret_cast< ::QGeoRouteRequest *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoRouteRequest));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteRequest* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGeoRouteRequest, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QGeoRouteRequest::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, ne_slot, sipType_QGeoRouteRequest, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QGeoRouteRequest___eq__(PyObject *, PyObject *);}
static PyObject *slot_QGeoRouteRequest___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoRouteRequest *sipCpp = reinterpret_cast< ::QGeoRouteRequest *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoRouteRequest));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRouteRequest* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGeoRouteRequest, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QGeoRouteRequest::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, eq_slot, sipType_QGeoRouteRequest, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoRouteRequest(void *, int);}
static void release_QGeoRouteRequest(void *sipCppV, int)
{
    delete reinterpret_cast< ::QGeoRouteRequest *>(sipCppV);
}


extern "C" {static void *array_QGeoRouteRequest(Py_ssize_t);}
static void *array_QGeoRouteRequest(Py_ssize_t sipNrElem)
{
    return new ::QGeoRouteRequest[sipNrElem];
}


extern "C" {static void array_delete_QGeoRouteRequest(void *);}
static void array_delete_QGeoRouteRequest(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGeoRouteRequest *>(sipCpp);
}


extern "C" {static void assign_QGeoRouteRequest(void *, Py_ssize_t, void *);}
static void assign_QGeoRouteRequest(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QGeoRouteRequest *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QGeoRouteRequest *>(sipSrc);
}


extern "C" {static void *copy_QGeoRouteRequest(const void *, Py_ssize_t);}
static void *copy_QGeoRouteRequest(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QGeoRouteRequest(reinterpret_cast<const ::QGeoRouteRequest *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QGeoRouteRequest(sipSimpleWrapper *);}
static void dealloc_QGeoRouteRequest(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoRouteRequest(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QGeoRouteRequest(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoRouteRequest(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QGeoRouteRequest *sipCpp = SIP_NULLPTR;

    {
        const QList< ::QGeoCoordinate>& a0def = QList<QGeoCoordinate>();
        const QList< ::QGeoCoordinate>* a0 = &a0def;
        int a0State = 0;

        static const char *sipKwdList[] = {
            sipName_waypoints,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|J1", sipType_QList_0100QGeoCoordinate, &a0, &a0State))
        {
            sipCpp = new ::QGeoRouteRequest(*a0);
            sipReleaseType(const_cast<QList< ::QGeoCoordinate> *>(a0), sipType_QList_0100QGeoCoordinate, a0State);

            return sipCpp;
        }
    }

    {
        const ::QGeoCoordinate* a0;
        const ::QGeoCoordinate* a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9J9", sipType_QGeoCoordinate, &a0, sipType_QGeoCoordinate, &a1))
        {
            sipCpp = new ::QGeoRouteRequest(*a0, *a1);

            return sipCpp;
        }
    }

    {
        const ::QGeoRouteRequest* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QGeoRouteRequest, &a0))
        {
            sipCpp = new ::QGeoRouteRequest(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QGeoRouteRequest[] = {
    {(void *)slot_QGeoRouteRequest___ne__, ne_slot},
    {(void *)slot_QGeoRouteRequest___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QGeoRouteRequest[] = {
    {sipName_departureTime, meth_QGeoRouteRequest_departureTime, METH_VARARGS, doc_QGeoRouteRequest_departureTime},
    {sipName_excludeAreas, meth_QGeoRouteRequest_excludeAreas, METH_VARARGS, doc_QGeoRouteRequest_excludeAreas},
    {sipName_extraParameters, meth_QGeoRouteRequest_extraParameters, METH_VARARGS, doc_QGeoRouteRequest_extraParameters},
    {sipName_featureTypes, meth_QGeoRouteRequest_featureTypes, METH_VARARGS, doc_QGeoRouteRequest_featureTypes},
    {sipName_featureWeight, meth_QGeoRouteRequest_featureWeight, METH_VARARGS, doc_QGeoRouteRequest_featureWeight},
    {sipName_maneuverDetail, meth_QGeoRouteRequest_maneuverDetail, METH_VARARGS, doc_QGeoRouteRequest_maneuverDetail},
    {sipName_numberAlternativeRoutes, meth_QGeoRouteRequest_numberAlternativeRoutes, METH_VARARGS, doc_QGeoRouteRequest_numberAlternativeRoutes},
    {sipName_routeOptimization, meth_QGeoRouteRequest_routeOptimization, METH_VARARGS, doc_QGeoRouteRequest_routeOptimization},
    {sipName_segmentDetail, meth_QGeoRouteRequest_segmentDetail, METH_VARARGS, doc_QGeoRouteRequest_segmentDetail},
    {sipName_setDepartureTime, meth_QGeoRouteRequest_setDepartureTime, METH_VARARGS, doc_QGeoRouteRequest_setDepartureTime},
    {sipName_setExcludeAreas, meth_QGeoRouteRequest_setExcludeAreas, METH_VARARGS, doc_QGeoRouteRequest_setExcludeAreas},
    {sipName_setExtraParameters, meth_QGeoRouteRequest_setExtraParameters, METH_VARARGS, doc_QGeoRouteRequest_setExtraParameters},
    {sipName_setFeatureWeight, meth_QGeoRouteRequest_setFeatureWeight, METH_VARARGS, doc_QGeoRouteRequest_setFeatureWeight},
    {sipName_setManeuverDetail, meth_QGeoRouteRequest_setManeuverDetail, METH_VARARGS, doc_QGeoRouteRequest_setManeuverDetail},
    {sipName_setNumberAlternativeRoutes, meth_QGeoRouteRequest_setNumberAlternativeRoutes, METH_VARARGS, doc_QGeoRouteRequest_setNumberAlternativeRoutes},
    {sipName_setRouteOptimization, meth_QGeoRouteRequest_setRouteOptimization, METH_VARARGS, doc_QGeoRouteRequest_setRouteOptimization},
    {sipName_setSegmentDetail, meth_QGeoRouteRequest_setSegmentDetail, METH_VARARGS, doc_QGeoRouteRequest_setSegmentDetail},
    {sipName_setTravelModes, meth_QGeoRouteRequest_setTravelModes, METH_VARARGS, doc_QGeoRouteRequest_setTravelModes},
    {sipName_setWaypoints, meth_QGeoRouteRequest_setWaypoints, METH_VARARGS, doc_QGeoRouteRequest_setWaypoints},
    {sipName_setWaypointsMetadata, meth_QGeoRouteRequest_setWaypointsMetadata, METH_VARARGS, doc_QGeoRouteRequest_setWaypointsMetadata},
    {sipName_travelModes, meth_QGeoRouteRequest_travelModes, METH_VARARGS, doc_QGeoRouteRequest_travelModes},
    {sipName_waypoints, meth_QGeoRouteRequest_waypoints, METH_VARARGS, doc_QGeoRouteRequest_waypoints},
    {sipName_waypointsMetadata, meth_QGeoRouteRequest_waypointsMetadata, METH_VARARGS, doc_QGeoRouteRequest_waypointsMetadata}
};

static sipEnumMemberDef enummembers_QGeoRouteRequest[] = {
    {sipName_AvoidFeatureWeight, static_cast<int>(::QGeoRouteRequest::AvoidFeatureWeight), 13},
    {sipName_BasicManeuvers, static_cast<int>(::QGeoRouteRequest::BasicManeuvers), 15},
    {sipName_BasicSegmentData, static_cast<int>(::QGeoRouteRequest::BasicSegmentData), 19},
    {sipName_BicycleTravel, static_cast<int>(::QGeoRouteRequest::BicycleTravel), 21},
    {sipName_CarTravel, static_cast<int>(::QGeoRouteRequest::CarTravel), 21},
    {sipName_DirtRoadFeature, static_cast<int>(::QGeoRouteRequest::DirtRoadFeature), 11},
    {sipName_DisallowFeatureWeight, static_cast<int>(::QGeoRouteRequest::DisallowFeatureWeight), 13},
    {sipName_FastestRoute, static_cast<int>(::QGeoRouteRequest::FastestRoute), 17},
    {sipName_FerryFeature, static_cast<int>(::QGeoRouteRequest::FerryFeature), 11},
    {sipName_HighwayFeature, static_cast<int>(::QGeoRouteRequest::HighwayFeature), 11},
    {sipName_MostEconomicRoute, static_cast<int>(::QGeoRouteRequest::MostEconomicRoute), 17},
    {sipName_MostScenicRoute, static_cast<int>(::QGeoRouteRequest::MostScenicRoute), 17},
    {sipName_MotorPoolLaneFeature, static_cast<int>(::QGeoRouteRequest::MotorPoolLaneFeature), 11},
    {sipName_NeutralFeatureWeight, static_cast<int>(::QGeoRouteRequest::NeutralFeatureWeight), 13},
    {sipName_NoFeature, static_cast<int>(::QGeoRouteRequest::NoFeature), 11},
    {sipName_NoManeuvers, static_cast<int>(::QGeoRouteRequest::NoManeuvers), 15},
    {sipName_NoSegmentData, static_cast<int>(::QGeoRouteRequest::NoSegmentData), 19},
    {sipName_ParksFeature, static_cast<int>(::QGeoRouteRequest::ParksFeature), 11},
    {sipName_PedestrianTravel, static_cast<int>(::QGeoRouteRequest::PedestrianTravel), 21},
    {sipName_PreferFeatureWeight, static_cast<int>(::QGeoRouteRequest::PreferFeatureWeight), 13},
    {sipName_PublicTransitFeature, static_cast<int>(::QGeoRouteRequest::PublicTransitFeature), 11},
    {sipName_PublicTransitTravel, static_cast<int>(::QGeoRouteRequest::PublicTransitTravel), 21},
    {sipName_RequireFeatureWeight, static_cast<int>(::QGeoRouteRequest::RequireFeatureWeight), 13},
    {sipName_ShortestRoute, static_cast<int>(::QGeoRouteRequest::ShortestRoute), 17},
    {sipName_TollFeature, static_cast<int>(::QGeoRouteRequest::TollFeature), 11},
    {sipName_TrafficFeature, static_cast<int>(::QGeoRouteRequest::TrafficFeature), 11},
    {sipName_TruckTravel, static_cast<int>(::QGeoRouteRequest::TruckTravel), 21},
    {sipName_TunnelFeature, static_cast<int>(::QGeoRouteRequest::TunnelFeature), 11},
};

PyDoc_STRVAR(doc_QGeoRouteRequest, "\1QGeoRouteRequest(waypoints: Iterable[QGeoCoordinate] = [])\n"
"QGeoRouteRequest(origin: QGeoCoordinate, destination: QGeoCoordinate)\n"
"QGeoRouteRequest(other: QGeoRouteRequest)");


static pyqt5ClassPluginDef plugin_QGeoRouteRequest = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QGeoRouteRequest = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoRouteRequest,
        SIP_NULLPTR,
        &plugin_QGeoRouteRequest,
    },
    {
        sipNameNr_QGeoRouteRequest,
        {0, 0, 1},
        23, methods_QGeoRouteRequest,
        28, enummembers_QGeoRouteRequest,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoRouteRequest,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QGeoRouteRequest,
    init_type_QGeoRouteRequest,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoRouteRequest,
    assign_QGeoRouteRequest,
    array_QGeoRouteRequest,
    copy_QGeoRouteRequest,
    release_QGeoRouteRequest,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGeoRouteRequest,
    sizeof (::QGeoRouteRequest),
};
