/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediametadata.sip"
#include <qmediametadata.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaMetaData.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQMediaMetaData.cpp"


extern "C" {static PyObject *varget_QMediaMetaData_AlbumArtist(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_AlbumArtist(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::AlbumArtist);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_AlbumTitle(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_AlbumTitle(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::AlbumTitle);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_AudioBitRate(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_AudioBitRate(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::AudioBitRate);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_AudioCodec(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_AudioCodec(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::AudioCodec);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Author(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Author(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Author);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_AverageLevel(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_AverageLevel(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::AverageLevel);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_CameraManufacturer(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_CameraManufacturer(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::CameraManufacturer);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_CameraModel(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_CameraModel(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::CameraModel);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Category(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Category(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Category);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_ChannelCount(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_ChannelCount(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::ChannelCount);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_ChapterNumber(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_ChapterNumber(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::ChapterNumber);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Comment(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Comment(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Comment);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Composer(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Composer(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Composer);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Conductor(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Conductor(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Conductor);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Contrast(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Contrast(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Contrast);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_ContributingArtist(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_ContributingArtist(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::ContributingArtist);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Copyright(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Copyright(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Copyright);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_CoverArtImage(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_CoverArtImage(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::CoverArtImage);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_CoverArtUrlLarge(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_CoverArtUrlLarge(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::CoverArtUrlLarge);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_CoverArtUrlSmall(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_CoverArtUrlSmall(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::CoverArtUrlSmall);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Date(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Date(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Date);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_DateTimeDigitized(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_DateTimeDigitized(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::DateTimeDigitized);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_DateTimeOriginal(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_DateTimeOriginal(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::DateTimeOriginal);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Description(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Description(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Description);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_DeviceSettingDescription(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_DeviceSettingDescription(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::DeviceSettingDescription);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_DigitalZoomRatio(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_DigitalZoomRatio(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::DigitalZoomRatio);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Director(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Director(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Director);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Duration(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Duration(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Duration);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Event(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Event(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Event);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_ExposureBiasValue(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_ExposureBiasValue(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::ExposureBiasValue);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_ExposureMode(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_ExposureMode(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::ExposureMode);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_ExposureProgram(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_ExposureProgram(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::ExposureProgram);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_ExposureTime(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_ExposureTime(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::ExposureTime);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_FNumber(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_FNumber(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::FNumber);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Flash(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Flash(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Flash);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_FocalLength(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_FocalLength(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::FocalLength);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_FocalLengthIn35mmFilm(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_FocalLengthIn35mmFilm(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::FocalLengthIn35mmFilm);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GPSAltitude(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GPSAltitude(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GPSAltitude);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GPSAreaInformation(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GPSAreaInformation(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GPSAreaInformation);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GPSDOP(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GPSDOP(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GPSDOP);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GPSImgDirection(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GPSImgDirection(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GPSImgDirection);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GPSImgDirectionRef(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GPSImgDirectionRef(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GPSImgDirectionRef);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GPSLatitude(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GPSLatitude(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GPSLatitude);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GPSLongitude(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GPSLongitude(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GPSLongitude);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GPSMapDatum(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GPSMapDatum(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GPSMapDatum);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GPSProcessingMethod(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GPSProcessingMethod(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GPSProcessingMethod);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GPSSatellites(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GPSSatellites(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GPSSatellites);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GPSSpeed(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GPSSpeed(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GPSSpeed);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GPSStatus(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GPSStatus(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GPSStatus);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GPSTimeStamp(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GPSTimeStamp(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GPSTimeStamp);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GPSTrack(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GPSTrack(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GPSTrack);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GPSTrackRef(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GPSTrackRef(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GPSTrackRef);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_GainControl(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_GainControl(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::GainControl);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Genre(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Genre(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Genre);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_ISOSpeedRatings(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_ISOSpeedRatings(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::ISOSpeedRatings);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Keywords(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Keywords(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Keywords);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Language(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Language(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Language);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_LeadPerformer(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_LeadPerformer(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::LeadPerformer);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_LightSource(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_LightSource(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::LightSource);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Lyrics(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Lyrics(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Lyrics);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_MediaType(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_MediaType(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::MediaType);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_MeteringMode(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_MeteringMode(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::MeteringMode);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Mood(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Mood(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Mood);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Orientation(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Orientation(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Orientation);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_ParentalRating(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_ParentalRating(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::ParentalRating);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_PeakValue(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_PeakValue(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::PeakValue);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_PixelAspectRatio(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_PixelAspectRatio(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::PixelAspectRatio);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_PosterImage(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_PosterImage(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::PosterImage);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_PosterUrl(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_PosterUrl(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::PosterUrl);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Publisher(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Publisher(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Publisher);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_RatingOrganization(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_RatingOrganization(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::RatingOrganization);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Resolution(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Resolution(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Resolution);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_SampleRate(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_SampleRate(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::SampleRate);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Saturation(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Saturation(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Saturation);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_SceneCaptureType(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_SceneCaptureType(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::SceneCaptureType);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Sharpness(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Sharpness(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Sharpness);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Size(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Size(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Size);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_SubTitle(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_SubTitle(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::SubTitle);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Subject(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Subject(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Subject);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_SubjectDistance(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_SubjectDistance(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::SubjectDistance);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_ThumbnailImage(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_ThumbnailImage(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::ThumbnailImage);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Title(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Title(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Title);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_TrackCount(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_TrackCount(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::TrackCount);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_TrackNumber(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_TrackNumber(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::TrackNumber);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_UserRating(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_UserRating(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::UserRating);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_VideoBitRate(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_VideoBitRate(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::VideoBitRate);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_VideoCodec(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_VideoCodec(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::VideoCodec);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_VideoFrameRate(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_VideoFrameRate(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::VideoFrameRate);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_WhiteBalance(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_WhiteBalance(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::WhiteBalance);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Writer(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Writer(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Writer);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}


extern "C" {static PyObject *varget_QMediaMetaData_Year(void *, PyObject *, PyObject *);}
static PyObject *varget_QMediaMetaData_Year(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QMediaMetaData::Year);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}

sipVariableDef variables_QMediaMetaData[] = {
    {ClassVariable, sipName_AlbumArtist, (PyMethodDef *)varget_QMediaMetaData_AlbumArtist, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AlbumTitle, (PyMethodDef *)varget_QMediaMetaData_AlbumTitle, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AudioBitRate, (PyMethodDef *)varget_QMediaMetaData_AudioBitRate, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AudioCodec, (PyMethodDef *)varget_QMediaMetaData_AudioCodec, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Author, (PyMethodDef *)varget_QMediaMetaData_Author, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_AverageLevel, (PyMethodDef *)varget_QMediaMetaData_AverageLevel, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_CameraManufacturer, (PyMethodDef *)varget_QMediaMetaData_CameraManufacturer, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_CameraModel, (PyMethodDef *)varget_QMediaMetaData_CameraModel, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Category, (PyMethodDef *)varget_QMediaMetaData_Category, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_ChannelCount, (PyMethodDef *)varget_QMediaMetaData_ChannelCount, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_ChapterNumber, (PyMethodDef *)varget_QMediaMetaData_ChapterNumber, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Comment, (PyMethodDef *)varget_QMediaMetaData_Comment, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Composer, (PyMethodDef *)varget_QMediaMetaData_Composer, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Conductor, (PyMethodDef *)varget_QMediaMetaData_Conductor, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Contrast, (PyMethodDef *)varget_QMediaMetaData_Contrast, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_ContributingArtist, (PyMethodDef *)varget_QMediaMetaData_ContributingArtist, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Copyright, (PyMethodDef *)varget_QMediaMetaData_Copyright, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_CoverArtImage, (PyMethodDef *)varget_QMediaMetaData_CoverArtImage, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_CoverArtUrlLarge, (PyMethodDef *)varget_QMediaMetaData_CoverArtUrlLarge, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_CoverArtUrlSmall, (PyMethodDef *)varget_QMediaMetaData_CoverArtUrlSmall, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Date, (PyMethodDef *)varget_QMediaMetaData_Date, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_DateTimeDigitized, (PyMethodDef *)varget_QMediaMetaData_DateTimeDigitized, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_DateTimeOriginal, (PyMethodDef *)varget_QMediaMetaData_DateTimeOriginal, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Description, (PyMethodDef *)varget_QMediaMetaData_Description, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_DeviceSettingDescription, (PyMethodDef *)varget_QMediaMetaData_DeviceSettingDescription, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_DigitalZoomRatio, (PyMethodDef *)varget_QMediaMetaData_DigitalZoomRatio, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Director, (PyMethodDef *)varget_QMediaMetaData_Director, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Duration, (PyMethodDef *)varget_QMediaMetaData_Duration, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Event, (PyMethodDef *)varget_QMediaMetaData_Event, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_ExposureBiasValue, (PyMethodDef *)varget_QMediaMetaData_ExposureBiasValue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_ExposureMode, (PyMethodDef *)varget_QMediaMetaData_ExposureMode, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_ExposureProgram, (PyMethodDef *)varget_QMediaMetaData_ExposureProgram, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_ExposureTime, (PyMethodDef *)varget_QMediaMetaData_ExposureTime, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_FNumber, (PyMethodDef *)varget_QMediaMetaData_FNumber, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Flash, (PyMethodDef *)varget_QMediaMetaData_Flash, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_FocalLength, (PyMethodDef *)varget_QMediaMetaData_FocalLength, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_FocalLengthIn35mmFilm, (PyMethodDef *)varget_QMediaMetaData_FocalLengthIn35mmFilm, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GPSAltitude, (PyMethodDef *)varget_QMediaMetaData_GPSAltitude, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GPSAreaInformation, (PyMethodDef *)varget_QMediaMetaData_GPSAreaInformation, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GPSDOP, (PyMethodDef *)varget_QMediaMetaData_GPSDOP, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GPSImgDirection, (PyMethodDef *)varget_QMediaMetaData_GPSImgDirection, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GPSImgDirectionRef, (PyMethodDef *)varget_QMediaMetaData_GPSImgDirectionRef, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GPSLatitude, (PyMethodDef *)varget_QMediaMetaData_GPSLatitude, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GPSLongitude, (PyMethodDef *)varget_QMediaMetaData_GPSLongitude, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GPSMapDatum, (PyMethodDef *)varget_QMediaMetaData_GPSMapDatum, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GPSProcessingMethod, (PyMethodDef *)varget_QMediaMetaData_GPSProcessingMethod, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GPSSatellites, (PyMethodDef *)varget_QMediaMetaData_GPSSatellites, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GPSSpeed, (PyMethodDef *)varget_QMediaMetaData_GPSSpeed, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GPSStatus, (PyMethodDef *)varget_QMediaMetaData_GPSStatus, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GPSTimeStamp, (PyMethodDef *)varget_QMediaMetaData_GPSTimeStamp, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GPSTrack, (PyMethodDef *)varget_QMediaMetaData_GPSTrack, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GPSTrackRef, (PyMethodDef *)varget_QMediaMetaData_GPSTrackRef, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_GainControl, (PyMethodDef *)varget_QMediaMetaData_GainControl, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Genre, (PyMethodDef *)varget_QMediaMetaData_Genre, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_ISOSpeedRatings, (PyMethodDef *)varget_QMediaMetaData_ISOSpeedRatings, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Keywords, (PyMethodDef *)varget_QMediaMetaData_Keywords, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Language, (PyMethodDef *)varget_QMediaMetaData_Language, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_LeadPerformer, (PyMethodDef *)varget_QMediaMetaData_LeadPerformer, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_LightSource, (PyMethodDef *)varget_QMediaMetaData_LightSource, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Lyrics, (PyMethodDef *)varget_QMediaMetaData_Lyrics, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_MediaType, (PyMethodDef *)varget_QMediaMetaData_MediaType, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_MeteringMode, (PyMethodDef *)varget_QMediaMetaData_MeteringMode, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Mood, (PyMethodDef *)varget_QMediaMetaData_Mood, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Orientation, (PyMethodDef *)varget_QMediaMetaData_Orientation, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_ParentalRating, (PyMethodDef *)varget_QMediaMetaData_ParentalRating, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_PeakValue, (PyMethodDef *)varget_QMediaMetaData_PeakValue, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_PixelAspectRatio, (PyMethodDef *)varget_QMediaMetaData_PixelAspectRatio, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_PosterImage, (PyMethodDef *)varget_QMediaMetaData_PosterImage, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_PosterUrl, (PyMethodDef *)varget_QMediaMetaData_PosterUrl, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Publisher, (PyMethodDef *)varget_QMediaMetaData_Publisher, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_RatingOrganization, (PyMethodDef *)varget_QMediaMetaData_RatingOrganization, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Resolution, (PyMethodDef *)varget_QMediaMetaData_Resolution, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_SampleRate, (PyMethodDef *)varget_QMediaMetaData_SampleRate, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Saturation, (PyMethodDef *)varget_QMediaMetaData_Saturation, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_SceneCaptureType, (PyMethodDef *)varget_QMediaMetaData_SceneCaptureType, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Sharpness, (PyMethodDef *)varget_QMediaMetaData_Sharpness, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Size, (PyMethodDef *)varget_QMediaMetaData_Size, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_SubTitle, (PyMethodDef *)varget_QMediaMetaData_SubTitle, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Subject, (PyMethodDef *)varget_QMediaMetaData_Subject, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_SubjectDistance, (PyMethodDef *)varget_QMediaMetaData_SubjectDistance, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_ThumbnailImage, (PyMethodDef *)varget_QMediaMetaData_ThumbnailImage, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Title, (PyMethodDef *)varget_QMediaMetaData_Title, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_TrackCount, (PyMethodDef *)varget_QMediaMetaData_TrackCount, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_TrackNumber, (PyMethodDef *)varget_QMediaMetaData_TrackNumber, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_UserRating, (PyMethodDef *)varget_QMediaMetaData_UserRating, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_VideoBitRate, (PyMethodDef *)varget_QMediaMetaData_VideoBitRate, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_VideoCodec, (PyMethodDef *)varget_QMediaMetaData_VideoCodec, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_VideoFrameRate, (PyMethodDef *)varget_QMediaMetaData_VideoFrameRate, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_WhiteBalance, (PyMethodDef *)varget_QMediaMetaData_WhiteBalance, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Writer, (PyMethodDef *)varget_QMediaMetaData_Writer, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {ClassVariable, sipName_Year, (PyMethodDef *)varget_QMediaMetaData_Year, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
};


static pyqt5ClassPluginDef plugin_QMediaMetaData = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QMediaMetaData = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_NAMESPACE,
        sipNameNr_QMediaMetaData,
        SIP_NULLPTR,
        &plugin_QMediaMetaData,
    },
    {
        sipNameNr_QMediaMetaData,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        91, variables_QMediaMetaData,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
