/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtHelp.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtHelp/qhelpsearchresultwidget.sip"
#include <qhelpsearchresultwidget.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"

#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 99 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 102 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 105 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 108 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 114 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 509 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 117 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 120 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 471 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 123 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 460 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 126 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 570 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 129 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 619 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 132 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 592 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 135 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 608 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 138 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 675 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 141 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 302 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 144 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 482 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 147 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 438 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 150 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 425 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 153 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 412 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 156 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 398 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 159 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 384 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 162 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 363 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 165 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 253 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 168 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 205 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 171 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 174 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 177 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 180 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 183 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 186 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 189 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 192 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 198 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 201 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 204 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 209 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 212 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 215 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 218 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 221 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 224 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 227 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 230 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 233 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 236 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 239 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 242 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpSearchResultWidget.cpp"


PyDoc_STRVAR(doc_QHelpSearchResultWidget_linkAt, "linkAt(self, point: QPoint) -> QUrl");

extern "C" {static PyObject *meth_QHelpSearchResultWidget_linkAt(PyObject *, PyObject *);}
static PyObject *meth_QHelpSearchResultWidget_linkAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        ::QHelpSearchResultWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QHelpSearchResultWidget, &sipCpp, sipType_QPoint, &a0))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->linkAt(*a0));

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpSearchResultWidget, sipName_linkAt, doc_QHelpSearchResultWidget_linkAt);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QHelpSearchResultWidget(void *, const sipTypeDef *);}
static void *cast_QHelpSearchResultWidget(void *sipCppV, const sipTypeDef *targetType)
{
    ::QHelpSearchResultWidget *sipCpp = reinterpret_cast< ::QHelpSearchResultWidget *>(sipCppV);

    if (targetType == sipType_QHelpSearchResultWidget)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QWidget)->ctd_cast(static_cast< ::QWidget *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QHelpSearchResultWidget(void *, int);}
static void release_QHelpSearchResultWidget(void *sipCppV, int)
{
    ::QHelpSearchResultWidget *sipCpp = reinterpret_cast< ::QHelpSearchResultWidget *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QHelpSearchResultWidget(sipSimpleWrapper *);}
static void dealloc_QHelpSearchResultWidget(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QHelpSearchResultWidget(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QHelpSearchResultWidget[] = {{10, 2, 1}};


static PyMethodDef methods_QHelpSearchResultWidget[] = {
    {sipName_linkAt, meth_QHelpSearchResultWidget_linkAt, METH_VARARGS, doc_QHelpSearchResultWidget_linkAt}
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QHelpSearchResultWidget[] = {
    {"requestShowLink(QUrl)", "\1requestShowLink(self, url: QUrl)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QHelpSearchResultWidget = {
    &::QHelpSearchResultWidget::staticMetaObject,
    0,
    signals_QHelpSearchResultWidget,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtHelp_QHelpSearchResultWidget = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QHelpSearchResultWidget,
        SIP_NULLPTR,
        &plugin_QHelpSearchResultWidget,
    },
    {
        sipNameNr_QHelpSearchResultWidget,
        {0, 0, 1},
        1, methods_QHelpSearchResultWidget,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QHelpSearchResultWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QHelpSearchResultWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QHelpSearchResultWidget,
    cast_QHelpSearchResultWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
