/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKitWidgets.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebframe.sip"
#include <qwebframe.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebHitTestResult.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebHitTestResult.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebHitTestResult.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebelement.sip"
#include <qwebelement.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebHitTestResult.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebHitTestResult.cpp"
#line 61 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebframe.sip"
#include <qwebframe.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebHitTestResult.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebHitTestResult.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebHitTestResult.cpp"


PyDoc_STRVAR(doc_QWebHitTestResult_isNull, "isNull(self) -> bool");

extern "C" {static PyObject *meth_QWebHitTestResult_isNull(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_isNull(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isNull();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_isNull, doc_QWebHitTestResult_isNull);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_pos, "pos(self) -> QPoint");

extern "C" {static PyObject *meth_QWebHitTestResult_pos(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_pos(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint(sipCpp->pos());

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_pos, doc_QWebHitTestResult_pos);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_title, "title(self) -> str");

extern "C" {static PyObject *meth_QWebHitTestResult_title(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_title(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->title());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_title, doc_QWebHitTestResult_title);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_linkText, "linkText(self) -> str");

extern "C" {static PyObject *meth_QWebHitTestResult_linkText(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_linkText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->linkText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_linkText, doc_QWebHitTestResult_linkText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_linkUrl, "linkUrl(self) -> QUrl");

extern "C" {static PyObject *meth_QWebHitTestResult_linkUrl(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_linkUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->linkUrl());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_linkUrl, doc_QWebHitTestResult_linkUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_linkTitle, "linkTitle(self) -> QUrl");

extern "C" {static PyObject *meth_QWebHitTestResult_linkTitle(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_linkTitle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->linkTitle());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_linkTitle, doc_QWebHitTestResult_linkTitle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_linkTargetFrame, "linkTargetFrame(self) -> Optional[QWebFrame]");

extern "C" {static PyObject *meth_QWebHitTestResult_linkTargetFrame(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_linkTargetFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QWebFrame*sipRes;

            sipRes = sipCpp->linkTargetFrame();

            return sipConvertFromType(sipRes, sipType_QWebFrame, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_linkTargetFrame, doc_QWebHitTestResult_linkTargetFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_alternateText, "alternateText(self) -> str");

extern "C" {static PyObject *meth_QWebHitTestResult_alternateText(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_alternateText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->alternateText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_alternateText, doc_QWebHitTestResult_alternateText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_imageUrl, "imageUrl(self) -> QUrl");

extern "C" {static PyObject *meth_QWebHitTestResult_imageUrl(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_imageUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->imageUrl());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_imageUrl, doc_QWebHitTestResult_imageUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_pixmap, "pixmap(self) -> QPixmap");

extern "C" {static PyObject *meth_QWebHitTestResult_pixmap(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_pixmap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QPixmap*sipRes;

            sipRes = new ::QPixmap(sipCpp->pixmap());

            return sipConvertFromNewType(sipRes, sipType_QPixmap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_pixmap, doc_QWebHitTestResult_pixmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_isContentEditable, "isContentEditable(self) -> bool");

extern "C" {static PyObject *meth_QWebHitTestResult_isContentEditable(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_isContentEditable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isContentEditable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_isContentEditable, doc_QWebHitTestResult_isContentEditable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_isContentSelected, "isContentSelected(self) -> bool");

extern "C" {static PyObject *meth_QWebHitTestResult_isContentSelected(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_isContentSelected(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isContentSelected();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_isContentSelected, doc_QWebHitTestResult_isContentSelected);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_frame, "frame(self) -> Optional[QWebFrame]");

extern "C" {static PyObject *meth_QWebHitTestResult_frame(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_frame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QWebFrame*sipRes;

            sipRes = sipCpp->frame();

            return sipConvertFromType(sipRes, sipType_QWebFrame, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_frame, doc_QWebHitTestResult_frame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_boundingRect, "boundingRect(self) -> QRect");

extern "C" {static PyObject *meth_QWebHitTestResult_boundingRect(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_boundingRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect(sipCpp->boundingRect());

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_boundingRect, doc_QWebHitTestResult_boundingRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_enclosingBlockElement, "enclosingBlockElement(self) -> QWebElement");

extern "C" {static PyObject *meth_QWebHitTestResult_enclosingBlockElement(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_enclosingBlockElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QWebElement*sipRes;

            sipRes = new ::QWebElement(sipCpp->enclosingBlockElement());

            return sipConvertFromNewType(sipRes, sipType_QWebElement, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_enclosingBlockElement, doc_QWebHitTestResult_enclosingBlockElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_linkElement, "linkElement(self) -> QWebElement");

extern "C" {static PyObject *meth_QWebHitTestResult_linkElement(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_linkElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QWebElement*sipRes;

            sipRes = new ::QWebElement(sipCpp->linkElement());

            return sipConvertFromNewType(sipRes, sipType_QWebElement, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_linkElement, doc_QWebHitTestResult_linkElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_element, "element(self) -> QWebElement");

extern "C" {static PyObject *meth_QWebHitTestResult_element(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_element(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QWebElement*sipRes;

            sipRes = new ::QWebElement(sipCpp->element());

            return sipConvertFromNewType(sipRes, sipType_QWebElement, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_element, doc_QWebHitTestResult_element);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_mediaUrl, "mediaUrl(self) -> QUrl");

extern "C" {static PyObject *meth_QWebHitTestResult_mediaUrl(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_mediaUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->mediaUrl());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_mediaUrl, doc_QWebHitTestResult_mediaUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHitTestResult_linkTitleString, "linkTitleString(self) -> str");

extern "C" {static PyObject *meth_QWebHitTestResult_linkTitleString(PyObject *, PyObject *);}
static PyObject *meth_QWebHitTestResult_linkTitleString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHitTestResult *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHitTestResult, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->linkTitleString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHitTestResult, sipName_linkTitleString, doc_QWebHitTestResult_linkTitleString);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebHitTestResult(void *, int);}
static void release_QWebHitTestResult(void *sipCppV, int)
{
    delete reinterpret_cast< ::QWebHitTestResult *>(sipCppV);
}


extern "C" {static void *array_QWebHitTestResult(Py_ssize_t);}
static void *array_QWebHitTestResult(Py_ssize_t sipNrElem)
{
    return new ::QWebHitTestResult[sipNrElem];
}


extern "C" {static void array_delete_QWebHitTestResult(void *);}
static void array_delete_QWebHitTestResult(void *sipCpp)
{
    delete[] reinterpret_cast< ::QWebHitTestResult *>(sipCpp);
}


extern "C" {static void assign_QWebHitTestResult(void *, Py_ssize_t, void *);}
static void assign_QWebHitTestResult(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QWebHitTestResult *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QWebHitTestResult *>(sipSrc);
}


extern "C" {static void *copy_QWebHitTestResult(const void *, Py_ssize_t);}
static void *copy_QWebHitTestResult(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QWebHitTestResult(reinterpret_cast<const ::QWebHitTestResult *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QWebHitTestResult(sipSimpleWrapper *);}
static void dealloc_QWebHitTestResult(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWebHitTestResult(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QWebHitTestResult(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWebHitTestResult(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QWebHitTestResult *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QWebHitTestResult();

            return sipCpp;
        }
    }

    {
        const ::QWebHitTestResult* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QWebHitTestResult, &a0))
        {
            sipCpp = new ::QWebHitTestResult(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QWebHitTestResult[] = {
    {sipName_alternateText, meth_QWebHitTestResult_alternateText, METH_VARARGS, doc_QWebHitTestResult_alternateText},
    {sipName_boundingRect, meth_QWebHitTestResult_boundingRect, METH_VARARGS, doc_QWebHitTestResult_boundingRect},
    {sipName_element, meth_QWebHitTestResult_element, METH_VARARGS, doc_QWebHitTestResult_element},
    {sipName_enclosingBlockElement, meth_QWebHitTestResult_enclosingBlockElement, METH_VARARGS, doc_QWebHitTestResult_enclosingBlockElement},
    {sipName_frame, meth_QWebHitTestResult_frame, METH_VARARGS, doc_QWebHitTestResult_frame},
    {sipName_imageUrl, meth_QWebHitTestResult_imageUrl, METH_VARARGS, doc_QWebHitTestResult_imageUrl},
    {sipName_isContentEditable, meth_QWebHitTestResult_isContentEditable, METH_VARARGS, doc_QWebHitTestResult_isContentEditable},
    {sipName_isContentSelected, meth_QWebHitTestResult_isContentSelected, METH_VARARGS, doc_QWebHitTestResult_isContentSelected},
    {sipName_isNull, meth_QWebHitTestResult_isNull, METH_VARARGS, doc_QWebHitTestResult_isNull},
    {sipName_linkElement, meth_QWebHitTestResult_linkElement, METH_VARARGS, doc_QWebHitTestResult_linkElement},
    {sipName_linkTargetFrame, meth_QWebHitTestResult_linkTargetFrame, METH_VARARGS, doc_QWebHitTestResult_linkTargetFrame},
    {sipName_linkText, meth_QWebHitTestResult_linkText, METH_VARARGS, doc_QWebHitTestResult_linkText},
    {sipName_linkTitle, meth_QWebHitTestResult_linkTitle, METH_VARARGS, doc_QWebHitTestResult_linkTitle},
    {sipName_linkTitleString, meth_QWebHitTestResult_linkTitleString, METH_VARARGS, doc_QWebHitTestResult_linkTitleString},
    {sipName_linkUrl, meth_QWebHitTestResult_linkUrl, METH_VARARGS, doc_QWebHitTestResult_linkUrl},
    {sipName_mediaUrl, meth_QWebHitTestResult_mediaUrl, METH_VARARGS, doc_QWebHitTestResult_mediaUrl},
    {sipName_pixmap, meth_QWebHitTestResult_pixmap, METH_VARARGS, doc_QWebHitTestResult_pixmap},
    {sipName_pos, meth_QWebHitTestResult_pos, METH_VARARGS, doc_QWebHitTestResult_pos},
    {sipName_title, meth_QWebHitTestResult_title, METH_VARARGS, doc_QWebHitTestResult_title}
};

PyDoc_STRVAR(doc_QWebHitTestResult, "\1QWebHitTestResult()\n"
"QWebHitTestResult(other: QWebHitTestResult)");


static pyqt5ClassPluginDef plugin_QWebHitTestResult = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebHitTestResult = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebHitTestResult,
        SIP_NULLPTR,
        &plugin_QWebHitTestResult,
    },
    {
        sipNameNr_QWebHitTestResult,
        {0, 0, 1},
        19, methods_QWebHitTestResult,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWebHitTestResult,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QWebHitTestResult,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWebHitTestResult,
    assign_QWebHitTestResult,
    array_QWebHitTestResult,
    copy_QWebHitTestResult,
    release_QWebHitTestResult,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QWebHitTestResult,
    sizeof (::QWebHitTestResult),
};
