/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPositioning.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtPositioning/qgeoaddress.sip"
#include <qgeoaddress.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPositioning/sipQtPositioningQGeoAddress.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtPositioning/sipQtPositioningQGeoAddress.cpp"


PyDoc_STRVAR(doc_QGeoAddress_text, "text(self) -> str");

extern "C" {static PyObject *meth_QGeoAddress_text(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_text(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAddress, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->text());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_text, doc_QGeoAddress_text);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_setText, "setText(self, text: Optional[str])");

extern "C" {static PyObject *meth_QGeoAddress_setText(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_setText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoAddress, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_setText, doc_QGeoAddress_setText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_country, "country(self) -> str");

extern "C" {static PyObject *meth_QGeoAddress_country(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_country(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAddress, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->country());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_country, doc_QGeoAddress_country);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_setCountry, "setCountry(self, country: Optional[str])");

extern "C" {static PyObject *meth_QGeoAddress_setCountry(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_setCountry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoAddress, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCountry(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_setCountry, doc_QGeoAddress_setCountry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_countryCode, "countryCode(self) -> str");

extern "C" {static PyObject *meth_QGeoAddress_countryCode(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_countryCode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAddress, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->countryCode());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_countryCode, doc_QGeoAddress_countryCode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_setCountryCode, "setCountryCode(self, countryCode: Optional[str])");

extern "C" {static PyObject *meth_QGeoAddress_setCountryCode(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_setCountryCode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoAddress, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCountryCode(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_setCountryCode, doc_QGeoAddress_setCountryCode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_state, "state(self) -> str");

extern "C" {static PyObject *meth_QGeoAddress_state(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_state(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAddress, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->state());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_state, doc_QGeoAddress_state);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_setState, "setState(self, state: Optional[str])");

extern "C" {static PyObject *meth_QGeoAddress_setState(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_setState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoAddress, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setState(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_setState, doc_QGeoAddress_setState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_county, "county(self) -> str");

extern "C" {static PyObject *meth_QGeoAddress_county(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_county(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAddress, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->county());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_county, doc_QGeoAddress_county);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_setCounty, "setCounty(self, county: Optional[str])");

extern "C" {static PyObject *meth_QGeoAddress_setCounty(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_setCounty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoAddress, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCounty(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_setCounty, doc_QGeoAddress_setCounty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_city, "city(self) -> str");

extern "C" {static PyObject *meth_QGeoAddress_city(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_city(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAddress, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->city());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_city, doc_QGeoAddress_city);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_setCity, "setCity(self, city: Optional[str])");

extern "C" {static PyObject *meth_QGeoAddress_setCity(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_setCity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoAddress, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCity(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_setCity, doc_QGeoAddress_setCity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_district, "district(self) -> str");

extern "C" {static PyObject *meth_QGeoAddress_district(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_district(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAddress, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->district());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_district, doc_QGeoAddress_district);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_setDistrict, "setDistrict(self, district: Optional[str])");

extern "C" {static PyObject *meth_QGeoAddress_setDistrict(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_setDistrict(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoAddress, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setDistrict(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_setDistrict, doc_QGeoAddress_setDistrict);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_postalCode, "postalCode(self) -> str");

extern "C" {static PyObject *meth_QGeoAddress_postalCode(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_postalCode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAddress, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->postalCode());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_postalCode, doc_QGeoAddress_postalCode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_setPostalCode, "setPostalCode(self, postalCode: Optional[str])");

extern "C" {static PyObject *meth_QGeoAddress_setPostalCode(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_setPostalCode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoAddress, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setPostalCode(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_setPostalCode, doc_QGeoAddress_setPostalCode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_street, "street(self) -> str");

extern "C" {static PyObject *meth_QGeoAddress_street(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_street(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAddress, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->street());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_street, doc_QGeoAddress_street);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_setStreet, "setStreet(self, street: Optional[str])");

extern "C" {static PyObject *meth_QGeoAddress_setStreet(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_setStreet(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGeoAddress, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setStreet(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_setStreet, doc_QGeoAddress_setStreet);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_isEmpty, "isEmpty(self) -> bool");

extern "C" {static PyObject *meth_QGeoAddress_isEmpty(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_isEmpty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAddress, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEmpty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_isEmpty, doc_QGeoAddress_isEmpty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_clear, "clear(self)");

extern "C" {static PyObject *meth_QGeoAddress_clear(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAddress, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_clear, doc_QGeoAddress_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoAddress_isTextGenerated, "isTextGenerated(self) -> bool");

extern "C" {static PyObject *meth_QGeoAddress_isTextGenerated(PyObject *, PyObject *);}
static PyObject *meth_QGeoAddress_isTextGenerated(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAddress *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoAddress, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isTextGenerated();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoAddress, sipName_isTextGenerated, doc_QGeoAddress_isTextGenerated);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QGeoAddress___ne__(PyObject *, PyObject *);}
static PyObject *slot_QGeoAddress___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoAddress *sipCpp = reinterpret_cast< ::QGeoAddress *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoAddress));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAddress* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGeoAddress, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QGeoAddress::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtPositioning, ne_slot, sipType_QGeoAddress, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QGeoAddress___eq__(PyObject *, PyObject *);}
static PyObject *slot_QGeoAddress___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoAddress *sipCpp = reinterpret_cast< ::QGeoAddress *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoAddress));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoAddress* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGeoAddress, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QGeoAddress::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtPositioning, eq_slot, sipType_QGeoAddress, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoAddress(void *, int);}
static void release_QGeoAddress(void *sipCppV, int)
{
    delete reinterpret_cast< ::QGeoAddress *>(sipCppV);
}


extern "C" {static void *array_QGeoAddress(Py_ssize_t);}
static void *array_QGeoAddress(Py_ssize_t sipNrElem)
{
    return new ::QGeoAddress[sipNrElem];
}


extern "C" {static void array_delete_QGeoAddress(void *);}
static void array_delete_QGeoAddress(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGeoAddress *>(sipCpp);
}


extern "C" {static void assign_QGeoAddress(void *, Py_ssize_t, void *);}
static void assign_QGeoAddress(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QGeoAddress *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QGeoAddress *>(sipSrc);
}


extern "C" {static void *copy_QGeoAddress(const void *, Py_ssize_t);}
static void *copy_QGeoAddress(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QGeoAddress(reinterpret_cast<const ::QGeoAddress *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QGeoAddress(sipSimpleWrapper *);}
static void dealloc_QGeoAddress(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoAddress(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QGeoAddress(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoAddress(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QGeoAddress *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QGeoAddress();

            return sipCpp;
        }
    }

    {
        const ::QGeoAddress* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QGeoAddress, &a0))
        {
            sipCpp = new ::QGeoAddress(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QGeoAddress[] = {
    {(void *)slot_QGeoAddress___ne__, ne_slot},
    {(void *)slot_QGeoAddress___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QGeoAddress[] = {
    {sipName_city, meth_QGeoAddress_city, METH_VARARGS, doc_QGeoAddress_city},
    {sipName_clear, meth_QGeoAddress_clear, METH_VARARGS, doc_QGeoAddress_clear},
    {sipName_country, meth_QGeoAddress_country, METH_VARARGS, doc_QGeoAddress_country},
    {sipName_countryCode, meth_QGeoAddress_countryCode, METH_VARARGS, doc_QGeoAddress_countryCode},
    {sipName_county, meth_QGeoAddress_county, METH_VARARGS, doc_QGeoAddress_county},
    {sipName_district, meth_QGeoAddress_district, METH_VARARGS, doc_QGeoAddress_district},
    {sipName_isEmpty, meth_QGeoAddress_isEmpty, METH_VARARGS, doc_QGeoAddress_isEmpty},
    {sipName_isTextGenerated, meth_QGeoAddress_isTextGenerated, METH_VARARGS, doc_QGeoAddress_isTextGenerated},
    {sipName_postalCode, meth_QGeoAddress_postalCode, METH_VARARGS, doc_QGeoAddress_postalCode},
    {sipName_setCity, meth_QGeoAddress_setCity, METH_VARARGS, doc_QGeoAddress_setCity},
    {sipName_setCountry, meth_QGeoAddress_setCountry, METH_VARARGS, doc_QGeoAddress_setCountry},
    {sipName_setCountryCode, meth_QGeoAddress_setCountryCode, METH_VARARGS, doc_QGeoAddress_setCountryCode},
    {sipName_setCounty, meth_QGeoAddress_setCounty, METH_VARARGS, doc_QGeoAddress_setCounty},
    {sipName_setDistrict, meth_QGeoAddress_setDistrict, METH_VARARGS, doc_QGeoAddress_setDistrict},
    {sipName_setPostalCode, meth_QGeoAddress_setPostalCode, METH_VARARGS, doc_QGeoAddress_setPostalCode},
    {sipName_setState, meth_QGeoAddress_setState, METH_VARARGS, doc_QGeoAddress_setState},
    {sipName_setStreet, meth_QGeoAddress_setStreet, METH_VARARGS, doc_QGeoAddress_setStreet},
    {sipName_setText, meth_QGeoAddress_setText, METH_VARARGS, doc_QGeoAddress_setText},
    {sipName_state, meth_QGeoAddress_state, METH_VARARGS, doc_QGeoAddress_state},
    {sipName_street, meth_QGeoAddress_street, METH_VARARGS, doc_QGeoAddress_street},
    {sipName_text, meth_QGeoAddress_text, METH_VARARGS, doc_QGeoAddress_text}
};

PyDoc_STRVAR(doc_QGeoAddress, "\1QGeoAddress()\n"
"QGeoAddress(other: QGeoAddress)");


static pyqt5ClassPluginDef plugin_QGeoAddress = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtPositioning_QGeoAddress = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoAddress,
        SIP_NULLPTR,
        &plugin_QGeoAddress,
    },
    {
        sipNameNr_QGeoAddress,
        {0, 0, 1},
        21, methods_QGeoAddress,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoAddress,
    -1,
    -1,
    SIP_NULLPTR,
    slots_QGeoAddress,
    init_type_QGeoAddress,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoAddress,
    assign_QGeoAddress,
    array_QGeoAddress,
    copy_QGeoAddress,
    release_QGeoAddress,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGeoAddress,
    sizeof (::QGeoAddress),
};
