/*
 * Module code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKit.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 32 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 35 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 55 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 58 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 61 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 103 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qdatastream.sip"
#include <qdatastream.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebhistory.sip"
#include <qwebhistory.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebdatabase.sip"
#include <qwebdatabase.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebelement.sip"
#include <qwebelement.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebelement.sip"
#include <qwebelement.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebhistory.sip"
#include <qwebhistory.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 94 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebsecurityorigin.sip"
#include <qwebsecurityorigin.h>
#line 97 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtWebKit[] = {
    'Q', 'W', 'e', 'b', 'S', 'e', 'c', 'u', 'r', 'i', 't', 'y', 'O', 'r', 'i', 'g', 'i', 'n', ':', ':', 'S', 'u', 'b', 'd', 'o', 'm', 'a', 'i', 'n', 'S', 'e', 't', 't', 'i', 'n', 'g', 0,
    'Q', 'W', 'e', 'b', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', ':', ':', 'T', 'h', 'i', 'r', 'd', 'P', 'a', 'r', 't', 'y', 'C', 'o', 'o', 'k', 'i', 'e', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'A', 'l', 'l', 'o', 'w', 'T', 'h', 'i', 'r', 'd', 'P', 'a', 'r', 't', 'y', 'W', 'i', 't', 'h', 'E', 'x', 'i', 's', 't', 'i', 'n', 'g', 'C', 'o', 'o', 'k', 'i', 'e', 's', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'W', 'e', 'b', 'P', 'l', 'u', 'g', 'i', 'n', 'F', 'a', 'c', 't', 'o', 'r', 'y', ':', ':', 'M', 'i', 'm', 'e', 'T', 'y', 'p', 'e', '>', 0,
    'Q', 'W', 'e', 'b', 'P', 'l', 'u', 'g', 'i', 'n', 'F', 'a', 'c', 't', 'o', 'r', 'y', ':', ':', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 'W', 'e', 'b', 'P', 'l', 'u', 'g', 'i', 'n', 'F', 'a', 'c', 't', 'o', 'r', 'y', ':', ':', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'R', 'e', 't', 'u', 'r', 'n', 0,
    's', 'e', 't', 'O', 'f', 'f', 'l', 'i', 'n', 'e', 'W', 'e', 'b', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'C', 'a', 'c', 'h', 'e', 'Q', 'u', 'o', 't', 'a', 0,
    'O', 'f', 'f', 'l', 'i', 'n', 'e', 'W', 'e', 'b', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'C', 'a', 'c', 'h', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 'W', 'e', 'b', 'E', 'l', 'e', 'm', 'e', 'n', 't', ':', ':', 'S', 't', 'y', 'l', 'e', 'R', 'e', 's', 'o', 'l', 'v', 'e', 'S', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    's', 'e', 't', 'O', 'f', 'f', 'l', 'i', 'n', 'e', 'W', 'e', 'b', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'C', 'a', 'c', 'h', 'e', 'P', 'a', 't', 'h', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'W', 'e', 'b', 'P', 'l', 'u', 'g', 'i', 'n', 'F', 'a', 'c', 't', 'o', 'r', 'y', ':', ':', 'P', 'l', 'u', 'g', 'i', 'n', '>', 0,
    'S', 'e', 'a', 'r', 'c', 'h', 'C', 'a', 'n', 'c', 'e', 'l', 'B', 'u', 't', 't', 'o', 'n', 'P', 'r', 'e', 's', 's', 'e', 'd', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 0,
    'L', 'o', 'c', 'a', 'l', 'C', 'o', 'n', 't', 'e', 'n', 't', 'C', 'a', 'n', 'A', 'c', 'c', 'e', 's', 's', 'R', 'e', 'm', 'o', 't', 'e', 'U', 'r', 'l', 's', 0,
    'o', 'f', 'f', 'l', 'i', 'n', 'e', 'W', 'e', 'b', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'C', 'a', 'c', 'h', 'e', 'Q', 'u', 'o', 't', 'a', 0,
    'o', 'f', 'f', 'l', 'i', 'n', 'e', 'W', 'e', 'b', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'C', 'a', 'c', 'h', 'e', 'P', 'a', 't', 'h', 0,
    'A', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'e', 'd', 'C', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'L', 'o', 'c', 'a', 'l', 'C', 'o', 'n', 't', 'e', 'n', 't', 'C', 'a', 'n', 'A', 'c', 'c', 'e', 's', 's', 'F', 'i', 'l', 'e', 'U', 'r', 'l', 's', 0,
    'O', 'f', 'f', 'l', 'i', 'n', 'e', 'S', 't', 'o', 'r', 'a', 'g', 'e', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'T', 'e', 'x', 't', 'A', 'r', 'e', 'a', 'S', 'i', 'z', 'e', 'G', 'r', 'i', 'p', 'C', 'o', 'r', 'n', 'e', 'r', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 0,
    's', 'e', 't', 'O', 'f', 'f', 'l', 'i', 'n', 'e', 'S', 't', 'o', 'r', 'a', 'g', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'Q', 'u', 'o', 't', 'a', 0,
    'A', 'l', 'w', 'a', 'y', 's', 'A', 'l', 'l', 'o', 'w', 'T', 'h', 'i', 'r', 'd', 'P', 'a', 'r', 't', 'y', 'C', 'o', 'o', 'k', 'i', 'e', 's', 0,
    'A', 'l', 'w', 'a', 'y', 's', 'B', 'l', 'o', 'c', 'k', 'T', 'h', 'i', 'r', 'd', 'P', 'a', 'r', 't', 'y', 'C', 'o', 'o', 'k', 'i', 'e', 's', 0,
    'J', 'a', 'v', 'a', 's', 'c', 'r', 'i', 'p', 't', 'C', 'a', 'n', 'A', 'c', 'c', 'e', 's', 's', 'C', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', 0,
    'Q', 'W', 'e', 'b', 'P', 'l', 'u', 'g', 'i', 'n', 'F', 'a', 'c', 't', 'o', 'r', 'y', ':', ':', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'L', 'o', 'c', 'a', 'l', 'S', 't', 'o', 'r', 'a', 'g', 'e', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 'W', 'e', 'b', 'P', 'l', 'u', 'g', 'i', 'n', 'F', 'a', 'c', 't', 'o', 'r', 'y', ':', ':', 'M', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 0,
    'A', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'e', 'd', '2', 'd', 'C', 'a', 'n', 'v', 'a', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 'W', 'e', 'b', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', ':', ':', 'W', 'e', 'b', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'o', 'f', 'f', 'l', 'i', 'n', 'e', 'S', 't', 'o', 'r', 'a', 'g', 'e', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'Q', 'u', 'o', 't', 'a', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'c', 'c', 'e', 's', 's', 'W', 'h', 'i', 't', 'e', 'l', 'i', 's', 't', 'E', 'n', 't', 'r', 'y', 0,
    'J', 'a', 'v', 'a', 's', 'c', 'r', 'i', 'p', 't', 'C', 'a', 'n', 'C', 'l', 'o', 's', 'e', 'W', 'i', 'n', 'd', 'o', 'w', 's', 0,
    'L', 'i', 'n', 'k', 's', 'I', 'n', 'c', 'l', 'u', 'd', 'e', 'd', 'I', 'n', 'F', 'o', 'c', 'u', 's', 'C', 'h', 'a', 'i', 'n', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'W', 'e', 'b', 'S', 'e', 'c', 'u', 'r', 'i', 't', 'y', 'O', 'r', 'i', 'g', 'i', 'n', '>', 0,
    'Q', 'W', 'e', 'b', 'P', 'l', 'u', 'g', 'i', 'n', 'F', 'a', 'c', 't', 'o', 'r', 'y', ':', ':', 'P', 'l', 'u', 'g', 'i', 'n', 0,
    'S', 'e', 'a', 'r', 'c', 'h', 'C', 'a', 'n', 'c', 'e', 'l', 'B', 'u', 't', 't', 'o', 'n', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 0,
    'S', 'i', 't', 'e', 'S', 'p', 'e', 'c', 'i', 'f', 'i', 'c', 'Q', 'u', 'i', 'r', 'k', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'T', 'h', 'i', 'r', 'd', 'P', 'a', 'r', 't', 'y', 'C', 'o', 'o', 'k', 'i', 'e', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'H', 'y', 'p', 'e', 'r', 'l', 'i', 'n', 'k', 'A', 'u', 'd', 'i', 't', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'I', 'n', 'p', 'u', 't', 'S', 'p', 'e', 'e', 'c', 'h', 'B', 'u', 't', 't', 'o', 'n', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 0,
    'J', 'a', 'v', 'a', 's', 'c', 'r', 'i', 'p', 't', 'C', 'a', 'n', 'O', 'p', 'e', 'n', 'W', 'i', 'n', 'd', 'o', 'w', 's', 0,
    'Q', 'W', 'e', 'b', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', ':', ':', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    'Q', 'W', 'e', 'b', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', ':', ':', 'W', 'e', 'b', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 0,
    'S', 'p', 'a', 't', 'i', 'a', 'l', 'N', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'T', 'i', 'l', 'e', 'd', 'B', 'a', 'c', 'k', 'i', 'n', 'g', 'S', 't', 'o', 'r', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'A', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'C', 'a', 'c', 'h', 'e', 'Q', 'u', 'o', 't', 'a', 0,
    's', 'e', 't', 'O', 'b', 'j', 'e', 'c', 't', 'C', 'a', 'c', 'h', 'e', 'C', 'a', 'p', 'a', 'c', 'i', 't', 'i', 'e', 's', 0,
    'D', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'r', 'a', 'm', 'e', 'I', 'c', 'o', 'n', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 0,
    'P', 'r', 'i', 'n', 't', 'E', 'l', 'e', 'm', 'e', 'n', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 's', 0,
    'a', 'd', 'd', 'A', 'c', 'c', 'e', 's', 's', 'W', 'h', 'i', 't', 'e', 'l', 'i', 's', 't', 'E', 'n', 't', 'r', 'y', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'P', 'e', 'r', 's', 'i', 's', 't', 'e', 'n', 't', 'S', 't', 'o', 'r', 'a', 'g', 'e', 0,
    'D', 'e', 'v', 'e', 'l', 'o', 'p', 'e', 'r', 'E', 'x', 't', 'r', 'a', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'F', 'r', 'a', 'm', 'e', 'F', 'l', 'a', 't', 't', 'e', 'n', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'M', 'i', 'n', 'i', 'm', 'u', 'm', 'L', 'o', 'g', 'i', 'c', 'a', 'l', 'F', 'o', 'n', 't', 'S', 'i', 'z', 'e', 0,
    'P', 'r', 'i', 'v', 'a', 't', 'e', 'B', 'r', 'o', 'w', 's', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'W', 'e', 'b', 'H', 'i', 's', 't', 'o', 'r', 'y', 'I', 't', 'e', 'm', '>', 0,
    'Q', 'W', 'e', 'b', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', ':', ':', 'F', 'o', 'n', 't', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'T', 'e', 'x', 't', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'P', 'a', 'g', 'e', 's', 'I', 'n', 'C', 'a', 'c', 'h', 'e', 0,
    't', 'h', 'i', 'r', 'd', 'P', 'a', 'r', 't', 'y', 'C', 'o', 'o', 'k', 'i', 'e', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'Q', 'W', 'e', 'b', 'E', 'l', 'e', 'm', 'e', 'n', 't', 'C', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'S', 'c', 'r', 'o', 'l', 'l', 'A', 'n', 'i', 'm', 'a', 't', 'o', 'r', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'O', 'f', 'f', 'l', 'i', 'n', 'e', 'S', 't', 'o', 'r', 'a', 'g', 'e', 'P', 'a', 't', 'h', 0,
    'C', 'S', 'S', 'G', 'r', 'i', 'd', 'L', 'a', 'y', 'o', 'u', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'C', 'a', 'r', 'e', 't', 'B', 'r', 'o', 'w', 's', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'D', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'i', 'x', 'e', 'd', 'F', 'o', 'n', 't', 'S', 'i', 'z', 'e', 0,
    'M', 'i', 's', 's', 'i', 'n', 'g', 'P', 'l', 'u', 'g', 'i', 'n', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 0,
    'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 'W', 'e', 'b', 'H', 'i', 's', 't', 'o', 'r', 'y', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 'S', 't', 'y', 'l', 'e', 'S', 'h', 'e', 'e', 't', 'U', 'r', 'l', 0,
    'L', 'o', 'c', 'a', 'l', 'S', 't', 'o', 'r', 'a', 'g', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'M', 'i', 's', 's', 'i', 'n', 'g', 'I', 'm', 'a', 'g', 'e', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'W', 'e', 'b', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', '>', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'T', 'e', 'x', 't', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 0,
    'e', 'n', 'c', 'l', 'o', 's', 'e', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 'W', 'i', 't', 'h', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'P', 'a', 'g', 'e', 's', 'I', 'n', 'C', 'a', 'c', 'h', 'e', 0,
    'q', 'W', 'e', 'b', 'K', 'i', 't', 'M', 'a', 'j', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'q', 'W', 'e', 'b', 'K', 'i', 't', 'M', 'i', 'n', 'o', 'r', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    's', 'e', 't', 'I', 'c', 'o', 'n', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 'P', 'a', 't', 'h', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'S', 't', 'o', 'r', 'a', 'g', 'e', 'P', 'a', 't', 'h', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'I', 't', 'e', 'm', 'C', 'o', 'u', 'n', 't', 0,
    'D', 'i', 's', 'a', 'l', 'l', 'o', 'w', 'S', 'u', 'b', 'd', 'o', 'm', 'a', 'i', 'n', 's', 0,
    'D', 'n', 's', 'P', 'r', 'e', 'f', 'e', 't', 'c', 'h', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'W', 'e', 'b', 'E', 'l', 'e', 'm', 'e', 'n', 't', '>', 0,
    'Q', 'W', 'e', 'b', 'S', 'e', 'c', 'u', 'r', 'i', 't', 'y', 'O', 'r', 'i', 'g', 'i', 'n', 0,
    'X', 'S', 'S', 'A', 'u', 'd', 'i', 't', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'e', 'v', 'a', 'l', 'u', 'a', 't', 'e', 'J', 'a', 'v', 'a', 'S', 'c', 'r', 'i', 'p', 't', 0,
    'o', 'f', 'f', 'l', 'i', 'n', 'e', 'S', 't', 'o', 'r', 'a', 'g', 'e', 'P', 'a', 't', 'h', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'l', 'l', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'F', 'r', 'o', 'm', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'C', 'S', 'S', 'R', 'e', 'g', 'i', 'o', 'n', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'J', 'a', 'v', 'a', 's', 'c', 'r', 'i', 'p', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 'W', 'e', 'b', 'P', 'l', 'u', 'g', 'i', 'n', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    'c', 'l', 'e', 'a', 'r', 'I', 'c', 'o', 'n', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 0,
    'c', 'l', 'e', 'a', 'r', 'M', 'e', 'm', 'o', 'r', 'y', 'C', 'a', 'c', 'h', 'e', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'l', 'l', 'C', 'h', 'i', 'l', 'd', 'r', 'e', 'n', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'S', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'L', 'o', 'c', 'a', 'l', 'S', 'c', 'h', 'e', 'm', 'e', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 's', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'u', 's', 'e', 'r', 'S', 't', 'y', 'l', 'e', 'S', 'h', 'e', 'e', 't', 'U', 'r', 'l', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'I', 't', 'e', 'm', 'I', 'n', 'd', 'e', 'x', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'i', 'c', 'o', 'n', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 'P', 'a', 't', 'h', 0,
    'l', 'o', 'c', 'a', 'l', 'S', 't', 'o', 'r', 'a', 'g', 'e', 'P', 'a', 't', 'h', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'I', 't', 'e', 'm', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 'Q', 'u', 'o', 't', 'a', 0,
    's', 'e', 't', 'S', 't', 'y', 'l', 'e', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    't', 'a', 'k', 'e', 'F', 'r', 'o', 'm', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'A', 'l', 'l', 'o', 'w', 'S', 'u', 'b', 'd', 'o', 'm', 'a', 'i', 'n', 's', 0,
    'D', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'o', 'n', 't', 'S', 'i', 'z', 'e', 0,
    'M', 'i', 'n', 'i', 'm', 'u', 'm', 'F', 'o', 'n', 't', 'S', 'i', 'z', 'e', 0,
    'Q', 'W', 'e', 'b', 'H', 'i', 's', 't', 'o', 'r', 'y', 'I', 't', 'e', 'm', 0,
    'W', 'e', 'b', 'A', 'u', 'd', 'i', 'o', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'a', 'd', 'd', 'H', 'i', 's', 't', 'o', 'r', 'y', 'E', 'n', 't', 'r', 'y', 0,
    'h', 'i', 's', 't', 'o', 'r', 'y', 'C', 'o', 'n', 't', 'a', 'i', 'n', 's', 0,
    'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'S', 'i', 'b', 'l', 'i', 'n', 'g', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'r', 'e', 's', 'e', 't', 'F', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    's', 'e', 't', 'C', 'S', 'S', 'M', 'e', 'd', 'i', 'a', 'T', 'y', 'p', 'e', 0,
    'A', 'u', 't', 'o', 'L', 'o', 'a', 'd', 'I', 'm', 'a', 'g', 'e', 's', 0,
    'P', 'l', 'u', 'g', 'i', 'n', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', 'W', 'e', 'b', 'K', 'i', 't', 0,
    'a', 'd', 'd', 'L', 'o', 'c', 'a', 'l', 'S', 'c', 'h', 'e', 'm', 'e', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'a', 'm', 'e', 's', 0,
    'f', 'i', 'l', 'e', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 0,
    'g', 'l', 'o', 'b', 'a', 'l', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'h', 'a', 's', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'S', 0,
    'p', 'r', 'e', 'p', 'e', 'n', 'd', 'O', 'u', 't', 's', 'i', 'd', 'e', 0,
    'q', 'W', 'e', 'b', 'K', 'i', 't', 'V', 'e', 'r', 's', 'i', 'o', 'n', 0,
    'r', 'e', 'f', 'r', 'e', 's', 'h', 'P', 'l', 'u', 'g', 'i', 'n', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 0,
    'r', 'e', 's', 'e', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    's', 'e', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'S', 0,
    'C', 'a', 's', 'c', 'a', 'd', 'e', 'd', 'S', 't', 'y', 'l', 'e', 0,
    'C', 'o', 'm', 'p', 'u', 't', 'e', 'd', 'S', 't', 'y', 'l', 'e', 0,
    'S', 'a', 'n', 's', 'S', 'e', 'r', 'i', 'f', 'F', 'o', 'n', 't', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'O', 'u', 't', 's', 'i', 'd', 'e', 0,
    'd', 'a', 't', 'a', 'b', 'a', 's', 'e', 'Q', 'u', 'o', 't', 'a', 0,
    'd', 'a', 't', 'a', 'b', 'a', 's', 'e', 'U', 's', 'a', 'g', 'e', 0,
    'h', 'a', 's', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', 0,
    'p', 'r', 'e', 'p', 'e', 'n', 'd', 'I', 'n', 's', 'i', 'd', 'e', 0,
    'r', 'e', 's', 'e', 't', 'F', 'o', 'n', 't', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'W', 'e', 'b', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 0,
    's', 't', 'y', 'l', 'e', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    't', 'e', 's', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'Q', 'W', 'e', 'b', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 0,
    'Q', 'W', 'e', 'b', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'S', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'F', 'o', 'n', 't', 0,
    'W', 'e', 'b', 'G', 'L', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Z', 'o', 'o', 'm', 'T', 'e', 'x', 't', 'O', 'n', 'l', 'y', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'I', 'n', 's', 'i', 'd', 'e', 0,
    'c', 'a', 'n', 'G', 'o', 'F', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    'c', 's', 's', 'M', 'e', 'd', 'i', 'a', 'T', 'y', 'p', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'V', 'a', 'l', 'u', 'e', 0,
    'e', 'x', 'p', 'e', 'c', 't', 'e', 'd', 'S', 'i', 'z', 'e', 0,
    'f', 'o', 'r', 'w', 'a', 'r', 'd', 'I', 't', 'e', 'm', 's', 0,
    'h', 'a', 's', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'l', 'o', 'c', 'a', 'l', 'S', 'c', 'h', 'e', 'm', 'e', 's', 0,
    'n', 'a', 'm', 'e', 's', 'p', 'a', 'c', 'e', 'U', 'r', 'i', 0,
    's', 'e', 't', 'P', 'l', 'a', 'i', 'n', 'T', 'e', 'x', 't', 0,
    'C', 'u', 'r', 's', 'i', 'v', 'e', 'F', 'o', 'n', 't', 0,
    'F', 'a', 'n', 't', 'a', 's', 'y', 'F', 'o', 'n', 't', 0,
    'I', 'n', 'l', 'i', 'n', 'e', 'S', 't', 'y', 'l', 'e', 0,
    'J', 'a', 'v', 'a', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 'W', 'e', 'b', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    'Q', 'W', 'e', 'b', 'H', 'i', 's', 't', 'o', 'r', 'y', 0,
    '_', '_', 'g', 'e', 't', 'i', 't', 'e', 'm', '_', '_', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'S', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'I', 't', 'e', 'm', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'd', 'i', 's', 'p', 'l', 'a', 'y', 'N', 'a', 'm', 'e', 0,
    'e', 'n', 'c', 'l', 'o', 's', 'e', 'W', 'i', 't', 'h', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'f', 'o', 'r', 'w', 'a', 'r', 'd', 'I', 't', 'e', 'm', 0,
    'l', 'a', 's', 't', 'V', 'i', 's', 'i', 't', 'e', 'd', 0,
    'n', 'e', 'x', 't', 'S', 'i', 'b', 'l', 'i', 'n', 'g', 0,
    'o', 'r', 'i', 'g', 'i', 'n', 'a', 'l', 'U', 'r', 'l', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'l', 'a', 's', 's', 0,
    's', 'e', 't', 'I', 'n', 'n', 'e', 'r', 'X', 'm', 'l', 0,
    's', 'e', 't', 'O', 'u', 't', 'e', 'r', 'X', 'm', 'l', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 'D', 'a', 't', 'a', 0,
    't', 'o', 'P', 'l', 'a', 'i', 'n', 'T', 'e', 'x', 't', 0,
    't', 'o', 'g', 'g', 'l', 'e', 'C', 'l', 'a', 's', 's', 0,
    '_', '_', 'l', 's', 'h', 'i', 'f', 't', '_', '_', 0,
    '_', '_', 'r', 's', 'h', 'i', 'f', 't', '_', '_', 0,
    'a', 'l', 'l', 'O', 'r', 'i', 'g', 'i', 'n', 's', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'i', 'r', 's', 't', 'C', 'h', 'i', 'l', 'd', 0,
    'f', 'o', 'n', 't', 'F', 'a', 'm', 'i', 'l', 'y', 0,
    'i', 'c', 'o', 'n', 'F', 'o', 'r', 'U', 'r', 'l', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    't', 'o', 'I', 'n', 'n', 'e', 'r', 'X', 'm', 'l', 0,
    't', 'o', 'O', 'u', 't', 'e', 'r', 'X', 'm', 'l', 0,
    'w', 'e', 'b', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 0,
    'F', 'i', 'x', 'e', 'd', 'F', 'o', 'n', 't', 0,
    'Q', 'W', 'e', 'b', 'F', 'r', 'a', 'm', 'e', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'b', 'a', 'c', 'k', 'I', 't', 'e', 'm', 's', 0,
    'c', 'a', 'n', 'G', 'o', 'B', 'a', 'c', 'k', 0,
    'd', 'a', 't', 'a', 'b', 'a', 's', 'e', 's', 0,
    'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'f', 'i', 'n', 'd', 'F', 'i', 'r', 's', 't', 0,
    'l', 'a', 's', 't', 'C', 'h', 'i', 'l', 'd', 0,
    'l', 'o', 'c', 'a', 'l', 'N', 'a', 'm', 'e', 0,
    'm', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 's', 0,
    '_', '_', 'i', 'a', 'd', 'd', '_', '_', 0,
    'a', 'd', 'd', 'C', 'l', 'a', 's', 's', 0,
    'b', 'a', 'c', 'k', 'I', 't', 'e', 'm', 0,
    'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    'f', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'f', 'o', 'n', 't', 'S', 'i', 'z', 'e', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'g', 'o', 'T', 'o', 'I', 't', 'e', 'm', 0,
    'h', 'a', 's', 'C', 'l', 'a', 's', 's', 0,
    'h', 'a', 's', 'F', 'o', 'c', 'u', 's', 0,
    's', 'e', 't', 'F', 'o', 'c', 'u', 's', 0,
    'u', 's', 'e', 'r', 'D', 'a', 't', 'a', 0,
    'w', 'e', 'b', 'F', 'r', 'a', 'm', 'e', 0,
    '_', '_', 'a', 'd', 'd', '_', '_', 0,
    '_', '_', 'l', 'e', 'n', '_', '_', 0,
    'c', 'l', 'a', 's', 's', 'e', 's', 0,
    'f', 'i', 'n', 'd', 'A', 'l', 'l', 0,
    'f', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    'p', 'l', 'u', 'g', 'i', 'n', 's', 0,
    'r', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    't', 'a', 'g', 'N', 'a', 'm', 'e', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 0,
    'c', 'r', 'e', 'a', 't', 'e', 0,
    'i', 's', 'N', 'u', 'l', 'l', 0,
    'i', 't', 'e', 'm', 'A', 't', 0,
    'o', 'p', 't', 'i', 'o', 'n', 0,
    'o', 'r', 'i', 'g', 'i', 'n', 0,
    'o', 'u', 't', 'p', 'u', 't', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'p', 'r', 'e', 'f', 'i', 'x', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 0,
    's', 'c', 'h', 'e', 'm', 'e', 0,
    't', 'o', 'L', 'i', 's', 't', 0,
    'c', 'l', 'e', 'a', 'r', 0,
    'c', 'l', 'o', 'n', 'e', 0,
    'c', 'o', 'u', 'n', 't', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'f', 'i', 'r', 's', 't', 0,
    'i', 't', 'e', 'm', 's', 0,
    't', 'i', 't', 'l', 'e', 0,
    'b', 'a', 'c', 'k', 0,
    'h', 'o', 's', 't', 0,
    'i', 'c', 'o', 'n', 0,
    'l', 'a', 's', 't', 0,
    'n', 'a', 'm', 'e', 0,
    'p', 'a', 't', 'h', 0,
    'p', 'o', 'r', 't', 0,
    's', 'i', 'z', 'e', 0,
    'u', 'r', 'l', 0,
    'a', 't', 0,
};
#line 24 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebkitglobal.sip"
#include <qwebkitglobal.h>
#line 365 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"

bool sipVH_QtWebKit_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWebPluginFactory::Extension a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QWebPluginFactory_Extension);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtWebKit_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWebPluginFactory::Extension a0, const ::QWebPluginFactory::ExtensionOption*a1, ::QWebPluginFactory::ExtensionReturn*a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "FDD", a0, sipType_QWebPluginFactory_Extension, const_cast< ::QWebPluginFactory::ExtensionOption *>(a1), sipType_QWebPluginFactory_ExtensionOption, SIP_NULLPTR, a2, sipType_QWebPluginFactory_ExtensionReturn, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QObject* sipVH_QtWebKit_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0, const ::QUrl& a1, const ::QStringList& a2, const ::QStringList& a3)
{
    ::QObject* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NNNN", new ::QString(a0), sipType_QString, SIP_NULLPTR, new ::QUrl(a1), sipType_QUrl, SIP_NULLPTR, new ::QStringList(a2), sipType_QStringList, SIP_NULLPTR, new ::QStringList(a3), sipType_QStringList, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QObject, &sipRes);

    return sipRes;
}

void sipVH_QtWebKit_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

QList< ::QWebPluginFactory::Plugin> sipVH_QtWebKit_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    QList< ::QWebPluginFactory::Plugin> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QWebPluginFactory_Plugin, &sipRes);

    return sipRes;
}

void sipVH_QtWebKit_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);
}

bool sipVH_QtWebKit_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtWebKit_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtWebKit_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtWebKit_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtWebKit_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtWebKit_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtWebKit_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}


extern "C" {static PyObject *slot___rshift__(PyObject *, PyObject *);}
static PyObject *slot___rshift__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDataStream* a0;
        ::QWebHistory* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QWebHistory, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 >> *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot___lshift__(PyObject *, PyObject *);}
static PyObject *slot___lshift__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDataStream* a0;
        const ::QWebHistory* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QDataStream, &a0, sipType_QWebHistory, &a1))
        {
            ::QDataStream*sipRes;

            Py_BEGIN_ALLOW_THREADS
            sipRes = &(*a0 << *a1);
            Py_END_ALLOW_THREADS

            return sipConvertFromType(sipRes, sipType_QDataStream, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


PyDoc_STRVAR(doc_qWebKitMinorVersion, "qWebKitMinorVersion() -> int");

extern "C" {static PyObject *func_qWebKitMinorVersion(PyObject *, PyObject *);}
static PyObject *func_qWebKitMinorVersion(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            int sipRes;

            sipRes = qWebKitMinorVersion();

            return PyLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qWebKitMinorVersion, doc_qWebKitMinorVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qWebKitMajorVersion, "qWebKitMajorVersion() -> int");

extern "C" {static PyObject *func_qWebKitMajorVersion(PyObject *, PyObject *);}
static PyObject *func_qWebKitMajorVersion(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            int sipRes;

            sipRes = qWebKitMajorVersion();

            return PyLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qWebKitMajorVersion, doc_qWebKitMajorVersion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_qWebKitVersion, "qWebKitVersion() -> str");

extern "C" {static PyObject *func_qWebKitVersion(PyObject *, PyObject *);}
static PyObject *func_qWebKitVersion(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QString*sipRes;

            sipRes = new ::QString(qWebKitVersion());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qWebKitVersion, doc_qWebKitVersion);

    return SIP_NULLPTR;
}

static sipPySlotExtenderDef slotExtenders[] = {
    {(void *)slot___rshift__, rshift_slot, {0, 0, 0}},
    {(void *)slot___lshift__, lshift_slot, {0, 0, 0}},
    {SIP_NULLPTR, (sipPySlotType)0, {0, 0, 0}}
};


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QWebPluginFactory(void **);}
static const sipTypeDef *sipSubClass_QWebPluginFactory(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
        {sipName_QWebHistoryInterface, &sipType_QWebHistoryInterface, -1, 1},
        {sipName_QWebPluginFactory, &sipType_QWebPluginFactory, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 649 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitcmodule.cpp"

    return sipType;
}


/* This defines each external type declared in this module, */
static sipExternalTypeDef externalTypesTable[] = {
    {10, "QWebFrame"},
    {-1, SIP_NULLPTR}
};
static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebElement__StyleResolveStrategy, SIP_NULLPTR, 0}, sipNameNr_StyleResolveStrategy, 7, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebPluginFactory__Extension, SIP_NULLPTR, 0}, sipNameNr_Extension, 14, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebSecurityOrigin__SubdomainSetting, SIP_NULLPTR, 0}, sipNameNr_SubdomainSetting, 20, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebSettings__FontFamily, SIP_NULLPTR, 0}, sipNameNr_FontFamily, 22, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebSettings__FontSize, SIP_NULLPTR, 0}, sipNameNr_FontSize, 22, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebSettings__ThirdPartyCookiePolicy, SIP_NULLPTR, 0}, sipNameNr_ThirdPartyCookiePolicy, 22, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebSettings__WebAttribute, SIP_NULLPTR, 0}, sipNameNr_WebAttribute, 22, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QWebSettings__WebGraphic, SIP_NULLPTR, 0}, sipNameNr_WebGraphic, 22, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtWebKit[] = {
    &sipTypeDef_QtWebKit_QList_0100QWebDatabase.mtd_base,
    &sipTypeDef_QtWebKit_QList_0100QWebElement.mtd_base,
    &sipTypeDef_QtWebKit_QList_0100QWebHistoryItem.mtd_base,
    &sipTypeDef_QtWebKit_QList_0100QWebPluginFactory_MimeType.mtd_base,
    &sipTypeDef_QtWebKit_QList_0100QWebPluginFactory_Plugin.mtd_base,
    &sipTypeDef_QtWebKit_QList_0100QWebSecurityOrigin.mtd_base,
    &sipTypeDef_QtWebKit_QWebDatabase.ctd_base,
    &sipTypeDef_QtWebKit_QWebElement.ctd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_QtWebKit_QWebElementCollection.ctd_base,
    0,
    &sipTypeDef_QtWebKit_QWebHistory.ctd_base,
    &sipTypeDef_QtWebKit_QWebHistoryInterface.ctd_base,
    &sipTypeDef_QtWebKit_QWebHistoryItem.ctd_base,
    &sipTypeDef_QtWebKit_QWebPluginFactory.ctd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_QtWebKit_QWebPluginFactory_ExtensionOption.ctd_base,
    &sipTypeDef_QtWebKit_QWebPluginFactory_ExtensionReturn.ctd_base,
    &sipTypeDef_QtWebKit_QWebPluginFactory_MimeType.ctd_base,
    &sipTypeDef_QtWebKit_QWebPluginFactory_Plugin.ctd_base,
    &sipTypeDef_QtWebKit_QWebSecurityOrigin.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_QtWebKit_QWebSettings.ctd_base,
    &enumTypes[3].etd_base,
    &enumTypes[4].etd_base,
    &enumTypes[5].etd_base,
    &enumTypes[6].etd_base,
    &enumTypes[7].etd_base,
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtWebKit_QtCore[] = {
    {"QChildEvent"},
    {"QDataStream"},
    {"QDateTime"},
    {"QEvent"},
    {"QMetaMethod"},
    {"QObject"},
    {"QRect"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QVariant"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtWebKit_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_QtWebKit_QtGui[] = {
    {"QIcon"},
    {"QPainter"},
    {"QPixmap"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_QtWebKit_QtCore, sipImportedVirtErrorHandlers_QtWebKit_QtCore, SIP_NULLPTR},
    {"PyQt5.QtGui", sipImportedTypes_QtWebKit_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.QtNetwork", SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QWebPluginFactory, {5, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtWebKit = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_QtWebKit,
    0,
    sipStrings_QtWebKit,
    importsTable,
    SIP_NULLPTR,
    28,
    sipExportedTypes_QtWebKit,
    externalTypesTable,
    0,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    slotExtenders,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtWebKit;

sip_qt_metaobject_func sip_QtWebKit_qt_metaobject;
sip_qt_metacall_func sip_QtWebKit_qt_metacall;
sip_qt_metacast_func sip_QtWebKit_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtWebKit()
#else
PyMODINIT_FUNC PyInit_QtWebKit()
#endif
{
    static PyMethodDef sip_methods[] = {
        {sipName_qWebKitMinorVersion, func_qWebKitMinorVersion, METH_VARARGS, doc_qWebKitMinorVersion},
        {sipName_qWebKitMajorVersion, func_qWebKitMajorVersion, METH_VARARGS, doc_qWebKitMajorVersion},
        {sipName_qWebKitVersion, func_qWebKitVersion, METH_VARARGS, doc_qWebKitVersion},
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.QtWebKit",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtWebKit = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_QtWebKit == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtWebKit, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtWebKit_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtWebKit_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtWebKit_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtWebKit_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtWebKit, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    return sipModule;
}
