/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacematchrequest.sip"
#include <qplacematchrequest.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceMatchRequest.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceMatchRequest.cpp"
#line 24 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceMatchRequest.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceMatchRequest.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplacesearchresult.sip"
#include <qplacesearchresult.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceMatchRequest.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceMatchRequest.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qplace.sip"
#include <qplace.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQPlaceMatchRequest.cpp"


PyDoc_STRVAR(doc_QPlaceMatchRequest_places, "places(self) -> list[QPlace]");

extern "C" {static PyObject *meth_QPlaceMatchRequest_places(PyObject *, PyObject *);}
static PyObject *meth_QPlaceMatchRequest_places(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceMatchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceMatchRequest, &sipCpp))
        {
            QList< ::QPlace>*sipRes;

            sipRes = new QList< ::QPlace>(sipCpp->places());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QPlace, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceMatchRequest, sipName_places, doc_QPlaceMatchRequest_places);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceMatchRequest_setPlaces, "setPlaces(self, places: Iterable[QPlace])");

extern "C" {static PyObject *meth_QPlaceMatchRequest_setPlaces(PyObject *, PyObject *);}
static PyObject *meth_QPlaceMatchRequest_setPlaces(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QPlace>* a0;
        int a0State = 0;
        ::QPlaceMatchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceMatchRequest, &sipCpp, sipType_QList_0100QPlace, &a0, &a0State))
        {
            sipCpp->setPlaces(*a0);
            sipReleaseType(const_cast<QList< ::QPlace> *>(a0), sipType_QList_0100QPlace, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceMatchRequest, sipName_setPlaces, doc_QPlaceMatchRequest_setPlaces);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceMatchRequest_setResults, "setResults(self, results: Iterable[QPlaceSearchResult])");

extern "C" {static PyObject *meth_QPlaceMatchRequest_setResults(PyObject *, PyObject *);}
static PyObject *meth_QPlaceMatchRequest_setResults(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QPlaceSearchResult>* a0;
        int a0State = 0;
        ::QPlaceMatchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceMatchRequest, &sipCpp, sipType_QList_0100QPlaceSearchResult, &a0, &a0State))
        {
            sipCpp->setResults(*a0);
            sipReleaseType(const_cast<QList< ::QPlaceSearchResult> *>(a0), sipType_QList_0100QPlaceSearchResult, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceMatchRequest, sipName_setResults, doc_QPlaceMatchRequest_setResults);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceMatchRequest_parameters, "parameters(self) -> dict[str, Any]");

extern "C" {static PyObject *meth_QPlaceMatchRequest_parameters(PyObject *, PyObject *);}
static PyObject *meth_QPlaceMatchRequest_parameters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceMatchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceMatchRequest, &sipCpp))
        {
            ::QVariantMap*sipRes;

            sipRes = new ::QVariantMap(sipCpp->parameters());

            return sipConvertFromNewType(sipRes, sipType_QVariantMap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceMatchRequest, sipName_parameters, doc_QPlaceMatchRequest_parameters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceMatchRequest_setParameters, "setParameters(self, parameters: dict[str, Any])");

extern "C" {static PyObject *meth_QPlaceMatchRequest_setParameters(PyObject *, PyObject *);}
static PyObject *meth_QPlaceMatchRequest_setParameters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVariantMap* a0;
        int a0State = 0;
        ::QPlaceMatchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPlaceMatchRequest, &sipCpp, sipType_QVariantMap, &a0, &a0State))
        {
            sipCpp->setParameters(*a0);
            sipReleaseType(const_cast< ::QVariantMap *>(a0), sipType_QVariantMap, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceMatchRequest, sipName_setParameters, doc_QPlaceMatchRequest_setParameters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPlaceMatchRequest_clear, "clear(self)");

extern "C" {static PyObject *meth_QPlaceMatchRequest_clear(PyObject *, PyObject *);}
static PyObject *meth_QPlaceMatchRequest_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QPlaceMatchRequest *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPlaceMatchRequest, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPlaceMatchRequest, sipName_clear, doc_QPlaceMatchRequest_clear);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QPlaceMatchRequest___ne__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceMatchRequest___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceMatchRequest *sipCpp = reinterpret_cast< ::QPlaceMatchRequest *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceMatchRequest));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceMatchRequest* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceMatchRequest, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceMatchRequest::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, ne_slot, sipType_QPlaceMatchRequest, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QPlaceMatchRequest___eq__(PyObject *, PyObject *);}
static PyObject *slot_QPlaceMatchRequest___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QPlaceMatchRequest *sipCpp = reinterpret_cast< ::QPlaceMatchRequest *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QPlaceMatchRequest));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPlaceMatchRequest* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPlaceMatchRequest, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QPlaceMatchRequest::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, eq_slot, sipType_QPlaceMatchRequest, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QPlaceMatchRequest(void *, int);}
static void release_QPlaceMatchRequest(void *sipCppV, int)
{
    delete reinterpret_cast< ::QPlaceMatchRequest *>(sipCppV);
}


extern "C" {static void *array_QPlaceMatchRequest(Py_ssize_t);}
static void *array_QPlaceMatchRequest(Py_ssize_t sipNrElem)
{
    return new ::QPlaceMatchRequest[sipNrElem];
}


extern "C" {static void array_delete_QPlaceMatchRequest(void *);}
static void array_delete_QPlaceMatchRequest(void *sipCpp)
{
    delete[] reinterpret_cast< ::QPlaceMatchRequest *>(sipCpp);
}


extern "C" {static void assign_QPlaceMatchRequest(void *, Py_ssize_t, void *);}
static void assign_QPlaceMatchRequest(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPlaceMatchRequest *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPlaceMatchRequest *>(sipSrc);
}


extern "C" {static void *copy_QPlaceMatchRequest(const void *, Py_ssize_t);}
static void *copy_QPlaceMatchRequest(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QPlaceMatchRequest(reinterpret_cast<const ::QPlaceMatchRequest *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPlaceMatchRequest(sipSimpleWrapper *);}
static void dealloc_QPlaceMatchRequest(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPlaceMatchRequest(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QPlaceMatchRequest(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPlaceMatchRequest(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QPlaceMatchRequest *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QPlaceMatchRequest();

            return sipCpp;
        }
    }

    {
        const ::QPlaceMatchRequest* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPlaceMatchRequest, &a0))
        {
            sipCpp = new ::QPlaceMatchRequest(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QPlaceMatchRequest[] = {
    {(void *)slot_QPlaceMatchRequest___ne__, ne_slot},
    {(void *)slot_QPlaceMatchRequest___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QPlaceMatchRequest[] = {
    {sipName_clear, meth_QPlaceMatchRequest_clear, METH_VARARGS, doc_QPlaceMatchRequest_clear},
    {sipName_parameters, meth_QPlaceMatchRequest_parameters, METH_VARARGS, doc_QPlaceMatchRequest_parameters},
    {sipName_places, meth_QPlaceMatchRequest_places, METH_VARARGS, doc_QPlaceMatchRequest_places},
    {sipName_setParameters, meth_QPlaceMatchRequest_setParameters, METH_VARARGS, doc_QPlaceMatchRequest_setParameters},
    {sipName_setPlaces, meth_QPlaceMatchRequest_setPlaces, METH_VARARGS, doc_QPlaceMatchRequest_setPlaces},
    {sipName_setResults, meth_QPlaceMatchRequest_setResults, METH_VARARGS, doc_QPlaceMatchRequest_setResults}
};


extern "C" {static PyObject *varget_QPlaceMatchRequest_AlternativeId(void *, PyObject *, PyObject *);}
static PyObject *varget_QPlaceMatchRequest_AlternativeId(void *, PyObject *, PyObject *)
{
    const ::QString*sipVal;

    sipVal = new ::QString(::QPlaceMatchRequest::AlternativeId);

    return sipConvertFromNewType(const_cast< ::QString *>(sipVal), sipType_QString, SIP_NULLPTR);
}

sipVariableDef variables_QPlaceMatchRequest[] = {
    {ClassVariable, sipName_AlternativeId, (PyMethodDef *)varget_QPlaceMatchRequest_AlternativeId, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
};

PyDoc_STRVAR(doc_QPlaceMatchRequest, "\1QPlaceMatchRequest()\n"
"QPlaceMatchRequest(other: QPlaceMatchRequest)");


static pyqt5ClassPluginDef plugin_QPlaceMatchRequest = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QPlaceMatchRequest = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPlaceMatchRequest,
        SIP_NULLPTR,
        &plugin_QPlaceMatchRequest,
    },
    {
        sipNameNr_QPlaceMatchRequest,
        {0, 0, 1},
        6, methods_QPlaceMatchRequest,
        0, SIP_NULLPTR,
        1, variables_QPlaceMatchRequest,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPlaceMatchRequest,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QPlaceMatchRequest,
    init_type_QPlaceMatchRequest,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QPlaceMatchRequest,
    assign_QPlaceMatchRequest,
    array_QPlaceMatchRequest,
    copy_QPlaceMatchRequest,
    release_QPlaceMatchRequest,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QPlaceMatchRequest,
    sizeof (::QPlaceMatchRequest),
};
