/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameraimageprocessing.sip"
#include <qcameraimageprocessing.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraImageProcessing.cpp"


PyDoc_STRVAR(doc_QCameraImageProcessing_isAvailable, "isAvailable(self) -> bool");

extern "C" {static PyObject *meth_QCameraImageProcessing_isAvailable(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_isAvailable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageProcessing, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAvailable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_isAvailable, doc_QCameraImageProcessing_isAvailable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_whiteBalanceMode, "whiteBalanceMode(self) -> QCameraImageProcessing.WhiteBalanceMode");

extern "C" {static PyObject *meth_QCameraImageProcessing_whiteBalanceMode(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_whiteBalanceMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageProcessing, &sipCpp))
        {
            ::QCameraImageProcessing::WhiteBalanceMode sipRes;

            sipRes = sipCpp->whiteBalanceMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCameraImageProcessing_WhiteBalanceMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_whiteBalanceMode, doc_QCameraImageProcessing_whiteBalanceMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_setWhiteBalanceMode, "setWhiteBalanceMode(self, mode: QCameraImageProcessing.WhiteBalanceMode)");

extern "C" {static PyObject *meth_QCameraImageProcessing_setWhiteBalanceMode(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_setWhiteBalanceMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCameraImageProcessing::WhiteBalanceMode a0;
        ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraImageProcessing, &sipCpp, sipType_QCameraImageProcessing_WhiteBalanceMode, &a0))
        {
            sipCpp->setWhiteBalanceMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_setWhiteBalanceMode, doc_QCameraImageProcessing_setWhiteBalanceMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_isWhiteBalanceModeSupported, "isWhiteBalanceModeSupported(self, mode: QCameraImageProcessing.WhiteBalanceMode) -> bool");

extern "C" {static PyObject *meth_QCameraImageProcessing_isWhiteBalanceModeSupported(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_isWhiteBalanceModeSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCameraImageProcessing::WhiteBalanceMode a0;
        const ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraImageProcessing, &sipCpp, sipType_QCameraImageProcessing_WhiteBalanceMode, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isWhiteBalanceModeSupported(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_isWhiteBalanceModeSupported, doc_QCameraImageProcessing_isWhiteBalanceModeSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_manualWhiteBalance, "manualWhiteBalance(self) -> float");

extern "C" {static PyObject *meth_QCameraImageProcessing_manualWhiteBalance(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_manualWhiteBalance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageProcessing, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->manualWhiteBalance();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_manualWhiteBalance, doc_QCameraImageProcessing_manualWhiteBalance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_setManualWhiteBalance, "setManualWhiteBalance(self, colorTemperature: float)");

extern "C" {static PyObject *meth_QCameraImageProcessing_setManualWhiteBalance(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_setManualWhiteBalance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QCameraImageProcessing, &sipCpp, &a0))
        {
            sipCpp->setManualWhiteBalance(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_setManualWhiteBalance, doc_QCameraImageProcessing_setManualWhiteBalance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_contrast, "contrast(self) -> float");

extern "C" {static PyObject *meth_QCameraImageProcessing_contrast(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_contrast(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageProcessing, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->contrast();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_contrast, doc_QCameraImageProcessing_contrast);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_setContrast, "setContrast(self, value: float)");

extern "C" {static PyObject *meth_QCameraImageProcessing_setContrast(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_setContrast(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QCameraImageProcessing, &sipCpp, &a0))
        {
            sipCpp->setContrast(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_setContrast, doc_QCameraImageProcessing_setContrast);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_saturation, "saturation(self) -> float");

extern "C" {static PyObject *meth_QCameraImageProcessing_saturation(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_saturation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageProcessing, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->saturation();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_saturation, doc_QCameraImageProcessing_saturation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_setSaturation, "setSaturation(self, value: float)");

extern "C" {static PyObject *meth_QCameraImageProcessing_setSaturation(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_setSaturation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QCameraImageProcessing, &sipCpp, &a0))
        {
            sipCpp->setSaturation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_setSaturation, doc_QCameraImageProcessing_setSaturation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_sharpeningLevel, "sharpeningLevel(self) -> float");

extern "C" {static PyObject *meth_QCameraImageProcessing_sharpeningLevel(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_sharpeningLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageProcessing, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->sharpeningLevel();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_sharpeningLevel, doc_QCameraImageProcessing_sharpeningLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_setSharpeningLevel, "setSharpeningLevel(self, value: float)");

extern "C" {static PyObject *meth_QCameraImageProcessing_setSharpeningLevel(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_setSharpeningLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QCameraImageProcessing, &sipCpp, &a0))
        {
            sipCpp->setSharpeningLevel(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_setSharpeningLevel, doc_QCameraImageProcessing_setSharpeningLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_denoisingLevel, "denoisingLevel(self) -> float");

extern "C" {static PyObject *meth_QCameraImageProcessing_denoisingLevel(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_denoisingLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageProcessing, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->denoisingLevel();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_denoisingLevel, doc_QCameraImageProcessing_denoisingLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_setDenoisingLevel, "setDenoisingLevel(self, value: float)");

extern "C" {static PyObject *meth_QCameraImageProcessing_setDenoisingLevel(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_setDenoisingLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QCameraImageProcessing, &sipCpp, &a0))
        {
            sipCpp->setDenoisingLevel(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_setDenoisingLevel, doc_QCameraImageProcessing_setDenoisingLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_colorFilter, "colorFilter(self) -> QCameraImageProcessing.ColorFilter");

extern "C" {static PyObject *meth_QCameraImageProcessing_colorFilter(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_colorFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageProcessing, &sipCpp))
        {
            ::QCameraImageProcessing::ColorFilter sipRes;

            sipRes = sipCpp->colorFilter();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCameraImageProcessing_ColorFilter);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_colorFilter, doc_QCameraImageProcessing_colorFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_setColorFilter, "setColorFilter(self, filter: QCameraImageProcessing.ColorFilter)");

extern "C" {static PyObject *meth_QCameraImageProcessing_setColorFilter(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_setColorFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCameraImageProcessing::ColorFilter a0;
        ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraImageProcessing, &sipCpp, sipType_QCameraImageProcessing_ColorFilter, &a0))
        {
            sipCpp->setColorFilter(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_setColorFilter, doc_QCameraImageProcessing_setColorFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_isColorFilterSupported, "isColorFilterSupported(self, filter: QCameraImageProcessing.ColorFilter) -> bool");

extern "C" {static PyObject *meth_QCameraImageProcessing_isColorFilterSupported(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_isColorFilterSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCameraImageProcessing::ColorFilter a0;
        const ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QCameraImageProcessing, &sipCpp, sipType_QCameraImageProcessing_ColorFilter, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isColorFilterSupported(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_isColorFilterSupported, doc_QCameraImageProcessing_isColorFilterSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_brightness, "brightness(self) -> float");

extern "C" {static PyObject *meth_QCameraImageProcessing_brightness(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_brightness(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraImageProcessing, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->brightness();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_brightness, doc_QCameraImageProcessing_brightness);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraImageProcessing_setBrightness, "setBrightness(self, value: float)");

extern "C" {static PyObject *meth_QCameraImageProcessing_setBrightness(PyObject *, PyObject *);}
static PyObject *meth_QCameraImageProcessing_setBrightness(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QCameraImageProcessing *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QCameraImageProcessing, &sipCpp, &a0))
        {
            sipCpp->setBrightness(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraImageProcessing, sipName_setBrightness, doc_QCameraImageProcessing_setBrightness);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QCameraImageProcessing(void *, const sipTypeDef *);}
static void *cast_QCameraImageProcessing(void *sipCppV, const sipTypeDef *targetType)
{
    ::QCameraImageProcessing *sipCpp = reinterpret_cast< ::QCameraImageProcessing *>(sipCppV);

    if (targetType == sipType_QCameraImageProcessing)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QCameraImageProcessing(void *, int);}
static void release_QCameraImageProcessing(void *, int)
{
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QCameraImageProcessing[] = {{9, 0, 1}};


static PyMethodDef methods_QCameraImageProcessing[] = {
    {sipName_brightness, meth_QCameraImageProcessing_brightness, METH_VARARGS, doc_QCameraImageProcessing_brightness},
    {sipName_colorFilter, meth_QCameraImageProcessing_colorFilter, METH_VARARGS, doc_QCameraImageProcessing_colorFilter},
    {sipName_contrast, meth_QCameraImageProcessing_contrast, METH_VARARGS, doc_QCameraImageProcessing_contrast},
    {sipName_denoisingLevel, meth_QCameraImageProcessing_denoisingLevel, METH_VARARGS, doc_QCameraImageProcessing_denoisingLevel},
    {sipName_isAvailable, meth_QCameraImageProcessing_isAvailable, METH_VARARGS, doc_QCameraImageProcessing_isAvailable},
    {sipName_isColorFilterSupported, meth_QCameraImageProcessing_isColorFilterSupported, METH_VARARGS, doc_QCameraImageProcessing_isColorFilterSupported},
    {sipName_isWhiteBalanceModeSupported, meth_QCameraImageProcessing_isWhiteBalanceModeSupported, METH_VARARGS, doc_QCameraImageProcessing_isWhiteBalanceModeSupported},
    {sipName_manualWhiteBalance, meth_QCameraImageProcessing_manualWhiteBalance, METH_VARARGS, doc_QCameraImageProcessing_manualWhiteBalance},
    {sipName_saturation, meth_QCameraImageProcessing_saturation, METH_VARARGS, doc_QCameraImageProcessing_saturation},
    {sipName_setBrightness, meth_QCameraImageProcessing_setBrightness, METH_VARARGS, doc_QCameraImageProcessing_setBrightness},
    {sipName_setColorFilter, meth_QCameraImageProcessing_setColorFilter, METH_VARARGS, doc_QCameraImageProcessing_setColorFilter},
    {sipName_setContrast, meth_QCameraImageProcessing_setContrast, METH_VARARGS, doc_QCameraImageProcessing_setContrast},
    {sipName_setDenoisingLevel, meth_QCameraImageProcessing_setDenoisingLevel, METH_VARARGS, doc_QCameraImageProcessing_setDenoisingLevel},
    {sipName_setManualWhiteBalance, meth_QCameraImageProcessing_setManualWhiteBalance, METH_VARARGS, doc_QCameraImageProcessing_setManualWhiteBalance},
    {sipName_setSaturation, meth_QCameraImageProcessing_setSaturation, METH_VARARGS, doc_QCameraImageProcessing_setSaturation},
    {sipName_setSharpeningLevel, meth_QCameraImageProcessing_setSharpeningLevel, METH_VARARGS, doc_QCameraImageProcessing_setSharpeningLevel},
    {sipName_setWhiteBalanceMode, meth_QCameraImageProcessing_setWhiteBalanceMode, METH_VARARGS, doc_QCameraImageProcessing_setWhiteBalanceMode},
    {sipName_sharpeningLevel, meth_QCameraImageProcessing_sharpeningLevel, METH_VARARGS, doc_QCameraImageProcessing_sharpeningLevel},
    {sipName_whiteBalanceMode, meth_QCameraImageProcessing_whiteBalanceMode, METH_VARARGS, doc_QCameraImageProcessing_whiteBalanceMode}
};

static sipEnumMemberDef enummembers_QCameraImageProcessing[] = {
    {sipName_ColorFilterAqua, static_cast<int>(::QCameraImageProcessing::ColorFilterAqua), 70},
    {sipName_ColorFilterBlackboard, static_cast<int>(::QCameraImageProcessing::ColorFilterBlackboard), 70},
    {sipName_ColorFilterGrayscale, static_cast<int>(::QCameraImageProcessing::ColorFilterGrayscale), 70},
    {sipName_ColorFilterNegative, static_cast<int>(::QCameraImageProcessing::ColorFilterNegative), 70},
    {sipName_ColorFilterNone, static_cast<int>(::QCameraImageProcessing::ColorFilterNone), 70},
    {sipName_ColorFilterPosterize, static_cast<int>(::QCameraImageProcessing::ColorFilterPosterize), 70},
    {sipName_ColorFilterSepia, static_cast<int>(::QCameraImageProcessing::ColorFilterSepia), 70},
    {sipName_ColorFilterSolarize, static_cast<int>(::QCameraImageProcessing::ColorFilterSolarize), 70},
    {sipName_ColorFilterVendor, static_cast<int>(::QCameraImageProcessing::ColorFilterVendor), 70},
    {sipName_ColorFilterWhiteboard, static_cast<int>(::QCameraImageProcessing::ColorFilterWhiteboard), 70},
    {sipName_WhiteBalanceAuto, static_cast<int>(::QCameraImageProcessing::WhiteBalanceAuto), 71},
    {sipName_WhiteBalanceCloudy, static_cast<int>(::QCameraImageProcessing::WhiteBalanceCloudy), 71},
    {sipName_WhiteBalanceFlash, static_cast<int>(::QCameraImageProcessing::WhiteBalanceFlash), 71},
    {sipName_WhiteBalanceFluorescent, static_cast<int>(::QCameraImageProcessing::WhiteBalanceFluorescent), 71},
    {sipName_WhiteBalanceManual, static_cast<int>(::QCameraImageProcessing::WhiteBalanceManual), 71},
    {sipName_WhiteBalanceShade, static_cast<int>(::QCameraImageProcessing::WhiteBalanceShade), 71},
    {sipName_WhiteBalanceSunlight, static_cast<int>(::QCameraImageProcessing::WhiteBalanceSunlight), 71},
    {sipName_WhiteBalanceSunset, static_cast<int>(::QCameraImageProcessing::WhiteBalanceSunset), 71},
    {sipName_WhiteBalanceTungsten, static_cast<int>(::QCameraImageProcessing::WhiteBalanceTungsten), 71},
    {sipName_WhiteBalanceVendor, static_cast<int>(::QCameraImageProcessing::WhiteBalanceVendor), 71},
};


static pyqt5ClassPluginDef plugin_QCameraImageProcessing = {
    &::QCameraImageProcessing::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QCameraImageProcessing = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCameraImageProcessing,
        SIP_NULLPTR,
        &plugin_QCameraImageProcessing,
    },
    {
        sipNameNr_QCameraImageProcessing,
        {0, 0, 1},
        19, methods_QCameraImageProcessing,
        20, enummembers_QCameraImageProcessing,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QCameraImageProcessing,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QCameraImageProcessing,
    cast_QCameraImageProcessing,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
