/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtHelp.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtHelp/qhelpenginecore.sip"
#include <qhelpenginecore.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"

#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtHelp/qhelplink.sip"
#include <qhelplink.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtHelp/qhelpfilterengine.sip"
#include <qhelpfilterengine.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtHelp/sipQtHelpQHelpEngineCore.cpp"


class sipQHelpEngineCore : public ::QHelpEngineCore
{
public:
    sipQHelpEngineCore(const ::QString&, ::QObject*);
    virtual ~sipQHelpEngineCore();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQHelpEngineCore(const sipQHelpEngineCore &);
    sipQHelpEngineCore &operator = (const sipQHelpEngineCore &);

    char sipPyMethods[7];
};

sipQHelpEngineCore::sipQHelpEngineCore(const ::QString& a0, ::QObject*a1): ::QHelpEngineCore(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQHelpEngineCore::~sipQHelpEngineCore()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQHelpEngineCore::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtHelp_qt_metaobject(sipPySelf, sipType_QHelpEngineCore);

    return ::QHelpEngineCore::metaObject();
}

int sipQHelpEngineCore::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QHelpEngineCore::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtHelp_qt_metacall(sipPySelf, sipType_QHelpEngineCore, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQHelpEngineCore::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtHelp_qt_metacast(sipPySelf, sipType_QHelpEngineCore, _clname, &sipCpp) ? sipCpp : ::QHelpEngineCore::qt_metacast(_clname));
}

bool sipQHelpEngineCore::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QHelpEngineCore::event(a0);

    extern bool sipVH_QtHelp_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtHelp_24(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQHelpEngineCore::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QHelpEngineCore::eventFilter(a0, a1);

    extern bool sipVH_QtHelp_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtHelp_25(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQHelpEngineCore::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QHelpEngineCore::timerEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtHelp_26(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpEngineCore::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QHelpEngineCore::childEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtHelp_27(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpEngineCore::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QHelpEngineCore::customEvent(a0);
        return;
    }

    extern void sipVH_QtHelp_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtHelp_28(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpEngineCore::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QHelpEngineCore::connectNotify(a0);
        return;
    }

    extern void sipVH_QtHelp_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtHelp_29(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHelpEngineCore::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QHelpEngineCore::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtHelp_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtHelp_29(sipGILState, sipImportedVirtErrorHandlers_QtHelp_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QHelpEngineCore_setupData, "setupData(self) -> bool");

extern "C" {static PyObject *meth_QHelpEngineCore_setupData(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_setupData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpEngineCore, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->setupData();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_setupData, doc_QHelpEngineCore_setupData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_collectionFile, "collectionFile(self) -> str");

extern "C" {static PyObject *meth_QHelpEngineCore_collectionFile(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_collectionFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpEngineCore, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->collectionFile());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_collectionFile, doc_QHelpEngineCore_collectionFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_setCollectionFile, "setCollectionFile(self, fileName: Optional[str])");

extern "C" {static PyObject *meth_QHelpEngineCore_setCollectionFile(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_setCollectionFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCollectionFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_setCollectionFile, doc_QHelpEngineCore_setCollectionFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_copyCollectionFile, "copyCollectionFile(self, fileName: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QHelpEngineCore_copyCollectionFile(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_copyCollectionFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->copyCollectionFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_copyCollectionFile, doc_QHelpEngineCore_copyCollectionFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_namespaceName, "namespaceName(documentationFileName: Optional[str]) -> str");

extern "C" {static PyObject *meth_QHelpEngineCore_namespaceName(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_namespaceName(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QHelpEngineCore::namespaceName(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_namespaceName, doc_QHelpEngineCore_namespaceName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_registerDocumentation, "registerDocumentation(self, documentationFileName: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QHelpEngineCore_registerDocumentation(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_registerDocumentation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->registerDocumentation(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_registerDocumentation, doc_QHelpEngineCore_registerDocumentation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_unregisterDocumentation, "unregisterDocumentation(self, namespaceName: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QHelpEngineCore_unregisterDocumentation(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_unregisterDocumentation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->unregisterDocumentation(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_unregisterDocumentation, doc_QHelpEngineCore_unregisterDocumentation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_documentationFileName, "documentationFileName(self, namespaceName: Optional[str]) -> str");

extern "C" {static PyObject *meth_QHelpEngineCore_documentationFileName(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_documentationFileName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->documentationFileName(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_documentationFileName, doc_QHelpEngineCore_documentationFileName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_customFilters, "customFilters(self) -> list[str]");

extern "C" {static PyObject *meth_QHelpEngineCore_customFilters(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_customFilters(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpEngineCore, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->customFilters());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_customFilters, doc_QHelpEngineCore_customFilters);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_removeCustomFilter, "removeCustomFilter(self, filterName: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QHelpEngineCore_removeCustomFilter(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_removeCustomFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->removeCustomFilter(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_removeCustomFilter, doc_QHelpEngineCore_removeCustomFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_addCustomFilter, "addCustomFilter(self, filterName: Optional[str], attributes: Iterable[Optional[str]]) -> bool");

extern "C" {static PyObject *meth_QHelpEngineCore_addCustomFilter(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_addCustomFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QStringList* a1;
        int a1State = 0;
        ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State, sipType_QStringList, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->addCustomFilter(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QStringList *>(a1), sipType_QStringList, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_addCustomFilter, doc_QHelpEngineCore_addCustomFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_filterAttributes, "filterAttributes(self) -> list[str]\n"
"filterAttributes(self, filterName: Optional[str]) -> list[str]");

extern "C" {static PyObject *meth_QHelpEngineCore_filterAttributes(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_filterAttributes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpEngineCore, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->filterAttributes());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->filterAttributes(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_filterAttributes, doc_QHelpEngineCore_filterAttributes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_currentFilter, "currentFilter(self) -> str");

extern "C" {static PyObject *meth_QHelpEngineCore_currentFilter(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_currentFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpEngineCore, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->currentFilter());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_currentFilter, doc_QHelpEngineCore_currentFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_setCurrentFilter, "setCurrentFilter(self, filterName: Optional[str])");

extern "C" {static PyObject *meth_QHelpEngineCore_setCurrentFilter(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_setCurrentFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCurrentFilter(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_setCurrentFilter, doc_QHelpEngineCore_setCurrentFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_registeredDocumentations, "registeredDocumentations(self) -> list[str]");

extern "C" {static PyObject *meth_QHelpEngineCore_registeredDocumentations(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_registeredDocumentations(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpEngineCore, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->registeredDocumentations());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_registeredDocumentations, doc_QHelpEngineCore_registeredDocumentations);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_filterAttributeSets, "filterAttributeSets(self, namespaceName: Optional[str]) -> list[list[str]]");

extern "C" {static PyObject *meth_QHelpEngineCore_filterAttributeSets(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_filterAttributeSets(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State))
        {
            QList< ::QStringList>*sipRes;

            sipRes = new QList< ::QStringList>(sipCpp->filterAttributeSets(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QList_0100QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_filterAttributeSets, doc_QHelpEngineCore_filterAttributeSets);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_files, "files(self, namespaceName: Optional[str], filterAttributes: Iterable[Optional[str]], extensionFilter: Optional[str] = '') -> list[QUrl]\n"
"files(self, namespaceName: Optional[str], filterName: Optional[str], extensionFilter: Optional[str] = '') -> list[QUrl]");

extern "C" {static PyObject *meth_QHelpEngineCore_files(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_files(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QStringList* a1;
        int a1State = 0;
        const ::QString& a2def = QString();
        const ::QString* a2 = &a2def;
        int a2State = 0;
        ::QHelpEngineCore *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_extensionFilter,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1J1|J1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State, sipType_QStringList, &a1, &a1State, sipType_QString, &a2, &a2State))
        {
            QList< ::QUrl>*sipRes;

            sipRes = new QList< ::QUrl>(sipCpp->files(*a0, *a1, *a2));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QStringList *>(a1), sipType_QStringList, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);

            return sipConvertFromNewType(sipRes, sipType_QList_0100QUrl, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString& a2def = QString();
        const ::QString* a2 = &a2def;
        int a2State = 0;
        ::QHelpEngineCore *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_extensionFilter,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1J1|J1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State))
        {
            QList< ::QUrl>*sipRes;

            sipRes = new QList< ::QUrl>(sipCpp->files(*a0, *a1, *a2));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);

            return sipConvertFromNewType(sipRes, sipType_QList_0100QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_files, doc_QHelpEngineCore_files);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_findFile, "findFile(self, url: QUrl) -> QUrl");

extern "C" {static PyObject *meth_QHelpEngineCore_findFile(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_findFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QUrl, &a0))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->findFile(*a0));

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_findFile, doc_QHelpEngineCore_findFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_fileData, "fileData(self, url: QUrl) -> QByteArray");

extern "C" {static PyObject *meth_QHelpEngineCore_fileData(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_fileData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QUrl, &a0))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(sipCpp->fileData(*a0));

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_fileData, doc_QHelpEngineCore_fileData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_linksForIdentifier, "linksForIdentifier(self, id: Optional[str]) -> dict[str, QUrl]");

extern "C" {static PyObject *meth_QHelpEngineCore_linksForIdentifier(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_linksForIdentifier(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State))
        {
            QMap< ::QString, ::QUrl>*sipRes;

            sipRes = new QMap< ::QString, ::QUrl>(sipCpp->linksForIdentifier(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QMap_0100QString_0100QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_linksForIdentifier, doc_QHelpEngineCore_linksForIdentifier);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_linksForKeyword, "linksForKeyword(self, keyword: Optional[str]) -> dict[str, QUrl]");

extern "C" {static PyObject *meth_QHelpEngineCore_linksForKeyword(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_linksForKeyword(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State))
        {
            QMap< ::QString, ::QUrl>*sipRes;

            sipRes = new QMap< ::QString, ::QUrl>(sipCpp->linksForKeyword(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QMap_0100QString_0100QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_linksForKeyword, doc_QHelpEngineCore_linksForKeyword);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_removeCustomValue, "removeCustomValue(self, key: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QHelpEngineCore_removeCustomValue(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_removeCustomValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->removeCustomValue(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_removeCustomValue, doc_QHelpEngineCore_removeCustomValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_customValue, "customValue(self, key: Optional[str], defaultValue: Any = None) -> Any");

extern "C" {static PyObject *meth_QHelpEngineCore_customValue(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_customValue(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariant& a1def = QVariant();
        const ::QVariant* a1 = &a1def;
        int a1State = 0;
        const ::QHelpEngineCore *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_defaultValue,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State, sipType_QVariant, &a1, &a1State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->customValue(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_customValue, doc_QHelpEngineCore_customValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_setCustomValue, "setCustomValue(self, key: Optional[str], value: Any) -> bool");

extern "C" {static PyObject *meth_QHelpEngineCore_setCustomValue(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_setCustomValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariant* a1;
        int a1State = 0;
        ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State, sipType_QVariant, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->setCustomValue(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_setCustomValue, doc_QHelpEngineCore_setCustomValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_metaData, "metaData(documentationFileName: Optional[str], name: Optional[str]) -> Any");

extern "C" {static PyObject *meth_QHelpEngineCore_metaData(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_metaData(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1J1", sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(::QHelpEngineCore::metaData(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_metaData, doc_QHelpEngineCore_metaData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_error, "error(self) -> str");

extern "C" {static PyObject *meth_QHelpEngineCore_error(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpEngineCore, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->error());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_error, doc_QHelpEngineCore_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_autoSaveFilter, "autoSaveFilter(self) -> bool");

extern "C" {static PyObject *meth_QHelpEngineCore_autoSaveFilter(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_autoSaveFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpEngineCore, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->autoSaveFilter();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_autoSaveFilter, doc_QHelpEngineCore_autoSaveFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_setAutoSaveFilter, "setAutoSaveFilter(self, save: bool)");

extern "C" {static PyObject *meth_QHelpEngineCore_setAutoSaveFilter(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_setAutoSaveFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QHelpEngineCore, &sipCpp, &a0))
        {
            sipCpp->setAutoSaveFilter(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_setAutoSaveFilter, doc_QHelpEngineCore_setAutoSaveFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_filterEngine, "filterEngine(self) -> Optional[QHelpFilterEngine]");

extern "C" {static PyObject *meth_QHelpEngineCore_filterEngine(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_filterEngine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpEngineCore, &sipCpp))
        {
            ::QHelpFilterEngine*sipRes;

            sipRes = sipCpp->filterEngine();

            return sipConvertFromType(sipRes, sipType_QHelpFilterEngine, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_filterEngine, doc_QHelpEngineCore_filterEngine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_setUsesFilterEngine, "setUsesFilterEngine(self, uses: bool)");

extern "C" {static PyObject *meth_QHelpEngineCore_setUsesFilterEngine(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_setUsesFilterEngine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QHelpEngineCore, &sipCpp, &a0))
        {
            sipCpp->setUsesFilterEngine(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_setUsesFilterEngine, doc_QHelpEngineCore_setUsesFilterEngine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_usesFilterEngine, "usesFilterEngine(self) -> bool");

extern "C" {static PyObject *meth_QHelpEngineCore_usesFilterEngine(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_usesFilterEngine(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHelpEngineCore, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->usesFilterEngine();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_usesFilterEngine, doc_QHelpEngineCore_usesFilterEngine);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_documentsForIdentifier, "documentsForIdentifier(self, id: Optional[str]) -> list[QHelpLink]\n"
"documentsForIdentifier(self, id: Optional[str], filterName: Optional[str]) -> list[QHelpLink]");

extern "C" {static PyObject *meth_QHelpEngineCore_documentsForIdentifier(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_documentsForIdentifier(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State))
        {
            QList< ::QHelpLink>*sipRes;

            sipRes = new QList< ::QHelpLink>(sipCpp->documentsForIdentifier(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QList_0100QHelpLink, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            QList< ::QHelpLink>*sipRes;

            sipRes = new QList< ::QHelpLink>(sipCpp->documentsForIdentifier(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QList_0100QHelpLink, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_documentsForIdentifier, doc_QHelpEngineCore_documentsForIdentifier);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHelpEngineCore_documentsForKeyword, "documentsForKeyword(self, keyword: Optional[str]) -> list[QHelpLink]\n"
"documentsForKeyword(self, keyword: Optional[str], filterName: Optional[str]) -> list[QHelpLink]");

extern "C" {static PyObject *meth_QHelpEngineCore_documentsForKeyword(PyObject *, PyObject *);}
static PyObject *meth_QHelpEngineCore_documentsForKeyword(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State))
        {
            QList< ::QHelpLink>*sipRes;

            sipRes = new QList< ::QHelpLink>(sipCpp->documentsForKeyword(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QList_0100QHelpLink, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QHelpEngineCore *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QHelpEngineCore, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            QList< ::QHelpLink>*sipRes;

            sipRes = new QList< ::QHelpLink>(sipCpp->documentsForKeyword(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QList_0100QHelpLink, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHelpEngineCore, sipName_documentsForKeyword, doc_QHelpEngineCore_documentsForKeyword);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QHelpEngineCore(void *, const sipTypeDef *);}
static void *cast_QHelpEngineCore(void *sipCppV, const sipTypeDef *targetType)
{
    ::QHelpEngineCore *sipCpp = reinterpret_cast< ::QHelpEngineCore *>(sipCppV);

    if (targetType == sipType_QHelpEngineCore)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QHelpEngineCore(void *, int);}
static void release_QHelpEngineCore(void *sipCppV, int)
{
    ::QHelpEngineCore *sipCpp = reinterpret_cast< ::QHelpEngineCore *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QHelpEngineCore(sipSimpleWrapper *);}
static void dealloc_QHelpEngineCore(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQHelpEngineCore *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QHelpEngineCore(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QHelpEngineCore(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QHelpEngineCore(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQHelpEngineCore *sipCpp = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QString, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQHelpEngineCore(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QHelpEngineCore[] = {{16, 0, 1}};


static PyMethodDef methods_QHelpEngineCore[] = {
    {sipName_addCustomFilter, meth_QHelpEngineCore_addCustomFilter, METH_VARARGS, doc_QHelpEngineCore_addCustomFilter},
    {sipName_autoSaveFilter, meth_QHelpEngineCore_autoSaveFilter, METH_VARARGS, doc_QHelpEngineCore_autoSaveFilter},
    {sipName_collectionFile, meth_QHelpEngineCore_collectionFile, METH_VARARGS, doc_QHelpEngineCore_collectionFile},
    {sipName_copyCollectionFile, meth_QHelpEngineCore_copyCollectionFile, METH_VARARGS, doc_QHelpEngineCore_copyCollectionFile},
    {sipName_currentFilter, meth_QHelpEngineCore_currentFilter, METH_VARARGS, doc_QHelpEngineCore_currentFilter},
    {sipName_customFilters, meth_QHelpEngineCore_customFilters, METH_VARARGS, doc_QHelpEngineCore_customFilters},
    {sipName_customValue, SIP_MLMETH_CAST(meth_QHelpEngineCore_customValue), METH_VARARGS|METH_KEYWORDS, doc_QHelpEngineCore_customValue},
    {sipName_documentationFileName, meth_QHelpEngineCore_documentationFileName, METH_VARARGS, doc_QHelpEngineCore_documentationFileName},
    {sipName_documentsForIdentifier, meth_QHelpEngineCore_documentsForIdentifier, METH_VARARGS, doc_QHelpEngineCore_documentsForIdentifier},
    {sipName_documentsForKeyword, meth_QHelpEngineCore_documentsForKeyword, METH_VARARGS, doc_QHelpEngineCore_documentsForKeyword},
    {sipName_error, meth_QHelpEngineCore_error, METH_VARARGS, doc_QHelpEngineCore_error},
    {sipName_fileData, meth_QHelpEngineCore_fileData, METH_VARARGS, doc_QHelpEngineCore_fileData},
    {sipName_files, SIP_MLMETH_CAST(meth_QHelpEngineCore_files), METH_VARARGS|METH_KEYWORDS, doc_QHelpEngineCore_files},
    {sipName_filterAttributeSets, meth_QHelpEngineCore_filterAttributeSets, METH_VARARGS, doc_QHelpEngineCore_filterAttributeSets},
    {sipName_filterAttributes, meth_QHelpEngineCore_filterAttributes, METH_VARARGS, doc_QHelpEngineCore_filterAttributes},
    {sipName_filterEngine, meth_QHelpEngineCore_filterEngine, METH_VARARGS, doc_QHelpEngineCore_filterEngine},
    {sipName_findFile, meth_QHelpEngineCore_findFile, METH_VARARGS, doc_QHelpEngineCore_findFile},
    {sipName_linksForIdentifier, meth_QHelpEngineCore_linksForIdentifier, METH_VARARGS, doc_QHelpEngineCore_linksForIdentifier},
    {sipName_linksForKeyword, meth_QHelpEngineCore_linksForKeyword, METH_VARARGS, doc_QHelpEngineCore_linksForKeyword},
    {sipName_metaData, meth_QHelpEngineCore_metaData, METH_VARARGS, doc_QHelpEngineCore_metaData},
    {sipName_namespaceName, meth_QHelpEngineCore_namespaceName, METH_VARARGS, doc_QHelpEngineCore_namespaceName},
    {sipName_registerDocumentation, meth_QHelpEngineCore_registerDocumentation, METH_VARARGS, doc_QHelpEngineCore_registerDocumentation},
    {sipName_registeredDocumentations, meth_QHelpEngineCore_registeredDocumentations, METH_VARARGS, doc_QHelpEngineCore_registeredDocumentations},
    {sipName_removeCustomFilter, meth_QHelpEngineCore_removeCustomFilter, METH_VARARGS, doc_QHelpEngineCore_removeCustomFilter},
    {sipName_removeCustomValue, meth_QHelpEngineCore_removeCustomValue, METH_VARARGS, doc_QHelpEngineCore_removeCustomValue},
    {sipName_setAutoSaveFilter, meth_QHelpEngineCore_setAutoSaveFilter, METH_VARARGS, doc_QHelpEngineCore_setAutoSaveFilter},
    {sipName_setCollectionFile, meth_QHelpEngineCore_setCollectionFile, METH_VARARGS, doc_QHelpEngineCore_setCollectionFile},
    {sipName_setCurrentFilter, meth_QHelpEngineCore_setCurrentFilter, METH_VARARGS, doc_QHelpEngineCore_setCurrentFilter},
    {sipName_setCustomValue, meth_QHelpEngineCore_setCustomValue, METH_VARARGS, doc_QHelpEngineCore_setCustomValue},
    {sipName_setUsesFilterEngine, meth_QHelpEngineCore_setUsesFilterEngine, METH_VARARGS, doc_QHelpEngineCore_setUsesFilterEngine},
    {sipName_setupData, meth_QHelpEngineCore_setupData, METH_VARARGS, doc_QHelpEngineCore_setupData},
    {sipName_unregisterDocumentation, meth_QHelpEngineCore_unregisterDocumentation, METH_VARARGS, doc_QHelpEngineCore_unregisterDocumentation},
    {sipName_usesFilterEngine, meth_QHelpEngineCore_usesFilterEngine, METH_VARARGS, doc_QHelpEngineCore_usesFilterEngine}
};

PyDoc_STRVAR(doc_QHelpEngineCore, "\1QHelpEngineCore(collectionFile: Optional[str], parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QHelpEngineCore[] = {
    {"readersAboutToBeInvalidated()", "\1readersAboutToBeInvalidated(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"warning(QString)", "\1warning(self, msg: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"currentFilterChanged(QString)", "\1currentFilterChanged(self, newFilter: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"setupFinished()", "\1setupFinished(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"setupStarted()", "\1setupStarted(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QHelpEngineCore = {
    &::QHelpEngineCore::staticMetaObject,
    0,
    signals_QHelpEngineCore,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtHelp_QHelpEngineCore = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QHelpEngineCore,
        SIP_NULLPTR,
        &plugin_QHelpEngineCore,
    },
    {
        sipNameNr_QHelpEngineCore,
        {0, 0, 1},
        33, methods_QHelpEngineCore,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QHelpEngineCore,
    -1,
    -1,
    supers_QHelpEngineCore,
    SIP_NULLPTR,
    init_type_QHelpEngineCore,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QHelpEngineCore,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QHelpEngineCore,
    cast_QHelpEngineCore,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QHelpEngineCore),
};
