/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qvideowindowcontrol.sip"
#include <qvideowindowcontrol.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQVideoWindowControl.cpp"


class sipQVideoWindowControl : public ::QVideoWindowControl
{
public:
    sipQVideoWindowControl(::QObject*);
    virtual ~sipQVideoWindowControl();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void setSaturation(int) SIP_OVERRIDE;
    int saturation() const SIP_OVERRIDE;
    void setHue(int) SIP_OVERRIDE;
    int hue() const SIP_OVERRIDE;
    void setContrast(int) SIP_OVERRIDE;
    int contrast() const SIP_OVERRIDE;
    void setBrightness(int) SIP_OVERRIDE;
    int brightness() const SIP_OVERRIDE;
    void setAspectRatioMode(::Qt::AspectRatioMode) SIP_OVERRIDE;
    ::Qt::AspectRatioMode aspectRatioMode() const SIP_OVERRIDE;
    ::QSize nativeSize() const SIP_OVERRIDE;
    void repaint() SIP_OVERRIDE;
    void setFullScreen(bool) SIP_OVERRIDE;
    bool isFullScreen() const SIP_OVERRIDE;
    void setDisplayRect(const ::QRect&) SIP_OVERRIDE;
    ::QRect displayRect() const SIP_OVERRIDE;
    void setWinId(::WId) SIP_OVERRIDE;
    ::WId winId() const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQVideoWindowControl(const sipQVideoWindowControl &);
    sipQVideoWindowControl &operator = (const sipQVideoWindowControl &);

    char sipPyMethods[25];
};

sipQVideoWindowControl::sipQVideoWindowControl(::QObject*a0): ::QVideoWindowControl(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQVideoWindowControl::~sipQVideoWindowControl()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQVideoWindowControl::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QVideoWindowControl);

    return ::QVideoWindowControl::metaObject();
}

int sipQVideoWindowControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QVideoWindowControl::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QVideoWindowControl, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQVideoWindowControl::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QVideoWindowControl, _clname, &sipCpp) ? sipCpp : ::QVideoWindowControl::qt_metacast(_clname));
}

void sipQVideoWindowControl::setSaturation(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, sipName_QVideoWindowControl, sipName_setSaturation);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_105(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtMultimedia_105(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQVideoWindowControl::saturation() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QVideoWindowControl, sipName_saturation);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtMultimedia_104(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_104(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQVideoWindowControl::setHue(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, sipName_QVideoWindowControl, sipName_setHue);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_105(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtMultimedia_105(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQVideoWindowControl::hue() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QVideoWindowControl, sipName_hue);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtMultimedia_104(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_104(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQVideoWindowControl::setContrast(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, sipName_QVideoWindowControl, sipName_setContrast);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_105(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtMultimedia_105(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQVideoWindowControl::contrast() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QVideoWindowControl, sipName_contrast);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtMultimedia_104(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_104(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQVideoWindowControl::setBrightness(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, sipName_QVideoWindowControl, sipName_setBrightness);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_105(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtMultimedia_105(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQVideoWindowControl::brightness() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QVideoWindowControl, sipName_brightness);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtMultimedia_104(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_104(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQVideoWindowControl::setAspectRatioMode(::Qt::AspectRatioMode a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, sipName_QVideoWindowControl, sipName_setAspectRatioMode);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_148(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::AspectRatioMode);

    sipVH_QtMultimedia_148(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::Qt::AspectRatioMode sipQVideoWindowControl::aspectRatioMode() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QVideoWindowControl, sipName_aspectRatioMode);

    if (!sipMeth)
        return ::Qt::IgnoreAspectRatio;

    extern ::Qt::AspectRatioMode sipVH_QtMultimedia_147(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_147(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQVideoWindowControl::nativeSize() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QVideoWindowControl, sipName_nativeSize);

    if (!sipMeth)
        return ::QSize();

    extern ::QSize sipVH_QtMultimedia_146(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_146(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQVideoWindowControl::repaint()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, sipName_QVideoWindowControl, sipName_repaint);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtMultimedia_2(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQVideoWindowControl::setFullScreen(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, sipName_QVideoWindowControl, sipName_setFullScreen);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_106(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtMultimedia_106(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQVideoWindowControl::isFullScreen() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QVideoWindowControl, sipName_isFullScreen);

    if (!sipMeth)
        return 0;

    extern bool sipVH_QtMultimedia_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_16(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQVideoWindowControl::setDisplayRect(const ::QRect& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, sipName_QVideoWindowControl, sipName_setDisplayRect);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_145(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QRect&);

    sipVH_QtMultimedia_145(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QRect sipQVideoWindowControl::displayRect() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[15]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QVideoWindowControl, sipName_displayRect);

    if (!sipMeth)
        return ::QRect();

    extern ::QRect sipVH_QtMultimedia_144(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_144(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQVideoWindowControl::setWinId(::WId a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, sipName_QVideoWindowControl, sipName_setWinId);

    if (!sipMeth)
        return;

    extern void sipVH_QtMultimedia_143(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::WId);

    sipVH_QtMultimedia_143(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::WId sipQVideoWindowControl::winId() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[17]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QVideoWindowControl, sipName_winId);

    if (!sipMeth)
        return ::WId();

    extern ::WId sipVH_QtMultimedia_142(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_142(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQVideoWindowControl::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QVideoWindowControl::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQVideoWindowControl::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QVideoWindowControl::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQVideoWindowControl::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QVideoWindowControl::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQVideoWindowControl::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QVideoWindowControl::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQVideoWindowControl::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QVideoWindowControl::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQVideoWindowControl::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QVideoWindowControl::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQVideoWindowControl::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QVideoWindowControl::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QVideoWindowControl_winId, "winId(self) -> PyQt5.sip.voidptr");

extern "C" {static PyObject *meth_QVideoWindowControl_winId(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_winId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoWindowControl, &sipCpp))
        {
            ::WId*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_winId);
                return SIP_NULLPTR;
            }

            sipRes = new ::WId(sipCpp->winId());

            return sipConvertFromNewType(sipRes, sipType_quintptr, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_winId, doc_QVideoWindowControl_winId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_setWinId, "setWinId(self, id: PyQt5.sip.voidptr)");

extern "C" {static PyObject *meth_QVideoWindowControl_setWinId(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_setWinId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::WId* a0;
        int a0State = 0;
        ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QVideoWindowControl, &sipCpp, sipType_quintptr, &a0, &a0State))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_setWinId);
                return SIP_NULLPTR;
            }

            sipCpp->setWinId(*a0);
            sipReleaseType(a0, sipType_quintptr, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_setWinId, doc_QVideoWindowControl_setWinId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_displayRect, "displayRect(self) -> QRect");

extern "C" {static PyObject *meth_QVideoWindowControl_displayRect(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_displayRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoWindowControl, &sipCpp))
        {
            ::QRect*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_displayRect);
                return SIP_NULLPTR;
            }

            sipRes = new ::QRect(sipCpp->displayRect());

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_displayRect, doc_QVideoWindowControl_displayRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_setDisplayRect, "setDisplayRect(self, rect: QRect)");

extern "C" {static PyObject *meth_QVideoWindowControl_setDisplayRect(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_setDisplayRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QRect* a0;
        ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QVideoWindowControl, &sipCpp, sipType_QRect, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_setDisplayRect);
                return SIP_NULLPTR;
            }

            sipCpp->setDisplayRect(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_setDisplayRect, doc_QVideoWindowControl_setDisplayRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_isFullScreen, "isFullScreen(self) -> bool");

extern "C" {static PyObject *meth_QVideoWindowControl_isFullScreen(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_isFullScreen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoWindowControl, &sipCpp))
        {
            bool sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_isFullScreen);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->isFullScreen();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_isFullScreen, doc_QVideoWindowControl_isFullScreen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_setFullScreen, "setFullScreen(self, fullScreen: bool)");

extern "C" {static PyObject *meth_QVideoWindowControl_setFullScreen(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_setFullScreen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        bool a0;
        ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QVideoWindowControl, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_setFullScreen);
                return SIP_NULLPTR;
            }

            sipCpp->setFullScreen(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_setFullScreen, doc_QVideoWindowControl_setFullScreen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_repaint, "repaint(self)");

extern "C" {static PyObject *meth_QVideoWindowControl_repaint(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_repaint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoWindowControl, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_repaint);
                return SIP_NULLPTR;
            }

            sipCpp->repaint();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_repaint, doc_QVideoWindowControl_repaint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_nativeSize, "nativeSize(self) -> QSize");

extern "C" {static PyObject *meth_QVideoWindowControl_nativeSize(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_nativeSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoWindowControl, &sipCpp))
        {
            ::QSize*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_nativeSize);
                return SIP_NULLPTR;
            }

            sipRes = new ::QSize(sipCpp->nativeSize());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_nativeSize, doc_QVideoWindowControl_nativeSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_aspectRatioMode, "aspectRatioMode(self) -> Qt.AspectRatioMode");

extern "C" {static PyObject *meth_QVideoWindowControl_aspectRatioMode(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_aspectRatioMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoWindowControl, &sipCpp))
        {
            ::Qt::AspectRatioMode sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_aspectRatioMode);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->aspectRatioMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_AspectRatioMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_aspectRatioMode, doc_QVideoWindowControl_aspectRatioMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_setAspectRatioMode, "setAspectRatioMode(self, mode: Qt.AspectRatioMode)");

extern "C" {static PyObject *meth_QVideoWindowControl_setAspectRatioMode(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_setAspectRatioMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::Qt::AspectRatioMode a0;
        ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QVideoWindowControl, &sipCpp, sipType_Qt_AspectRatioMode, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_setAspectRatioMode);
                return SIP_NULLPTR;
            }

            sipCpp->setAspectRatioMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_setAspectRatioMode, doc_QVideoWindowControl_setAspectRatioMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_brightness, "brightness(self) -> int");

extern "C" {static PyObject *meth_QVideoWindowControl_brightness(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_brightness(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoWindowControl, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_brightness);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->brightness();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_brightness, doc_QVideoWindowControl_brightness);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_setBrightness, "setBrightness(self, brightness: int)");

extern "C" {static PyObject *meth_QVideoWindowControl_setBrightness(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_setBrightness(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QVideoWindowControl, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_setBrightness);
                return SIP_NULLPTR;
            }

            sipCpp->setBrightness(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_setBrightness, doc_QVideoWindowControl_setBrightness);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_contrast, "contrast(self) -> int");

extern "C" {static PyObject *meth_QVideoWindowControl_contrast(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_contrast(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoWindowControl, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_contrast);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->contrast();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_contrast, doc_QVideoWindowControl_contrast);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_setContrast, "setContrast(self, contrast: int)");

extern "C" {static PyObject *meth_QVideoWindowControl_setContrast(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_setContrast(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QVideoWindowControl, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_setContrast);
                return SIP_NULLPTR;
            }

            sipCpp->setContrast(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_setContrast, doc_QVideoWindowControl_setContrast);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_hue, "hue(self) -> int");

extern "C" {static PyObject *meth_QVideoWindowControl_hue(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_hue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoWindowControl, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_hue);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->hue();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_hue, doc_QVideoWindowControl_hue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_setHue, "setHue(self, hue: int)");

extern "C" {static PyObject *meth_QVideoWindowControl_setHue(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_setHue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QVideoWindowControl, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_setHue);
                return SIP_NULLPTR;
            }

            sipCpp->setHue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_setHue, doc_QVideoWindowControl_setHue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_saturation, "saturation(self) -> int");

extern "C" {static PyObject *meth_QVideoWindowControl_saturation(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_saturation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QVideoWindowControl, &sipCpp))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_saturation);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->saturation();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_saturation, doc_QVideoWindowControl_saturation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QVideoWindowControl_setSaturation, "setSaturation(self, saturation: int)");

extern "C" {static PyObject *meth_QVideoWindowControl_setSaturation(PyObject *, PyObject *);}
static PyObject *meth_QVideoWindowControl_setSaturation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        int a0;
        ::QVideoWindowControl *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QVideoWindowControl, &sipCpp, &a0))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QVideoWindowControl, sipName_setSaturation);
                return SIP_NULLPTR;
            }

            sipCpp->setSaturation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QVideoWindowControl, sipName_setSaturation, doc_QVideoWindowControl_setSaturation);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QVideoWindowControl(void *, const sipTypeDef *);}
static void *cast_QVideoWindowControl(void *sipCppV, const sipTypeDef *targetType)
{
    ::QVideoWindowControl *sipCpp = reinterpret_cast< ::QVideoWindowControl *>(sipCppV);

    if (targetType == sipType_QVideoWindowControl)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QMediaControl)->ctd_cast(static_cast< ::QMediaControl *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QVideoWindowControl(void *, int);}
static void release_QVideoWindowControl(void *sipCppV, int)
{
    ::QVideoWindowControl *sipCpp = reinterpret_cast< ::QVideoWindowControl *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QVideoWindowControl(sipSimpleWrapper *);}
static void dealloc_QVideoWindowControl(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQVideoWindowControl *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QVideoWindowControl(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QVideoWindowControl(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QVideoWindowControl(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQVideoWindowControl *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQVideoWindowControl(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QVideoWindowControl[] = {{104, 255, 1}};


static PyMethodDef methods_QVideoWindowControl[] = {
    {sipName_aspectRatioMode, meth_QVideoWindowControl_aspectRatioMode, METH_VARARGS, doc_QVideoWindowControl_aspectRatioMode},
    {sipName_brightness, meth_QVideoWindowControl_brightness, METH_VARARGS, doc_QVideoWindowControl_brightness},
    {sipName_contrast, meth_QVideoWindowControl_contrast, METH_VARARGS, doc_QVideoWindowControl_contrast},
    {sipName_displayRect, meth_QVideoWindowControl_displayRect, METH_VARARGS, doc_QVideoWindowControl_displayRect},
    {sipName_hue, meth_QVideoWindowControl_hue, METH_VARARGS, doc_QVideoWindowControl_hue},
    {sipName_isFullScreen, meth_QVideoWindowControl_isFullScreen, METH_VARARGS, doc_QVideoWindowControl_isFullScreen},
    {sipName_nativeSize, meth_QVideoWindowControl_nativeSize, METH_VARARGS, doc_QVideoWindowControl_nativeSize},
    {sipName_repaint, meth_QVideoWindowControl_repaint, METH_VARARGS, doc_QVideoWindowControl_repaint},
    {sipName_saturation, meth_QVideoWindowControl_saturation, METH_VARARGS, doc_QVideoWindowControl_saturation},
    {sipName_setAspectRatioMode, meth_QVideoWindowControl_setAspectRatioMode, METH_VARARGS, doc_QVideoWindowControl_setAspectRatioMode},
    {sipName_setBrightness, meth_QVideoWindowControl_setBrightness, METH_VARARGS, doc_QVideoWindowControl_setBrightness},
    {sipName_setContrast, meth_QVideoWindowControl_setContrast, METH_VARARGS, doc_QVideoWindowControl_setContrast},
    {sipName_setDisplayRect, meth_QVideoWindowControl_setDisplayRect, METH_VARARGS, doc_QVideoWindowControl_setDisplayRect},
    {sipName_setFullScreen, meth_QVideoWindowControl_setFullScreen, METH_VARARGS, doc_QVideoWindowControl_setFullScreen},
    {sipName_setHue, meth_QVideoWindowControl_setHue, METH_VARARGS, doc_QVideoWindowControl_setHue},
    {sipName_setSaturation, meth_QVideoWindowControl_setSaturation, METH_VARARGS, doc_QVideoWindowControl_setSaturation},
    {sipName_setWinId, meth_QVideoWindowControl_setWinId, METH_VARARGS, doc_QVideoWindowControl_setWinId},
    {sipName_winId, meth_QVideoWindowControl_winId, METH_VARARGS, doc_QVideoWindowControl_winId}
};

PyDoc_STRVAR(doc_QVideoWindowControl, "\1QVideoWindowControl(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QVideoWindowControl[] = {
    {"nativeSizeChanged()", "\1nativeSizeChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"saturationChanged(int)", "\1saturationChanged(self, saturation: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"hueChanged(int)", "\1hueChanged(self, hue: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"contrastChanged(int)", "\1contrastChanged(self, contrast: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"brightnessChanged(int)", "\1brightnessChanged(self, brightness: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"fullScreenChanged(bool)", "\1fullScreenChanged(self, fullScreen: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QVideoWindowControl = {
    &::QVideoWindowControl::staticMetaObject,
    0,
    signals_QVideoWindowControl,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QVideoWindowControl = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QVideoWindowControl,
        SIP_NULLPTR,
        &plugin_QVideoWindowControl,
    },
    {
        sipNameNr_QVideoWindowControl,
        {0, 0, 1},
        18, methods_QVideoWindowControl,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QVideoWindowControl,
    -1,
    -1,
    supers_QVideoWindowControl,
    SIP_NULLPTR,
    init_type_QVideoWindowControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QVideoWindowControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QVideoWindowControl,
    cast_QVideoWindowControl,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QVideoWindowControl),
};
