/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qradiodata.sip"
#include <qradiodata.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaobject.sip"
#include <qmediaobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmultimedia.sip"
#include <qmultimedia.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQRadioData.cpp"


class sipQRadioData : public ::QRadioData
{
public:
    sipQRadioData(::QMediaObject*, ::QObject*);
    virtual ~sipQRadioData();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QMediaObject* mediaObject() const SIP_OVERRIDE;
    bool setMediaObject(::QMediaObject*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQRadioData(const sipQRadioData &);
    sipQRadioData &operator = (const sipQRadioData &);

    char sipPyMethods[9];
};

sipQRadioData::sipQRadioData(::QMediaObject*a0, ::QObject*a1): ::QRadioData(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQRadioData::~sipQRadioData()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQRadioData::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtMultimedia_qt_metaobject(sipPySelf, sipType_QRadioData);

    return ::QRadioData::metaObject();
}

int sipQRadioData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QRadioData::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtMultimedia_qt_metacall(sipPySelf, sipType_QRadioData, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQRadioData::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtMultimedia_qt_metacast(sipPySelf, sipType_QRadioData, _clname, &sipCpp) ? sipCpp : ::QRadioData::qt_metacast(_clname));
}

::QMediaObject* sipQRadioData::mediaObject() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_mediaObject);

    if (!sipMeth)
        return ::QRadioData::mediaObject();

    extern ::QMediaObject* sipVH_QtMultimedia_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtMultimedia_36(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQRadioData::setMediaObject(::QMediaObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_setMediaObject);

    if (!sipMeth)
        return ::QRadioData::setMediaObject(a0);

    extern bool sipVH_QtMultimedia_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMediaObject*);

    return sipVH_QtMultimedia_37(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQRadioData::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QRadioData::event(a0);

    extern bool sipVH_QtMultimedia_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtMultimedia_10(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQRadioData::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QRadioData::eventFilter(a0, a1);

    extern bool sipVH_QtMultimedia_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtMultimedia_9(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQRadioData::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QRadioData::timerEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtMultimedia_8(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioData::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QRadioData::childEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtMultimedia_7(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioData::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QRadioData::customEvent(a0);
        return;
    }

    extern void sipVH_QtMultimedia_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtMultimedia_6(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioData::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QRadioData::connectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQRadioData::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QRadioData::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtMultimedia_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtMultimedia_5(sipGILState, sipImportedVirtErrorHandlers_QtMultimedia_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QRadioData_mediaObject, "mediaObject(self) -> Optional[QMediaObject]");

extern "C" {static PyObject *meth_QRadioData_mediaObject(PyObject *, PyObject *);}
static PyObject *meth_QRadioData_mediaObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QRadioData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioData, &sipCpp))
        {
            ::QMediaObject*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRadioData::mediaObject() : sipCpp->mediaObject());

            return sipConvertFromType(sipRes, sipType_QMediaObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioData, sipName_mediaObject, doc_QRadioData_mediaObject);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioData_availability, "availability(self) -> QMultimedia.AvailabilityStatus");

extern "C" {static PyObject *meth_QRadioData_availability(PyObject *, PyObject *);}
static PyObject *meth_QRadioData_availability(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioData, &sipCpp))
        {
            ::QMultimedia::AvailabilityStatus sipRes;

            sipRes = sipCpp->availability();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QMultimedia_AvailabilityStatus);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioData, sipName_availability, doc_QRadioData_availability);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioData_stationId, "stationId(self) -> str");

extern "C" {static PyObject *meth_QRadioData_stationId(PyObject *, PyObject *);}
static PyObject *meth_QRadioData_stationId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioData, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->stationId());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioData, sipName_stationId, doc_QRadioData_stationId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioData_programType, "programType(self) -> QRadioData.ProgramType");

extern "C" {static PyObject *meth_QRadioData_programType(PyObject *, PyObject *);}
static PyObject *meth_QRadioData_programType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioData, &sipCpp))
        {
            ::QRadioData::ProgramType sipRes;

            sipRes = sipCpp->programType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QRadioData_ProgramType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioData, sipName_programType, doc_QRadioData_programType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioData_programTypeName, "programTypeName(self) -> str");

extern "C" {static PyObject *meth_QRadioData_programTypeName(PyObject *, PyObject *);}
static PyObject *meth_QRadioData_programTypeName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioData, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->programTypeName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioData, sipName_programTypeName, doc_QRadioData_programTypeName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioData_stationName, "stationName(self) -> str");

extern "C" {static PyObject *meth_QRadioData_stationName(PyObject *, PyObject *);}
static PyObject *meth_QRadioData_stationName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioData, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->stationName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioData, sipName_stationName, doc_QRadioData_stationName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioData_radioText, "radioText(self) -> str");

extern "C" {static PyObject *meth_QRadioData_radioText(PyObject *, PyObject *);}
static PyObject *meth_QRadioData_radioText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioData, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->radioText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioData, sipName_radioText, doc_QRadioData_radioText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioData_isAlternativeFrequenciesEnabled, "isAlternativeFrequenciesEnabled(self) -> bool");

extern "C" {static PyObject *meth_QRadioData_isAlternativeFrequenciesEnabled(PyObject *, PyObject *);}
static PyObject *meth_QRadioData_isAlternativeFrequenciesEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioData, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAlternativeFrequenciesEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioData, sipName_isAlternativeFrequenciesEnabled, doc_QRadioData_isAlternativeFrequenciesEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioData_error, "error(self) -> QRadioData.Error");

extern "C" {static PyObject *meth_QRadioData_error(PyObject *, PyObject *);}
static PyObject *meth_QRadioData_error(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioData, &sipCpp))
        {
            ::QRadioData::Error sipRes;

            sipRes = sipCpp->error();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QRadioData_Error);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioData, sipName_error, doc_QRadioData_error);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioData_errorString, "errorString(self) -> str");

extern "C" {static PyObject *meth_QRadioData_errorString(PyObject *, PyObject *);}
static PyObject *meth_QRadioData_errorString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRadioData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QRadioData, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->errorString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioData, sipName_errorString, doc_QRadioData_errorString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioData_setAlternativeFrequenciesEnabled, "setAlternativeFrequenciesEnabled(self, enabled: bool)");

extern "C" {static PyObject *meth_QRadioData_setAlternativeFrequenciesEnabled(PyObject *, PyObject *);}
static PyObject *meth_QRadioData_setAlternativeFrequenciesEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QRadioData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QRadioData, &sipCpp, &a0))
        {
            sipCpp->setAlternativeFrequenciesEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioData, sipName_setAlternativeFrequenciesEnabled, doc_QRadioData_setAlternativeFrequenciesEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QRadioData_setMediaObject, "setMediaObject(self, a0: Optional[QMediaObject]) -> bool");

extern "C" {static PyObject *meth_QRadioData_setMediaObject(PyObject *, PyObject *);}
static PyObject *meth_QRadioData_setMediaObject(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMediaObject* a0;
        ::QRadioData *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QRadioData, &sipCpp, sipType_QMediaObject, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QRadioData::setMediaObject(a0) : sipCpp->setMediaObject(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QRadioData, sipName_setMediaObject, doc_QRadioData_setMediaObject);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QRadioData(void *, const sipTypeDef *);}
static void *cast_QRadioData(void *sipCppV, const sipTypeDef *targetType)
{
    ::QRadioData *sipCpp = reinterpret_cast< ::QRadioData *>(sipCppV);

    if (targetType == sipType_QRadioData)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    if (targetType == sipType_QMediaBindableInterface)
        return static_cast< ::QMediaBindableInterface *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QRadioData(void *, int);}
static void release_QRadioData(void *sipCppV, int)
{
    ::QRadioData *sipCpp = reinterpret_cast< ::QRadioData *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QRadioData(sipSimpleWrapper *);}
static void dealloc_QRadioData(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQRadioData *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QRadioData(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QRadioData(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QRadioData(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQRadioData *sipCpp = SIP_NULLPTR;

    {
        ::QMediaObject* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J8|JH", sipType_QMediaObject, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQRadioData(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QRadioData[] = {{9, 0, 0}, {101, 255, 1}};


static PyMethodDef methods_QRadioData[] = {
    {sipName_availability, meth_QRadioData_availability, METH_VARARGS, doc_QRadioData_availability},
    {sipName_error, meth_QRadioData_error, METH_VARARGS, doc_QRadioData_error},
    {sipName_errorString, meth_QRadioData_errorString, METH_VARARGS, doc_QRadioData_errorString},
    {sipName_isAlternativeFrequenciesEnabled, meth_QRadioData_isAlternativeFrequenciesEnabled, METH_VARARGS, doc_QRadioData_isAlternativeFrequenciesEnabled},
    {sipName_mediaObject, meth_QRadioData_mediaObject, METH_VARARGS, doc_QRadioData_mediaObject},
    {sipName_programType, meth_QRadioData_programType, METH_VARARGS, doc_QRadioData_programType},
    {sipName_programTypeName, meth_QRadioData_programTypeName, METH_VARARGS, doc_QRadioData_programTypeName},
    {sipName_radioText, meth_QRadioData_radioText, METH_VARARGS, doc_QRadioData_radioText},
    {sipName_setAlternativeFrequenciesEnabled, meth_QRadioData_setAlternativeFrequenciesEnabled, METH_VARARGS, doc_QRadioData_setAlternativeFrequenciesEnabled},
    {sipName_setMediaObject, meth_QRadioData_setMediaObject, METH_VARARGS, doc_QRadioData_setMediaObject},
    {sipName_stationId, meth_QRadioData_stationId, METH_VARARGS, doc_QRadioData_stationId},
    {sipName_stationName, meth_QRadioData_stationName, METH_VARARGS, doc_QRadioData_stationName}
};

static sipEnumMemberDef enummembers_QRadioData[] = {
    {sipName_AdultHits, static_cast<int>(::QRadioData::AdultHits), 140},
    {sipName_Alarm, static_cast<int>(::QRadioData::Alarm), 140},
    {sipName_AlarmTest, static_cast<int>(::QRadioData::AlarmTest), 140},
    {sipName_ChildrensProgrammes, static_cast<int>(::QRadioData::ChildrensProgrammes), 140},
    {sipName_ClassicRock, static_cast<int>(::QRadioData::ClassicRock), 140},
    {sipName_Classical, static_cast<int>(::QRadioData::Classical), 140},
    {sipName_College, static_cast<int>(::QRadioData::College), 140},
    {sipName_CountryMusic, static_cast<int>(::QRadioData::CountryMusic), 140},
    {sipName_Culture, static_cast<int>(::QRadioData::Culture), 140},
    {sipName_CurrentAffairs, static_cast<int>(::QRadioData::CurrentAffairs), 140},
    {sipName_Documentary, static_cast<int>(::QRadioData::Documentary), 140},
    {sipName_Drama, static_cast<int>(::QRadioData::Drama), 140},
    {sipName_EasyListening, static_cast<int>(::QRadioData::EasyListening), 140},
    {sipName_Education, static_cast<int>(::QRadioData::Education), 140},
    {sipName_Finance, static_cast<int>(::QRadioData::Finance), 140},
    {sipName_FolkMusic, static_cast<int>(::QRadioData::FolkMusic), 140},
    {sipName_Information, static_cast<int>(::QRadioData::Information), 140},
    {sipName_JazzMusic, static_cast<int>(::QRadioData::JazzMusic), 140},
    {sipName_Language, static_cast<int>(::QRadioData::Language), 140},
    {sipName_Leisure, static_cast<int>(::QRadioData::Leisure), 140},
    {sipName_LightClassical, static_cast<int>(::QRadioData::LightClassical), 140},
    {sipName_NationalMusic, static_cast<int>(::QRadioData::NationalMusic), 140},
    {sipName_News, static_cast<int>(::QRadioData::News), 140},
    {sipName_NoError, static_cast<int>(::QRadioData::NoError), 139},
    {sipName_Nostalgia, static_cast<int>(::QRadioData::Nostalgia), 140},
    {sipName_OldiesMusic, static_cast<int>(::QRadioData::OldiesMusic), 140},
    {sipName_OpenError, static_cast<int>(::QRadioData::OpenError), 139},
    {sipName_OtherMusic, static_cast<int>(::QRadioData::OtherMusic), 140},
    {sipName_OutOfRangeError, static_cast<int>(::QRadioData::OutOfRangeError), 139},
    {sipName_Personality, static_cast<int>(::QRadioData::Personality), 140},
    {sipName_PhoneIn, static_cast<int>(::QRadioData::PhoneIn), 140},
    {sipName_PopMusic, static_cast<int>(::QRadioData::PopMusic), 140},
    {sipName_Public, static_cast<int>(::QRadioData::Public), 140},
    {sipName_Religion, static_cast<int>(::QRadioData::Religion), 140},
    {sipName_ReligiousMusic, static_cast<int>(::QRadioData::ReligiousMusic), 140},
    {sipName_ReligiousTalk, static_cast<int>(::QRadioData::ReligiousTalk), 140},
    {sipName_ResourceError, static_cast<int>(::QRadioData::ResourceError), 139},
    {sipName_RhythmAndBlues, static_cast<int>(::QRadioData::RhythmAndBlues), 140},
    {sipName_RockMusic, static_cast<int>(::QRadioData::RockMusic), 140},
    {sipName_Science, static_cast<int>(::QRadioData::Science), 140},
    {sipName_SeriousClassical, static_cast<int>(::QRadioData::SeriousClassical), 140},
    {sipName_SocialAffairs, static_cast<int>(::QRadioData::SocialAffairs), 140},
    {sipName_Soft, static_cast<int>(::QRadioData::Soft), 140},
    {sipName_SoftRhythmAndBlues, static_cast<int>(::QRadioData::SoftRhythmAndBlues), 140},
    {sipName_SoftRock, static_cast<int>(::QRadioData::SoftRock), 140},
    {sipName_Sport, static_cast<int>(::QRadioData::Sport), 140},
    {sipName_Talk, static_cast<int>(::QRadioData::Talk), 140},
    {sipName_Top40, static_cast<int>(::QRadioData::Top40), 140},
    {sipName_Travel, static_cast<int>(::QRadioData::Travel), 140},
    {sipName_Undefined, static_cast<int>(::QRadioData::Undefined), 140},
    {sipName_Varied, static_cast<int>(::QRadioData::Varied), 140},
    {sipName_Weather, static_cast<int>(::QRadioData::Weather), 140},
};

PyDoc_STRVAR(doc_QRadioData, "\1QRadioData(mediaObject: Optional[QMediaObject], parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QRadioData[] = {
    {"alternativeFrequenciesEnabledChanged(bool)", "\1alternativeFrequenciesEnabledChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"radioTextChanged(QString)", "\1radioTextChanged(self, radioText: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"stationNameChanged(QString)", "\1stationNameChanged(self, stationName: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"programTypeNameChanged(QString)", "\1programTypeNameChanged(self, programTypeName: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"programTypeChanged(QRadioData::ProgramType)", "\1programTypeChanged(self, programType: QRadioData.ProgramType)", SIP_NULLPTR, SIP_NULLPTR},
    {"stationIdChanged(QString)", "\1stationIdChanged(self, stationId: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"error(QRadioData::Error)", "\1error(self, error: QRadioData.Error)", &methods_QRadioData[1], SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QRadioData = {
    &::QRadioData::staticMetaObject,
    0,
    signals_QRadioData,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QRadioData = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QRadioData,
        SIP_NULLPTR,
        &plugin_QRadioData,
    },
    {
        sipNameNr_QRadioData,
        {0, 0, 1},
        12, methods_QRadioData,
        52, enummembers_QRadioData,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QRadioData,
    -1,
    -1,
    supers_QRadioData,
    SIP_NULLPTR,
    init_type_QRadioData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QRadioData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QRadioData,
    cast_QRadioData,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QRadioData),
};
