/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDesigner.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/default_extensionfactory.sip"
#include <default_extensionfactory.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/qextensionmanager.sip"
#include <qextensionmanager.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignerQExtensionFactory.cpp"


class sipQExtensionFactory : public ::QExtensionFactory
{
public:
    sipQExtensionFactory(::QExtensionManager*);
    virtual ~sipQExtensionFactory();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::QObject* createExtension(::QObject*, const ::QString&, ::QObject*) const SIP_OVERRIDE;
    ::QObject* extension(::QObject*, const ::QString&) const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQExtensionFactory(const sipQExtensionFactory &);
    sipQExtensionFactory &operator = (const sipQExtensionFactory &);

    char sipPyMethods[9];
};

sipQExtensionFactory::sipQExtensionFactory(::QExtensionManager*a0): ::QExtensionFactory(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQExtensionFactory::~sipQExtensionFactory()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQExtensionFactory::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDesigner_qt_metaobject(sipPySelf, sipType_QExtensionFactory);

    return ::QExtensionFactory::metaObject();
}

int sipQExtensionFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QExtensionFactory::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDesigner_qt_metacall(sipPySelf, sipType_QExtensionFactory, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQExtensionFactory::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDesigner_qt_metacast(sipPySelf, sipType_QExtensionFactory, _clname, &sipCpp) ? sipCpp : ::QExtensionFactory::qt_metacast(_clname));
}

::QObject* sipQExtensionFactory::createExtension(::QObject*a0, const ::QString& a1, ::QObject*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_createExtension);

    if (!sipMeth)
        return ::QExtensionFactory::createExtension(a0, a1, a2);

    extern ::QObject* sipVH_QtDesigner_85(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, const ::QString&, ::QObject*);

    return sipVH_QtDesigner_85(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QObject* sipQExtensionFactory::extension(::QObject*a0, const ::QString& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_extension);

    if (!sipMeth)
        return ::QExtensionFactory::extension(a0, a1);

    extern ::QObject* sipVH_QtDesigner_84(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, const ::QString&);

    return sipVH_QtDesigner_84(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQExtensionFactory::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QExtensionFactory::event(a0);

    extern bool sipVH_QtDesigner_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDesigner_31(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQExtensionFactory::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QExtensionFactory::eventFilter(a0, a1);

    extern bool sipVH_QtDesigner_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDesigner_32(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQExtensionFactory::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QExtensionFactory::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDesigner_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDesigner_33(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQExtensionFactory::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QExtensionFactory::childEvent(a0);
        return;
    }

    extern void sipVH_QtDesigner_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDesigner_34(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQExtensionFactory::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QExtensionFactory::customEvent(a0);
        return;
    }

    extern void sipVH_QtDesigner_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDesigner_7(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQExtensionFactory::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QExtensionFactory::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDesigner_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDesigner_35(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQExtensionFactory::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QExtensionFactory::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDesigner_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDesigner_35(sipGILState, sipImportedVirtErrorHandlers_QtDesigner_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QExtensionFactory_extension, "extension(self, object: Optional[QObject], iid: Optional[str]) -> Optional[QObject]");

extern "C" {static PyObject *meth_QExtensionFactory_extension(PyObject *, PyObject *);}
static PyObject *meth_QExtensionFactory_extension(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QObject* a0;
        const ::QString* a1;
        int a1State = 0;
        const ::QExtensionFactory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J1", &sipSelf, sipType_QExtensionFactory, &sipCpp, sipType_QObject, &a0, sipType_QString, &a1, &a1State))
        {
            ::QObject*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QExtensionFactory::extension(a0, *a1) : sipCpp->extension(a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromType(sipRes, sipType_QObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QExtensionFactory, sipName_extension, doc_QExtensionFactory_extension);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QExtensionFactory_extensionManager, "extensionManager(self) -> Optional[QExtensionManager]");

extern "C" {static PyObject *meth_QExtensionFactory_extensionManager(PyObject *, PyObject *);}
static PyObject *meth_QExtensionFactory_extensionManager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QExtensionFactory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QExtensionFactory, &sipCpp))
        {
            ::QExtensionManager*sipRes;

            sipRes = sipCpp->extensionManager();

            return sipConvertFromType(sipRes, sipType_QExtensionManager, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QExtensionFactory, sipName_extensionManager, doc_QExtensionFactory_extensionManager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QExtensionFactory_createExtension, "createExtension(self, object: Optional[QObject], iid: Optional[str], parent: Optional[QObject]) -> Optional[QObject]");

extern "C" {static PyObject *meth_QExtensionFactory_createExtension(PyObject *, PyObject *);}
static PyObject *meth_QExtensionFactory_createExtension(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QObject* a0;
        const ::QString* a1;
        int a1State = 0;
        ::QObject* a2;
        sipWrapper *sipOwner = SIP_NULLPTR;
        const ::QExtensionFactory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8J1JH", &sipSelf, sipType_QExtensionFactory, &sipCpp, sipType_QObject, &a0, sipType_QString, &a1, &a1State, sipType_QObject, &a2, &sipOwner))
        {
            ::QObject*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QExtensionFactory::createExtension(a0, *a1, a2) : sipCpp->createExtension(a0, *a1, a2));
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QObject, (PyObject *)sipOwner);
        }
    }

    sipNoMethod(sipParseErr, sipName_QExtensionFactory, sipName_createExtension, doc_QExtensionFactory_createExtension);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QExtensionFactory(void *, const sipTypeDef *);}
static void *cast_QExtensionFactory(void *sipCppV, const sipTypeDef *targetType)
{
    ::QExtensionFactory *sipCpp = reinterpret_cast< ::QExtensionFactory *>(sipCppV);

    if (targetType == sipType_QExtensionFactory)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    if (targetType == sipType_QAbstractExtensionFactory)
        return static_cast< ::QAbstractExtensionFactory *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QExtensionFactory(void *, int);}
static void release_QExtensionFactory(void *sipCppV, int)
{
    ::QExtensionFactory *sipCpp = reinterpret_cast< ::QExtensionFactory *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QExtensionFactory(Py_ssize_t);}
static void *array_QExtensionFactory(Py_ssize_t sipNrElem)
{
    return new ::QExtensionFactory[sipNrElem];
}


extern "C" {static void array_delete_QExtensionFactory(void *);}
static void array_delete_QExtensionFactory(void *sipCpp)
{
    delete[] reinterpret_cast< ::QExtensionFactory *>(sipCpp);
}


extern "C" {static void dealloc_QExtensionFactory(sipSimpleWrapper *);}
static void dealloc_QExtensionFactory(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQExtensionFactory *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QExtensionFactory(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QExtensionFactory(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QExtensionFactory(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQExtensionFactory *sipCpp = SIP_NULLPTR;

    {
        ::QExtensionManager* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QExtensionManager, &a0, sipOwner))
        {
            sipCpp = new sipQExtensionFactory(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QExtensionFactory[] = {{7, 0, 0}, {0, 255, 1}};


static PyMethodDef methods_QExtensionFactory[] = {
    {sipName_createExtension, meth_QExtensionFactory_createExtension, METH_VARARGS, doc_QExtensionFactory_createExtension},
    {sipName_extension, meth_QExtensionFactory_extension, METH_VARARGS, doc_QExtensionFactory_extension},
    {sipName_extensionManager, meth_QExtensionFactory_extensionManager, METH_VARARGS, doc_QExtensionFactory_extensionManager}
};

PyDoc_STRVAR(doc_QExtensionFactory, "\1QExtensionFactory(parent: Optional[QExtensionManager] = None)");


static pyqt5ClassPluginDef plugin_QExtensionFactory = {
    &::QExtensionFactory::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDesigner_QExtensionFactory = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QExtensionFactory,
        SIP_NULLPTR,
        &plugin_QExtensionFactory,
    },
    {
        sipNameNr_QExtensionFactory,
        {0, 0, 1},
        3, methods_QExtensionFactory,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QExtensionFactory,
    -1,
    -1,
    supers_QExtensionFactory,
    SIP_NULLPTR,
    init_type_QExtensionFactory,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QExtensionFactory,
    SIP_NULLPTR,
    array_QExtensionFactory,
    SIP_NULLPTR,
    release_QExtensionFactory,
    cast_QExtensionFactory,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QExtensionFactory,
    sizeof (::QExtensionFactory),
};
