/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerafocus.sip"
#include <qcamerafocus.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusZone.cpp"

#line 164 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediaQCameraFocusZone.cpp"


PyDoc_STRVAR(doc_QCameraFocusZone_isValid, "isValid(self) -> bool");

extern "C" {static PyObject *meth_QCameraFocusZone_isValid(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocusZone_isValid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraFocusZone *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocusZone, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isValid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocusZone, sipName_isValid, doc_QCameraFocusZone_isValid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocusZone_area, "area(self) -> QRectF");

extern "C" {static PyObject *meth_QCameraFocusZone_area(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocusZone_area(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraFocusZone *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocusZone, &sipCpp))
        {
            ::QRectF*sipRes;

            sipRes = new ::QRectF(sipCpp->area());

            return sipConvertFromNewType(sipRes, sipType_QRectF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocusZone, sipName_area, doc_QCameraFocusZone_area);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QCameraFocusZone_status, "status(self) -> QCameraFocusZone.FocusZoneStatus");

extern "C" {static PyObject *meth_QCameraFocusZone_status(PyObject *, PyObject *);}
static PyObject *meth_QCameraFocusZone_status(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraFocusZone *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QCameraFocusZone, &sipCpp))
        {
            ::QCameraFocusZone::FocusZoneStatus sipRes;

            sipRes = sipCpp->status();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QCameraFocusZone_FocusZoneStatus);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCameraFocusZone, sipName_status, doc_QCameraFocusZone_status);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QCameraFocusZone___ne__(PyObject *, PyObject *);}
static PyObject *slot_QCameraFocusZone___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QCameraFocusZone *sipCpp = reinterpret_cast< ::QCameraFocusZone *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QCameraFocusZone));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraFocusZone* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QCameraFocusZone, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QCameraFocusZone::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, ne_slot, sipType_QCameraFocusZone, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QCameraFocusZone___eq__(PyObject *, PyObject *);}
static PyObject *slot_QCameraFocusZone___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QCameraFocusZone *sipCpp = reinterpret_cast< ::QCameraFocusZone *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QCameraFocusZone));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QCameraFocusZone* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QCameraFocusZone, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QCameraFocusZone::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtMultimedia, eq_slot, sipType_QCameraFocusZone, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QCameraFocusZone(void *, int);}
static void release_QCameraFocusZone(void *sipCppV, int)
{
    delete reinterpret_cast< ::QCameraFocusZone *>(sipCppV);
}


extern "C" {static void assign_QCameraFocusZone(void *, Py_ssize_t, void *);}
static void assign_QCameraFocusZone(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QCameraFocusZone *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QCameraFocusZone *>(sipSrc);
}


extern "C" {static void *copy_QCameraFocusZone(const void *, Py_ssize_t);}
static void *copy_QCameraFocusZone(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QCameraFocusZone(reinterpret_cast<const ::QCameraFocusZone *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QCameraFocusZone(sipSimpleWrapper *);}
static void dealloc_QCameraFocusZone(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QCameraFocusZone(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QCameraFocusZone(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QCameraFocusZone(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QCameraFocusZone *sipCpp = SIP_NULLPTR;

    {
        const ::QCameraFocusZone* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QCameraFocusZone, &a0))
        {
            sipCpp = new ::QCameraFocusZone(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QCameraFocusZone[] = {
    {(void *)slot_QCameraFocusZone___ne__, ne_slot},
    {(void *)slot_QCameraFocusZone___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QCameraFocusZone[] = {
    {sipName_area, meth_QCameraFocusZone_area, METH_VARARGS, doc_QCameraFocusZone_area},
    {sipName_isValid, meth_QCameraFocusZone_isValid, METH_VARARGS, doc_QCameraFocusZone_isValid},
    {sipName_status, meth_QCameraFocusZone_status, METH_VARARGS, doc_QCameraFocusZone_status}
};

static sipEnumMemberDef enummembers_QCameraFocusZone[] = {
    {sipName_Focused, static_cast<int>(::QCameraFocusZone::Focused), 62},
    {sipName_Invalid, static_cast<int>(::QCameraFocusZone::Invalid), 62},
    {sipName_Selected, static_cast<int>(::QCameraFocusZone::Selected), 62},
    {sipName_Unused, static_cast<int>(::QCameraFocusZone::Unused), 62},
};

PyDoc_STRVAR(doc_QCameraFocusZone, "\1QCameraFocusZone(other: QCameraFocusZone)");


static pyqt5ClassPluginDef plugin_QCameraFocusZone = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtMultimedia_QCameraFocusZone = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QCameraFocusZone,
        SIP_NULLPTR,
        &plugin_QCameraFocusZone,
    },
    {
        sipNameNr_QCameraFocusZone,
        {0, 0, 1},
        3, methods_QCameraFocusZone,
        4, enummembers_QCameraFocusZone,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QCameraFocusZone,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QCameraFocusZone,
    init_type_QCameraFocusZone,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QCameraFocusZone,
    assign_QCameraFocusZone,
    SIP_NULLPTR,
    copy_QCameraFocusZone,
    release_QCameraFocusZone,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QCameraFocusZone),
};
