/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtXml.h"

#line 429 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"

#line 54 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 312 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 364 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 275 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 388 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 402 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 351 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 417 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 174 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 63 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 192 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 66 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 263 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 69 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 376 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 72 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 295 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 237 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 78 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"
#line 154 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtXml/qdom.sip"
#include <qdom.h>
#line 81 "/build/pyqt5/src/PyQt5-5.15.11/build/QtXml/sipQtXmlQDomProcessingInstruction.cpp"


PyDoc_STRVAR(doc_QDomProcessingInstruction_target, "target(self) -> str");

extern "C" {static PyObject *meth_QDomProcessingInstruction_target(PyObject *, PyObject *);}
static PyObject *meth_QDomProcessingInstruction_target(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomProcessingInstruction *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomProcessingInstruction, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->target());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomProcessingInstruction, sipName_target, doc_QDomProcessingInstruction_target);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomProcessingInstruction_data, "data(self) -> str");

extern "C" {static PyObject *meth_QDomProcessingInstruction_data(PyObject *, PyObject *);}
static PyObject *meth_QDomProcessingInstruction_data(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomProcessingInstruction *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomProcessingInstruction, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->data());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomProcessingInstruction, sipName_data, doc_QDomProcessingInstruction_data);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomProcessingInstruction_setData, "setData(self, d: Optional[str])");

extern "C" {static PyObject *meth_QDomProcessingInstruction_setData(PyObject *, PyObject *);}
static PyObject *meth_QDomProcessingInstruction_setData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QDomProcessingInstruction *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QDomProcessingInstruction, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setData(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomProcessingInstruction, sipName_setData, doc_QDomProcessingInstruction_setData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QDomProcessingInstruction_nodeType, "nodeType(self) -> QDomNode.NodeType");

extern "C" {static PyObject *meth_QDomProcessingInstruction_nodeType(PyObject *, PyObject *);}
static PyObject *meth_QDomProcessingInstruction_nodeType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QDomProcessingInstruction *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QDomProcessingInstruction, &sipCpp))
        {
            ::QDomNode::NodeType sipRes;

            sipRes = sipCpp->nodeType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QDomNode_NodeType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QDomProcessingInstruction, sipName_nodeType, doc_QDomProcessingInstruction_nodeType);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QDomProcessingInstruction(void *, const sipTypeDef *);}
static void *cast_QDomProcessingInstruction(void *sipCppV, const sipTypeDef *targetType)
{
    ::QDomProcessingInstruction *sipCpp = reinterpret_cast< ::QDomProcessingInstruction *>(sipCppV);

    if (targetType == sipType_QDomProcessingInstruction)
        return sipCppV;

    if (targetType == sipType_QDomNode)
        return static_cast< ::QDomNode *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QDomProcessingInstruction(void *, int);}
static void release_QDomProcessingInstruction(void *sipCppV, int)
{
    delete reinterpret_cast< ::QDomProcessingInstruction *>(sipCppV);
}


extern "C" {static void *array_QDomProcessingInstruction(Py_ssize_t);}
static void *array_QDomProcessingInstruction(Py_ssize_t sipNrElem)
{
    return new ::QDomProcessingInstruction[sipNrElem];
}


extern "C" {static void array_delete_QDomProcessingInstruction(void *);}
static void array_delete_QDomProcessingInstruction(void *sipCpp)
{
    delete[] reinterpret_cast< ::QDomProcessingInstruction *>(sipCpp);
}


extern "C" {static void assign_QDomProcessingInstruction(void *, Py_ssize_t, void *);}
static void assign_QDomProcessingInstruction(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QDomProcessingInstruction *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QDomProcessingInstruction *>(sipSrc);
}


extern "C" {static void *copy_QDomProcessingInstruction(const void *, Py_ssize_t);}
static void *copy_QDomProcessingInstruction(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QDomProcessingInstruction(reinterpret_cast<const ::QDomProcessingInstruction *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QDomProcessingInstruction(sipSimpleWrapper *);}
static void dealloc_QDomProcessingInstruction(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QDomProcessingInstruction(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QDomProcessingInstruction(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QDomProcessingInstruction(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QDomProcessingInstruction *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QDomProcessingInstruction();

            return sipCpp;
        }
    }

    {
        const ::QDomProcessingInstruction* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QDomProcessingInstruction, &a0))
        {
            sipCpp = new ::QDomProcessingInstruction(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QDomProcessingInstruction[] = {{13, 255, 1}};


static PyMethodDef methods_QDomProcessingInstruction[] = {
    {sipName_data, meth_QDomProcessingInstruction_data, METH_VARARGS, doc_QDomProcessingInstruction_data},
    {sipName_nodeType, meth_QDomProcessingInstruction_nodeType, METH_VARARGS, doc_QDomProcessingInstruction_nodeType},
    {sipName_setData, meth_QDomProcessingInstruction_setData, METH_VARARGS, doc_QDomProcessingInstruction_setData},
    {sipName_target, meth_QDomProcessingInstruction_target, METH_VARARGS, doc_QDomProcessingInstruction_target}
};

PyDoc_STRVAR(doc_QDomProcessingInstruction, "\1QDomProcessingInstruction()\n"
"QDomProcessingInstruction(x: QDomProcessingInstruction)");


static pyqt5ClassPluginDef plugin_QDomProcessingInstruction = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtXml_QDomProcessingInstruction = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QDomProcessingInstruction,
        SIP_NULLPTR,
        &plugin_QDomProcessingInstruction,
    },
    {
        sipNameNr_QDomProcessingInstruction,
        {0, 0, 1},
        4, methods_QDomProcessingInstruction,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QDomProcessingInstruction,
    -1,
    -1,
    supers_QDomProcessingInstruction,
    SIP_NULLPTR,
    init_type_QDomProcessingInstruction,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QDomProcessingInstruction,
    assign_QDomProcessingInstruction,
    array_QDomProcessingInstruction,
    copy_QDomProcessingInstruction,
    release_QDomProcessingInstruction,
    cast_QDomProcessingInstruction,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QDomProcessingInstruction,
    sizeof (::QDomProcessingInstruction),
};
