/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKit.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 103 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 43 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 46 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 49 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 55 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 75 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 60 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebPluginFactory.cpp"


class sipQWebPluginFactory : public ::QWebPluginFactory
{
public:
    sipQWebPluginFactory(::QObject*);
    virtual ~sipQWebPluginFactory();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool supportsExtension(::QWebPluginFactory::Extension) const SIP_OVERRIDE;
    bool extension(::QWebPluginFactory::Extension, const ::QWebPluginFactory::ExtensionOption*, ::QWebPluginFactory::ExtensionReturn*) SIP_OVERRIDE;
    ::QObject* create(const ::QString&, const ::QUrl&, const ::QStringList&, const ::QStringList&) const SIP_OVERRIDE;
    void refreshPlugins() SIP_OVERRIDE;
    QList< ::QWebPluginFactory::Plugin> plugins() const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQWebPluginFactory(const sipQWebPluginFactory &);
    sipQWebPluginFactory &operator = (const sipQWebPluginFactory &);

    char sipPyMethods[12];
};

sipQWebPluginFactory::sipQWebPluginFactory(::QObject*a0): ::QWebPluginFactory(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQWebPluginFactory::~sipQWebPluginFactory()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQWebPluginFactory::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWebKit_qt_metaobject(sipPySelf, sipType_QWebPluginFactory);

    return ::QWebPluginFactory::metaObject();
}

int sipQWebPluginFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QWebPluginFactory::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWebKit_qt_metacall(sipPySelf, sipType_QWebPluginFactory, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQWebPluginFactory::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWebKit_qt_metacast(sipPySelf, sipType_QWebPluginFactory, _clname, &sipCpp) ? sipCpp : ::QWebPluginFactory::qt_metacast(_clname));
}

bool sipQWebPluginFactory::supportsExtension(::QWebPluginFactory::Extension a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_supportsExtension);

    if (!sipMeth)
        return ::QWebPluginFactory::supportsExtension(a0);

    extern bool sipVH_QtWebKit_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWebPluginFactory::Extension);

    return sipVH_QtWebKit_12(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWebPluginFactory::extension(::QWebPluginFactory::Extension a0, const ::QWebPluginFactory::ExtensionOption*a1, ::QWebPluginFactory::ExtensionReturn*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_extension);

    if (!sipMeth)
        return ::QWebPluginFactory::extension(a0, a1, a2);

    extern bool sipVH_QtWebKit_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWebPluginFactory::Extension, const ::QWebPluginFactory::ExtensionOption*, ::QWebPluginFactory::ExtensionReturn*);

    return sipVH_QtWebKit_11(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QObject* sipQWebPluginFactory::create(const ::QString& a0, const ::QUrl& a1, const ::QStringList& a2, const ::QStringList& a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QWebPluginFactory, sipName_create);

    if (!sipMeth)
        return 0;

    extern ::QObject* sipVH_QtWebKit_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&, const ::QUrl&, const ::QStringList&, const ::QStringList&);

    return sipVH_QtWebKit_10(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

void sipQWebPluginFactory::refreshPlugins()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_refreshPlugins);

    if (!sipMeth)
    {
        ::QWebPluginFactory::refreshPlugins();
        return;
    }

    extern void sipVH_QtWebKit_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWebKit_9(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

QList< ::QWebPluginFactory::Plugin> sipQWebPluginFactory::plugins() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), sipName_QWebPluginFactory, sipName_plugins);

    if (!sipMeth)
        return QList< ::QWebPluginFactory::Plugin>();

    extern QList< ::QWebPluginFactory::Plugin> sipVH_QtWebKit_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWebKit_8(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQWebPluginFactory::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QWebPluginFactory::event(a0);

    extern bool sipVH_QtWebKit_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWebKit_5(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWebPluginFactory::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QWebPluginFactory::eventFilter(a0, a1);

    extern bool sipVH_QtWebKit_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWebKit_4(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQWebPluginFactory::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QWebPluginFactory::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWebKit_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWebKit_3(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebPluginFactory::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QWebPluginFactory::childEvent(a0);
        return;
    }

    extern void sipVH_QtWebKit_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWebKit_2(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebPluginFactory::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QWebPluginFactory::customEvent(a0);
        return;
    }

    extern void sipVH_QtWebKit_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebKit_1(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebPluginFactory::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QWebPluginFactory::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWebKit_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebKit_0(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebPluginFactory::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QWebPluginFactory::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWebKit_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebKit_0(sipGILState, sipImportedVirtErrorHandlers_QtWebKit_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QWebPluginFactory_plugins, "plugins(self) -> list[QWebPluginFactory.Plugin]");

extern "C" {static PyObject *meth_QWebPluginFactory_plugins(PyObject *, PyObject *);}
static PyObject *meth_QWebPluginFactory_plugins(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QWebPluginFactory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPluginFactory, &sipCpp))
        {
            QList< ::QWebPluginFactory::Plugin>*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QWebPluginFactory, sipName_plugins);
                return SIP_NULLPTR;
            }

            sipRes = new QList< ::QWebPluginFactory::Plugin>(sipCpp->plugins());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QWebPluginFactory_Plugin, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPluginFactory, sipName_plugins, doc_QWebPluginFactory_plugins);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPluginFactory_refreshPlugins, "refreshPlugins(self)");

extern "C" {static PyObject *meth_QWebPluginFactory_refreshPlugins(PyObject *, PyObject *);}
static PyObject *meth_QWebPluginFactory_refreshPlugins(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWebPluginFactory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPluginFactory, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QWebPluginFactory::refreshPlugins() : sipCpp->refreshPlugins());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPluginFactory, sipName_refreshPlugins, doc_QWebPluginFactory_refreshPlugins);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPluginFactory_create, "create(self, mimeType: Optional[str], url: QUrl, argumentNames: Iterable[Optional[str]], argumentValues: Iterable[Optional[str]]) -> Optional[QObject]");

extern "C" {static PyObject *meth_QWebPluginFactory_create(PyObject *, PyObject *);}
static PyObject *meth_QWebPluginFactory_create(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QUrl* a1;
        const ::QStringList* a2;
        int a2State = 0;
        const ::QStringList* a3;
        int a3State = 0;
        const ::QWebPluginFactory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J9J1J1", &sipSelf, sipType_QWebPluginFactory, &sipCpp, sipType_QString, &a0, &a0State, sipType_QUrl, &a1, sipType_QStringList, &a2, &a2State, sipType_QStringList, &a3, &a3State))
        {
            ::QObject*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QWebPluginFactory, sipName_create);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->create(*a0, *a1, *a2, *a3);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QStringList *>(a2), sipType_QStringList, a2State);
            sipReleaseType(const_cast< ::QStringList *>(a3), sipType_QStringList, a3State);

            return sipConvertFromNewType(sipRes, sipType_QObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPluginFactory, sipName_create, doc_QWebPluginFactory_create);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPluginFactory_extension, "extension(self, extension: QWebPluginFactory.Extension, option: Optional[QWebPluginFactory.ExtensionOption] = None, output: Optional[QWebPluginFactory.ExtensionReturn] = None) -> bool");

extern "C" {static PyObject *meth_QWebPluginFactory_extension(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebPluginFactory_extension(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWebPluginFactory::Extension a0;
        const ::QWebPluginFactory::ExtensionOption* a1 = 0;
        ::QWebPluginFactory::ExtensionReturn* a2 = 0;
        ::QWebPluginFactory *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_option,
            sipName_output,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|J8J8", &sipSelf, sipType_QWebPluginFactory, &sipCpp, sipType_QWebPluginFactory_Extension, &a0, sipType_QWebPluginFactory_ExtensionOption, &a1, sipType_QWebPluginFactory_ExtensionReturn, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWebPluginFactory::extension(a0, a1, a2) : sipCpp->extension(a0, a1, a2));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPluginFactory, sipName_extension, doc_QWebPluginFactory_extension);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPluginFactory_supportsExtension, "supportsExtension(self, extension: QWebPluginFactory.Extension) -> bool");

extern "C" {static PyObject *meth_QWebPluginFactory_supportsExtension(PyObject *, PyObject *);}
static PyObject *meth_QWebPluginFactory_supportsExtension(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWebPluginFactory::Extension a0;
        const ::QWebPluginFactory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebPluginFactory, &sipCpp, sipType_QWebPluginFactory_Extension, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWebPluginFactory::supportsExtension(a0) : sipCpp->supportsExtension(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPluginFactory, sipName_supportsExtension, doc_QWebPluginFactory_supportsExtension);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QWebPluginFactory(void *, const sipTypeDef *);}
static void *cast_QWebPluginFactory(void *sipCppV, const sipTypeDef *targetType)
{
    ::QWebPluginFactory *sipCpp = reinterpret_cast< ::QWebPluginFactory *>(sipCppV);

    if (targetType == sipType_QWebPluginFactory)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebPluginFactory(void *, int);}
static void release_QWebPluginFactory(void *sipCppV, int)
{
    ::QWebPluginFactory *sipCpp = reinterpret_cast< ::QWebPluginFactory *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QWebPluginFactory(sipSimpleWrapper *);}
static void dealloc_QWebPluginFactory(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQWebPluginFactory *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWebPluginFactory(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QWebPluginFactory(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWebPluginFactory(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQWebPluginFactory *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQWebPluginFactory(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QWebPluginFactory[] = {{5, 0, 1}};


static PyMethodDef methods_QWebPluginFactory[] = {
    {sipName_create, meth_QWebPluginFactory_create, METH_VARARGS, doc_QWebPluginFactory_create},
    {sipName_extension, SIP_MLMETH_CAST(meth_QWebPluginFactory_extension), METH_VARARGS|METH_KEYWORDS, doc_QWebPluginFactory_extension},
    {sipName_plugins, meth_QWebPluginFactory_plugins, METH_VARARGS, doc_QWebPluginFactory_plugins},
    {sipName_refreshPlugins, meth_QWebPluginFactory_refreshPlugins, METH_VARARGS, doc_QWebPluginFactory_refreshPlugins},
    {sipName_supportsExtension, meth_QWebPluginFactory_supportsExtension, METH_VARARGS, doc_QWebPluginFactory_supportsExtension}
};

PyDoc_STRVAR(doc_QWebPluginFactory, "\1QWebPluginFactory(parent: Optional[QObject] = None)");


static pyqt5ClassPluginDef plugin_QWebPluginFactory = {
    &::QWebPluginFactory::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKit_QWebPluginFactory = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebPluginFactory,
        SIP_NULLPTR,
        &plugin_QWebPluginFactory,
    },
    {
        sipNameNr_QWebPluginFactory,
        {0, 0, 1},
        5, methods_QWebPluginFactory,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWebPluginFactory,
    -1,
    -1,
    supers_QWebPluginFactory,
    SIP_NULLPTR,
    init_type_QWebPluginFactory,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWebPluginFactory,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QWebPluginFactory,
    cast_QWebPluginFactory,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    sizeof (::QWebPluginFactory),
};
