/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKit.h"

#line 45 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebhistory.sip"
#include <qwebhistory.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistory.cpp"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebhistory.sip"
#include <qwebhistory.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistory.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistory.cpp"


PyDoc_STRVAR(doc_QWebHistory_clear, "clear(self)");

extern "C" {static PyObject *meth_QWebHistory_clear(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHistory, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_clear, doc_QWebHistory_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_items, "items(self) -> list[QWebHistoryItem]");

extern "C" {static PyObject *meth_QWebHistory_items(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_items(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHistory, &sipCpp))
        {
            QList< ::QWebHistoryItem>*sipRes;

            sipRes = new QList< ::QWebHistoryItem>(sipCpp->items());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QWebHistoryItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_items, doc_QWebHistory_items);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_backItems, "backItems(self, maxItems: int) -> list[QWebHistoryItem]");

extern "C" {static PyObject *meth_QWebHistory_backItems(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_backItems(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWebHistory, &sipCpp, &a0))
        {
            QList< ::QWebHistoryItem>*sipRes;

            sipRes = new QList< ::QWebHistoryItem>(sipCpp->backItems(a0));

            return sipConvertFromNewType(sipRes, sipType_QList_0100QWebHistoryItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_backItems, doc_QWebHistory_backItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_forwardItems, "forwardItems(self, maxItems: int) -> list[QWebHistoryItem]");

extern "C" {static PyObject *meth_QWebHistory_forwardItems(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_forwardItems(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWebHistory, &sipCpp, &a0))
        {
            QList< ::QWebHistoryItem>*sipRes;

            sipRes = new QList< ::QWebHistoryItem>(sipCpp->forwardItems(a0));

            return sipConvertFromNewType(sipRes, sipType_QList_0100QWebHistoryItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_forwardItems, doc_QWebHistory_forwardItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_canGoBack, "canGoBack(self) -> bool");

extern "C" {static PyObject *meth_QWebHistory_canGoBack(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_canGoBack(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHistory, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->canGoBack();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_canGoBack, doc_QWebHistory_canGoBack);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_canGoForward, "canGoForward(self) -> bool");

extern "C" {static PyObject *meth_QWebHistory_canGoForward(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_canGoForward(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHistory, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->canGoForward();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_canGoForward, doc_QWebHistory_canGoForward);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_back, "back(self)");

extern "C" {static PyObject *meth_QWebHistory_back(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_back(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHistory, &sipCpp))
        {
            sipCpp->back();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_back, doc_QWebHistory_back);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_forward, "forward(self)");

extern "C" {static PyObject *meth_QWebHistory_forward(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_forward(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHistory, &sipCpp))
        {
            sipCpp->forward();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_forward, doc_QWebHistory_forward);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_goToItem, "goToItem(self, item: QWebHistoryItem)");

extern "C" {static PyObject *meth_QWebHistory_goToItem(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_goToItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHistoryItem* a0;
        ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebHistory, &sipCpp, sipType_QWebHistoryItem, &a0))
        {
            sipCpp->goToItem(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_goToItem, doc_QWebHistory_goToItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_backItem, "backItem(self) -> QWebHistoryItem");

extern "C" {static PyObject *meth_QWebHistory_backItem(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_backItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHistory, &sipCpp))
        {
            ::QWebHistoryItem*sipRes;

            sipRes = new ::QWebHistoryItem(sipCpp->backItem());

            return sipConvertFromNewType(sipRes, sipType_QWebHistoryItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_backItem, doc_QWebHistory_backItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_currentItem, "currentItem(self) -> QWebHistoryItem");

extern "C" {static PyObject *meth_QWebHistory_currentItem(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_currentItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHistory, &sipCpp))
        {
            ::QWebHistoryItem*sipRes;

            sipRes = new ::QWebHistoryItem(sipCpp->currentItem());

            return sipConvertFromNewType(sipRes, sipType_QWebHistoryItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_currentItem, doc_QWebHistory_currentItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_forwardItem, "forwardItem(self) -> QWebHistoryItem");

extern "C" {static PyObject *meth_QWebHistory_forwardItem(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_forwardItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHistory, &sipCpp))
        {
            ::QWebHistoryItem*sipRes;

            sipRes = new ::QWebHistoryItem(sipCpp->forwardItem());

            return sipConvertFromNewType(sipRes, sipType_QWebHistoryItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_forwardItem, doc_QWebHistory_forwardItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_itemAt, "itemAt(self, i: int) -> QWebHistoryItem");

extern "C" {static PyObject *meth_QWebHistory_itemAt(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_itemAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWebHistory, &sipCpp, &a0))
        {
            ::QWebHistoryItem*sipRes;

            sipRes = new ::QWebHistoryItem(sipCpp->itemAt(a0));

            return sipConvertFromNewType(sipRes, sipType_QWebHistoryItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_itemAt, doc_QWebHistory_itemAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_count, "count(self) -> int");

extern "C" {static PyObject *meth_QWebHistory_count(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_count(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHistory, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->count();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_count, doc_QWebHistory_count);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_currentItemIndex, "currentItemIndex(self) -> int");

extern "C" {static PyObject *meth_QWebHistory_currentItemIndex(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_currentItemIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHistory, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->currentItemIndex();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_currentItemIndex, doc_QWebHistory_currentItemIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_maximumItemCount, "maximumItemCount(self) -> int");

extern "C" {static PyObject *meth_QWebHistory_maximumItemCount(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_maximumItemCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebHistory, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->maximumItemCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_maximumItemCount, doc_QWebHistory_maximumItemCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebHistory_setMaximumItemCount, "setMaximumItemCount(self, count: int)");

extern "C" {static PyObject *meth_QWebHistory_setMaximumItemCount(PyObject *, PyObject *);}
static PyObject *meth_QWebHistory_setMaximumItemCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QWebHistory *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QWebHistory, &sipCpp, &a0))
        {
            sipCpp->setMaximumItemCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebHistory, sipName_setMaximumItemCount, doc_QWebHistory_setMaximumItemCount);

    return SIP_NULLPTR;
}


extern "C" {static Py_ssize_t slot_QWebHistory___len__(PyObject *);}
static Py_ssize_t slot_QWebHistory___len__(PyObject *sipSelf)
{
    ::QWebHistory *sipCpp = reinterpret_cast< ::QWebHistory *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QWebHistory));

    if (!sipCpp)
        return 0;


    {
        {
            Py_ssize_t sipRes = 0;

#line 1 "Auto-generated"
            sipRes = (Py_ssize_t)sipCpp->count();
#line 496 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKit/sipQtWebKitQWebHistory.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebHistory(void *, int);}
static void release_QWebHistory(void *, int)
{
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QWebHistory[] = {
    {(void *)slot_QWebHistory___len__, len_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QWebHistory[] = {
    {sipName_back, meth_QWebHistory_back, METH_VARARGS, doc_QWebHistory_back},
    {sipName_backItem, meth_QWebHistory_backItem, METH_VARARGS, doc_QWebHistory_backItem},
    {sipName_backItems, meth_QWebHistory_backItems, METH_VARARGS, doc_QWebHistory_backItems},
    {sipName_canGoBack, meth_QWebHistory_canGoBack, METH_VARARGS, doc_QWebHistory_canGoBack},
    {sipName_canGoForward, meth_QWebHistory_canGoForward, METH_VARARGS, doc_QWebHistory_canGoForward},
    {sipName_clear, meth_QWebHistory_clear, METH_VARARGS, doc_QWebHistory_clear},
    {sipName_count, meth_QWebHistory_count, METH_VARARGS, doc_QWebHistory_count},
    {sipName_currentItem, meth_QWebHistory_currentItem, METH_VARARGS, doc_QWebHistory_currentItem},
    {sipName_currentItemIndex, meth_QWebHistory_currentItemIndex, METH_VARARGS, doc_QWebHistory_currentItemIndex},
    {sipName_forward, meth_QWebHistory_forward, METH_VARARGS, doc_QWebHistory_forward},
    {sipName_forwardItem, meth_QWebHistory_forwardItem, METH_VARARGS, doc_QWebHistory_forwardItem},
    {sipName_forwardItems, meth_QWebHistory_forwardItems, METH_VARARGS, doc_QWebHistory_forwardItems},
    {sipName_goToItem, meth_QWebHistory_goToItem, METH_VARARGS, doc_QWebHistory_goToItem},
    {sipName_itemAt, meth_QWebHistory_itemAt, METH_VARARGS, doc_QWebHistory_itemAt},
    {sipName_items, meth_QWebHistory_items, METH_VARARGS, doc_QWebHistory_items},
    {sipName_maximumItemCount, meth_QWebHistory_maximumItemCount, METH_VARARGS, doc_QWebHistory_maximumItemCount},
    {sipName_setMaximumItemCount, meth_QWebHistory_setMaximumItemCount, METH_VARARGS, doc_QWebHistory_setMaximumItemCount}
};


static pyqt5ClassPluginDef plugin_QWebHistory = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKit_QWebHistory = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebHistory,
        SIP_NULLPTR,
        &plugin_QWebHistory,
    },
    {
        sipNameNr_QWebHistory,
        {0, 0, 1},
        17, methods_QWebHistory,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QWebHistory,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QWebHistory,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
