/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 75 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 54 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipQtWidgetsQGraphicsColorizeEffect.cpp"


class sipQGraphicsColorizeEffect : public ::QGraphicsColorizeEffect
{
public:
    sipQGraphicsColorizeEffect(::QObject*);
    virtual ~sipQGraphicsColorizeEffect();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    ::QRectF boundingRectFor(const ::QRectF&) const SIP_OVERRIDE;
    void draw(::QPainter*) SIP_OVERRIDE;
    void sourceChanged(::QGraphicsEffect::ChangeFlags) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQGraphicsColorizeEffect(const sipQGraphicsColorizeEffect &);
    sipQGraphicsColorizeEffect &operator = (const sipQGraphicsColorizeEffect &);

    char sipPyMethods[10];
};

sipQGraphicsColorizeEffect::sipQGraphicsColorizeEffect(::QObject*a0): ::QGraphicsColorizeEffect(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQGraphicsColorizeEffect::~sipQGraphicsColorizeEffect()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQGraphicsColorizeEffect::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QGraphicsColorizeEffect);

    return ::QGraphicsColorizeEffect::metaObject();
}

int sipQGraphicsColorizeEffect::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QGraphicsColorizeEffect::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QGraphicsColorizeEffect, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQGraphicsColorizeEffect::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QGraphicsColorizeEffect, _clname, &sipCpp) ? sipCpp : ::QGraphicsColorizeEffect::qt_metacast(_clname));
}

void sipQGraphicsColorizeEffect::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QGraphicsColorizeEffect::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsColorizeEffect::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QGraphicsColorizeEffect::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsColorizeEffect::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QGraphicsColorizeEffect::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsColorizeEffect::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QGraphicsColorizeEffect::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsColorizeEffect::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QGraphicsColorizeEffect::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQGraphicsColorizeEffect::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QGraphicsColorizeEffect::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQGraphicsColorizeEffect::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QGraphicsColorizeEffect::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QRectF sipQGraphicsColorizeEffect::boundingRectFor(const ::QRectF& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_boundingRectFor);

    if (!sipMeth)
        return ::QGraphicsColorizeEffect::boundingRectFor(a0);

    extern ::QRectF sipVH_QtWidgets_142(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QRectF&);

    return sipVH_QtWidgets_142(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsColorizeEffect::draw(::QPainter*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_draw);

    if (!sipMeth)
    {
        ::QGraphicsColorizeEffect::draw(a0);
        return;
    }

    extern void sipVH_QtWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQGraphicsColorizeEffect::sourceChanged(::QGraphicsEffect::ChangeFlags a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_sourceChanged);

    if (!sipMeth)
    {
        ::QGraphicsColorizeEffect::sourceChanged(a0);
        return;
    }

    extern void sipVH_QtWidgets_143(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QGraphicsEffect::ChangeFlags);

    sipVH_QtWidgets_143(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QGraphicsColorizeEffect_color, "color(self) -> QColor");

extern "C" {static PyObject *meth_QGraphicsColorizeEffect_color(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsColorizeEffect_color(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsColorizeEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsColorizeEffect, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->color());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsColorizeEffect, sipName_color, doc_QGraphicsColorizeEffect_color);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsColorizeEffect_strength, "strength(self) -> float");

extern "C" {static PyObject *meth_QGraphicsColorizeEffect_strength(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsColorizeEffect_strength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGraphicsColorizeEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGraphicsColorizeEffect, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->strength();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsColorizeEffect, sipName_strength, doc_QGraphicsColorizeEffect_strength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsColorizeEffect_setColor, "setColor(self, c: Union[QColor, Qt.GlobalColor])");

extern "C" {static PyObject *meth_QGraphicsColorizeEffect_setColor(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsColorizeEffect_setColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QGraphicsColorizeEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QGraphicsColorizeEffect, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsColorizeEffect, sipName_setColor, doc_QGraphicsColorizeEffect_setColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsColorizeEffect_setStrength, "setStrength(self, strength: float)");

extern "C" {static PyObject *meth_QGraphicsColorizeEffect_setStrength(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsColorizeEffect_setStrength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QGraphicsColorizeEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QGraphicsColorizeEffect, &sipCpp, &a0))
        {
            sipCpp->setStrength(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsColorizeEffect, sipName_setStrength, doc_QGraphicsColorizeEffect_setStrength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGraphicsColorizeEffect_draw, "draw(self, painter: Optional[QPainter])");

extern "C" {static PyObject *meth_QGraphicsColorizeEffect_draw(PyObject *, PyObject *);}
static PyObject *meth_QGraphicsColorizeEffect_draw(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPainter* a0;
        ::QGraphicsColorizeEffect *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QGraphicsColorizeEffect, &sipCpp, sipType_QPainter, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QGraphicsColorizeEffect::draw(a0) : sipCpp->draw(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGraphicsColorizeEffect, sipName_draw, doc_QGraphicsColorizeEffect_draw);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGraphicsColorizeEffect(void *, const sipTypeDef *);}
static void *cast_QGraphicsColorizeEffect(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGraphicsColorizeEffect *sipCpp = reinterpret_cast< ::QGraphicsColorizeEffect *>(sipCppV);

    if (targetType == sipType_QGraphicsColorizeEffect)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QGraphicsEffect)->ctd_cast(static_cast< ::QGraphicsEffect *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGraphicsColorizeEffect(void *, int);}
static void release_QGraphicsColorizeEffect(void *sipCppV, int)
{
    ::QGraphicsColorizeEffect *sipCpp = reinterpret_cast< ::QGraphicsColorizeEffect *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QGraphicsColorizeEffect(Py_ssize_t);}
static void *array_QGraphicsColorizeEffect(Py_ssize_t sipNrElem)
{
    return new ::QGraphicsColorizeEffect[sipNrElem];
}


extern "C" {static void array_delete_QGraphicsColorizeEffect(void *);}
static void array_delete_QGraphicsColorizeEffect(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGraphicsColorizeEffect *>(sipCpp);
}


extern "C" {static void dealloc_QGraphicsColorizeEffect(sipSimpleWrapper *);}
static void dealloc_QGraphicsColorizeEffect(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQGraphicsColorizeEffect *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGraphicsColorizeEffect(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QGraphicsColorizeEffect(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGraphicsColorizeEffect(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQGraphicsColorizeEffect *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQGraphicsColorizeEffect(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGraphicsColorizeEffect[] = {{120, 255, 1}};


static PyMethodDef methods_QGraphicsColorizeEffect[] = {
    {sipName_color, meth_QGraphicsColorizeEffect_color, METH_VARARGS, doc_QGraphicsColorizeEffect_color},
    {sipName_draw, meth_QGraphicsColorizeEffect_draw, METH_VARARGS, doc_QGraphicsColorizeEffect_draw},
    {sipName_setColor, meth_QGraphicsColorizeEffect_setColor, METH_VARARGS, doc_QGraphicsColorizeEffect_setColor},
    {sipName_setStrength, meth_QGraphicsColorizeEffect_setStrength, METH_VARARGS, doc_QGraphicsColorizeEffect_setStrength},
    {sipName_strength, meth_QGraphicsColorizeEffect_strength, METH_VARARGS, doc_QGraphicsColorizeEffect_strength}
};

PyDoc_STRVAR(doc_QGraphicsColorizeEffect, "\1QGraphicsColorizeEffect(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QGraphicsColorizeEffect[] = {
    {"strengthChanged(qreal)", "\1strengthChanged(self, strength: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"colorChanged(QColor)", "\1colorChanged(self, color: Union[QColor, Qt.GlobalColor])", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QGraphicsColorizeEffect = {
    &::QGraphicsColorizeEffect::staticMetaObject,
    0,
    signals_QGraphicsColorizeEffect,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsColorizeEffect = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGraphicsColorizeEffect,
        SIP_NULLPTR,
        &plugin_QGraphicsColorizeEffect,
    },
    {
        sipNameNr_QGraphicsColorizeEffect,
        {0, 0, 1},
        5, methods_QGraphicsColorizeEffect,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGraphicsColorizeEffect,
    -1,
    -1,
    supers_QGraphicsColorizeEffect,
    SIP_NULLPTR,
    init_type_QGraphicsColorizeEffect,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGraphicsColorizeEffect,
    SIP_NULLPTR,
    array_QGraphicsColorizeEffect,
    SIP_NULLPTR,
    release_QGraphicsColorizeEffect,
    cast_QGraphicsColorizeEffect,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGraphicsColorizeEffect,
    sizeof (::QGraphicsColorizeEffect),
};
