/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtTextToSpeechAPI_H
#define _QtTextToSpeechAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_PyQt5_QtTextToSpeech 0
#define sipName_PyQt5_QtTextToSpeech &sipStrings_QtTextToSpeech[0]
#define sipNameNr_QTextToSpeech__State 21
#define sipName_QTextToSpeech__State &sipStrings_QtTextToSpeech[21]
#define sipNameNr_sip_simplewrapper 42
#define sipName_sip_simplewrapper &sipStrings_QtTextToSpeech[42]
#define sipNameNr_60 60
#define sipName_60 &sipStrings_QtTextToSpeech[60]
#define sipNameNr_availableEngines 77
#define sipName_availableEngines &sipStrings_QtTextToSpeech[77]
#define sipNameNr_availableLocales 94
#define sipName_availableLocales &sipStrings_QtTextToSpeech[94]
#define sipNameNr_disconnectNotify 111
#define sipName_disconnectNotify &sipStrings_QtTextToSpeech[111]
#define sipNameNr_128 128
#define sipName_128 &sipStrings_QtTextToSpeech[128]
#define sipNameNr_availableVoices 144
#define sipName_availableVoices &sipStrings_QtTextToSpeech[144]
#define sipNameNr_QVoice__Gender 160
#define sipName_QVoice__Gender &sipStrings_QtTextToSpeech[160]
#define sipNameNr_QTextToSpeech 175
#define sipName_QTextToSpeech &sipStrings_QtTextToSpeech[175]
#define sipNameNr_connectNotify 114
#define sipName_connectNotify &sipStrings_QtTextToSpeech[114]
#define sipNameNr_localeChanged 189
#define sipName_localeChanged &sipStrings_QtTextToSpeech[189]
#define sipNameNr_volumeChanged 203
#define sipName_volumeChanged &sipStrings_QtTextToSpeech[203]
#define sipNameNr_BackendError 217
#define sipName_BackendError &sipStrings_QtTextToSpeech[217]
#define sipNameNr_pitchChanged 230
#define sipName_pitchChanged &sipStrings_QtTextToSpeech[230]
#define sipNameNr_stateChanged 243
#define sipName_stateChanged &sipStrings_QtTextToSpeech[243]
#define sipNameNr_voiceChanged 256
#define sipName_voiceChanged &sipStrings_QtTextToSpeech[256]
#define sipNameNr_QVoice__Age 269
#define sipName_QVoice__Age &sipStrings_QtTextToSpeech[269]
#define sipNameNr_customEvent 281
#define sipName_customEvent &sipStrings_QtTextToSpeech[281]
#define sipNameNr_eventFilter 293
#define sipName_eventFilter &sipStrings_QtTextToSpeech[293]
#define sipNameNr_rateChanged 305
#define sipName_rateChanged &sipStrings_QtTextToSpeech[305]
#define sipNameNr_childEvent 317
#define sipName_childEvent &sipStrings_QtTextToSpeech[317]
#define sipNameNr_genderName 328
#define sipName_genderName &sipStrings_QtTextToSpeech[328]
#define sipNameNr_timerEvent 339
#define sipName_timerEvent &sipStrings_QtTextToSpeech[339]
#define sipNameNr_setLocale 350
#define sipName_setLocale &sipStrings_QtTextToSpeech[350]
#define sipNameNr_setVolume 360
#define sipName_setVolume &sipStrings_QtTextToSpeech[360]
#define sipNameNr_Speaking 370
#define sipName_Speaking &sipStrings_QtTextToSpeech[370]
#define sipNameNr_Teenager 379
#define sipName_Teenager &sipStrings_QtTextToSpeech[379]
#define sipNameNr_setPitch 388
#define sipName_setPitch &sipStrings_QtTextToSpeech[388]
#define sipNameNr_setVoice 397
#define sipName_setVoice &sipStrings_QtTextToSpeech[397]
#define sipNameNr_Unknown 406
#define sipName_Unknown &sipStrings_QtTextToSpeech[406]
#define sipNameNr_ageName 414
#define sipName_ageName &sipStrings_QtTextToSpeech[414]
#define sipNameNr_setRate 422
#define sipName_setRate &sipStrings_QtTextToSpeech[422]
#define sipNameNr_Female 430
#define sipName_Female &sipStrings_QtTextToSpeech[430]
#define sipNameNr_Gender 168
#define sipName_Gender &sipStrings_QtTextToSpeech[168]
#define sipNameNr_Paused 437
#define sipName_Paused &sipStrings_QtTextToSpeech[437]
#define sipNameNr_QVoice 444
#define sipName_QVoice &sipStrings_QtTextToSpeech[444]
#define sipNameNr_Senior 451
#define sipName_Senior &sipStrings_QtTextToSpeech[451]
#define sipNameNr___eq__ 458
#define sipName___eq__ &sipStrings_QtTextToSpeech[458]
#define sipNameNr___ne__ 465
#define sipName___ne__ &sipStrings_QtTextToSpeech[465]
#define sipNameNr_gender 472
#define sipName_gender &sipStrings_QtTextToSpeech[472]
#define sipNameNr_locale 479
#define sipName_locale &sipStrings_QtTextToSpeech[479]
#define sipNameNr_parent 486
#define sipName_parent &sipStrings_QtTextToSpeech[486]
#define sipNameNr_resume 493
#define sipName_resume &sipStrings_QtTextToSpeech[493]
#define sipNameNr_volume 500
#define sipName_volume &sipStrings_QtTextToSpeech[500]
#define sipNameNr_Adult 507
#define sipName_Adult &sipStrings_QtTextToSpeech[507]
#define sipNameNr_Child 513
#define sipName_Child &sipStrings_QtTextToSpeech[513]
#define sipNameNr_Other 519
#define sipName_Other &sipStrings_QtTextToSpeech[519]
#define sipNameNr_Ready 525
#define sipName_Ready &sipStrings_QtTextToSpeech[525]
#define sipNameNr_State 36
#define sipName_State &sipStrings_QtTextToSpeech[36]
#define sipNameNr_event 531
#define sipName_event &sipStrings_QtTextToSpeech[531]
#define sipNameNr_pause 537
#define sipName_pause &sipStrings_QtTextToSpeech[537]
#define sipNameNr_pitch 543
#define sipName_pitch &sipStrings_QtTextToSpeech[543]
#define sipNameNr_state 549
#define sipName_state &sipStrings_QtTextToSpeech[549]
#define sipNameNr_voice 555
#define sipName_voice &sipStrings_QtTextToSpeech[555]
#define sipNameNr_Male 561
#define sipName_Male &sipStrings_QtTextToSpeech[561]
#define sipNameNr_name 566
#define sipName_name &sipStrings_QtTextToSpeech[566]
#define sipNameNr_rate 571
#define sipName_rate &sipStrings_QtTextToSpeech[571]
#define sipNameNr_stop 576
#define sipName_stop &sipStrings_QtTextToSpeech[576]
#define sipNameNr_Age 277
#define sipName_Age &sipStrings_QtTextToSpeech[277]
#define sipNameNr_age 581
#define sipName_age &sipStrings_QtTextToSpeech[581]
#define sipNameNr_say 585
#define sipName_say &sipStrings_QtTextToSpeech[585]

#define sipMalloc                   sipAPI_QtTextToSpeech->api_malloc
#define sipFree                     sipAPI_QtTextToSpeech->api_free
#define sipBuildResult              sipAPI_QtTextToSpeech->api_build_result
#define sipCallMethod               sipAPI_QtTextToSpeech->api_call_method
#define sipCallProcedureMethod      sipAPI_QtTextToSpeech->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtTextToSpeech->api_call_error_handler
#define sipParseResultEx            sipAPI_QtTextToSpeech->api_parse_result_ex
#define sipParseResult              sipAPI_QtTextToSpeech->api_parse_result
#define sipParseArgs                sipAPI_QtTextToSpeech->api_parse_args
#define sipParseKwdArgs             sipAPI_QtTextToSpeech->api_parse_kwd_args
#define sipParsePair                sipAPI_QtTextToSpeech->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtTextToSpeech->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtTextToSpeech->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtTextToSpeech->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtTextToSpeech->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtTextToSpeech->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtTextToSpeech->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtTextToSpeech->api_add_exception
#define sipNoFunction               sipAPI_QtTextToSpeech->api_no_function
#define sipNoMethod                 sipAPI_QtTextToSpeech->api_no_method
#define sipAbstractMethod           sipAPI_QtTextToSpeech->api_abstract_method
#define sipBadClass                 sipAPI_QtTextToSpeech->api_bad_class
#define sipBadCatcherResult         sipAPI_QtTextToSpeech->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtTextToSpeech->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtTextToSpeech->api_bad_operator_arg
#define sipTrace                    sipAPI_QtTextToSpeech->api_trace
#define sipTransferBack             sipAPI_QtTextToSpeech->api_transfer_back
#define sipTransferTo               sipAPI_QtTextToSpeech->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtTextToSpeech->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtTextToSpeech->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtTextToSpeech->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtTextToSpeech->api_voidptr_type
#define sipGetPyObject              sipAPI_QtTextToSpeech->api_get_pyobject
#define sipGetAddress               sipAPI_QtTextToSpeech->api_get_address
#define sipGetMixinAddress          sipAPI_QtTextToSpeech->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtTextToSpeech->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtTextToSpeech->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtTextToSpeech->api_call_hook
#define sipEndThread                sipAPI_QtTextToSpeech->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtTextToSpeech->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtTextToSpeech->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtTextToSpeech->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtTextToSpeech->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtTextToSpeech->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtTextToSpeech->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtTextToSpeech->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtTextToSpeech->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtTextToSpeech->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtTextToSpeech->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtTextToSpeech->api_convert_to_bool
#define sipReleaseType              sipAPI_QtTextToSpeech->api_release_type
#define sipConvertFromType          sipAPI_QtTextToSpeech->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtTextToSpeech->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtTextToSpeech->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtTextToSpeech->api_convert_from_enum
#define sipGetState                 sipAPI_QtTextToSpeech->api_get_state
#define sipExportSymbol             sipAPI_QtTextToSpeech->api_export_symbol
#define sipImportSymbol             sipAPI_QtTextToSpeech->api_import_symbol
#define sipFindType                 sipAPI_QtTextToSpeech->api_find_type
#define sipBytes_AsChar             sipAPI_QtTextToSpeech->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtTextToSpeech->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtTextToSpeech->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtTextToSpeech->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtTextToSpeech->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtTextToSpeech->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtTextToSpeech->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtTextToSpeech->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtTextToSpeech->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtTextToSpeech->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtTextToSpeech->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtTextToSpeech->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtTextToSpeech->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtTextToSpeech->api_get_reference
#define sipKeepReference            sipAPI_QtTextToSpeech->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtTextToSpeech->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtTextToSpeech->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtTextToSpeech->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtTextToSpeech->api_type_scope
#define sipResolveTypedef           sipAPI_QtTextToSpeech->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtTextToSpeech->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtTextToSpeech->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtTextToSpeech->api_init_mixin
#define sipExportModule             sipAPI_QtTextToSpeech->api_export_module
#define sipInitModule               sipAPI_QtTextToSpeech->api_init_module
#define sipGetInterpreter           sipAPI_QtTextToSpeech->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtTextToSpeech->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtTextToSpeech->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtTextToSpeech->api_py_type_dict
#define sipPyTypeName               sipAPI_QtTextToSpeech->api_py_type_name
#define sipGetCFunction             sipAPI_QtTextToSpeech->api_get_c_function
#define sipGetMethod                sipAPI_QtTextToSpeech->api_get_method
#define sipFromMethod               sipAPI_QtTextToSpeech->api_from_method
#define sipGetDate                  sipAPI_QtTextToSpeech->api_get_date
#define sipFromDate                 sipAPI_QtTextToSpeech->api_from_date
#define sipGetDateTime              sipAPI_QtTextToSpeech->api_get_datetime
#define sipFromDateTime             sipAPI_QtTextToSpeech->api_from_datetime
#define sipGetTime                  sipAPI_QtTextToSpeech->api_get_time
#define sipFromTime                 sipAPI_QtTextToSpeech->api_from_time
#define sipIsUserType               sipAPI_QtTextToSpeech->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtTextToSpeech->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtTextToSpeech->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtTextToSpeech->api_unicode_write
#define sipUnicodeData              sipAPI_QtTextToSpeech->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtTextToSpeech->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtTextToSpeech->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtTextToSpeech->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtTextToSpeech->api_is_derived_class
#define sipGetUserObject            sipAPI_QtTextToSpeech->api_get_user_object
#define sipSetUserObject            sipAPI_QtTextToSpeech->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtTextToSpeech->api_register_event_handler
#define sipConvertToArray           sipAPI_QtTextToSpeech->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtTextToSpeech->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtTextToSpeech->api_enable_gc
#define sipPrintObject              sipAPI_QtTextToSpeech->api_print_object
#define sipLong_AsChar              sipAPI_QtTextToSpeech->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtTextToSpeech->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtTextToSpeech->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtTextToSpeech->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtTextToSpeech->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtTextToSpeech->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtTextToSpeech->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtTextToSpeech->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtTextToSpeech->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtTextToSpeech->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtTextToSpeech->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtTextToSpeech->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtTextToSpeech->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtTextToSpeech->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtTextToSpeech->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtTextToSpeech->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtTextToSpeech->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtTextToSpeech->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtTextToSpeech->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtTextToSpeech->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtTextToSpeech->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtTextToSpeech->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtTextToSpeech->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtTextToSpeech->api_connect_rx
#define sipConvertRx                sipAPI_QtTextToSpeech->api_convert_rx
#define sipDisconnectRx             sipAPI_QtTextToSpeech->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtTextToSpeech->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtTextToSpeech->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtTextToSpeech->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtTextToSpeech->api_same_slot
#define sipSaveSlot                 sipAPI_QtTextToSpeech->api_save_slot
#define sipVisitSlot                sipAPI_QtTextToSpeech->api_visit_slot
#define sipIsPyMethod               sipAPI_QtTextToSpeech->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtTextToSpeech[];

#define sipType_QTextToSpeech sipExportedTypes_QtTextToSpeech[0]

#define sipType_QTextToSpeech_State sipExportedTypes_QtTextToSpeech[1]

extern sipClassTypeDef sipTypeDef_QtTextToSpeech_QTextToSpeech;

#define sipType_QVoice sipExportedTypes_QtTextToSpeech[4]

#define sipType_QVoice_Age sipExportedTypes_QtTextToSpeech[5]

#define sipType_QVoice_Gender sipExportedTypes_QtTextToSpeech[6]

extern sipClassTypeDef sipTypeDef_QtTextToSpeech_QVoice;

#define sipType_QVector_0100QVoice sipExportedTypes_QtTextToSpeech[3]

extern sipMappedTypeDef sipTypeDef_QtTextToSpeech_QVector_0100QVoice;

#define sipType_QVector_0100QLocale sipExportedTypes_QtTextToSpeech[2]

extern sipMappedTypeDef sipTypeDef_QtTextToSpeech_QVector_0100QLocale;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtTextToSpeech;
extern sipExportedModuleDef sipModuleAPI_QtTextToSpeech;
extern sipTypeDef *sipExportedTypes_QtTextToSpeech[];

#define sipType_QObject sipImportedTypes_QtTextToSpeech_QtCore[4].it_td

#define sipType_QEvent sipImportedTypes_QtTextToSpeech_QtCore[1].it_td

#define sipType_QTimerEvent sipImportedTypes_QtTextToSpeech_QtCore[7].it_td

#define sipType_QChildEvent sipImportedTypes_QtTextToSpeech_QtCore[0].it_td

#define sipType_QLocale sipImportedTypes_QtTextToSpeech_QtCore[2].it_td

#define sipType_QMetaMethod sipImportedTypes_QtTextToSpeech_QtCore[3].it_td

#define sipType_QStringList sipImportedTypes_QtTextToSpeech_QtCore[6].it_td

#define sipType_QString sipImportedTypes_QtTextToSpeech_QtCore[5].it_td
extern sipImportedTypeDef sipImportedTypes_QtTextToSpeech_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtTextToSpeech_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtTextToSpeech_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtTextToSpeech_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtTextToSpeech_qt_metacast;

#endif
