/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtLocation.h"

#line 31 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoserviceprovider.sip"
#include <qgeoserviceprovider.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProviderPlacesFeatures.cpp"

#line 31 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtLocation/qgeoserviceprovider.sip"
#include <qgeoserviceprovider.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProviderPlacesFeatures.cpp"


extern "C" {static long slot_QGeoServiceProvider_PlacesFeatures___hash__(PyObject *);}
static long slot_QGeoServiceProvider_PlacesFeatures___hash__(PyObject *sipSelf)
{
    ::QGeoServiceProvider::PlacesFeatures *sipCpp = reinterpret_cast< ::QGeoServiceProvider::PlacesFeatures *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoServiceProvider_PlacesFeatures));

    if (!sipCpp)
        return 0L;


    {
        {
            long sipRes = 0;

#line 122 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
        sipRes = sipCpp->operator QGeoServiceProvider::PlacesFeatures::Int();
#line 51 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProviderPlacesFeatures.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static int slot_QGeoServiceProvider_PlacesFeatures___bool__(PyObject *);}
static int slot_QGeoServiceProvider_PlacesFeatures___bool__(PyObject *sipSelf)
{
    ::QGeoServiceProvider::PlacesFeatures *sipCpp = reinterpret_cast< ::QGeoServiceProvider::PlacesFeatures *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoServiceProvider_PlacesFeatures));

    if (!sipCpp)
        return -1;


    {
        {
            int sipRes = 0;

#line 117 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QGeoServiceProvider::PlacesFeatures::Int() != 0);
#line 76 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProviderPlacesFeatures.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QGeoServiceProvider_PlacesFeatures___ne__(PyObject *, PyObject *);}
static PyObject *slot_QGeoServiceProvider_PlacesFeatures___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoServiceProvider::PlacesFeatures *sipCpp = reinterpret_cast< ::QGeoServiceProvider::PlacesFeatures *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoServiceProvider_PlacesFeatures));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider::PlacesFeatures* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QGeoServiceProvider_PlacesFeatures, &a0, &a0State))
        {
            bool sipRes = 0;

#line 112 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QGeoServiceProvider::PlacesFeatures::Int() != a0->operator QGeoServiceProvider::PlacesFeatures::Int());
#line 106 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProviderPlacesFeatures.cpp"
            sipReleaseType(const_cast< ::QGeoServiceProvider::PlacesFeatures *>(a0), sipType_QGeoServiceProvider_PlacesFeatures, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, ne_slot, sipType_QGeoServiceProvider_PlacesFeatures, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QGeoServiceProvider_PlacesFeatures___eq__(PyObject *, PyObject *);}
static PyObject *slot_QGeoServiceProvider_PlacesFeatures___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QGeoServiceProvider::PlacesFeatures *sipCpp = reinterpret_cast< ::QGeoServiceProvider::PlacesFeatures *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoServiceProvider_PlacesFeatures));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoServiceProvider::PlacesFeatures* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QGeoServiceProvider_PlacesFeatures, &a0, &a0State))
        {
            bool sipRes = 0;

#line 107 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QGeoServiceProvider::PlacesFeatures::Int() == a0->operator QGeoServiceProvider::PlacesFeatures::Int());
#line 139 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProviderPlacesFeatures.cpp"
            sipReleaseType(const_cast< ::QGeoServiceProvider::PlacesFeatures *>(a0), sipType_QGeoServiceProvider_PlacesFeatures, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtLocation, eq_slot, sipType_QGeoServiceProvider_PlacesFeatures, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QGeoServiceProvider_PlacesFeatures___ixor__(PyObject *, PyObject *);}
static PyObject *slot_QGeoServiceProvider_PlacesFeatures___ixor__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGeoServiceProvider_PlacesFeatures)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QGeoServiceProvider::PlacesFeatures *sipCpp = reinterpret_cast< ::QGeoServiceProvider::PlacesFeatures *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoServiceProvider_PlacesFeatures));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
        *sipCpp = QGeoServiceProvider::PlacesFeatures(*sipCpp ^ a0);
#line 175 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProviderPlacesFeatures.cpp"

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QGeoServiceProvider_PlacesFeatures___xor__(PyObject *, PyObject *);}
static PyObject *slot_QGeoServiceProvider_PlacesFeatures___xor__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoServiceProvider::PlacesFeatures* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QGeoServiceProvider_PlacesFeatures, &a0, &a0State, &a1))
        {
            ::QGeoServiceProvider::PlacesFeatures*sipRes;

            sipRes = new ::QGeoServiceProvider::PlacesFeatures((*a0 ^ a1));
            sipReleaseType(a0, sipType_QGeoServiceProvider_PlacesFeatures, a0State);

            return sipConvertFromNewType(sipRes, sipType_QGeoServiceProvider_PlacesFeatures, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtLocation, xor_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QGeoServiceProvider_PlacesFeatures___ior__(PyObject *, PyObject *);}
static PyObject *slot_QGeoServiceProvider_PlacesFeatures___ior__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGeoServiceProvider_PlacesFeatures)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QGeoServiceProvider::PlacesFeatures *sipCpp = reinterpret_cast< ::QGeoServiceProvider::PlacesFeatures *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoServiceProvider_PlacesFeatures));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
        *sipCpp = QGeoServiceProvider::PlacesFeatures(*sipCpp | a0);
#line 247 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProviderPlacesFeatures.cpp"

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QGeoServiceProvider_PlacesFeatures___or__(PyObject *, PyObject *);}
static PyObject *slot_QGeoServiceProvider_PlacesFeatures___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoServiceProvider::PlacesFeatures* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QGeoServiceProvider_PlacesFeatures, &a0, &a0State, &a1))
        {
            ::QGeoServiceProvider::PlacesFeatures*sipRes;

            sipRes = new ::QGeoServiceProvider::PlacesFeatures((*a0 | a1));
            sipReleaseType(a0, sipType_QGeoServiceProvider_PlacesFeatures, a0State);

            return sipConvertFromNewType(sipRes, sipType_QGeoServiceProvider_PlacesFeatures, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtLocation, or_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QGeoServiceProvider_PlacesFeatures___iand__(PyObject *, PyObject *);}
static PyObject *slot_QGeoServiceProvider_PlacesFeatures___iand__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGeoServiceProvider_PlacesFeatures)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QGeoServiceProvider::PlacesFeatures *sipCpp = reinterpret_cast< ::QGeoServiceProvider::PlacesFeatures *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoServiceProvider_PlacesFeatures));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
            sipCpp->::QGeoServiceProvider::PlacesFeatures::operator&=(a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QGeoServiceProvider_PlacesFeatures___and__(PyObject *, PyObject *);}
static PyObject *slot_QGeoServiceProvider_PlacesFeatures___and__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoServiceProvider::PlacesFeatures* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QGeoServiceProvider_PlacesFeatures, &a0, &a0State, &a1))
        {
            ::QGeoServiceProvider::PlacesFeatures*sipRes;

            sipRes = new ::QGeoServiceProvider::PlacesFeatures((*a0 & a1));
            sipReleaseType(a0, sipType_QGeoServiceProvider_PlacesFeatures, a0State);

            return sipConvertFromNewType(sipRes, sipType_QGeoServiceProvider_PlacesFeatures, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtLocation, and_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QGeoServiceProvider_PlacesFeatures___invert__(PyObject *);}
static PyObject *slot_QGeoServiceProvider_PlacesFeatures___invert__(PyObject *sipSelf)
{
    ::QGeoServiceProvider::PlacesFeatures *sipCpp = reinterpret_cast< ::QGeoServiceProvider::PlacesFeatures *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoServiceProvider_PlacesFeatures));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            ::QGeoServiceProvider::PlacesFeatures*sipRes;

            sipRes = new ::QGeoServiceProvider::PlacesFeatures(~(*sipCpp));

            return sipConvertFromNewType(sipRes, sipType_QGeoServiceProvider_PlacesFeatures, SIP_NULLPTR);
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QGeoServiceProvider_PlacesFeatures___index__(PyObject *);}
static PyObject *slot_QGeoServiceProvider_PlacesFeatures___index__(PyObject *sipSelf)
{
    ::QGeoServiceProvider::PlacesFeatures *sipCpp = reinterpret_cast< ::QGeoServiceProvider::PlacesFeatures *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoServiceProvider_PlacesFeatures));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            int sipRes = 0;

#line 84 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
        sipRes = sipCpp->operator QGeoServiceProvider::PlacesFeatures::Int();
#line 404 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProviderPlacesFeatures.cpp"

            return PyLong_FromLong(sipRes);
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QGeoServiceProvider_PlacesFeatures___int__(PyObject *);}
static PyObject *slot_QGeoServiceProvider_PlacesFeatures___int__(PyObject *sipSelf)
{
    ::QGeoServiceProvider::PlacesFeatures *sipCpp = reinterpret_cast< ::QGeoServiceProvider::PlacesFeatures *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoServiceProvider_PlacesFeatures));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            int sipRes;

            sipRes = int(*sipCpp);

            return PyLong_FromLong(sipRes);
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoServiceProvider_PlacesFeatures(void *, int);}
static void release_QGeoServiceProvider_PlacesFeatures(void *sipCppV, int)
{
    delete reinterpret_cast< ::QGeoServiceProvider::PlacesFeatures *>(sipCppV);
}


extern "C" {static void *array_QGeoServiceProvider_PlacesFeatures(Py_ssize_t);}
static void *array_QGeoServiceProvider_PlacesFeatures(Py_ssize_t sipNrElem)
{
    return new ::QGeoServiceProvider::PlacesFeatures[sipNrElem];
}


extern "C" {static void array_delete_QGeoServiceProvider_PlacesFeatures(void *);}
static void array_delete_QGeoServiceProvider_PlacesFeatures(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGeoServiceProvider::PlacesFeatures *>(sipCpp);
}


extern "C" {static void assign_QGeoServiceProvider_PlacesFeatures(void *, Py_ssize_t, void *);}
static void assign_QGeoServiceProvider_PlacesFeatures(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QGeoServiceProvider::PlacesFeatures *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QGeoServiceProvider::PlacesFeatures *>(sipSrc);
}


extern "C" {static void *copy_QGeoServiceProvider_PlacesFeatures(const void *, Py_ssize_t);}
static void *copy_QGeoServiceProvider_PlacesFeatures(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QGeoServiceProvider::PlacesFeatures(reinterpret_cast<const ::QGeoServiceProvider::PlacesFeatures *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QGeoServiceProvider_PlacesFeatures(sipSimpleWrapper *);}
static void dealloc_QGeoServiceProvider_PlacesFeatures(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoServiceProvider_PlacesFeatures(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QGeoServiceProvider_PlacesFeatures(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoServiceProvider_PlacesFeatures(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QGeoServiceProvider::PlacesFeatures *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QGeoServiceProvider::PlacesFeatures();

            return sipCpp;
        }
    }

    {
        int a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "i", &a0))
        {
            sipCpp = new ::QGeoServiceProvider::PlacesFeatures(a0);

            return sipCpp;
        }
    }

    {
        const ::QGeoServiceProvider::PlacesFeatures* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QGeoServiceProvider_PlacesFeatures, &a0, &a0State))
        {
            sipCpp = new ::QGeoServiceProvider::PlacesFeatures(*a0);
            sipReleaseType(const_cast< ::QGeoServiceProvider::PlacesFeatures *>(a0), sipType_QGeoServiceProvider_PlacesFeatures, a0State);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static int convertTo_QGeoServiceProvider_PlacesFeatures(PyObject *, void **, int *, PyObject *);}
static int convertTo_QGeoServiceProvider_PlacesFeatures(PyObject *sipPy, void **sipCppPtrV, int *sipIsErr, PyObject *sipTransferObj)
{
    ::QGeoServiceProvider::PlacesFeatures **sipCppPtr = reinterpret_cast< ::QGeoServiceProvider::PlacesFeatures **>(sipCppPtrV);

#line 127 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
// Allow an instance of the base enum whenever a QGeoServiceProvider::PlacesFeatures is expected.

if (sipIsErr == NULL)
    return (PyObject_TypeCheck(sipPy, sipTypeAsPyTypeObject(sipType_QGeoServiceProvider_PlacesFeature)) ||
            sipCanConvertToType(sipPy, sipType_QGeoServiceProvider_PlacesFeatures, SIP_NO_CONVERTORS));

if (PyObject_TypeCheck(sipPy, sipTypeAsPyTypeObject(sipType_QGeoServiceProvider_PlacesFeature)))
{
    *sipCppPtr = new QGeoServiceProvider::PlacesFeatures(int(SIPLong_AsLong(sipPy)));

    return sipGetState(sipTransferObj);
}

*sipCppPtr = reinterpret_cast<QGeoServiceProvider::PlacesFeatures *>(sipConvertToType(sipPy, sipType_QGeoServiceProvider_PlacesFeatures, sipTransferObj, SIP_NO_CONVERTORS, 0, sipIsErr));

return 0;
#line 547 "/build/pyqt5/src/PyQt5-5.15.11/build/QtLocation/sipQtLocationQGeoServiceProviderPlacesFeatures.cpp"
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QGeoServiceProvider_PlacesFeatures[] = {
    {(void *)slot_QGeoServiceProvider_PlacesFeatures___hash__, hash_slot},
    {(void *)slot_QGeoServiceProvider_PlacesFeatures___bool__, bool_slot},
    {(void *)slot_QGeoServiceProvider_PlacesFeatures___ne__, ne_slot},
    {(void *)slot_QGeoServiceProvider_PlacesFeatures___eq__, eq_slot},
    {(void *)slot_QGeoServiceProvider_PlacesFeatures___ixor__, ixor_slot},
    {(void *)slot_QGeoServiceProvider_PlacesFeatures___xor__, xor_slot},
    {(void *)slot_QGeoServiceProvider_PlacesFeatures___ior__, ior_slot},
    {(void *)slot_QGeoServiceProvider_PlacesFeatures___or__, or_slot},
    {(void *)slot_QGeoServiceProvider_PlacesFeatures___iand__, iand_slot},
    {(void *)slot_QGeoServiceProvider_PlacesFeatures___and__, and_slot},
    {(void *)slot_QGeoServiceProvider_PlacesFeatures___invert__, invert_slot},
    {(void *)slot_QGeoServiceProvider_PlacesFeatures___index__, index_slot},
    {(void *)slot_QGeoServiceProvider_PlacesFeatures___int__, int_slot},
    {0, (sipPySlotType)0}
};

PyDoc_STRVAR(doc_QGeoServiceProvider_PlacesFeatures, "\1QGeoServiceProvider.PlacesFeatures()\n"
"QGeoServiceProvider.PlacesFeatures(f: Union[QGeoServiceProvider.PlacesFeatures, QGeoServiceProvider.PlacesFeature])\n"
"QGeoServiceProvider.PlacesFeatures(a0: QGeoServiceProvider.PlacesFeatures)");


static pyqt5ClassPluginDef plugin_QGeoServiceProvider_PlacesFeatures = {
    SIP_NULLPTR,
    1,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtLocation_QGeoServiceProvider_PlacesFeatures = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoServiceProvider__PlacesFeatures,
        SIP_NULLPTR,
        &plugin_QGeoServiceProvider_PlacesFeatures,
    },
    {
        sipNameNr_PlacesFeatures,
        {26, 255, 0},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoServiceProvider_PlacesFeatures,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QGeoServiceProvider_PlacesFeatures,
    init_type_QGeoServiceProvider_PlacesFeatures,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoServiceProvider_PlacesFeatures,
    assign_QGeoServiceProvider_PlacesFeatures,
    array_QGeoServiceProvider_PlacesFeatures,
    copy_QGeoServiceProvider_PlacesFeatures,
    release_QGeoServiceProvider_PlacesFeatures,
    SIP_NULLPTR,
    convertTo_QGeoServiceProvider_PlacesFeatures,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGeoServiceProvider_PlacesFeatures,
    sizeof (::QGeoServiceProvider::PlacesFeatures),
};
