/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtLocationAPI_H
#define _QtLocationAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QGeoServiceProvider__NavigationFeatures 0
#define sipName_QGeoServiceProvider__NavigationFeatures &sipStrings_QtLocation[0]
#define sipNameNr_QGeoServiceProvider__GeocodingFeatures 40
#define sipName_QGeoServiceProvider__GeocodingFeatures &sipStrings_QtLocation[40]
#define sipNameNr_QGeoServiceProvider__NavigationFeature 79
#define sipName_QGeoServiceProvider__NavigationFeature &sipStrings_QtLocation[79]
#define sipNameNr_QGeoServiceProvider__GeocodingFeature 118
#define sipName_QGeoServiceProvider__GeocodingFeature &sipStrings_QtLocation[118]
#define sipNameNr_QGeoRouteRequest__RouteOptimizations 156
#define sipName_QGeoRouteRequest__RouteOptimizations &sipStrings_QtLocation[156]
#define sipNameNr_QGeoServiceProvider__MappingFeatures 193
#define sipName_QGeoServiceProvider__MappingFeatures &sipStrings_QtLocation[193]
#define sipNameNr_QGeoServiceProvider__RoutingFeatures 230
#define sipName_QGeoServiceProvider__RoutingFeatures &sipStrings_QtLocation[230]
#define sipNameNr_267 267
#define sipName_267 &sipStrings_QtLocation[267]
#define sipNameNr_QPlaceSearchResult__SearchResultType 304
#define sipName_QPlaceSearchResult__SearchResultType &sipStrings_QtLocation[304]
#define sipNameNr_QGeoRouteRequest__RouteOptimization 341
#define sipName_QGeoRouteRequest__RouteOptimization &sipStrings_QtLocation[341]
#define sipNameNr_QGeoServiceProvider__MappingFeature 377
#define sipName_QGeoServiceProvider__MappingFeature &sipStrings_QtLocation[377]
#define sipNameNr_QGeoServiceProvider__PlacesFeatures 413
#define sipName_QGeoServiceProvider__PlacesFeatures &sipStrings_QtLocation[413]
#define sipNameNr_QGeoServiceProvider__RoutingFeature 449
#define sipName_QGeoServiceProvider__RoutingFeature &sipStrings_QtLocation[449]
#define sipNameNr_QGeoManeuver__InstructionDirection 485
#define sipName_QGeoManeuver__InstructionDirection &sipStrings_QtLocation[485]
#define sipNameNr_QGeoServiceProvider__PlacesFeature 520
#define sipName_QGeoServiceProvider__PlacesFeature &sipStrings_QtLocation[520]
#define sipNameNr_QPlaceSearchRequest__RelevanceHint 555
#define sipName_QPlaceSearchRequest__RelevanceHint &sipStrings_QtLocation[555]
#define sipNameNr_QGeoRouteRequest__ManeuverDetails 590
#define sipName_QGeoRouteRequest__ManeuverDetails &sipStrings_QtLocation[590]
#define sipNameNr_QGeoRouteRequest__FeatureWeights 624
#define sipName_QGeoRouteRequest__FeatureWeights &sipStrings_QtLocation[624]
#define sipNameNr_QGeoRouteRequest__ManeuverDetail 657
#define sipName_QGeoRouteRequest__ManeuverDetail &sipStrings_QtLocation[657]
#define sipNameNr_QGeoRouteRequest__SegmentDetails 690
#define sipName_QGeoRouteRequest__SegmentDetails &sipStrings_QtLocation[690]
#define sipNameNr_QGeoRouteRequest__FeatureWeight 723
#define sipName_QGeoRouteRequest__FeatureWeight &sipStrings_QtLocation[723]
#define sipNameNr_QGeoRouteRequest__SegmentDetail 755
#define sipName_QGeoRouteRequest__SegmentDetail &sipStrings_QtLocation[755]
#define sipNameNr_QGeoRouteRequest__FeatureTypes 787
#define sipName_QGeoRouteRequest__FeatureTypes &sipStrings_QtLocation[787]
#define sipNameNr_setSupportedRouteOptimizations 818
#define sipName_setSupportedRouteOptimizations &sipStrings_QtLocation[818]
#define sipNameNr_MissingRequiredParameterError 849
#define sipName_MissingRequiredParameterError &sipStrings_QtLocation[849]
#define sipNameNr_QGeoRouteRequest__FeatureType 879
#define sipName_QGeoRouteRequest__FeatureType &sipStrings_QtLocation[879]
#define sipNameNr_QGeoRouteRequest__TravelModes 909
#define sipName_QGeoRouteRequest__TravelModes &sipStrings_QtLocation[909]
#define sipNameNr_QGeoRouteRequest__TravelMode 939
#define sipName_QGeoRouteRequest__TravelMode &sipStrings_QtLocation[939]
#define sipNameNr_QPlaceIdReply__OperationType 968
#define sipName_QPlaceIdReply__OperationType &sipStrings_QtLocation[968]
#define sipNameNr_setDistanceToNextInstruction 997
#define sipName_setDistanceToNextInstruction &sipStrings_QtLocation[997]
#define sipNameNr_PlaceRecommendationsFeature 1026
#define sipName_PlaceRecommendationsFeature &sipStrings_QtLocation[1026]
#define sipNameNr_QPlaceSearchSuggestionReply 1054
#define sipName_QPlaceSearchSuggestionReply &sipStrings_QtLocation[1054]
#define sipNameNr_setSupportedManeuverDetails 1082
#define sipName_setSupportedManeuverDetails &sipStrings_QtLocation[1082]
#define sipNameNr_supportedRouteOptimizations 1110
#define sipName_supportedRouteOptimizations &sipStrings_QtLocation[1110]
#define sipNameNr_ExcludeAreasRoutingFeature 1138
#define sipName_ExcludeAreasRoutingFeature &sipStrings_QtLocation[1138]
#define sipNameNr_QGeoServiceProvider__Error 1165
#define sipName_QGeoServiceProvider__Error &sipStrings_QtLocation[1165]
#define sipNameNr_1192 1192
#define sipName_1192 &sipStrings_QtLocation[1192]
#define sipNameNr_QLocation__VisibilityScope 1219
#define sipName_QLocation__VisibilityScope &sipStrings_QtLocation[1219]
#define sipNameNr_QPlaceProposedSearchResult 1246
#define sipName_QPlaceProposedSearchResult &sipStrings_QtLocation[1246]
#define sipNameNr_setNumberAlternativeRoutes 1273
#define sipName_setNumberAlternativeRoutes &sipStrings_QtLocation[1273]
#define sipNameNr_setSupportedFeatureWeights 1300
#define sipName_setSupportedFeatureWeights &sipStrings_QtLocation[1300]
#define sipNameNr_setSupportedSegmentDetails 1327
#define sipName_setSupportedSegmentDetails &sipStrings_QtLocation[1327]
#define sipNameNr_CategoryDoesNotExistError 1354
#define sipName_CategoryDoesNotExistError &sipStrings_QtLocation[1354]
#define sipNameNr_LocalizedGeocodingFeature 1380
#define sipName_LocalizedGeocodingFeature &sipStrings_QtLocation[1380]
#define sipNameNr_1406 1406
#define sipName_1406 &sipStrings_QtLocation[1406]
#define sipNameNr_availableServiceProviders 1432
#define sipName_availableServiceProviders &sipStrings_QtLocation[1432]
#define sipNameNr_distanceToNextInstruction 1458
#define sipName_distanceToNextInstruction &sipStrings_QtLocation[1458]
#define sipNameNr_AlternativeRoutesFeature 1484
#define sipName_AlternativeRoutesFeature &sipStrings_QtLocation[1484]
#define sipNameNr_OfflineNavigationFeature 1509
#define sipName_OfflineNavigationFeature &sipStrings_QtLocation[1509]
#define sipNameNr_QGeoRoutingManagerEngine 1534
#define sipName_QGeoRoutingManagerEngine &sipStrings_QtLocation[1534]
#define sipNameNr_SearchSuggestionsFeature 1559
#define sipName_SearchSuggestionsFeature &sipStrings_QtLocation[1559]
#define sipNameNr_setSupportedFeatureTypes 1584
#define sipName_setSupportedFeatureTypes &sipStrings_QtLocation[1584]
#define sipNameNr_setTimeToNextInstruction 1609
#define sipName_setTimeToNextInstruction &sipStrings_QtLocation[1609]
#define sipNameNr_supportedManeuverDetails 1634
#define sipName_supportedManeuverDetails &sipStrings_QtLocation[1634]
#define sipNameNr_LocalizedMappingFeature 1659
#define sipName_LocalizedMappingFeature &sipStrings_QtLocation[1659]
#define sipNameNr_LocalizedRoutingFeature 1683
#define sipName_LocalizedRoutingFeature &sipStrings_QtLocation[1683]
#define sipNameNr_OfflineGeocodingFeature 1707
#define sipName_OfflineGeocodingFeature &sipStrings_QtLocation[1707]
#define sipNameNr_OnlineNavigationFeature 1731
#define sipName_OnlineNavigationFeature &sipStrings_QtLocation[1731]
#define sipNameNr_QGeoCodingManagerEngine 1755
#define sipName_QGeoCodingManagerEngine &sipStrings_QtLocation[1755]
#define sipNameNr_1779 1779
#define sipName_1779 &sipStrings_QtLocation[1779]
#define sipNameNr_ReverseGeocodingFeature 1803
#define sipName_ReverseGeocodingFeature &sipStrings_QtLocation[1803]
#define sipNameNr_numberAlternativeRoutes 1827
#define sipName_numberAlternativeRoutes &sipStrings_QtLocation[1827]
#define sipNameNr_removeExtendedAttribute 1851
#define sipName_removeExtendedAttribute &sipStrings_QtLocation[1851]
#define sipNameNr_setSupportedTravelModes 1875
#define sipName_setSupportedTravelModes &sipStrings_QtLocation[1875]
#define sipNameNr_supportedFeatureWeights 1899
#define sipName_supportedFeatureWeights &sipStrings_QtLocation[1899]
#define sipNameNr_supportedSegmentDetails 1923
#define sipName_supportedSegmentDetails &sipStrings_QtLocation[1923]
#define sipNameNr_LocalizedPlacesFeature 1947
#define sipName_LocalizedPlacesFeature &sipStrings_QtLocation[1947]
#define sipNameNr_OnlineGeocodingFeature 1970
#define sipName_OnlineGeocodingFeature &sipStrings_QtLocation[1970]
#define sipNameNr_PlaceDoesNotExistError 1993
#define sipName_PlaceDoesNotExistError &sipStrings_QtLocation[1993]
#define sipNameNr_UnsupportedOptionError 2016
#define sipName_UnsupportedOptionError &sipStrings_QtLocation[2016]
#define sipNameNr_extendedAttributeTypes 2039
#define sipName_extendedAttributeTypes &sipStrings_QtLocation[2039]
#define sipNameNr_setPreviousPageRequest 2062
#define sipName_setPreviousPageRequest &sipStrings_QtLocation[2062]
#define sipNameNr_AnyNavigationFeatures 2085
#define sipName_AnyNavigationFeatures &sipStrings_QtLocation[2085]
#define sipNameNr_DisallowFeatureWeight 2107
#define sipName_DisallowFeatureWeight &sipStrings_QtLocation[2107]
#define sipNameNr_OfflineMappingFeature 2129
#define sipName_OfflineMappingFeature &sipStrings_QtLocation[2129]
#define sipNameNr_OfflineRoutingFeature 2151
#define sipName_OfflineRoutingFeature &sipStrings_QtLocation[2151]
#define sipNameNr_QGeoRouteReply__Error 2173
#define sipName_QGeoRouteReply__Error &sipStrings_QtLocation[2173]
#define sipNameNr_2195 2195
#define sipName_2195 &sipStrings_QtLocation[2195]
#define sipNameNr_QLocation__Visibility 2217
#define sipName_QLocation__Visibility &sipStrings_QtLocation[2217]
#define sipNameNr_RemoveCategoryFeature 2239
#define sipName_RemoveCategoryFeature &sipStrings_QtLocation[2239]
#define sipNameNr_SearchSuggestionReply 1060
#define sipName_SearchSuggestionReply &sipStrings_QtLocation[1060]
#define sipNameNr_UnknownParameterError 2261
#define sipName_UnknownParameterError &sipStrings_QtLocation[2261]
#define sipNameNr_UnspecifiedVisibility 2283
#define sipName_UnspecifiedVisibility &sipStrings_QtLocation[2283]
#define sipNameNr_navigationErrorString 2305
#define sipName_navigationErrorString &sipStrings_QtLocation[2305]
#define sipNameNr_setExtendedAttributes 2327
#define sipName_setExtendedAttributes &sipStrings_QtLocation[2327]
#define sipNameNr_supportedFeatureTypes 2349
#define sipName_supportedFeatureTypes &sipStrings_QtLocation[2349]
#define sipNameNr_timeToNextInstruction 2371
#define sipName_timeToNextInstruction &sipStrings_QtLocation[2371]
#define sipNameNr_AnyGeocodingFeatures 2393
#define sipName_AnyGeocodingFeatures &sipStrings_QtLocation[2393]
#define sipNameNr_InstructionDirection 499
#define sipName_InstructionDirection &sipStrings_QtLocation[499]
#define sipNameNr_LexicalPlaceNameHint 2414
#define sipName_LexicalPlaceNameHint &sipStrings_QtLocation[2414]
#define sipNameNr_MotorPoolLaneFeature 2435
#define sipName_MotorPoolLaneFeature &sipStrings_QtLocation[2435]
#define sipNameNr_NeutralFeatureWeight 2456
#define sipName_NeutralFeatureWeight &sipStrings_QtLocation[2456]
#define sipNameNr_NoNavigationFeatures 2477
#define sipName_NoNavigationFeatures &sipStrings_QtLocation[2477]
#define sipNameNr_NotificationsFeature 2498
#define sipName_NotificationsFeature &sipStrings_QtLocation[2498]
#define sipNameNr_OfflinePlacesFeature 2519
#define sipName_OfflinePlacesFeature &sipStrings_QtLocation[2519]
#define sipNameNr_OnlineMappingFeature 2540
#define sipName_OnlineMappingFeature &sipStrings_QtLocation[2540]
#define sipNameNr_OnlineRoutingFeature 2561
#define sipName_OnlineRoutingFeature &sipStrings_QtLocation[2561]
#define sipNameNr_PlaceMatchingFeature 2582
#define sipName_PlaceMatchingFeature &sipStrings_QtLocation[2582]
#define sipNameNr_ProposedSearchResult 1252
#define sipName_ProposedSearchResult &sipStrings_QtLocation[1252]
#define sipNameNr_PublicTransitFeature 2603
#define sipName_PublicTransitFeature &sipStrings_QtLocation[2603]
#define sipNameNr_QGeoCodeReply__Error 2624
#define sipName_QGeoCodeReply__Error &sipStrings_QtLocation[2624]
#define sipNameNr_2645 2645
#define sipName_2645 &sipStrings_QtLocation[2645]
#define sipNameNr_QPlaceContentRequest 2666
#define sipName_QPlaceContentRequest &sipStrings_QtLocation[2666]
#define sipNameNr_RequireFeatureWeight 2687
#define sipName_RequireFeatureWeight &sipStrings_QtLocation[2687]
#define sipNameNr_geocodingErrorString 2708
#define sipName_geocodingErrorString &sipStrings_QtLocation[2708]
#define sipNameNr_initializeCategories 2729
#define sipName_initializeCategories &sipStrings_QtLocation[2729]
#define sipNameNr_removeContactDetails 2750
#define sipName_removeContactDetails &sipStrings_QtLocation[2750]
#define sipNameNr_setAllowExperimental 2771
#define sipName_setAllowExperimental &sipStrings_QtLocation[2771]
#define sipNameNr_setExtendedAttribute 2792
#define sipName_setExtendedAttribute &sipStrings_QtLocation[2792]
#define sipNameNr_setFirstRouteSegment 2813
#define sipName_setFirstRouteSegment &sipStrings_QtLocation[2813]
#define sipNameNr_setMeasurementSystem 2834
#define sipName_setMeasurementSystem &sipStrings_QtLocation[2834]
#define sipNameNr_setRouteOptimization 2855
#define sipName_setRouteOptimization &sipStrings_QtLocation[2855]
#define sipNameNr_setTotalContentCount 2876
#define sipName_setTotalContentCount &sipStrings_QtLocation[2876]
#define sipNameNr_setWaypointsMetadata 2897
#define sipName_setWaypointsMetadata &sipStrings_QtLocation[2897]
#define sipNameNr_supportedTravelModes 2918
#define sipName_supportedTravelModes &sipStrings_QtLocation[2918]
#define sipNameNr_DirectionLightRight 2939
#define sipName_DirectionLightRight &sipStrings_QtLocation[2939]
#define sipNameNr_DirectionUTurnRight 2959
#define sipName_DirectionUTurnRight &sipStrings_QtLocation[2959]
#define sipNameNr_NoGeocodingFeatures 2979
#define sipName_NoGeocodingFeatures &sipStrings_QtLocation[2979]
#define sipNameNr_OnlinePlacesFeature 2999
#define sipName_OnlinePlacesFeature &sipStrings_QtLocation[2999]
#define sipNameNr_PreferFeatureWeight 3019
#define sipName_PreferFeatureWeight &sipStrings_QtLocation[3019]
#define sipNameNr_PublicTransitTravel 3039
#define sipName_PublicTransitTravel &sipStrings_QtLocation[3039]
#define sipNameNr_QGeoServiceProvider 3059
#define sipName_QGeoServiceProvider &sipStrings_QtLocation[3059]
#define sipNameNr_3079 3079
#define sipName_3079 &sipStrings_QtLocation[3079]
#define sipNameNr_3099 3099
#define sipName_3099 &sipStrings_QtLocation[3099]
#define sipNameNr_QPlaceContactDetail 3119
#define sipName_QPlaceContactDetail &sipStrings_QtLocation[3119]
#define sipNameNr_QPlaceContent__Type 3139
#define sipName_QPlaceContent__Type &sipStrings_QtLocation[3139]
#define sipNameNr_QPlaceManagerEngine 3159
#define sipName_QPlaceManagerEngine &sipStrings_QtLocation[3159]
#define sipNameNr_QPlaceSearchRequest 3179
#define sipName_QPlaceSearchRequest &sipStrings_QtLocation[3179]
#define sipNameNr_RouteUpdatesFeature 3199
#define sipName_RouteUpdatesFeature &sipStrings_QtLocation[3199]
#define sipNameNr_SaveCategoryFeature 3219
#define sipName_SaveCategoryFeature &sipStrings_QtLocation[3219]
#define sipNameNr_UnknownSearchResult 3239
#define sipName_UnknownSearchResult &sipStrings_QtLocation[3239]
#define sipNameNr_appendContactDetail 3259
#define sipName_appendContactDetail &sipStrings_QtLocation[3259]
#define sipNameNr_previousPageRequest 3279
#define sipName_previousPageRequest &sipStrings_QtLocation[3279]
#define sipNameNr_setNextRouteSegment 3299
#define sipName_setNextRouteSegment &sipStrings_QtLocation[3299]
#define sipNameNr_setRecommendationId 3319
#define sipName_setRecommendationId &sipStrings_QtLocation[3319]
#define sipNameNr_AnyMappingFeatures 3339
#define sipName_AnyMappingFeatures &sipStrings_QtLocation[3339]
#define sipNameNr_AnyRoutingFeatures 3358
#define sipName_AnyRoutingFeatures &sipStrings_QtLocation[3358]
#define sipNameNr_AvoidFeatureWeight 3377
#define sipName_AvoidFeatureWeight &sipStrings_QtLocation[3377]
#define sipNameNr_CommunicationError 3396
#define sipName_CommunicationError &sipStrings_QtLocation[3396]
#define sipNameNr_DirectionBearRight 3415
#define sipName_DirectionBearRight &sipStrings_QtLocation[3415]
#define sipNameNr_DirectionHardRight 3434
#define sipName_DirectionHardRight &sipStrings_QtLocation[3434]
#define sipNameNr_DirectionLightLeft 3453
#define sipName_DirectionLightLeft &sipStrings_QtLocation[3453]
#define sipNameNr_DirectionUTurnLeft 3472
#define sipName_DirectionUTurnLeft &sipStrings_QtLocation[3472]
#define sipNameNr_NavigationFeatures 21
#define sipName_NavigationFeatures &sipStrings_QtLocation[21]
#define sipNameNr_QGeoRoutingManager 3491
#define sipName_QGeoRoutingManager &sipStrings_QtLocation[3491]
#define sipNameNr_3510 3510
#define sipName_3510 &sipStrings_QtLocation[3510]
#define sipNameNr_QNavigationManager 3529
#define sipName_QNavigationManager &sipStrings_QtLocation[3529]
#define sipNameNr_QPlaceContentReply 3548
#define sipName_QPlaceContentReply &sipStrings_QtLocation[3548]
#define sipNameNr_QPlaceDetailsReply 3567
#define sipName_QPlaceDetailsReply &sipStrings_QtLocation[3567]
#define sipNameNr_QPlaceMatchRequest 3586
#define sipName_QPlaceMatchRequest &sipStrings_QtLocation[3586]
#define sipNameNr_QPlaceReply__Error 3605
#define sipName_QPlaceReply__Error &sipStrings_QtLocation[3605]
#define sipNameNr_QPlaceSearchResult 3624
#define sipName_QPlaceSearchResult &sipStrings_QtLocation[3624]
#define sipNameNr_RemovePlaceFeature 3643
#define sipName_RemovePlaceFeature &sipStrings_QtLocation[3643]
#define sipNameNr_RouteOptimizations 174
#define sipName_RouteOptimizations &sipStrings_QtLocation[174]
#define sipNameNr_extendedAttributes 3662
#define sipName_extendedAttributes &sipStrings_QtLocation[3662]
#define sipNameNr_mappingErrorString 3681
#define sipName_mappingErrorString &sipStrings_QtLocation[3681]
#define sipNameNr_navigationFeatures 3700
#define sipName_navigationFeatures &sipStrings_QtLocation[3700]
#define sipNameNr_routingErrorString 3719
#define sipName_routingErrorString &sipStrings_QtLocation[3719]
#define sipNameNr_setExtraParameters 3738
#define sipName_setExtraParameters &sipStrings_QtLocation[3738]
#define sipNameNr_setInstructionText 3757
#define sipName_setInstructionText &sipStrings_QtLocation[3757]
#define sipNameNr_setNextPageRequest 3776
#define sipName_setNextPageRequest &sipStrings_QtLocation[3776]
#define sipNameNr_setVisibilityScope 3795
#define sipName_setVisibilityScope &sipStrings_QtLocation[3795]
#define sipNameNr_AnyPlacesFeatures 3814
#define sipName_AnyPlacesFeatures &sipStrings_QtLocation[3814]
#define sipNameNr_DirectionBearLeft 3832
#define sipName_DirectionBearLeft &sipStrings_QtLocation[3832]
#define sipNameNr_DirectionHardLeft 3850
#define sipName_DirectionHardLeft &sipStrings_QtLocation[3850]
#define sipNameNr_EngineNotSetError 3868
#define sipName_EngineNotSetError &sipStrings_QtLocation[3868]
#define sipNameNr_GeocodingFeatures 61
#define sipName_GeocodingFeatures &sipStrings_QtLocation[61]
#define sipNameNr_MostEconomicRoute 3886
#define sipName_MostEconomicRoute &sipStrings_QtLocation[3886]
#define sipNameNr_NavigationFeature 100
#define sipName_NavigationFeature &sipStrings_QtLocation[100]
#define sipNameNr_NoMappingFeatures 3904
#define sipName_NoMappingFeatures &sipStrings_QtLocation[3904]
#define sipNameNr_NoRoutingFeatures 3922
#define sipName_NoRoutingFeatures &sipStrings_QtLocation[3922]
#define sipNameNr_NotSupportedError 3940
#define sipName_NotSupportedError &sipStrings_QtLocation[3940]
#define sipNameNr_PrivateVisibility 3958
#define sipName_PrivateVisibility &sipStrings_QtLocation[3958]
#define sipNameNr_QGeoCodingManager 3976
#define sipName_QGeoCodingManager &sipStrings_QtLocation[3976]
#define sipNameNr_QPlaceReply__Type 3994
#define sipName_QPlaceReply__Type &sipStrings_QtLocation[3994]
#define sipNameNr_QPlaceSearchReply 4012
#define sipName_QPlaceSearchReply &sipStrings_QtLocation[4012]
#define sipNameNr_RouteOptimization 359
#define sipName_RouteOptimization &sipStrings_QtLocation[359]
#define sipNameNr_allowExperimental 4030
#define sipName_allowExperimental &sipStrings_QtLocation[4030]
#define sipNameNr_extendedAttribute 4048
#define sipName_extendedAttribute &sipStrings_QtLocation[4048]
#define sipNameNr_firstRouteSegment 4066
#define sipName_firstRouteSegment &sipStrings_QtLocation[4066]
#define sipNameNr_geocodingFeatures 4084
#define sipName_geocodingFeatures &sipStrings_QtLocation[4084]
#define sipNameNr_measurementSystem 4102
#define sipName_measurementSystem &sipStrings_QtLocation[4102]
#define sipNameNr_navigationManager 4120
#define sipName_navigationManager &sipStrings_QtLocation[4120]
#define sipNameNr_placesErrorString 4138
#define sipName_placesErrorString &sipStrings_QtLocation[4138]
#define sipNameNr_routeOptimization 4156
#define sipName_routeOptimization &sipStrings_QtLocation[4156]
#define sipNameNr_searchSuggestions 4174
#define sipName_searchSuggestions &sipStrings_QtLocation[4174]
#define sipNameNr_setContactDetails 4192
#define sipName_setContactDetails &sipStrings_QtLocation[4192]
#define sipNameNr_setContentContext 4210
#define sipName_setContentContext &sipStrings_QtLocation[4210]
#define sipNameNr_setDetailsFetched 4228
#define sipName_setDetailsFetched &sipStrings_QtLocation[4228]
#define sipNameNr_setManeuverDetail 4246
#define sipName_setManeuverDetail &sipStrings_QtLocation[4246]
#define sipNameNr_sip_simplewrapper 4264
#define sipName_sip_simplewrapper &sipStrings_QtLocation[4264]
#define sipNameNr_totalContentCount 4282
#define sipName_totalContentCount &sipStrings_QtLocation[4282]
#define sipNameNr_waypointsMetadata 4300
#define sipName_waypointsMetadata &sipStrings_QtLocation[4300]
#define sipNameNr_BadArgumentError 4318
#define sipName_BadArgumentError &sipStrings_QtLocation[4318]
#define sipNameNr_BasicSegmentData 4335
#define sipName_BasicSegmentData &sipStrings_QtLocation[4335]
#define sipNameNr_CombinationError 4352
#define sipName_CombinationError &sipStrings_QtLocation[4352]
#define sipNameNr_DeviceVisibility 4369
#define sipName_DeviceVisibility &sipStrings_QtLocation[4369]
#define sipNameNr_DirectionForward 4386
#define sipName_DirectionForward &sipStrings_QtLocation[4386]
#define sipNameNr_GeocodingFeature 139
#define sipName_GeocodingFeature &sipStrings_QtLocation[139]
#define sipNameNr_NoPlacesFeatures 4403
#define sipName_NoPlacesFeatures &sipStrings_QtLocation[4403]
#define sipNameNr_PedestrianTravel 4420
#define sipName_PedestrianTravel &sipStrings_QtLocation[4420]
#define sipNameNr_PermissionsError 4437
#define sipName_PermissionsError &sipStrings_QtLocation[4437]
#define sipNameNr_PublicVisibility 4454
#define sipName_PublicVisibility &sipStrings_QtLocation[4454]
#define sipNameNr_PyQt5_QtLocation 4471
#define sipName_PyQt5_QtLocation &sipStrings_QtLocation[4471]
#define sipNameNr_QGeoRouteRequest 4488
#define sipName_QGeoRouteRequest &sipStrings_QtLocation[4488]
#define sipNameNr_QGeoRouteSegment 4505
#define sipName_QGeoRouteSegment &sipStrings_QtLocation[4505]
#define sipNameNr_4522 4522
#define sipName_4522 &sipStrings_QtLocation[4522]
#define sipNameNr_QPlaceMatchReply 4539
#define sipName_QPlaceMatchReply &sipStrings_QtLocation[4539]
#define sipNameNr_SavePlaceFeature 4556
#define sipName_SavePlaceFeature &sipStrings_QtLocation[4556]
#define sipNameNr_SearchResultType 324
#define sipName_SearchResultType &sipStrings_QtLocation[324]
#define sipNameNr_UnsupportedError 4573
#define sipName_UnsupportedError &sipStrings_QtLocation[4573]
#define sipNameNr_childCategoryIds 4590
#define sipName_childCategoryIds &sipStrings_QtLocation[4590]
#define sipNameNr_constructIconUrl 4607
#define sipName_constructIconUrl &sipStrings_QtLocation[4607]
#define sipNameNr_disconnectNotify 4624
#define sipName_disconnectNotify &sipStrings_QtLocation[4624]
#define sipNameNr_geocodingManager 4641
#define sipName_geocodingManager &sipStrings_QtLocation[4641]
#define sipNameNr_isLegLastSegment 4658
#define sipName_isLegLastSegment &sipStrings_QtLocation[4658]
#define sipNameNr_nextRouteSegment 4675
#define sipName_nextRouteSegment &sipStrings_QtLocation[4675]
#define sipNameNr_parentCategoryId 4692
#define sipName_parentCategoryId &sipStrings_QtLocation[4692]
#define sipNameNr_recommendationId 4709
#define sipName_recommendationId &sipStrings_QtLocation[4709]
#define sipNameNr_setDepartureTime 4726
#define sipName_setDepartureTime &sipStrings_QtLocation[4726]
#define sipNameNr_setFeatureWeight 4743
#define sipName_setFeatureWeight &sipStrings_QtLocation[4743]
#define sipNameNr_setRelevanceHint 4760
#define sipName_setRelevanceHint &sipStrings_QtLocation[4760]
#define sipNameNr_setSearchContext 4777
#define sipName_setSearchContext &sipStrings_QtLocation[4777]
#define sipNameNr_setSearchRequest 4794
#define sipName_setSearchRequest &sipStrings_QtLocation[4794]
#define sipNameNr_setSegmentDetail 4811
#define sipName_setSegmentDetail &sipStrings_QtLocation[4811]
#define sipNameNr_ConnectionError 4828
#define sipName_ConnectionError &sipStrings_QtLocation[4828]
#define sipNameNr_DirtRoadFeature 4844
#define sipName_DirtRoadFeature &sipStrings_QtLocation[4844]
#define sipNameNr_ManeuverDetails 608
#define sipName_ManeuverDetails &sipStrings_QtLocation[608]
#define sipNameNr_MappingFeatures 214
#define sipName_MappingFeatures &sipStrings_QtLocation[214]
#define sipNameNr_MostScenicRoute 4860
#define sipName_MostScenicRoute &sipStrings_QtLocation[4860]
#define sipNameNr_QPlaceAttribute 4876
#define sipName_QPlaceAttribute &sipStrings_QtLocation[4876]
#define sipNameNr_QPlaceEditorial 4892
#define sipName_QPlaceEditorial &sipStrings_QtLocation[4892]
#define sipNameNr_RoutingFeatures 251
#define sipName_RoutingFeatures &sipStrings_QtLocation[251]
#define sipNameNr_UnspecifiedHint 4908
#define sipName_UnspecifiedHint &sipStrings_QtLocation[4908]
#define sipNameNr_VisibilityScope 1230
#define sipName_VisibilityScope &sipStrings_QtLocation[1230]
#define sipNameNr_categoryRemoved 4924
#define sipName_categoryRemoved &sipStrings_QtLocation[4924]
#define sipNameNr_categoryUpdated 4940
#define sipName_categoryUpdated &sipStrings_QtLocation[4940]
#define sipNameNr_childCategories 4956
#define sipName_childCategories &sipStrings_QtLocation[4956]
#define sipNameNr_compatiblePlace 4972
#define sipName_compatiblePlace &sipStrings_QtLocation[4972]
#define sipNameNr_extraParameters 4988
#define sipName_extraParameters &sipStrings_QtLocation[4988]
#define sipNameNr_getPlaceContent 5004
#define sipName_getPlaceContent &sipStrings_QtLocation[5004]
#define sipNameNr_getPlaceDetails 5020
#define sipName_getPlaceDetails &sipStrings_QtLocation[5020]
#define sipNameNr_instructionText 5036
#define sipName_instructionText &sipStrings_QtLocation[5036]
#define sipNameNr_mappingFeatures 5052
#define sipName_mappingFeatures &sipStrings_QtLocation[5052]
#define sipNameNr_navigationError 5068
#define sipName_navigationError &sipStrings_QtLocation[5068]
#define sipNameNr_nextPageRequest 5084
#define sipName_nextPageRequest &sipStrings_QtLocation[5084]
#define sipNameNr_routingFeatures 5100
#define sipName_routingFeatures &sipStrings_QtLocation[5100]
#define sipNameNr_setExcludeAreas 5116
#define sipName_setExcludeAreas &sipStrings_QtLocation[5116]
#define sipNameNr_setOverallRoute 5132
#define sipName_setOverallRoute &sipStrings_QtLocation[5132]
#define sipNameNr_visibilityScope 5148
#define sipName_visibilityScope &sipStrings_QtLocation[5148]
#define sipNameNr_BasicManeuvers 5164
#define sipName_BasicManeuvers &sipStrings_QtLocation[5164]
#define sipNameNr_DirectionRight 5179
#define sipName_DirectionRight &sipStrings_QtLocation[5179]
#define sipNameNr_FeatureWeights 642
#define sipName_FeatureWeights &sipStrings_QtLocation[642]
#define sipNameNr_HighwayFeature 5194
#define sipName_HighwayFeature &sipStrings_QtLocation[5194]
#define sipNameNr_ManeuverDetail 675
#define sipName_ManeuverDetail &sipStrings_QtLocation[675]
#define sipNameNr_MappingFeature 398
#define sipName_MappingFeature &sipStrings_QtLocation[398]
#define sipNameNr_PlacesFeatures 434
#define sipName_PlacesFeatures &sipStrings_QtLocation[434]
#define sipNameNr_QGeoRouteReply 5209
#define sipName_QGeoRouteReply &sipStrings_QtLocation[5209]
#define sipNameNr_QPlaceCategory 5224
#define sipName_QPlaceCategory &sipStrings_QtLocation[5224]
#define sipNameNr_QPlaceSupplier 5239
#define sipName_QPlaceSupplier &sipStrings_QtLocation[5239]
#define sipNameNr_RemoveCategory 5254
#define sipName_RemoveCategory &sipStrings_QtLocation[5254]
#define sipNameNr_RoutingFeature 470
#define sipName_RoutingFeature &sipStrings_QtLocation[470]
#define sipNameNr_SegmentDetails 708
#define sipName_SegmentDetails &sipStrings_QtLocation[708]
#define sipNameNr_TrafficFeature 5269
#define sipName_TrafficFeature &sipStrings_QtLocation[5269]
#define sipNameNr_calculateRoute 5284
#define sipName_calculateRoute &sipStrings_QtLocation[5284]
#define sipNameNr_contactDetails 5299
#define sipName_contactDetails &sipStrings_QtLocation[5299]
#define sipNameNr_contentContext 5314
#define sipName_contentContext &sipStrings_QtLocation[5314]
#define sipNameNr_contentUpdated 5329
#define sipName_contentUpdated &sipStrings_QtLocation[5329]
#define sipNameNr_detailsFetched 5344
#define sipName_detailsFetched &sipStrings_QtLocation[5344]
#define sipNameNr_geocodingError 5359
#define sipName_geocodingError &sipStrings_QtLocation[5359]
#define sipNameNr_managerVersion 5374
#define sipName_managerVersion &sipStrings_QtLocation[5374]
#define sipNameNr_maneuverDetail 5389
#define sipName_maneuverDetail &sipStrings_QtLocation[5389]
#define sipNameNr_matchingPlaces 5404
#define sipName_matchingPlaces &sipStrings_QtLocation[5404]
#define sipNameNr_placesFeatures 5419
#define sipName_placesFeatures &sipStrings_QtLocation[5419]
#define sipNameNr_primaryWebsite 5434
#define sipName_primaryWebsite &sipStrings_QtLocation[5434]
#define sipNameNr_removeCategory 5449
#define sipName_removeCategory &sipStrings_QtLocation[5449]
#define sipNameNr_reverseGeocode 5464
#define sipName_reverseGeocode &sipStrings_QtLocation[5464]
#define sipNameNr_routingManager 5479
#define sipName_routingManager &sipStrings_QtLocation[5479]
#define sipNameNr_setAttribution 5494
#define sipName_setAttribution &sipStrings_QtLocation[5494]
#define sipNameNr_setContentType 5509
#define sipName_setContentType &sipStrings_QtLocation[5509]
#define sipNameNr_setSuggestions 5524
#define sipName_setSuggestions &sipStrings_QtLocation[5524]
#define sipNameNr_setTravelModes 5539
#define sipName_setTravelModes &sipStrings_QtLocation[5539]
#define sipNameNr_AlternativeId 5554
#define sipName_AlternativeId &sipStrings_QtLocation[5554]
#define sipNameNr_BicycleTravel 5568
#define sipName_BicycleTravel &sipStrings_QtLocation[5568]
#define sipNameNr_DirectionLeft 5582
#define sipName_DirectionLeft &sipStrings_QtLocation[5582]
#define sipNameNr_EditorialType 5596
#define sipName_EditorialType &sipStrings_QtLocation[5596]
#define sipNameNr_FeatureWeight 741
#define sipName_FeatureWeight &sipStrings_QtLocation[741]
#define sipNameNr_NoSegmentData 5610
#define sipName_NoSegmentData &sipStrings_QtLocation[5610]
#define sipNameNr_OperationType 983
#define sipName_OperationType &sipStrings_QtLocation[983]
#define sipNameNr_PlacesFeature 541
#define sipName_PlacesFeature &sipStrings_QtLocation[541]
#define sipNameNr_QGeoCodeReply 5624
#define sipName_QGeoCodeReply &sipStrings_QtLocation[5624]
#define sipNameNr_5638 5638
#define sipName_5638 &sipStrings_QtLocation[5638]
#define sipNameNr_QPlaceContent 5652
#define sipName_QPlaceContent &sipStrings_QtLocation[5652]
#define sipNameNr_QPlaceIdReply 5666
#define sipName_QPlaceIdReply &sipStrings_QtLocation[5666]
#define sipNameNr_QPlaceManager 5680
#define sipName_QPlaceManager &sipStrings_QtLocation[5680]
#define sipNameNr_QPlaceRatings 5694
#define sipName_QPlaceRatings &sipStrings_QtLocation[5694]
#define sipNameNr_RelevanceHint 576
#define sipName_RelevanceHint &sipStrings_QtLocation[576]
#define sipNameNr_SegmentDetail 773
#define sipName_SegmentDetail &sipStrings_QtLocation[773]
#define sipNameNr_ShortestRoute 5708
#define sipName_ShortestRoute &sipStrings_QtLocation[5708]
#define sipNameNr_TunnelFeature 5722
#define sipName_TunnelFeature &sipStrings_QtLocation[5722]
#define sipNameNr_categoryAdded 5736
#define sipName_categoryAdded &sipStrings_QtLocation[5736]
#define sipNameNr_connectNotify 4627
#define sipName_connectNotify &sipStrings_QtLocation[4627]
#define sipNameNr_departureTime 5750
#define sipName_departureTime &sipStrings_QtLocation[5750]
#define sipNameNr_featureWeight 5764
#define sipName_featureWeight &sipStrings_QtLocation[5764]
#define sipNameNr_insertContent 5778
#define sipName_insertContent &sipStrings_QtLocation[5778]
#define sipNameNr_operationType 5792
#define sipName_operationType &sipStrings_QtLocation[5792]
#define sipNameNr_relevanceHint 5806
#define sipName_relevanceHint &sipStrings_QtLocation[5806]
#define sipNameNr_searchContext 5820
#define sipName_searchContext &sipStrings_QtLocation[5820]
#define sipNameNr_searchRequest 5834
#define sipName_searchRequest &sipStrings_QtLocation[5834]
#define sipNameNr_segmentDetail 5848
#define sipName_segmentDetail &sipStrings_QtLocation[5848]
#define sipNameNr_setCategories 5862
#define sipName_setCategories &sipStrings_QtLocation[5862]
#define sipNameNr_setCategoryId 5876
#define sipName_setCategoryId &sipStrings_QtLocation[5876]
#define sipNameNr_setParameters 5890
#define sipName_setParameters &sipStrings_QtLocation[5890]
#define sipNameNr_setSearchArea 5904
#define sipName_setSearchArea &sipStrings_QtLocation[5904]
#define sipNameNr_setSearchTerm 5918
#define sipName_setSearchTerm &sipStrings_QtLocation[5918]
#define sipNameNr_setSupplierId 5932
#define sipName_setSupplierId &sipStrings_QtLocation[5932]
#define sipNameNr_setTotalCount 5946
#define sipName_setTotalCount &sipStrings_QtLocation[5946]
#define sipNameNr_setTravelMode 5960
#define sipName_setTravelMode &sipStrings_QtLocation[5960]
#define sipNameNr_setTravelTime 5974
#define sipName_setTravelTime &sipStrings_QtLocation[5974]
#define sipNameNr_setVisibility 5988
#define sipName_setVisibility &sipStrings_QtLocation[5988]
#define sipNameNr_ContentReply 3554
#define sipName_ContentReply &sipStrings_QtLocation[3554]
#define sipNameNr_DetailsReply 3573
#define sipName_DetailsReply &sipStrings_QtLocation[3573]
#define sipNameNr_DistanceHint 6002
#define sipName_DistanceHint &sipStrings_QtLocation[6002]
#define sipNameNr_FastestRoute 6015
#define sipName_FastestRoute &sipStrings_QtLocation[6015]
#define sipNameNr_FeatureTypes 805
#define sipName_FeatureTypes &sipStrings_QtLocation[805]
#define sipNameNr_FerryFeature 6028
#define sipName_FerryFeature &sipStrings_QtLocation[6028]
#define sipNameNr_OpeningHours 6041
#define sipName_OpeningHours &sipStrings_QtLocation[6041]
#define sipNameNr_ParksFeature 6054
#define sipName_ParksFeature &sipStrings_QtLocation[6054]
#define sipNameNr_QGeoManeuver 6067
#define sipName_QGeoManeuver &sipStrings_QtLocation[6067]
#define sipNameNr_QGeoRouteLeg 6080
#define sipName_QGeoRouteLeg &sipStrings_QtLocation[6080]
#define sipNameNr_QPlaceResult 6093
#define sipName_QPlaceResult &sipStrings_QtLocation[6093]
#define sipNameNr_QPlaceReview 6106
#define sipName_QPlaceReview &sipStrings_QtLocation[6106]
#define sipNameNr_SaveCategory 6119
#define sipName_SaveCategory &sipStrings_QtLocation[6119]
#define sipNameNr_UnknownError 6132
#define sipName_UnknownError &sipStrings_QtLocation[6132]
#define sipNameNr_contactTypes 6145
#define sipName_contactTypes &sipStrings_QtLocation[6145]
#define sipNameNr_excludeAreas 6158
#define sipName_excludeAreas &sipStrings_QtLocation[6158]
#define sipNameNr_featureTypes 6171
#define sipName_featureTypes &sipStrings_QtLocation[6171]
#define sipNameNr_mappingError 6184
#define sipName_mappingError &sipStrings_QtLocation[6184]
#define sipNameNr_overallRoute 6197
#define sipName_overallRoute &sipStrings_QtLocation[6197]
#define sipNameNr_placeManager 6210
#define sipName_placeManager &sipStrings_QtLocation[6210]
#define sipNameNr_placeRemoved 6223
#define sipName_placeRemoved &sipStrings_QtLocation[6223]
#define sipNameNr_placeUpdated 6236
#define sipName_placeUpdated &sipStrings_QtLocation[6236]
#define sipNameNr_primaryEmail 6249
#define sipName_primaryEmail &sipStrings_QtLocation[6249]
#define sipNameNr_primaryPhone 6262
#define sipName_primaryPhone &sipStrings_QtLocation[6262]
#define sipNameNr_routingError 6275
#define sipName_routingError &sipStrings_QtLocation[6275]
#define sipNameNr_saveCategory 6288
#define sipName_saveCategory &sipStrings_QtLocation[6288]
#define sipNameNr_setDirection 6301
#define sipName_setDirection &sipStrings_QtLocation[6301]
#define sipNameNr_setLocations 6314
#define sipName_setLocations &sipStrings_QtLocation[6314]
#define sipNameNr_setRouteLegs 6327
#define sipName_setRouteLegs &sipStrings_QtLocation[6327]
#define sipNameNr_setSponsored 6340
#define sipName_setSponsored &sipStrings_QtLocation[6340]
#define sipNameNr_setWaypoints 6353
#define sipName_setWaypoints &sipStrings_QtLocation[6353]
#define sipNameNr_CancelError 6366
#define sipName_CancelError &sipStrings_QtLocation[6366]
#define sipNameNr_FeatureType 897
#define sipName_FeatureType &sipStrings_QtLocation[897]
#define sipNameNr_LoaderError 6378
#define sipName_LoaderError &sipStrings_QtLocation[6378]
#define sipNameNr_NoDirection 6390
#define sipName_NoDirection &sipStrings_QtLocation[6390]
#define sipNameNr_NoManeuvers 6402
#define sipName_NoManeuvers &sipStrings_QtLocation[6402]
#define sipNameNr_PlaceResult 6094
#define sipName_PlaceResult &sipStrings_QtLocation[6094]
#define sipNameNr_QPlaceImage 6414
#define sipName_QPlaceImage &sipStrings_QtLocation[6414]
#define sipNameNr_QPlaceReply 6426
#define sipName_QPlaceReply &sipStrings_QtLocation[6426]
#define sipNameNr_RemovePlace 6438
#define sipName_RemovePlace &sipStrings_QtLocation[6438]
#define sipNameNr_SearchReply 4018
#define sipName_SearchReply &sipStrings_QtLocation[4018]
#define sipNameNr_TollFeature 6450
#define sipName_TollFeature &sipStrings_QtLocation[6450]
#define sipNameNr_TravelModes 927
#define sipName_TravelModes &sipStrings_QtLocation[927]
#define sipNameNr_TruckTravel 6462
#define sipName_TruckTravel &sipStrings_QtLocation[6462]
#define sipNameNr_addLocation 6474
#define sipName_addLocation &sipStrings_QtLocation[6474]
#define sipNameNr_attribution 6486
#define sipName_attribution &sipStrings_QtLocation[6486]
#define sipNameNr_contentType 6498
#define sipName_contentType &sipStrings_QtLocation[6498]
#define sipNameNr_customEvent 6510
#define sipName_customEvent &sipStrings_QtLocation[6510]
#define sipNameNr_dataChanged 6522
#define sipName_dataChanged &sipStrings_QtLocation[6522]
#define sipNameNr_errorString 6534
#define sipName_errorString &sipStrings_QtLocation[6534]
#define sipNameNr_eventFilter 6546
#define sipName_eventFilter &sipStrings_QtLocation[6546]
#define sipNameNr_isSponsored 6558
#define sipName_isSponsored &sipStrings_QtLocation[6558]
#define sipNameNr_managerName 6570
#define sipName_managerName &sipStrings_QtLocation[6570]
#define sipNameNr_placesError 6582
#define sipName_placesError &sipStrings_QtLocation[6582]
#define sipNameNr_removePlace 6594
#define sipName_removePlace &sipStrings_QtLocation[6594]
#define sipNameNr_setCategory 6606
#define sipName_setCategory &sipStrings_QtLocation[6606]
#define sipNameNr_setDateTime 6618
#define sipName_setDateTime &sipStrings_QtLocation[6618]
#define sipNameNr_setDistance 6630
#define sipName_setDistance &sipStrings_QtLocation[6630]
#define sipNameNr_setFinished 6642
#define sipName_setFinished &sipStrings_QtLocation[6642]
#define sipNameNr_setLanguage 6654
#define sipName_setLanguage &sipStrings_QtLocation[6654]
#define sipNameNr_setLegIndex 6666
#define sipName_setLegIndex &sipStrings_QtLocation[6666]
#define sipNameNr_setLocation 6678
#define sipName_setLocation &sipStrings_QtLocation[6678]
#define sipNameNr_setManeuver 6690
#define sipName_setManeuver &sipStrings_QtLocation[6690]
#define sipNameNr_setMimeType 6702
#define sipName_setMimeType &sipStrings_QtLocation[6702]
#define sipNameNr_setPosition 6714
#define sipName_setPosition &sipStrings_QtLocation[6714]
#define sipNameNr_setReviewId 6726
#define sipName_setReviewId &sipStrings_QtLocation[6726]
#define sipNameNr_setSupplier 6738
#define sipName_setSupplier &sipStrings_QtLocation[6738]
#define sipNameNr_setViewport 6750
#define sipName_setViewport &sipStrings_QtLocation[6750]
#define sipNameNr_setWaypoint 6762
#define sipName_setWaypoint &sipStrings_QtLocation[6762]
#define sipNameNr_suggestions 6774
#define sipName_suggestions &sipStrings_QtLocation[6774]
#define sipNameNr_travelModes 6786
#define sipName_travelModes &sipStrings_QtLocation[6786]
#define sipNameNr_updateRoute 6798
#define sipName_updateRoute &sipStrings_QtLocation[6798]
#define sipNameNr_CustomType 6810
#define sipName_CustomType &sipStrings_QtLocation[6810]
#define sipNameNr_MatchReply 4545
#define sipName_MatchReply &sipStrings_QtLocation[4545]
#define sipNameNr_ParseError 6821
#define sipName_ParseError &sipStrings_QtLocation[6821]
#define sipNameNr_QPlaceIcon 6832
#define sipName_QPlaceIcon &sipStrings_QtLocation[6832]
#define sipNameNr_QPlaceUser 6843
#define sipName_QPlaceUser &sipStrings_QtLocation[6843]
#define sipNameNr_ReviewType 6854
#define sipName_ReviewType &sipStrings_QtLocation[6854]
#define sipNameNr_TravelMode 957
#define sipName_TravelMode &sipStrings_QtLocation[957]
#define sipNameNr_Visibility 2228
#define sipName_Visibility &sipStrings_QtLocation[2228]
#define sipNameNr___invert__ 6865
#define sipName___invert__ &sipStrings_QtLocation[6865]
#define sipNameNr_categories 6876
#define sipName_categories &sipStrings_QtLocation[6876]
#define sipNameNr_categoryId 6887
#define sipName_categoryId &sipStrings_QtLocation[6887]
#define sipNameNr_childEvent 6898
#define sipName_childEvent &sipStrings_QtLocation[6898]
#define sipNameNr_isFinished 6909
#define sipName_isFinished &sipStrings_QtLocation[6909]
#define sipNameNr_parameters 6920
#define sipName_parameters &sipStrings_QtLocation[6920]
#define sipNameNr_placeAdded 6931
#define sipName_placeAdded &sipStrings_QtLocation[6931]
#define sipNameNr_primaryFax 6942
#define sipName_primaryFax &sipStrings_QtLocation[6942]
#define sipNameNr_searchArea 6953
#define sipName_searchArea &sipStrings_QtLocation[6953]
#define sipNameNr_searchTerm 6964
#define sipName_searchTerm &sipStrings_QtLocation[6964]
#define sipNameNr_setAverage 6975
#define sipName_setAverage &sipStrings_QtLocation[6975]
#define sipNameNr_setContent 6986
#define sipName_setContent &sipStrings_QtLocation[6986]
#define sipNameNr_setImageId 6997
#define sipName_setImageId &sipStrings_QtLocation[6997]
#define sipNameNr_setLocales 7008
#define sipName_setLocales &sipStrings_QtLocation[7008]
#define sipNameNr_setManager 7019
#define sipName_setManager &sipStrings_QtLocation[7019]
#define sipNameNr_setMaximum 7030
#define sipName_setMaximum &sipStrings_QtLocation[7030]
#define sipNameNr_setPlaceId 7041
#define sipName_setPlaceId &sipStrings_QtLocation[7041]
#define sipNameNr_setRatings 7052
#define sipName_setRatings &sipStrings_QtLocation[7052]
#define sipNameNr_setRequest 7063
#define sipName_setRequest &sipStrings_QtLocation[7063]
#define sipNameNr_setResults 7074
#define sipName_setResults &sipStrings_QtLocation[7074]
#define sipNameNr_setRouteId 7085
#define sipName_setRouteId &sipStrings_QtLocation[7085]
#define sipNameNr_supplierId 7096
#define sipName_supplierId &sipStrings_QtLocation[7096]
#define sipNameNr_timerEvent 7107
#define sipName_timerEvent &sipStrings_QtLocation[7107]
#define sipNameNr_totalCount 7118
#define sipName_totalCount &sipStrings_QtLocation[7118]
#define sipNameNr_travelMode 7129
#define sipName_travelMode &sipStrings_QtLocation[7129]
#define sipNameNr_travelTime 7140
#define sipName_travelTime &sipStrings_QtLocation[7140]
#define sipNameNr_visibility 7151
#define sipName_visibility &sipStrings_QtLocation[7151]
#define sipNameNr_CarTravel 7162
#define sipName_CarTravel &sipStrings_QtLocation[7162]
#define sipNameNr_ImageType 7172
#define sipName_ImageType &sipStrings_QtLocation[7172]
#define sipNameNr_NoFeature 7182
#define sipName_NoFeature &sipStrings_QtLocation[7182]
#define sipNameNr_QGeoRoute 7192
#define sipName_QGeoRoute &sipStrings_QtLocation[7192]
#define sipNameNr_QLocation 7202
#define sipName_QLocation &sipStrings_QtLocation[7202]
#define sipNameNr_SavePlace 7212
#define sipName_SavePlace &sipStrings_QtLocation[7212]
#define sipNameNr_SingleUrl 7222
#define sipName_SingleUrl &sipStrings_QtLocation[7222]
#define sipNameNr___index__ 7232
#define sipName___index__ &sipStrings_QtLocation[7232]
#define sipNameNr_addRoutes 7242
#define sipName_addRoutes &sipStrings_QtLocation[7242]
#define sipNameNr_direction 7252
#define sipName_direction &sipStrings_QtLocation[7252]
#define sipNameNr_locations 7262
#define sipName_locations &sipStrings_QtLocation[7262]
#define sipNameNr_routeLegs 7272
#define sipName_routeLegs &sipStrings_QtLocation[7272]
#define sipNameNr_savePlace 7282
#define sipName_savePlace &sipStrings_QtLocation[7282]
#define sipNameNr_setBounds 7292
#define sipName_setBounds &sipStrings_QtLocation[7292]
#define sipNameNr_setLocale 7302
#define sipName_setLocale &sipStrings_QtLocation[7302]
#define sipNameNr_setOffset 7312
#define sipName_setOffset &sipStrings_QtLocation[7312]
#define sipNameNr_setPlaces 7322
#define sipName_setPlaces &sipStrings_QtLocation[7322]
#define sipNameNr_setRating 7332
#define sipName_setRating &sipStrings_QtLocation[7332]
#define sipNameNr_setRoutes 7342
#define sipName_setRoutes &sipStrings_QtLocation[7342]
#define sipNameNr_setUserId 7352
#define sipName_setUserId &sipStrings_QtLocation[7352]
#define sipNameNr_waypoints 7362
#define sipName_waypoints &sipStrings_QtLocation[7362]
#define sipNameNr_Provider 3070
#define sipName_Provider &sipStrings_QtLocation[3070]
#define sipNameNr___bool__ 7372
#define sipName___bool__ &sipStrings_QtLocation[7372]
#define sipNameNr___hash__ 7381
#define sipName___hash__ &sipStrings_QtLocation[7381]
#define sipNameNr___iand__ 7390
#define sipName___iand__ &sipStrings_QtLocation[7390]
#define sipNameNr___ixor__ 7399
#define sipName___ixor__ &sipStrings_QtLocation[7399]
#define sipNameNr_category 7408
#define sipName_category &sipStrings_QtLocation[7408]
#define sipNameNr_dateTime 7417
#define sipName_dateTime &sipStrings_QtLocation[7417]
#define sipNameNr_distance 7426
#define sipName_distance &sipStrings_QtLocation[7426]
#define sipNameNr_finished 7435
#define sipName_finished &sipStrings_QtLocation[7435]
#define sipNameNr_language 7444
#define sipName_language &sipStrings_QtLocation[7444]
#define sipNameNr_legIndex 7453
#define sipName_legIndex &sipStrings_QtLocation[7453]
#define sipNameNr_location 7462
#define sipName_location &sipStrings_QtLocation[7462]
#define sipNameNr_maneuver 7471
#define sipName_maneuver &sipStrings_QtLocation[7471]
#define sipNameNr_mimeType 7480
#define sipName_mimeType &sipStrings_QtLocation[7480]
#define sipNameNr_parentId 7489
#define sipName_parentId &sipStrings_QtLocation[7489]
#define sipNameNr_position 7498
#define sipName_position &sipStrings_QtLocation[7498]
#define sipNameNr_reviewId 7507
#define sipName_reviewId &sipStrings_QtLocation[7507]
#define sipNameNr_setCount 7516
#define sipName_setCount &sipStrings_QtLocation[7516]
#define sipNameNr_setError 7525
#define sipName_setError &sipStrings_QtLocation[7525]
#define sipNameNr_setLabel 7534
#define sipName_setLabel &sipStrings_QtLocation[7534]
#define sipNameNr_setLimit 7543
#define sipName_setLimit &sipStrings_QtLocation[7543]
#define sipNameNr_setPlace 7552
#define sipName_setPlace &sipStrings_QtLocation[7552]
#define sipNameNr_setTitle 7561
#define sipName_setTitle &sipStrings_QtLocation[7561]
#define sipNameNr_setValue 7570
#define sipName_setValue &sipStrings_QtLocation[7570]
#define sipNameNr_supplier 7579
#define sipName_supplier &sipStrings_QtLocation[7579]
#define sipNameNr_viewport 7588
#define sipName_viewport &sipStrings_QtLocation[7588]
#define sipNameNr_waypoint 7597
#define sipName_waypoint &sipStrings_QtLocation[7597]
#define sipNameNr_IdReply 5672
#define sipName_IdReply &sipStrings_QtLocation[5672]
#define sipNameNr_NoError 7606
#define sipName_NoError &sipStrings_QtLocation[7606]
#define sipNameNr_Payment 7614
#define sipName_Payment &sipStrings_QtLocation[7614]
#define sipNameNr_Website 5441
#define sipName_Website &sipStrings_QtLocation[5441]
#define sipNameNr___and__ 7622
#define sipName___and__ &sipStrings_QtLocation[7622]
#define sipNameNr___int__ 7630
#define sipName___int__ &sipStrings_QtLocation[7630]
#define sipNameNr___ior__ 7638
#define sipName___ior__ &sipStrings_QtLocation[7638]
#define sipNameNr___xor__ 7646
#define sipName___xor__ &sipStrings_QtLocation[7646]
#define sipNameNr_aborted 7654
#define sipName_aborted &sipStrings_QtLocation[7654]
#define sipNameNr_average 7662
#define sipName_average &sipStrings_QtLocation[7662]
#define sipNameNr_content 7670
#define sipName_content &sipStrings_QtLocation[7670]
#define sipNameNr_geocode 7678
#define sipName_geocode &sipStrings_QtLocation[7678]
#define sipNameNr_imageId 7686
#define sipName_imageId &sipStrings_QtLocation[7686]
#define sipNameNr_isEmpty 7694
#define sipName_isEmpty &sipStrings_QtLocation[7694]
#define sipNameNr_isValid 7702
#define sipName_isValid &sipStrings_QtLocation[7702]
#define sipNameNr_locales 7710
#define sipName_locales &sipStrings_QtLocation[7710]
#define sipNameNr_manager 7718
#define sipName_manager &sipStrings_QtLocation[7718]
#define sipNameNr_maximum 7726
#define sipName_maximum &sipStrings_QtLocation[7726]
#define sipNameNr_placeId 7734
#define sipName_placeId &sipStrings_QtLocation[7734]
#define sipNameNr_ratings 7742
#define sipName_ratings &sipStrings_QtLocation[7742]
#define sipNameNr_request 7750
#define sipName_request &sipStrings_QtLocation[7750]
#define sipNameNr_results 7758
#define sipName_results &sipStrings_QtLocation[7758]
#define sipNameNr_routeId 7766
#define sipName_routeId &sipStrings_QtLocation[7766]
#define sipNameNr_setIcon 7774
#define sipName_setIcon &sipStrings_QtLocation[7774]
#define sipNameNr_setName 7782
#define sipName_setName &sipStrings_QtLocation[7782]
#define sipNameNr_setPath 7790
#define sipName_setPath &sipStrings_QtLocation[7790]
#define sipNameNr_setText 7798
#define sipName_setText &sipStrings_QtLocation[7798]
#define sipNameNr_setUser 7806
#define sipName_setUser &sipStrings_QtLocation[7806]
#define sipNameNr_NoType 7814
#define sipName_NoType &sipStrings_QtLocation[7814]
#define sipNameNr_QPlace 7821
#define sipName_QPlace &sipStrings_QtLocation[7821]
#define sipNameNr___eq__ 7828
#define sipName___eq__ &sipStrings_QtLocation[7828]
#define sipNameNr___ne__ 7835
#define sipName___ne__ &sipStrings_QtLocation[7835]
#define sipNameNr___or__ 7842
#define sipName___or__ &sipStrings_QtLocation[7842]
#define sipNameNr_bounds 7849
#define sipName_bounds &sipStrings_QtLocation[7849]
#define sipNameNr_locale 7856
#define sipName_locale &sipStrings_QtLocation[7856]
#define sipNameNr_offset 7863
#define sipName_offset &sipStrings_QtLocation[7863]
#define sipNameNr_parent 7870
#define sipName_parent &sipStrings_QtLocation[7870]
#define sipNameNr_places 7877
#define sipName_places &sipStrings_QtLocation[7877]
#define sipNameNr_rating 7884
#define sipName_rating &sipStrings_QtLocation[7884]
#define sipNameNr_routes 7891
#define sipName_routes &sipStrings_QtLocation[7891]
#define sipNameNr_search 7898
#define sipName_search &sipStrings_QtLocation[7898]
#define sipNameNr_setUrl 7905
#define sipName_setUrl &sipStrings_QtLocation[7905]
#define sipNameNr_userId 7912
#define sipName_userId &sipStrings_QtLocation[7912]
#define sipNameNr_Email 6256
#define sipName_Email &sipStrings_QtLocation[6256]
#define sipNameNr_Error 873
#define sipName_Error &sipStrings_QtLocation[873]
#define sipNameNr_Phone 6269
#define sipName_Phone &sipStrings_QtLocation[6269]
#define sipNameNr_Reply 1076
#define sipName_Reply &sipStrings_QtLocation[1076]
#define sipNameNr_abort 7919
#define sipName_abort &sipStrings_QtLocation[7919]
#define sipNameNr_clear 7925
#define sipName_clear &sipStrings_QtLocation[7925]
#define sipNameNr_count 7931
#define sipName_count &sipStrings_QtLocation[7931]
#define sipNameNr_error 7937
#define sipName_error &sipStrings_QtLocation[7937]
#define sipNameNr_event 7943
#define sipName_event &sipStrings_QtLocation[7943]
#define sipNameNr_label 7949
#define sipName_label &sipStrings_QtLocation[7949]
#define sipNameNr_limit 7955
#define sipName_limit &sipStrings_QtLocation[7955]
#define sipNameNr_place 7961
#define sipName_place &sipStrings_QtLocation[7961]
#define sipNameNr_setId 7967
#define sipName_setId &sipStrings_QtLocation[7967]
#define sipNameNr_title 7973
#define sipName_title &sipStrings_QtLocation[7973]
#define sipNameNr_value 7979
#define sipName_value &sipStrings_QtLocation[7979]
#define sipNameNr_Type 336
#define sipName_Type &sipStrings_QtLocation[336]
#define sipNameNr_icon 7985
#define sipName_icon &sipStrings_QtLocation[7985]
#define sipNameNr_name 7990
#define sipName_name &sipStrings_QtLocation[7990]
#define sipNameNr_path 7995
#define sipName_path &sipStrings_QtLocation[7995]
#define sipNameNr_size 8000
#define sipName_size &sipStrings_QtLocation[8000]
#define sipNameNr_text 4223
#define sipName_text &sipStrings_QtLocation[4223]
#define sipNameNr_type 8005
#define sipName_type &sipStrings_QtLocation[8005]
#define sipNameNr_user 8010
#define sipName_user &sipStrings_QtLocation[8010]
#define sipNameNr_Fax 6949
#define sipName_Fax &sipStrings_QtLocation[6949]
#define sipNameNr_url 8015
#define sipName_url &sipStrings_QtLocation[8015]
#define sipNameNr_id 7707
#define sipName_id &sipStrings_QtLocation[7707]

#define sipMalloc                   sipAPI_QtLocation->api_malloc
#define sipFree                     sipAPI_QtLocation->api_free
#define sipBuildResult              sipAPI_QtLocation->api_build_result
#define sipCallMethod               sipAPI_QtLocation->api_call_method
#define sipCallProcedureMethod      sipAPI_QtLocation->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtLocation->api_call_error_handler
#define sipParseResultEx            sipAPI_QtLocation->api_parse_result_ex
#define sipParseResult              sipAPI_QtLocation->api_parse_result
#define sipParseArgs                sipAPI_QtLocation->api_parse_args
#define sipParseKwdArgs             sipAPI_QtLocation->api_parse_kwd_args
#define sipParsePair                sipAPI_QtLocation->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtLocation->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtLocation->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtLocation->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtLocation->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtLocation->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtLocation->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtLocation->api_add_exception
#define sipNoFunction               sipAPI_QtLocation->api_no_function
#define sipNoMethod                 sipAPI_QtLocation->api_no_method
#define sipAbstractMethod           sipAPI_QtLocation->api_abstract_method
#define sipBadClass                 sipAPI_QtLocation->api_bad_class
#define sipBadCatcherResult         sipAPI_QtLocation->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtLocation->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtLocation->api_bad_operator_arg
#define sipTrace                    sipAPI_QtLocation->api_trace
#define sipTransferBack             sipAPI_QtLocation->api_transfer_back
#define sipTransferTo               sipAPI_QtLocation->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtLocation->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtLocation->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtLocation->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtLocation->api_voidptr_type
#define sipGetPyObject              sipAPI_QtLocation->api_get_pyobject
#define sipGetAddress               sipAPI_QtLocation->api_get_address
#define sipGetMixinAddress          sipAPI_QtLocation->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtLocation->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtLocation->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtLocation->api_call_hook
#define sipEndThread                sipAPI_QtLocation->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtLocation->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtLocation->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtLocation->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtLocation->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtLocation->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtLocation->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtLocation->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtLocation->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtLocation->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtLocation->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtLocation->api_convert_to_bool
#define sipReleaseType              sipAPI_QtLocation->api_release_type
#define sipConvertFromType          sipAPI_QtLocation->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtLocation->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtLocation->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtLocation->api_convert_from_enum
#define sipGetState                 sipAPI_QtLocation->api_get_state
#define sipExportSymbol             sipAPI_QtLocation->api_export_symbol
#define sipImportSymbol             sipAPI_QtLocation->api_import_symbol
#define sipFindType                 sipAPI_QtLocation->api_find_type
#define sipBytes_AsChar             sipAPI_QtLocation->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtLocation->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtLocation->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtLocation->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtLocation->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtLocation->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtLocation->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtLocation->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtLocation->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtLocation->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtLocation->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtLocation->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtLocation->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtLocation->api_get_reference
#define sipKeepReference            sipAPI_QtLocation->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtLocation->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtLocation->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtLocation->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtLocation->api_type_scope
#define sipResolveTypedef           sipAPI_QtLocation->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtLocation->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtLocation->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtLocation->api_init_mixin
#define sipExportModule             sipAPI_QtLocation->api_export_module
#define sipInitModule               sipAPI_QtLocation->api_init_module
#define sipGetInterpreter           sipAPI_QtLocation->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtLocation->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtLocation->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtLocation->api_py_type_dict
#define sipPyTypeName               sipAPI_QtLocation->api_py_type_name
#define sipGetCFunction             sipAPI_QtLocation->api_get_c_function
#define sipGetMethod                sipAPI_QtLocation->api_get_method
#define sipFromMethod               sipAPI_QtLocation->api_from_method
#define sipGetDate                  sipAPI_QtLocation->api_get_date
#define sipFromDate                 sipAPI_QtLocation->api_from_date
#define sipGetDateTime              sipAPI_QtLocation->api_get_datetime
#define sipFromDateTime             sipAPI_QtLocation->api_from_datetime
#define sipGetTime                  sipAPI_QtLocation->api_get_time
#define sipFromTime                 sipAPI_QtLocation->api_from_time
#define sipIsUserType               sipAPI_QtLocation->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtLocation->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtLocation->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtLocation->api_unicode_write
#define sipUnicodeData              sipAPI_QtLocation->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtLocation->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtLocation->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtLocation->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtLocation->api_is_derived_class
#define sipGetUserObject            sipAPI_QtLocation->api_get_user_object
#define sipSetUserObject            sipAPI_QtLocation->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtLocation->api_register_event_handler
#define sipConvertToArray           sipAPI_QtLocation->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtLocation->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtLocation->api_enable_gc
#define sipPrintObject              sipAPI_QtLocation->api_print_object
#define sipLong_AsChar              sipAPI_QtLocation->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtLocation->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtLocation->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtLocation->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtLocation->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtLocation->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtLocation->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtLocation->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtLocation->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtLocation->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtLocation->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtLocation->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtLocation->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtLocation->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtLocation->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtLocation->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtLocation->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtLocation->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtLocation->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtLocation->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtLocation->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtLocation->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtLocation->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtLocation->api_connect_rx
#define sipConvertRx                sipAPI_QtLocation->api_convert_rx
#define sipDisconnectRx             sipAPI_QtLocation->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtLocation->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtLocation->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtLocation->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtLocation->api_same_slot
#define sipSaveSlot                 sipAPI_QtLocation->api_save_slot
#define sipVisitSlot                sipAPI_QtLocation->api_visit_slot
#define sipIsPyMethod               sipAPI_QtLocation->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtLocation[];

#define sipType_QGeoCodeReply sipExportedTypes_QtLocation[0]

#define sipType_QGeoCodeReply_Error sipExportedTypes_QtLocation[1]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoCodeReply;

#define sipType_QGeoCodingManager sipExportedTypes_QtLocation[2]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoCodingManager;

#define sipType_QGeoCodingManagerEngine sipExportedTypes_QtLocation[3]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoCodingManagerEngine;

#define sipType_QGeoManeuver sipExportedTypes_QtLocation[4]

#define sipType_QGeoManeuver_InstructionDirection sipExportedTypes_QtLocation[5]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoManeuver;

#define sipType_QGeoRoute sipExportedTypes_QtLocation[6]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoRoute;

#define sipType_QGeoRouteLeg sipExportedTypes_QtLocation[7]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoRouteLeg;

#define sipType_QGeoRouteReply sipExportedTypes_QtLocation[8]

#define sipType_QGeoRouteReply_Error sipExportedTypes_QtLocation[9]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoRouteReply;

#define sipType_QGeoRouteRequest sipExportedTypes_QtLocation[10]

#define sipType_QGeoRouteRequest_ManeuverDetail sipExportedTypes_QtLocation[15]

#define sipType_QGeoRouteRequest_SegmentDetail sipExportedTypes_QtLocation[19]

#define sipType_QGeoRouteRequest_RouteOptimization sipExportedTypes_QtLocation[17]

#define sipType_QGeoRouteRequest_FeatureWeight sipExportedTypes_QtLocation[13]

#define sipType_QGeoRouteRequest_FeatureType sipExportedTypes_QtLocation[11]

#define sipType_QGeoRouteRequest_TravelMode sipExportedTypes_QtLocation[21]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoRouteRequest;

#define sipType_QGeoRouteRequest_TravelModes sipExportedTypes_QtLocation[22]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoRouteRequest_TravelModes;

#define sipType_QGeoRouteRequest_FeatureTypes sipExportedTypes_QtLocation[12]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoRouteRequest_FeatureTypes;

#define sipType_QGeoRouteRequest_FeatureWeights sipExportedTypes_QtLocation[14]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoRouteRequest_FeatureWeights;

#define sipType_QGeoRouteRequest_RouteOptimizations sipExportedTypes_QtLocation[18]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoRouteRequest_RouteOptimizations;

#define sipType_QGeoRouteRequest_SegmentDetails sipExportedTypes_QtLocation[20]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoRouteRequest_SegmentDetails;

#define sipType_QGeoRouteRequest_ManeuverDetails sipExportedTypes_QtLocation[16]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoRouteRequest_ManeuverDetails;

#define sipType_QGeoRouteSegment sipExportedTypes_QtLocation[23]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoRouteSegment;

#define sipType_QGeoRoutingManager sipExportedTypes_QtLocation[24]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoRoutingManager;

#define sipType_QGeoRoutingManagerEngine sipExportedTypes_QtLocation[25]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoRoutingManagerEngine;

#define sipType_QNavigationManager sipExportedTypes_QtLocation[52]

extern sipClassTypeDef sipTypeDef_QtLocation_QNavigationManager;

#define sipType_QGeoServiceProvider sipExportedTypes_QtLocation[26]

#define sipType_QGeoServiceProvider_NavigationFeature sipExportedTypes_QtLocation[32]

#define sipType_QGeoServiceProvider_PlacesFeature sipExportedTypes_QtLocation[34]

#define sipType_QGeoServiceProvider_MappingFeature sipExportedTypes_QtLocation[30]

#define sipType_QGeoServiceProvider_GeocodingFeature sipExportedTypes_QtLocation[28]

#define sipType_QGeoServiceProvider_RoutingFeature sipExportedTypes_QtLocation[36]

#define sipType_QGeoServiceProvider_Error sipExportedTypes_QtLocation[27]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoServiceProvider;

#define sipType_QGeoServiceProvider_RoutingFeatures sipExportedTypes_QtLocation[37]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoServiceProvider_RoutingFeatures;

#define sipType_QGeoServiceProvider_GeocodingFeatures sipExportedTypes_QtLocation[29]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoServiceProvider_GeocodingFeatures;

#define sipType_QGeoServiceProvider_MappingFeatures sipExportedTypes_QtLocation[31]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoServiceProvider_MappingFeatures;

#define sipType_QGeoServiceProvider_PlacesFeatures sipExportedTypes_QtLocation[35]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoServiceProvider_PlacesFeatures;

#define sipType_QGeoServiceProvider_NavigationFeatures sipExportedTypes_QtLocation[33]

extern sipClassTypeDef sipTypeDef_QtLocation_QGeoServiceProvider_NavigationFeatures;

#define sipType_QLocation sipExportedTypes_QtLocation[48]

#define sipType_QLocation_Visibility sipExportedTypes_QtLocation[49]

extern sipClassTypeDef sipTypeDef_QtLocation_QLocation;

#define sipType_QLocation_VisibilityScope sipExportedTypes_QtLocation[50]

extern sipClassTypeDef sipTypeDef_QtLocation_QLocation_VisibilityScope;

#define sipType_QPlace sipExportedTypes_QtLocation[53]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlace;

#define sipType_QPlaceAttribute sipExportedTypes_QtLocation[54]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceAttribute;

#define sipType_QPlaceCategory sipExportedTypes_QtLocation[55]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceCategory;

#define sipType_QPlaceContactDetail sipExportedTypes_QtLocation[56]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceContactDetail;

#define sipType_QPlaceContent sipExportedTypes_QtLocation[57]

#define sipType_QPlaceContent_Type sipExportedTypes_QtLocation[58]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceContent;

#define sipType_QPlaceReply sipExportedTypes_QtLocation[73]

#define sipType_QPlaceReply_Type sipExportedTypes_QtLocation[75]

#define sipType_QPlaceReply_Error sipExportedTypes_QtLocation[74]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceReply;

#define sipType_QPlaceContentReply sipExportedTypes_QtLocation[59]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceContentReply;

#define sipType_QPlaceContentRequest sipExportedTypes_QtLocation[60]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceContentRequest;

#define sipType_QPlaceDetailsReply sipExportedTypes_QtLocation[61]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceDetailsReply;

#define sipType_QPlaceEditorial sipExportedTypes_QtLocation[62]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceEditorial;

#define sipType_QPlaceIcon sipExportedTypes_QtLocation[63]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceIcon;

#define sipType_QPlaceIdReply sipExportedTypes_QtLocation[64]

#define sipType_QPlaceIdReply_OperationType sipExportedTypes_QtLocation[65]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceIdReply;

#define sipType_QPlaceImage sipExportedTypes_QtLocation[66]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceImage;

#define sipType_QPlaceManager sipExportedTypes_QtLocation[67]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceManager;

#define sipType_QPlaceManagerEngine sipExportedTypes_QtLocation[68]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceManagerEngine;

#define sipType_QPlaceMatchReply sipExportedTypes_QtLocation[69]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceMatchReply;

#define sipType_QPlaceMatchRequest sipExportedTypes_QtLocation[70]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceMatchRequest;

#define sipType_QPlaceSearchResult sipExportedTypes_QtLocation[81]

#define sipType_QPlaceSearchResult_SearchResultType sipExportedTypes_QtLocation[82]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceSearchResult;

#define sipType_QPlaceProposedSearchResult sipExportedTypes_QtLocation[71]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceProposedSearchResult;

#define sipType_QPlaceRatings sipExportedTypes_QtLocation[72]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceRatings;

#define sipType_QPlaceResult sipExportedTypes_QtLocation[76]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceResult;

#define sipType_QPlaceReview sipExportedTypes_QtLocation[77]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceReview;

#define sipType_QPlaceSearchReply sipExportedTypes_QtLocation[78]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceSearchReply;

#define sipType_QPlaceSearchRequest sipExportedTypes_QtLocation[79]

#define sipType_QPlaceSearchRequest_RelevanceHint sipExportedTypes_QtLocation[80]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceSearchRequest;

#define sipType_QPlaceSearchSuggestionReply sipExportedTypes_QtLocation[83]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceSearchSuggestionReply;

#define sipType_QPlaceSupplier sipExportedTypes_QtLocation[84]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceSupplier;

#define sipType_QPlaceUser sipExportedTypes_QtLocation[85]

extern sipClassTypeDef sipTypeDef_QtLocation_QPlaceUser;

#define sipType_QList_0100QPlaceSearchResult sipExportedTypes_QtLocation[46]

extern sipMappedTypeDef sipTypeDef_QtLocation_QList_0100QPlaceSearchResult;

#define sipType_QList_0100QPlace sipExportedTypes_QtLocation[43]

extern sipMappedTypeDef sipTypeDef_QtLocation_QList_0100QPlace;

#define sipType_QList_0100QPlaceContactDetail sipExportedTypes_QtLocation[45]

extern sipMappedTypeDef sipTypeDef_QtLocation_QList_0100QPlaceContactDetail;

#define sipType_QList_0100QPlaceCategory sipExportedTypes_QtLocation[44]

extern sipMappedTypeDef sipTypeDef_QtLocation_QList_0100QPlaceCategory;

#define sipType_QList_0100QVariantMap sipExportedTypes_QtLocation[47]

extern sipMappedTypeDef sipTypeDef_QtLocation_QList_0100QVariantMap;

#define sipType_QList_0100QGeoRouteRequest_FeatureType sipExportedTypes_QtLocation[42]

extern sipMappedTypeDef sipTypeDef_QtLocation_QList_0100QGeoRouteRequest_FeatureType;

#define sipType_QList_0100QGeoRectangle sipExportedTypes_QtLocation[39]

extern sipMappedTypeDef sipTypeDef_QtLocation_QList_0100QGeoRectangle;

#define sipType_QList_0100QGeoRoute sipExportedTypes_QtLocation[40]

extern sipMappedTypeDef sipTypeDef_QtLocation_QList_0100QGeoRoute;

#define sipType_QList_0100QGeoRouteLeg sipExportedTypes_QtLocation[41]

extern sipMappedTypeDef sipTypeDef_QtLocation_QList_0100QGeoRouteLeg;

#define sipType_QList_0100QGeoLocation sipExportedTypes_QtLocation[38]

extern sipMappedTypeDef sipTypeDef_QtLocation_QList_0100QGeoLocation;

#define sipType_QMap_1800_0100QPlaceContent sipExportedTypes_QtLocation[51]

extern sipMappedTypeDef sipTypeDef_QtLocation_QMap_1800_0100QPlaceContent;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtLocation;
extern sipExportedModuleDef sipModuleAPI_QtLocation;
extern sipTypeDef *sipExportedTypes_QtLocation[];

#define sipType_QObject sipImportedTypes_QtLocation_QtCore[7].it_td

#define sipType_QEvent sipImportedTypes_QtLocation_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtLocation_QtCore[11].it_td

#define sipType_QChildEvent sipImportedTypes_QtLocation_QtCore[0].it_td

#define sipType_QDateTime sipImportedTypes_QtLocation_QtCore[1].it_td

#define sipType_QLocale sipImportedTypes_QtLocation_QtCore[4].it_td

#define sipType_QLocale_MeasurementSystem sipImportedTypes_QtLocation_QtCore[5].it_td

#define sipType_QMetaMethod sipImportedTypes_QtLocation_QtCore[6].it_td

#define sipType_QSize sipImportedTypes_QtLocation_QtCore[8].it_td

#define sipType_QUrl sipImportedTypes_QtLocation_QtCore[12].it_td

#define sipType_QVariant sipImportedTypes_QtLocation_QtCore[13].it_td

#define sipType_QList_0100QLocale sipImportedTypes_QtLocation_QtCore[3].it_td

#define sipType_QVariantMap sipImportedTypes_QtLocation_QtCore[14].it_td

#define sipType_QStringList sipImportedTypes_QtLocation_QtCore[10].it_td

#define sipType_QString sipImportedTypes_QtLocation_QtCore[9].it_td
extern sipImportedTypeDef sipImportedTypes_QtLocation_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtLocation_QtCore[];

#define sipType_QGeoAddress sipImportedTypes_QtLocation_QtPositioning[0].it_td

#define sipType_QGeoShape sipImportedTypes_QtLocation_QtPositioning[4].it_td

#define sipType_QGeoCoordinate sipImportedTypes_QtLocation_QtPositioning[1].it_td

#define sipType_QGeoLocation sipImportedTypes_QtLocation_QtPositioning[2].it_td

#define sipType_QGeoRectangle sipImportedTypes_QtLocation_QtPositioning[3].it_td

#define sipType_QList_0100QGeoCoordinate sipImportedTypes_QtLocation_QtPositioning[5].it_td
extern sipImportedTypeDef sipImportedTypes_QtLocation_QtPositioning[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtLocation_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtLocation_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtLocation_qt_metacast;

#endif
