/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPI_QOpenGLFunctions_2_1.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
#include <qopenglfunctions_2_1.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"



class sipQOpenGLFunctions_2_1 : public ::QOpenGLFunctions_2_1
{
public:
    sipQOpenGLFunctions_2_1();
    virtual ~sipQOpenGLFunctions_2_1();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool initializeOpenGLFunctions() SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQOpenGLFunctions_2_1(const sipQOpenGLFunctions_2_1 &);
    sipQOpenGLFunctions_2_1 &operator = (const sipQOpenGLFunctions_2_1 &);

    char sipPyMethods[1];
};

sipQOpenGLFunctions_2_1::sipQOpenGLFunctions_2_1(): ::QOpenGLFunctions_2_1(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQOpenGLFunctions_2_1::~sipQOpenGLFunctions_2_1()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

bool sipQOpenGLFunctions_2_1::initializeOpenGLFunctions()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_initializeOpenGLFunctions);

    if (!sipMeth)
        return ::QOpenGLFunctions_2_1::initializeOpenGLFunctions();

    extern bool sipVH__QOpenGLFunctions_2_1_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH__QOpenGLFunctions_2_1_0(sipGILState, sipImportedVirtErrorHandlers__QOpenGLFunctions_2_1_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_initializeOpenGLFunctions, "initializeOpenGLFunctions(self) -> bool");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_initializeOpenGLFunctions(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_initializeOpenGLFunctions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QOpenGLFunctions_2_1::initializeOpenGLFunctions() : sipCpp->initializeOpenGLFunctions());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_initializeOpenGLFunctions, doc_QOpenGLFunctions_2_1_initializeOpenGLFunctions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glViewport, "glViewport(self, x: int, y: int, width: int, height: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glViewport(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glViewport(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLsizei a2;
        ::GLsizei a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glViewport(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glViewport, doc_QOpenGLFunctions_2_1_glViewport);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDepthRange, "glDepthRange(self, nearVal: float, farVal: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDepthRange(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDepthRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glDepthRange(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDepthRange, doc_QOpenGLFunctions_2_1_glDepthRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIsEnabled, "glIsEnabled(self, cap: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIsEnabled(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIsEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsEnabled(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIsEnabled, doc_QOpenGLFunctions_2_1_glIsEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetTexLevelParameteriv, "glGetTexLevelParameteriv(self, target: int, level: int, pname: int) -> Optional[int]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetTexLevelParameteriv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetTexLevelParameteriv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLenum a2;
        PyObject * a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            int sipIsErr = 0;

#line 40 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint params[1];
            
        sipCpp->glGetTexLevelParameteriv(a0, a1, a2, params);
        
        a3 = qpyopengl_from_GLint(&sipIsErr, params, 1);
#line 216 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a3;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetTexLevelParameteriv, doc_QOpenGLFunctions_2_1_glGetTexLevelParameteriv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetTexLevelParameterfv, "glGetTexLevelParameterfv(self, target: int, level: int, pname: int) -> Optional[float]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetTexLevelParameterfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetTexLevelParameterfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLenum a2;
        PyObject * a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            int sipIsErr = 0;

#line 49 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLfloat params[1];
            
        sipCpp->glGetTexLevelParameterfv(a0, a1, a2, params);
        
        a3 = qpyopengl_from_GLfloat(&sipIsErr, params, 1);
#line 255 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a3;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetTexLevelParameterfv, doc_QOpenGLFunctions_2_1_glGetTexLevelParameterfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetTexParameteriv, "glGetTexParameteriv(self, target: int, pname: int) -> Optional[Union[int, tuple[int, int, int, int]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetTexParameteriv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetTexParameteriv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 58 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        #if defined(GL_TEXTURE_SWIZZLE_RGBA) || defined(GL_TEXTURE_BORDER_COLOR)
        #if defined(GL_TEXTURE_SWIZZLE_RGBA)
        case GL_TEXTURE_SWIZZLE_RGBA:
        #endif
        #if defined(GL_TEXTURE_BORDER_COLOR)
        case GL_TEXTURE_BORDER_COLOR:
        #endif
            nr_params = 4;
            break;
        #endif
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetTexParameteriv(a0, a1, params);
        
        a2 = qpyopengl_from_GLint(&sipIsErr, params, nr_params);
#line 311 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetTexParameteriv, doc_QOpenGLFunctions_2_1_glGetTexParameteriv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetTexParameterfv, "glGetTexParameterfv(self, target: int, pname: int) -> Optional[Union[float, tuple[float, float, float, float]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetTexParameterfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetTexParameterfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 85 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLfloat params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        #if defined(GL_TEXTURE_SWIZZLE_RGBA) || defined(GL_TEXTURE_BORDER_COLOR)
        #if defined(GL_TEXTURE_SWIZZLE_RGBA)
        case GL_TEXTURE_SWIZZLE_RGBA:
        #endif
        #if defined(GL_TEXTURE_BORDER_COLOR)
        case GL_TEXTURE_BORDER_COLOR:
        #endif
            nr_params = 4;
            break;
        #endif
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetTexParameterfv(a0, a1, params);
        
        a2 = qpyopengl_from_GLfloat(&sipIsErr, params, nr_params);
#line 367 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetTexParameterfv, doc_QOpenGLFunctions_2_1_glGetTexParameterfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetString, "glGetString(self, name: int) -> Optional[str]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetString(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            const char*sipRes = 0;

#line 112 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        sipRes = reinterpret_cast<const char *>(sipCpp->glGetString(a0));
#line 399 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipRes == SIP_NULLPTR)
            {
                Py_INCREF(Py_None);
                return Py_None;
            }

            return PyUnicode_DecodeASCII(sipRes, strlen(sipRes), SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetString, doc_QOpenGLFunctions_2_1_glGetString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetIntegerv, "glGetIntegerv(self, pname: int) -> Optional[Union[int, tuple[int, ...]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetIntegerv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetIntegerv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            int sipIsErr = 0;

#line 117 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint fixed_params[16], *params;
        GLint nr_params;
        GLenum query;
        
        nr_params = qpyopengl_get(a0, &query);
        
        if (nr_params == 0)
        {
            sipCpp->glGetIntegerv(query, &nr_params);
            params = new GLint[nr_params];
        }
        else
        {
            params = fixed_params;
        }
        
        sipCpp->glGetIntegerv(a0, params);
        a1 = qpyopengl_from_GLint(&sipIsErr, params, nr_params);
            
        if (params != fixed_params)
            delete[] params;
#line 455 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a1;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetIntegerv, doc_QOpenGLFunctions_2_1_glGetIntegerv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetFloatv, "glGetFloatv(self, pname: int) -> Optional[Union[float, tuple[float, ...]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetFloatv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetFloatv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            int sipIsErr = 0;

#line 142 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLfloat fixed_params[16], *params;
        GLint nr_params;
        GLenum query;
        
        nr_params = qpyopengl_get(a0, &query);
        
        if (nr_params == 0)
        {
            sipCpp->glGetIntegerv(query, &nr_params);
            params = new GLfloat[nr_params];
        }
        else
        {
            params = fixed_params;
        }
        
        sipCpp->glGetFloatv(a0, params);
        a1 = qpyopengl_from_GLfloat(&sipIsErr, params, nr_params);
            
        if (params != fixed_params)
            delete[] params;
#line 508 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a1;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetFloatv, doc_QOpenGLFunctions_2_1_glGetFloatv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetError, "glGetError(self) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetError(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetError(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp))
        {
            ::GLenum sipRes;

            sipRes = sipCpp->glGetError();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetError, doc_QOpenGLFunctions_2_1_glGetError);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetDoublev, "glGetDoublev(self, pname: int) -> Optional[Union[float, tuple[float, ...]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetDoublev(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetDoublev(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            int sipIsErr = 0;

#line 168 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLdouble fixed_params[16], *params;
        GLint nr_params;
        GLenum query;
        
        nr_params = qpyopengl_get(a0, &query);
        
        if (nr_params == 0)
        {
            sipCpp->glGetIntegerv(query, &nr_params);
            params = new GLdouble[nr_params];
        }
        else
        {
            params = fixed_params;
        }
        
        sipCpp->glGetDoublev(a0, params);
        a1 = qpyopengl_from_GLdouble(&sipIsErr, params, nr_params);
            
        if (params != fixed_params)
            delete[] params;
#line 587 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a1;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetDoublev, doc_QOpenGLFunctions_2_1_glGetDoublev);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetBooleanv, "glGetBooleanv(self, pname: int) -> Optional[Union[bool, tuple[bool, ...]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetBooleanv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetBooleanv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            int sipIsErr = 0;

#line 193 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLboolean fixed_params[16], *params;
        GLint nr_params;
        GLenum query;
        
        nr_params = qpyopengl_get(a0, &query);
        
        if (nr_params == 0)
        {
            sipCpp->glGetIntegerv(query, &nr_params);
            params = new GLboolean[nr_params];
        }
        else
        {
            params = fixed_params;
        }
        
        sipCpp->glGetBooleanv(a0, params);
        a1 = qpyopengl_from_GLboolean(&sipIsErr, params, nr_params);
            
        if (params != fixed_params)
            delete[] params;
#line 640 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a1;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetBooleanv, doc_QOpenGLFunctions_2_1_glGetBooleanv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glReadPixels, "glReadPixels(self, x: int, y: int, width: int, height: int, format: int, type: int) -> Union[tuple[float, ...], tuple[int, ...]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glReadPixels(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glReadPixels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLsizei a2;
        ::GLsizei a3;
        ::GLenum a4;
        ::GLenum a5;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiiiuu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            PyObject * sipRes = SIP_NULLPTR;
            int sipIsErr = 0;

#line 218 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        int components;
        
        switch (a4)
        {
            case GL_BGR:
            case GL_RGB:
            {
                components = 3;
                break;
            }
        
            case GL_BGRA:
            case GL_RGBA:
            {
                components = 4;
                break;
            }
        
            case GL_RED:
            case GL_GREEN:
            case GL_BLUE:
            case GL_ALPHA:
            case GL_DEPTH_COMPONENT:
            case GL_STENCIL_INDEX:
            case GL_DEPTH_STENCIL:
            {
                components = 1;
                break;
            }
        
            default:
                components = 0;
        }
        
        Py_ssize_t length = components * a2 * a3;
        
        switch (a5)
        {
            case GL_FLOAT:
            {
                GLfloat *data = new GLfloat[length];
        
                sipCpp->glReadPixels(a0, a1, a2, a3, a4, a5, data);
                sipRes = qpyopengl_from_GLfloat(&sipIsErr, data, length);
                delete [] data;
        
                break;
            }
        
            case GL_INT:
            {
                GLint *data = new GLint[length];
        
                sipCpp->glReadPixels(a0, a1, a2, a3, a4, a5, data);
                sipRes = qpyopengl_from_GLint(&sipIsErr, data, length);
                delete [] data;
        
                break;
            }
        
            case GL_UNSIGNED_INT:
            case GL_UNSIGNED_INT_8_8_8_8:
            case GL_UNSIGNED_INT_8_8_8_8_REV:
            case GL_UNSIGNED_INT_10_10_10_2:
            case GL_UNSIGNED_INT_2_10_10_10_REV:
            case GL_UNSIGNED_INT_24_8:
            case GL_UNSIGNED_INT_10F_11F_11F_REV:
            case GL_UNSIGNED_INT_5_9_9_9_REV:
            {
                GLuint *data = new GLuint[length];
        
                sipCpp->glReadPixels(a0, a1, a2, a3, a4, a5, data);
                sipRes = qpyopengl_from_GLuint(&sipIsErr, data, length);
                delete [] data;
        
                break;
            }
        
            case GL_SHORT:
            case GL_UNSIGNED_SHORT:
            case GL_UNSIGNED_SHORT_5_6_5:
            case GL_UNSIGNED_SHORT_5_6_5_REV:
            case GL_UNSIGNED_SHORT_4_4_4_4:
            case GL_UNSIGNED_SHORT_4_4_4_4_REV:
            case GL_UNSIGNED_SHORT_5_5_5_1:
            case GL_UNSIGNED_SHORT_1_5_5_5_REV:
            case GL_BYTE:
            case GL_UNSIGNED_BYTE:
            case GL_UNSIGNED_BYTE_3_3_2:
            case GL_UNSIGNED_BYTE_2_3_3_REV:
            case GL_HALF_FLOAT:
            case GL_FLOAT_32_UNSIGNED_INT_24_8_REV:
            default:
                sipIsErr = 1;
                PyErr_SetString(PyExc_ValueError, "pixel data format not supported");
        }
#line 773 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glReadPixels, doc_QOpenGLFunctions_2_1_glReadPixels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glReadBuffer, "glReadBuffer(self, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glReadBuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glReadBuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glReadBuffer(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glReadBuffer, doc_QOpenGLFunctions_2_1_glReadBuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPixelStorei, "glPixelStorei(self, pname: int, param: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPixelStorei(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPixelStorei(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bui", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glPixelStorei(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPixelStorei, doc_QOpenGLFunctions_2_1_glPixelStorei);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPixelStoref, "glPixelStoref(self, pname: int, param: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPixelStoref(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPixelStoref(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glPixelStoref(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPixelStoref, doc_QOpenGLFunctions_2_1_glPixelStoref);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDepthFunc, "glDepthFunc(self, func: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDepthFunc(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDepthFunc(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glDepthFunc(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDepthFunc, doc_QOpenGLFunctions_2_1_glDepthFunc);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glStencilOp, "glStencilOp(self, fail: int, zfail: int, zpass: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glStencilOp(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glStencilOp(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLenum a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glStencilOp(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glStencilOp, doc_QOpenGLFunctions_2_1_glStencilOp);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glStencilFunc, "glStencilFunc(self, func: int, ref: int, mask: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glStencilFunc(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glStencilFunc(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLuint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glStencilFunc(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glStencilFunc, doc_QOpenGLFunctions_2_1_glStencilFunc);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLogicOp, "glLogicOp(self, opcode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLogicOp(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLogicOp(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glLogicOp(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLogicOp, doc_QOpenGLFunctions_2_1_glLogicOp);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glBlendFunc, "glBlendFunc(self, sfactor: int, dfactor: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glBlendFunc(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glBlendFunc(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glBlendFunc(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glBlendFunc, doc_QOpenGLFunctions_2_1_glBlendFunc);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glFlush, "glFlush(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glFlush(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glFlush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp))
        {
            sipCpp->glFlush();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glFlush, doc_QOpenGLFunctions_2_1_glFlush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glFinish, "glFinish(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glFinish(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glFinish(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp))
        {
            sipCpp->glFinish();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glFinish, doc_QOpenGLFunctions_2_1_glFinish);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEnable, "glEnable(self, cap: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEnable(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEnable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glEnable(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEnable, doc_QOpenGLFunctions_2_1_glEnable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDisable, "glDisable(self, cap: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDisable(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDisable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glDisable(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDisable, doc_QOpenGLFunctions_2_1_glDisable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDepthMask, "glDepthMask(self, flag: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDepthMask(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDepthMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLboolean a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BM", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glDepthMask(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDepthMask, doc_QOpenGLFunctions_2_1_glDepthMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColorMask, "glColorMask(self, red: int, green: int, blue: int, alpha: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColorMask(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColorMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLboolean a0;
        ::GLboolean a1;
        ::GLboolean a2;
        ::GLboolean a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BMMMM", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glColorMask(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColorMask, doc_QOpenGLFunctions_2_1_glColorMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glStencilMask, "glStencilMask(self, mask: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glStencilMask(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glStencilMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glStencilMask(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glStencilMask, doc_QOpenGLFunctions_2_1_glStencilMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glClearDepth, "glClearDepth(self, depth: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glClearDepth(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glClearDepth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glClearDepth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glClearDepth, doc_QOpenGLFunctions_2_1_glClearDepth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glClearStencil, "glClearStencil(self, s: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glClearStencil(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glClearStencil(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glClearStencil(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glClearStencil, doc_QOpenGLFunctions_2_1_glClearStencil);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glClearColor, "glClearColor(self, red: float, green: float, blue: float, alpha: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glClearColor(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glClearColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bffff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glClearColor(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glClearColor, doc_QOpenGLFunctions_2_1_glClearColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glClear, "glClear(self, mask: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glClear(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glClear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLbitfield a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glClear(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glClear, doc_QOpenGLFunctions_2_1_glClear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDrawBuffer, "glDrawBuffer(self, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDrawBuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDrawBuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glDrawBuffer(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDrawBuffer, doc_QOpenGLFunctions_2_1_glDrawBuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexImage2D, "glTexImage2D(self, target: int, level: int, internalformat: int, width: int, height: int, border: int, format: int, type: int, pixels: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexImage2D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexImage2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLsizei a3;
        ::GLsizei a4;
        ::GLint a5;
        ::GLenum a6;
        ::GLenum a7;
        PyObject * a8;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiiuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8))
        {
            sipErrorState sipError = sipErrorNone;

#line 338 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a8, a7, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexImage2D(a0, a1, a2, a3, a4, a5, a6, a7, array);
#line 1347 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexImage2D, doc_QOpenGLFunctions_2_1_glTexImage2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexImage1D, "glTexImage1D(self, target: int, level: int, internalformat: int, width: int, border: int, format: int, type: int, pixels: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexImage1D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexImage1D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLsizei a3;
        ::GLint a4;
        ::GLenum a5;
        ::GLenum a6;
        PyObject * a7;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7))
        {
            sipErrorState sipError = sipErrorNone;

#line 346 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a7, a6, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexImage1D(a0, a1, a2, a3, a4, a5, a6, array);
#line 1395 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexImage1D, doc_QOpenGLFunctions_2_1_glTexImage1D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexParameteriv, "glTexParameteriv(self, target: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexParameteriv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexParameteriv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 354 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexParameteriv(a0, a1, reinterpret_cast<const GLint *>(array));
#line 1438 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexParameteriv, doc_QOpenGLFunctions_2_1_glTexParameteriv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexParameteri, "glTexParameteri(self, target: int, pname: int, param: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexParameteri(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexParameteri(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buui", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTexParameteri(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexParameteri, doc_QOpenGLFunctions_2_1_glTexParameteri);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexParameterfv, "glTexParameterfv(self, target: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexParameterfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexParameterfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 363 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexParameterfv(a0, a1, reinterpret_cast<const GLfloat *>(array));
#line 1509 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexParameterfv, doc_QOpenGLFunctions_2_1_glTexParameterfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexParameterf, "glTexParameterf(self, target: int, pname: int, param: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexParameterf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexParameterf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTexParameterf(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexParameterf, doc_QOpenGLFunctions_2_1_glTexParameterf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glScissor, "glScissor(self, x: int, y: int, width: int, height: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glScissor(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glScissor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLsizei a2;
        ::GLsizei a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glScissor(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glScissor, doc_QOpenGLFunctions_2_1_glScissor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPolygonMode, "glPolygonMode(self, face: int, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPolygonMode(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPolygonMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glPolygonMode(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPolygonMode, doc_QOpenGLFunctions_2_1_glPolygonMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPointSize, "glPointSize(self, size: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPointSize(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPointSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glPointSize(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPointSize, doc_QOpenGLFunctions_2_1_glPointSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLineWidth, "glLineWidth(self, width: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLineWidth(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLineWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glLineWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLineWidth, doc_QOpenGLFunctions_2_1_glLineWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glHint, "glHint(self, target: int, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glHint(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glHint(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glHint, doc_QOpenGLFunctions_2_1_glHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glFrontFace, "glFrontFace(self, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glFrontFace(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glFrontFace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glFrontFace(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glFrontFace, doc_QOpenGLFunctions_2_1_glFrontFace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCullFace, "glCullFace(self, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCullFace(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCullFace(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glCullFace(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCullFace, doc_QOpenGLFunctions_2_1_glCullFace);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIndexubv, "glIndexubv(self, c: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIndexubv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIndexubv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 379 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glIndexubv(reinterpret_cast<const GLubyte *>(array));
#line 1766 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIndexubv, doc_QOpenGLFunctions_2_1_glIndexubv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIndexub, "glIndexub(self, c: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIndexub(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIndexub(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLubyte a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BM", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glIndexub(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIndexub, doc_QOpenGLFunctions_2_1_glIndexub);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIsTexture, "glIsTexture(self, texture: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIsTexture(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIsTexture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsTexture(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIsTexture, doc_QOpenGLFunctions_2_1_glIsTexture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGenTextures, "glGenTextures(self, n: int) -> Optional[Union[int, tuple[int, ...]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGenTextures(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGenTextures(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            int sipIsErr = 0;

#line 390 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLuint *params = new GLuint[a0];
            
        sipCpp->glGenTextures(a0, params);
        
        a1 = qpyopengl_from_GLuint(&sipIsErr, params, a0);
        
        delete[] params;
#line 1864 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a1;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGenTextures, doc_QOpenGLFunctions_2_1_glGenTextures);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDeleteTextures, "glDeleteTextures(self, n: int, textures: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDeleteTextures(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDeleteTextures(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 401 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_UNSIGNED_INT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glDeleteTextures(a0, reinterpret_cast<const GLuint *>(array));
#line 1901 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDeleteTextures, doc_QOpenGLFunctions_2_1_glDeleteTextures);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glBindTexture, "glBindTexture(self, target: int, texture: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glBindTexture(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glBindTexture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glBindTexture(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glBindTexture, doc_QOpenGLFunctions_2_1_glBindTexture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexSubImage2D, "glTexSubImage2D(self, target: int, level: int, xoffset: int, yoffset: int, width: int, height: int, format: int, type: int, pixels: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexSubImage2D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexSubImage2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLsizei a4;
        ::GLsizei a5;
        ::GLenum a6;
        ::GLenum a7;
        PyObject * a8;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiiuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8))
        {
            sipErrorState sipError = sipErrorNone;

#line 411 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a8, a7, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexSubImage2D(a0, a1, a2, a3, a4, a5, a6, a7, array);
#line 1977 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexSubImage2D, doc_QOpenGLFunctions_2_1_glTexSubImage2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexSubImage1D, "glTexSubImage1D(self, target: int, level: int, xoffset: int, width: int, format: int, type: int, pixels: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexSubImage1D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexSubImage1D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLsizei a3;
        ::GLenum a4;
        ::GLenum a5;
        PyObject * a6;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6))
        {
            sipErrorState sipError = sipErrorNone;

#line 419 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a6, a5, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexSubImage1D(a0, a1, a2, a3, a4, a5, array);
#line 2024 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexSubImage1D, doc_QOpenGLFunctions_2_1_glTexSubImage1D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCopyTexSubImage2D, "glCopyTexSubImage2D(self, target: int, level: int, xoffset: int, yoffset: int, x: int, y: int, width: int, height: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCopyTexSubImage2D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCopyTexSubImage2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::GLint a5;
        ::GLsizei a6;
        ::GLsizei a7;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiiiiiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7))
        {
            sipCpp->glCopyTexSubImage2D(a0, a1, a2, a3, a4, a5, a6, a7);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCopyTexSubImage2D, doc_QOpenGLFunctions_2_1_glCopyTexSubImage2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCopyTexSubImage1D, "glCopyTexSubImage1D(self, target: int, level: int, xoffset: int, x: int, y: int, width: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCopyTexSubImage1D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCopyTexSubImage1D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::GLsizei a5;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiiiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->glCopyTexSubImage1D(a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCopyTexSubImage1D, doc_QOpenGLFunctions_2_1_glCopyTexSubImage1D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCopyTexImage2D, "glCopyTexImage2D(self, target: int, level: int, internalformat: int, x: int, y: int, width: int, height: int, border: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCopyTexImage2D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCopyTexImage2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLenum a2;
        ::GLint a3;
        ::GLint a4;
        ::GLsizei a5;
        ::GLsizei a6;
        ::GLint a7;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiuiiiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7))
        {
            sipCpp->glCopyTexImage2D(a0, a1, a2, a3, a4, a5, a6, a7);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCopyTexImage2D, doc_QOpenGLFunctions_2_1_glCopyTexImage2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCopyTexImage1D, "glCopyTexImage1D(self, target: int, level: int, internalformat: int, x: int, y: int, width: int, border: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCopyTexImage1D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCopyTexImage1D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLenum a2;
        ::GLint a3;
        ::GLint a4;
        ::GLsizei a5;
        ::GLint a6;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiuiiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6))
        {
            sipCpp->glCopyTexImage1D(a0, a1, a2, a3, a4, a5, a6);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCopyTexImage1D, doc_QOpenGLFunctions_2_1_glCopyTexImage1D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPolygonOffset, "glPolygonOffset(self, factor: float, units: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPolygonOffset(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPolygonOffset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glPolygonOffset(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPolygonOffset, doc_QOpenGLFunctions_2_1_glPolygonOffset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDrawElements, "glDrawElements(self, mode: int, count: int, type: int, indices: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDrawElements(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDrawElements(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLsizei a1;
        ::GLenum a2;
        PyObject * a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 432 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a3, a2, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glDrawElements(a0, a1, a2, array);
#line 2224 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDrawElements, doc_QOpenGLFunctions_2_1_glDrawElements);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDrawArrays, "glDrawArrays(self, mode: int, first: int, count: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDrawArrays(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDrawArrays(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLsizei a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glDrawArrays(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDrawArrays, doc_QOpenGLFunctions_2_1_glDrawArrays);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCopyTexSubImage3D, "glCopyTexSubImage3D(self, target: int, level: int, xoffset: int, yoffset: int, zoffset: int, x: int, y: int, width: int, height: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCopyTexSubImage3D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCopyTexSubImage3D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::GLint a5;
        ::GLint a6;
        ::GLsizei a7;
        ::GLsizei a8;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiiiiiiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8))
        {
            sipCpp->glCopyTexSubImage3D(a0, a1, a2, a3, a4, a5, a6, a7, a8);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCopyTexSubImage3D, doc_QOpenGLFunctions_2_1_glCopyTexSubImage3D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexSubImage3D, "glTexSubImage3D(self, target: int, level: int, xoffset: int, yoffset: int, zoffset: int, width: int, height: int, depth: int, format: int, type: int, pixels: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexSubImage3D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexSubImage3D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::GLsizei a5;
        ::GLsizei a6;
        ::GLsizei a7;
        ::GLenum a8;
        ::GLenum a9;
        PyObject * a10;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiiiiuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8, &a9, &a10))
        {
            sipErrorState sipError = sipErrorNone;

#line 442 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a10, a9, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexSubImage3D(a0, a1, a2, a3, a4, a5, a6, a7, a8, a9, array);
#line 2337 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexSubImage3D, doc_QOpenGLFunctions_2_1_glTexSubImage3D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexImage3D, "glTexImage3D(self, target: int, level: int, internalformat: int, width: int, height: int, depth: int, border: int, format: int, type: int, pixels: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexImage3D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexImage3D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLsizei a3;
        ::GLsizei a4;
        ::GLsizei a5;
        ::GLint a6;
        ::GLenum a7;
        ::GLenum a8;
        PyObject * a9;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiiiuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8, &a9))
        {
            sipErrorState sipError = sipErrorNone;

#line 450 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a9, a8, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexImage3D(a0, a1, a2, a3, a4, a5, a6, a7, a8, array);
#line 2387 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexImage3D, doc_QOpenGLFunctions_2_1_glTexImage3D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDrawRangeElements, "glDrawRangeElements(self, mode: int, start: int, end: int, count: int, type: int, indices: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDrawRangeElements(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDrawRangeElements(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::GLuint a2;
        ::GLsizei a3;
        ::GLenum a4;
        PyObject * a5;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuuiuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipErrorState sipError = sipErrorNone;

#line 458 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a5, a4, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glDrawRangeElements(a0, a1, a2, a3, a4, array);
#line 2433 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDrawRangeElements, doc_QOpenGLFunctions_2_1_glDrawRangeElements);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glBlendEquation, "glBlendEquation(self, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glBlendEquation(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glBlendEquation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glBlendEquation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glBlendEquation, doc_QOpenGLFunctions_2_1_glBlendEquation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glBlendColor, "glBlendColor(self, red: float, green: float, blue: float, alpha: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glBlendColor(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glBlendColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bffff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glBlendColor(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glBlendColor, doc_QOpenGLFunctions_2_1_glBlendColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCompressedTexSubImage1D, "glCompressedTexSubImage1D(self, target: int, level: int, xoffset: int, width: int, format: int, imageSize: int, data: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCompressedTexSubImage1D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCompressedTexSubImage1D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLsizei a3;
        ::GLenum a4;
        ::GLsizei a5;
        PyObject * a6;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiuiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6))
        {
            sipErrorState sipError = sipErrorNone;

#line 468 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a6, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glCompressedTexSubImage1D(a0, a1, a2, a3, a4, a5, array);
#line 2536 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCompressedTexSubImage1D, doc_QOpenGLFunctions_2_1_glCompressedTexSubImage1D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCompressedTexSubImage2D, "glCompressedTexSubImage2D(self, target: int, level: int, xoffset: int, yoffset: int, width: int, height: int, format: int, imageSize: int, data: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCompressedTexSubImage2D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCompressedTexSubImage2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLsizei a4;
        ::GLsizei a5;
        ::GLenum a6;
        ::GLsizei a7;
        PyObject * a8;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiiuiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8))
        {
            sipErrorState sipError = sipErrorNone;

#line 477 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a8, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glCompressedTexSubImage2D(a0, a1, a2, a3, a4, a5, a6, a7, array);
#line 2586 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCompressedTexSubImage2D, doc_QOpenGLFunctions_2_1_glCompressedTexSubImage2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCompressedTexSubImage3D, "glCompressedTexSubImage3D(self, target: int, level: int, xoffset: int, yoffset: int, zoffset: int, width: int, height: int, depth: int, format: int, imageSize: int, data: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCompressedTexSubImage3D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCompressedTexSubImage3D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::GLsizei a5;
        ::GLsizei a6;
        ::GLsizei a7;
        ::GLenum a8;
        ::GLsizei a9;
        PyObject * a10;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiiiiiiuiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8, &a9, &a10))
        {
            sipErrorState sipError = sipErrorNone;

#line 486 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a10, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glCompressedTexSubImage3D(a0, a1, a2, a3, a4, a5, a6, a7, a8, a9,
                array);
#line 2639 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCompressedTexSubImage3D, doc_QOpenGLFunctions_2_1_glCompressedTexSubImage3D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCompressedTexImage1D, "glCompressedTexImage1D(self, target: int, level: int, internalformat: int, width: int, border: int, imageSize: int, data: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCompressedTexImage1D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCompressedTexImage1D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLenum a2;
        ::GLsizei a3;
        ::GLint a4;
        ::GLsizei a5;
        PyObject * a6;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiuiiiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6))
        {
            sipErrorState sipError = sipErrorNone;

#line 496 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a6, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glCompressedTexImage1D(a0, a1, a2, a3, a4, a5, array);
#line 2687 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCompressedTexImage1D, doc_QOpenGLFunctions_2_1_glCompressedTexImage1D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCompressedTexImage2D, "glCompressedTexImage2D(self, target: int, level: int, internalformat: int, width: int, height: int, border: int, imageSize: int, data: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCompressedTexImage2D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCompressedTexImage2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLenum a2;
        ::GLsizei a3;
        ::GLsizei a4;
        ::GLint a5;
        ::GLsizei a6;
        PyObject * a7;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiuiiiiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7))
        {
            sipErrorState sipError = sipErrorNone;

#line 505 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a7, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glCompressedTexImage2D(a0, a1, a2, a3, a4, a5, a6, array);
#line 2736 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCompressedTexImage2D, doc_QOpenGLFunctions_2_1_glCompressedTexImage2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCompressedTexImage3D, "glCompressedTexImage3D(self, target: int, level: int, internalformat: int, width: int, height: int, depth: int, border: int, imageSize: int, data: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCompressedTexImage3D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCompressedTexImage3D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLenum a2;
        ::GLsizei a3;
        ::GLsizei a4;
        ::GLsizei a5;
        ::GLint a6;
        ::GLsizei a7;
        PyObject * a8;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiuiiiiiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8))
        {
            sipErrorState sipError = sipErrorNone;

#line 514 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a8, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glCompressedTexImage3D(a0, a1, a2, a3, a4, a5, a6, a7, array);
#line 2786 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCompressedTexImage3D, doc_QOpenGLFunctions_2_1_glCompressedTexImage3D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSampleCoverage, "glSampleCoverage(self, value: float, invert: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSampleCoverage(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSampleCoverage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLboolean a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BfM", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glSampleCoverage(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSampleCoverage, doc_QOpenGLFunctions_2_1_glSampleCoverage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glActiveTexture, "glActiveTexture(self, texture: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glActiveTexture(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glActiveTexture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glActiveTexture(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glActiveTexture, doc_QOpenGLFunctions_2_1_glActiveTexture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPointParameteriv, "glPointParameteriv(self, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPointParameteriv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPointParameteriv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 525 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glPointParameteriv(a0, reinterpret_cast<const GLint *>(array));
#line 2881 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPointParameteriv, doc_QOpenGLFunctions_2_1_glPointParameteriv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPointParameteri, "glPointParameteri(self, pname: int, param: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPointParameteri(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPointParameteri(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bui", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glPointParameteri(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPointParameteri, doc_QOpenGLFunctions_2_1_glPointParameteri);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPointParameterfv, "glPointParameterfv(self, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPointParameterfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPointParameterfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 534 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glPointParameterfv(a0, reinterpret_cast<const GLfloat *>(array));
#line 2950 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPointParameterfv, doc_QOpenGLFunctions_2_1_glPointParameterfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPointParameterf, "glPointParameterf(self, pname: int, param: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPointParameterf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPointParameterf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glPointParameterf(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPointParameterf, doc_QOpenGLFunctions_2_1_glPointParameterf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glBlendFuncSeparate, "glBlendFuncSeparate(self, sfactorRGB: int, dfactorRGB: int, sfactorAlpha: int, dfactorAlpha: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glBlendFuncSeparate(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glBlendFuncSeparate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLenum a2;
        ::GLenum a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuuu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glBlendFuncSeparate(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glBlendFuncSeparate, doc_QOpenGLFunctions_2_1_glBlendFuncSeparate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetBufferParameteriv, "glGetBufferParameteriv(self, target: int, pname: int) -> Optional[int]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetBufferParameteriv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetBufferParameteriv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glGetBufferParameteriv(a0, a1, &a2);

            return PyLong_FromLong(a2);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetBufferParameteriv, doc_QOpenGLFunctions_2_1_glGetBufferParameteriv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUnmapBuffer, "glUnmapBuffer(self, target: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUnmapBuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUnmapBuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glUnmapBuffer(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUnmapBuffer, doc_QOpenGLFunctions_2_1_glUnmapBuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glBufferSubData, "glBufferSubData(self, target: int, offset: int, size: int, data: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glBufferSubData(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glBufferSubData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLintptr a1;
        ::GLsizeiptr a2;
        PyObject * a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BullP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 546 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array;
        
        if (a3 == Py_None)
            array = 0;
        else
            array = qpyopengl_value_array(&sipError, a3, GL_UNSIGNED_BYTE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glBufferSubData(a0, a1, a2, array);
#line 3109 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glBufferSubData, doc_QOpenGLFunctions_2_1_glBufferSubData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glBufferData, "glBufferData(self, target: int, size: int, data: PYQT_OPENGL_ARRAY, usage: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glBufferData(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glBufferData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLsizeiptr a1;
        PyObject * a2;
        ::GLenum a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BulP0u", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 559 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array;
        
        if (a2 == Py_None)
            array = 0;
        else
            array = qpyopengl_value_array(&sipError, a2, GL_UNSIGNED_BYTE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glBufferData(a0, a1, array, a3);
#line 3158 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glBufferData, doc_QOpenGLFunctions_2_1_glBufferData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIsBuffer, "glIsBuffer(self, buffer: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIsBuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIsBuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsBuffer(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIsBuffer, doc_QOpenGLFunctions_2_1_glIsBuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGenBuffers, "glGenBuffers(self, n: int) -> Optional[Union[int, tuple[int, ...]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGenBuffers(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGenBuffers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            int sipIsErr = 0;

#line 573 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLuint *params = new GLuint[a0];
            
        sipCpp->glGenBuffers(a0, params);
        
        a1 = qpyopengl_from_GLuint(&sipIsErr, params, a0);
        
        delete[] params;
#line 3230 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a1;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGenBuffers, doc_QOpenGLFunctions_2_1_glGenBuffers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDeleteBuffers, "glDeleteBuffers(self, n: int, buffers: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDeleteBuffers(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDeleteBuffers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 584 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_UNSIGNED_INT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glDeleteBuffers(a0, reinterpret_cast<const GLuint *>(array));
#line 3267 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDeleteBuffers, doc_QOpenGLFunctions_2_1_glDeleteBuffers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glBindBuffer, "glBindBuffer(self, target: int, buffer: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glBindBuffer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glBindBuffer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glBindBuffer(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glBindBuffer, doc_QOpenGLFunctions_2_1_glBindBuffer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetQueryiv, "glGetQueryiv(self, target: int, pname: int) -> Optional[int]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetQueryiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetQueryiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glGetQueryiv(a0, a1, &a2);

            return PyLong_FromLong(a2);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetQueryiv, doc_QOpenGLFunctions_2_1_glGetQueryiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEndQuery, "glEndQuery(self, target: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEndQuery(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEndQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glEndQuery(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEndQuery, doc_QOpenGLFunctions_2_1_glEndQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glBeginQuery, "glBeginQuery(self, target: int, id: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glBeginQuery(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glBeginQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glBeginQuery(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glBeginQuery, doc_QOpenGLFunctions_2_1_glBeginQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIsQuery, "glIsQuery(self, id: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIsQuery(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIsQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsQuery(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIsQuery, doc_QOpenGLFunctions_2_1_glIsQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDeleteQueries, "glDeleteQueries(self, n: int, ids: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDeleteQueries(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDeleteQueries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 598 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_UNSIGNED_INT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glDeleteQueries(a0, reinterpret_cast<const GLuint *>(array));
#line 3444 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDeleteQueries, doc_QOpenGLFunctions_2_1_glDeleteQueries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGenQueries, "glGenQueries(self, n: int) -> Optional[Union[int, tuple[int, ...]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGenQueries(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGenQueries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            int sipIsErr = 0;

#line 607 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLuint *params = new GLuint[a0];
            
        sipCpp->glGenQueries(a0, params);
        
        a1 = qpyopengl_from_GLuint(&sipIsErr, params, a0);
        
        delete[] params;
#line 3489 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a1;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGenQueries, doc_QOpenGLFunctions_2_1_glGenQueries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttribPointer, "glVertexAttribPointer(self, index: int, size: int, type: int, normalized: int, stride: int, pointer: PYQT_OPENGL_BOUND_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttribPointer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttribPointer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLint a1;
        ::GLenum a2;
        ::GLboolean a3;
        ::GLsizei a4;
        PyObject * a5;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiuMiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipErrorState sipError = sipErrorNone;

#line 618 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array_cached(&sipError, a5, a2, sipSelf,
                "VertexAttribPointer", a0);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttribPointer(a0, a1, a2, a3, a4, array);
#line 3530 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttribPointer, doc_QOpenGLFunctions_2_1_glVertexAttribPointer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glValidateProgram, "glValidateProgram(self, program: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glValidateProgram(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glValidateProgram(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glValidateProgram(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glValidateProgram, doc_QOpenGLFunctions_2_1_glValidateProgram);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniformMatrix4fv, "glUniformMatrix4fv(self, location: int, count: int, transpose: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniformMatrix4fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniformMatrix4fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        ::GLboolean a2;
        PyObject * a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiMP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 628 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a3, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniformMatrix4fv(a0, a1, a2,
                    reinterpret_cast<const GLfloat *>(array));
#line 3601 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniformMatrix4fv, doc_QOpenGLFunctions_2_1_glUniformMatrix4fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniformMatrix3fv, "glUniformMatrix3fv(self, location: int, count: int, transpose: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniformMatrix3fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniformMatrix3fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        ::GLboolean a2;
        PyObject * a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiMP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 637 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a3, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniformMatrix3fv(a0, a1, a2,
                    reinterpret_cast<const GLfloat *>(array));
#line 3646 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniformMatrix3fv, doc_QOpenGLFunctions_2_1_glUniformMatrix3fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniformMatrix2fv, "glUniformMatrix2fv(self, location: int, count: int, transpose: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniformMatrix2fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniformMatrix2fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        ::GLboolean a2;
        PyObject * a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiMP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 646 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a3, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniformMatrix2fv(a0, a1, a2,
                    reinterpret_cast<const GLfloat *>(array));
#line 3691 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniformMatrix2fv, doc_QOpenGLFunctions_2_1_glUniformMatrix2fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform4iv, "glUniform4iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform4iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform4iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 655 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform4iv(a0, a1, reinterpret_cast<const GLint *>(array));
#line 3734 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform4iv, doc_QOpenGLFunctions_2_1_glUniform4iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform3iv, "glUniform3iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform3iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform3iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 663 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform3iv(a0, a1, reinterpret_cast<const GLint *>(array));
#line 3777 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform3iv, doc_QOpenGLFunctions_2_1_glUniform3iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform2iv, "glUniform2iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform2iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform2iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 671 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform2iv(a0, a1, reinterpret_cast<const GLint *>(array));
#line 3820 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform2iv, doc_QOpenGLFunctions_2_1_glUniform2iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform1iv, "glUniform1iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform1iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform1iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 679 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform1iv(a0, a1, reinterpret_cast<const GLint *>(array));
#line 3863 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform1iv, doc_QOpenGLFunctions_2_1_glUniform1iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform4fv, "glUniform4fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform4fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform4fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 687 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform4fv(a0, a1, reinterpret_cast<const GLfloat *>(array));
#line 3906 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform4fv, doc_QOpenGLFunctions_2_1_glUniform4fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform3fv, "glUniform3fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform3fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform3fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 695 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform3fv(a0, a1, reinterpret_cast<const GLfloat *>(array));
#line 3949 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform3fv, doc_QOpenGLFunctions_2_1_glUniform3fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform2fv, "glUniform2fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform2fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform2fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 703 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform2fv(a0, a1, reinterpret_cast<const GLfloat *>(array));
#line 3992 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform2fv, doc_QOpenGLFunctions_2_1_glUniform2fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform1fv, "glUniform1fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform1fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform1fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 711 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glUniform1fv(a0, a1, reinterpret_cast<const GLfloat *>(array));
#line 4035 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform1fv, doc_QOpenGLFunctions_2_1_glUniform1fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform4i, "glUniform4i(self, location: int, v0: int, v1: int, v2: int, v3: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform4i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform4i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glUniform4i(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform4i, doc_QOpenGLFunctions_2_1_glUniform4i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform3i, "glUniform3i(self, location: int, v0: int, v1: int, v2: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform3i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform3i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glUniform3i(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform3i, doc_QOpenGLFunctions_2_1_glUniform3i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform2i, "glUniform2i(self, location: int, v0: int, v1: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform2i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform2i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glUniform2i(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform2i, doc_QOpenGLFunctions_2_1_glUniform2i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform1i, "glUniform1i(self, location: int, v0: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform1i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform1i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glUniform1i(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform1i, doc_QOpenGLFunctions_2_1_glUniform1i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform4f, "glUniform4f(self, location: int, v0: float, v1: float, v2: float, v3: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform4f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform4f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::GLfloat a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biffff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glUniform4f(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform4f, doc_QOpenGLFunctions_2_1_glUniform4f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform3f, "glUniform3f(self, location: int, v0: float, v1: float, v2: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform3f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform3f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bifff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glUniform3f(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform3f, doc_QOpenGLFunctions_2_1_glUniform3f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform2f, "glUniform2f(self, location: int, v0: float, v1: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform2f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform2f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glUniform2f(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform2f, doc_QOpenGLFunctions_2_1_glUniform2f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUniform1f, "glUniform1f(self, location: int, v0: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUniform1f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUniform1f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bif", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glUniform1f(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUniform1f, doc_QOpenGLFunctions_2_1_glUniform1f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glUseProgram, "glUseProgram(self, program: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glUseProgram(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glUseProgram(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glUseProgram(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glUseProgram, doc_QOpenGLFunctions_2_1_glUseProgram);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLinkProgram, "glLinkProgram(self, program: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLinkProgram(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLinkProgram(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glLinkProgram(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLinkProgram, doc_QOpenGLFunctions_2_1_glLinkProgram);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIsShader, "glIsShader(self, shader: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIsShader(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIsShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsShader(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIsShader, doc_QOpenGLFunctions_2_1_glIsShader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIsProgram, "glIsProgram(self, program: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIsProgram(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIsProgram(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsProgram(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIsProgram, doc_QOpenGLFunctions_2_1_glIsProgram);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetVertexAttribiv, "glGetVertexAttribiv(self, index: int, pname: int) -> Optional[Union[int, tuple[int, int, int, int]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetVertexAttribiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetVertexAttribiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 731 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_CURRENT_VERTEX_ATTRIB:
            nr_params = 4;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetVertexAttribiv(a0, a1, params);
        
        a2 = qpyopengl_from_GLint(&sipIsErr, params, nr_params);
#line 4424 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetVertexAttribiv, doc_QOpenGLFunctions_2_1_glGetVertexAttribiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetVertexAttribfv, "glGetVertexAttribfv(self, index: int, pname: int) -> Optional[Union[float, tuple[float, float, float, float]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetVertexAttribfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetVertexAttribfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 751 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLfloat params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_CURRENT_VERTEX_ATTRIB:
            nr_params = 4;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetVertexAttribfv(a0, a1, params);
        
        a2 = qpyopengl_from_GLfloat(&sipIsErr, params, nr_params);
#line 4473 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetVertexAttribfv, doc_QOpenGLFunctions_2_1_glGetVertexAttribfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetVertexAttribdv, "glGetVertexAttribdv(self, index: int, pname: int) -> Optional[Union[float, tuple[float, float, float, float]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetVertexAttribdv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetVertexAttribdv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 771 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLdouble params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_CURRENT_VERTEX_ATTRIB:
            nr_params = 4;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetVertexAttribdv(a0, a1, params);
        
        a2 = qpyopengl_from_GLdouble(&sipIsErr, params, nr_params);
#line 4522 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetVertexAttribdv, doc_QOpenGLFunctions_2_1_glGetVertexAttribdv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetUniformLocation, "glGetUniformLocation(self, program: int, name: Optional[str]) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetUniformLocation(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetUniformLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        const ::GLchar* a1;
        PyObject *a1Keep;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuAA", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1Keep, &a1))
        {
            ::GLint sipRes;

            sipRes = sipCpp->glGetUniformLocation(a0, a1);
            Py_DECREF(a1Keep);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetUniformLocation, doc_QOpenGLFunctions_2_1_glGetUniformLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetShaderSource, "glGetShaderSource(self, shader: int) -> str");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetShaderSource(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetShaderSource(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            PyObject * sipRes = SIP_NULLPTR;

#line 792 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint bufsize;
        
        sipCpp->glGetShaderiv(a0, GL_SHADER_SOURCE_LENGTH, &bufsize);
        
        if (bufsize > 0)
        {
            GLchar *source = new GLchar[bufsize];
        
            sipCpp->glGetShaderSource(a0, bufsize, 0, source);
            sipRes = SIPBytes_FromString(source);
        
            delete[] source;
        }
        else
        {
            sipRes = SIPBytes_FromString("");
        }
#line 4600 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetShaderSource, doc_QOpenGLFunctions_2_1_glGetShaderSource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetShaderInfoLog, "glGetShaderInfoLog(self, shader: int) -> str");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetShaderInfoLog(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetShaderInfoLog(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            PyObject * sipRes = SIP_NULLPTR;

#line 813 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint bufsize;
        
        sipCpp->glGetShaderiv(a0, GL_INFO_LOG_LENGTH, &bufsize);
        
        if (bufsize > 0)
        {
            GLchar *log = new GLchar[bufsize];
        
            sipCpp->glGetShaderInfoLog(a0, bufsize, 0, log);
            sipRes = SIPBytes_FromString(log);
        
            delete[] log;
        }
        else
        {
            sipRes = SIPBytes_FromString("");
        }
#line 4645 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetShaderInfoLog, doc_QOpenGLFunctions_2_1_glGetShaderInfoLog);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetShaderiv, "glGetShaderiv(self, shader: int, pname: int) -> Optional[int]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetShaderiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetShaderiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glGetShaderiv(a0, a1, &a2);

            return PyLong_FromLong(a2);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetShaderiv, doc_QOpenGLFunctions_2_1_glGetShaderiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetProgramInfoLog, "glGetProgramInfoLog(self, program: int) -> str");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetProgramInfoLog(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetProgramInfoLog(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            PyObject * sipRes = SIP_NULLPTR;

#line 835 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint bufsize;
        
        sipCpp->glGetProgramiv(a0, GL_INFO_LOG_LENGTH, &bufsize);
        
        if (bufsize > 0)
        {
            GLchar *log = new GLchar[bufsize];
        
            sipCpp->glGetProgramInfoLog(a0, bufsize, 0, log);
            sipRes = SIPBytes_FromString(log);
        
            delete[] log;
        }
        else
        {
            sipRes = SIPBytes_FromString("");
        }
#line 4717 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetProgramInfoLog, doc_QOpenGLFunctions_2_1_glGetProgramInfoLog);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetProgramiv, "glGetProgramiv(self, program: int, pname: int) -> Optional[Union[int, tuple[int, int, int]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetProgramiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetProgramiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 856 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint params[3];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        #if defined(GL_COMPUTE_LOCAL_WORK_SIZE)
        case GL_COMPUTE_LOCAL_WORK_SIZE:
            nr_params = 3;
            break;
        #endif
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetProgramiv(a0, a1, params);
        
        a2 = qpyopengl_from_GLint(&sipIsErr, params, nr_params);
#line 4765 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetProgramiv, doc_QOpenGLFunctions_2_1_glGetProgramiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetAttribLocation, "glGetAttribLocation(self, program: int, name: Optional[str]) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetAttribLocation(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetAttribLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        const ::GLchar* a1;
        PyObject *a1Keep;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuAA", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1Keep, &a1))
        {
            ::GLint sipRes;

            sipRes = sipCpp->glGetAttribLocation(a0, a1);
            Py_DECREF(a1Keep);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetAttribLocation, doc_QOpenGLFunctions_2_1_glGetAttribLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetAttachedShaders, "glGetAttachedShaders(self, program: int) -> tuple[int, ...]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetAttachedShaders(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetAttachedShaders(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            PyObject * sipRes = SIP_NULLPTR;
            int sipIsErr = 0;

#line 879 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint nr_shaders;
        
        sipCpp->glGetProgramiv(a0, GL_ATTACHED_SHADERS, &nr_shaders);
        
        if (nr_shaders < 1)
        {
            sipRes = PyTuple_New(0);
        }
        else
        {
            GLuint *shaders = new GLuint[nr_shaders];
        
            sipCpp->glGetAttachedShaders(a0, nr_shaders, 0, shaders);
        
            sipRes = PyTuple_New(nr_shaders);
        
            if (sipRes)
            {
                for (GLint i = 0; i < nr_shaders; ++i)
                {
                    PyObject *itm = SIPLong_FromLong(shaders[i]);
                    
                    if (!itm)
                    {
                        Py_DECREF(sipRes);
                        sipRes = 0;
                        break;
                    }
                    
                    PyTuple_SetItem(sipRes, i, itm);
                }
            }
        
            delete[] shaders;
        }
        
        if (!sipRes)
            sipIsErr = 1;
#line 4865 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetAttachedShaders, doc_QOpenGLFunctions_2_1_glGetAttachedShaders);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetActiveUniform, "glGetActiveUniform(self, program: int, index: int) -> tuple[str, int, int]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetActiveUniform(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetActiveUniform(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            PyObject * sipRes = SIP_NULLPTR;
            int sipIsErr = 0;

#line 921 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint bufsize;
        
        sipCpp->glGetProgramiv(a0, GL_ACTIVE_UNIFORM_MAX_LENGTH, &bufsize);
        
        GLchar *name = new GLchar[bufsize];
        GLint size;
        GLenum type;
        
        sipCpp->glGetActiveUniform(a0, a1, bufsize, 0, &size, &type, name);
        
        sipRes = Py_BuildValue("siI", name, size, type);
        
        if (!sipRes)
            sipIsErr = 1;
        
        delete[] name;
#line 4914 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetActiveUniform, doc_QOpenGLFunctions_2_1_glGetActiveUniform);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetActiveAttrib, "glGetActiveAttrib(self, program: int, index: int) -> tuple[str, int, int]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetActiveAttrib(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetActiveAttrib(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            PyObject * sipRes = SIP_NULLPTR;
            int sipIsErr = 0;

#line 941 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint bufsize;
        
        sipCpp->glGetProgramiv(a0, GL_ACTIVE_ATTRIBUTE_MAX_LENGTH, &bufsize);
        
        GLchar *name = new GLchar[bufsize];
        GLint size;
        GLenum type;
        
        sipCpp->glGetActiveAttrib(a0, a1, bufsize, 0, &size, &type, name);
        
        sipRes = Py_BuildValue("siI", name, size, type);
        
        if (!sipRes)
            sipIsErr = 1;
        
        delete[] name;
#line 4963 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetActiveAttrib, doc_QOpenGLFunctions_2_1_glGetActiveAttrib);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEnableVertexAttribArray, "glEnableVertexAttribArray(self, index: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEnableVertexAttribArray(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEnableVertexAttribArray(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glEnableVertexAttribArray(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEnableVertexAttribArray, doc_QOpenGLFunctions_2_1_glEnableVertexAttribArray);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDisableVertexAttribArray, "glDisableVertexAttribArray(self, index: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDisableVertexAttribArray(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDisableVertexAttribArray(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glDisableVertexAttribArray(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDisableVertexAttribArray, doc_QOpenGLFunctions_2_1_glDisableVertexAttribArray);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDetachShader, "glDetachShader(self, program: int, shader: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDetachShader(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDetachShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glDetachShader(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDetachShader, doc_QOpenGLFunctions_2_1_glDetachShader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDeleteShader, "glDeleteShader(self, shader: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDeleteShader(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDeleteShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glDeleteShader(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDeleteShader, doc_QOpenGLFunctions_2_1_glDeleteShader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDeleteProgram, "glDeleteProgram(self, program: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDeleteProgram(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDeleteProgram(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glDeleteProgram(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDeleteProgram, doc_QOpenGLFunctions_2_1_glDeleteProgram);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCreateShader, "glCreateShader(self, type: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCreateShader(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCreateShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            ::GLuint sipRes;

            sipRes = sipCpp->glCreateShader(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCreateShader, doc_QOpenGLFunctions_2_1_glCreateShader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCreateProgram, "glCreateProgram(self) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCreateProgram(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCreateProgram(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp))
        {
            ::GLuint sipRes;

            sipRes = sipCpp->glCreateProgram();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCreateProgram, doc_QOpenGLFunctions_2_1_glCreateProgram);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCompileShader, "glCompileShader(self, shader: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCompileShader(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCompileShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glCompileShader(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCompileShader, doc_QOpenGLFunctions_2_1_glCompileShader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glBindAttribLocation, "glBindAttribLocation(self, program: int, index: int, name: Optional[str])");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glBindAttribLocation(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glBindAttribLocation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        const ::GLchar* a2;
        PyObject *a2Keep;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuAA", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2Keep, &a2))
        {
            sipCpp->glBindAttribLocation(a0, a1, a2);
            Py_DECREF(a2Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glBindAttribLocation, doc_QOpenGLFunctions_2_1_glBindAttribLocation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glAttachShader, "glAttachShader(self, program: int, shader: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glAttachShader(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glAttachShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glAttachShader(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glAttachShader, doc_QOpenGLFunctions_2_1_glAttachShader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glStencilMaskSeparate, "glStencilMaskSeparate(self, face: int, mask: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glStencilMaskSeparate(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glStencilMaskSeparate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLuint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glStencilMaskSeparate(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glStencilMaskSeparate, doc_QOpenGLFunctions_2_1_glStencilMaskSeparate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glStencilFuncSeparate, "glStencilFuncSeparate(self, face: int, func: int, ref: int, mask: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glStencilFuncSeparate(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glStencilFuncSeparate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::GLuint a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuiu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glStencilFuncSeparate(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glStencilFuncSeparate, doc_QOpenGLFunctions_2_1_glStencilFuncSeparate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glStencilOpSeparate, "glStencilOpSeparate(self, face: int, sfail: int, dpfail: int, dppass: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glStencilOpSeparate(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glStencilOpSeparate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLenum a2;
        ::GLenum a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuuu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glStencilOpSeparate(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glStencilOpSeparate, doc_QOpenGLFunctions_2_1_glStencilOpSeparate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDrawBuffers, "glDrawBuffers(self, n: int, bufs: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDrawBuffers(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDrawBuffers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 974 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_UNSIGNED_INT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glDrawBuffers(a0, reinterpret_cast<const GLenum *>(array));
#line 5352 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDrawBuffers, doc_QOpenGLFunctions_2_1_glDrawBuffers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glBlendEquationSeparate, "glBlendEquationSeparate(self, modeRGB: int, modeAlpha: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glBlendEquationSeparate(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glBlendEquationSeparate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glBlendEquationSeparate(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glBlendEquationSeparate, doc_QOpenGLFunctions_2_1_glBlendEquationSeparate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTranslatef, "glTranslatef(self, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTranslatef(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTranslatef(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bfff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTranslatef(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTranslatef, doc_QOpenGLFunctions_2_1_glTranslatef);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTranslated, "glTranslated(self, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTranslated(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTranslated(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTranslated(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTranslated, doc_QOpenGLFunctions_2_1_glTranslated);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glScalef, "glScalef(self, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glScalef(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glScalef(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bfff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glScalef(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glScalef, doc_QOpenGLFunctions_2_1_glScalef);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glScaled, "glScaled(self, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glScaled(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glScaled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glScaled(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glScaled, doc_QOpenGLFunctions_2_1_glScaled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRotatef, "glRotatef(self, angle: float, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRotatef(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRotatef(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bffff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glRotatef(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRotatef, doc_QOpenGLFunctions_2_1_glRotatef);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRotated, "glRotated(self, angle: float, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRotated(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRotated(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glRotated(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRotated, doc_QOpenGLFunctions_2_1_glRotated);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPushMatrix, "glPushMatrix(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPushMatrix(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPushMatrix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp))
        {
            sipCpp->glPushMatrix();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPushMatrix, doc_QOpenGLFunctions_2_1_glPushMatrix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPopMatrix, "glPopMatrix(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPopMatrix(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPopMatrix(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp))
        {
            sipCpp->glPopMatrix();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPopMatrix, doc_QOpenGLFunctions_2_1_glPopMatrix);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glOrtho, "glOrtho(self, left: float, right: float, bottom: float, top: float, zNear: float, zFar: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glOrtho(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glOrtho(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::GLdouble a4;
        ::GLdouble a5;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdddddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->glOrtho(a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glOrtho, doc_QOpenGLFunctions_2_1_glOrtho);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultMatrixd, "glMultMatrixd(self, m: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultMatrixd(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultMatrixd(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 993 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultMatrixd(reinterpret_cast<const GLdouble *>(array));
#line 5671 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultMatrixd, doc_QOpenGLFunctions_2_1_glMultMatrixd);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultMatrixf, "glMultMatrixf(self, m: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultMatrixf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultMatrixf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1001 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultMatrixf(reinterpret_cast<const GLfloat *>(array));
#line 5712 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultMatrixf, doc_QOpenGLFunctions_2_1_glMultMatrixf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMatrixMode, "glMatrixMode(self, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMatrixMode(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMatrixMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glMatrixMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMatrixMode, doc_QOpenGLFunctions_2_1_glMatrixMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLoadMatrixd, "glLoadMatrixd(self, m: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLoadMatrixd(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLoadMatrixd(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1010 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glLoadMatrixd(reinterpret_cast<const GLdouble *>(array));
#line 5779 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLoadMatrixd, doc_QOpenGLFunctions_2_1_glLoadMatrixd);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLoadMatrixf, "glLoadMatrixf(self, m: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLoadMatrixf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLoadMatrixf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1018 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glLoadMatrixf(reinterpret_cast<const GLfloat *>(array));
#line 5820 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLoadMatrixf, doc_QOpenGLFunctions_2_1_glLoadMatrixf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLoadIdentity, "glLoadIdentity(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLoadIdentity(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLoadIdentity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp))
        {
            sipCpp->glLoadIdentity();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLoadIdentity, doc_QOpenGLFunctions_2_1_glLoadIdentity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glFrustum, "glFrustum(self, left: float, right: float, bottom: float, top: float, zNear: float, zFar: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glFrustum(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glFrustum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::GLdouble a4;
        ::GLdouble a5;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdddddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->glFrustum(a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glFrustum, doc_QOpenGLFunctions_2_1_glFrustum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIsList, "glIsList(self, list: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIsList(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIsList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            ::GLboolean sipRes;

            sipRes = sipCpp->glIsList(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIsList, doc_QOpenGLFunctions_2_1_glIsList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetTexGeniv, "glGetTexGeniv(self, coord: int, pname: int) -> Optional[Union[int, tuple[int, int, int, int]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetTexGeniv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetTexGeniv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 1029 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_OBJECT_PLANE:
        case GL_EYE_PLANE:
            nr_params = 4;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetTexGeniv(a0, a1, params);
        
        a2 = qpyopengl_from_GLint(&sipIsErr, params, nr_params);
#line 5959 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetTexGeniv, doc_QOpenGLFunctions_2_1_glGetTexGeniv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetTexGenfv, "glGetTexGenfv(self, coord: int, pname: int) -> Optional[Union[float, tuple[float, float, float, float]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetTexGenfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetTexGenfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 1050 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLfloat params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_OBJECT_PLANE:
        case GL_EYE_PLANE:
            nr_params = 4;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetTexGenfv(a0, a1, params);
        
        a2 = qpyopengl_from_GLfloat(&sipIsErr, params, nr_params);
#line 6009 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetTexGenfv, doc_QOpenGLFunctions_2_1_glGetTexGenfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetTexGendv, "glGetTexGendv(self, coord: int, pname: int) -> Optional[Union[float, tuple[float, float, float, float]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetTexGendv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetTexGendv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 1071 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLdouble params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_OBJECT_PLANE:
        case GL_EYE_PLANE:
            nr_params = 4;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetTexGendv(a0, a1, params);
        
        a2 = qpyopengl_from_GLdouble(&sipIsErr, params, nr_params);
#line 6059 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetTexGendv, doc_QOpenGLFunctions_2_1_glGetTexGendv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetTexEnviv, "glGetTexEnviv(self, target: int, pname: int) -> Optional[Union[int, tuple[int, int, int, int]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetTexEnviv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetTexEnviv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 1092 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_TEXTURE_ENV_COLOR:
            nr_params = 4;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetTexEnviv(a0, a1, params);
        
        a2 = qpyopengl_from_GLint(&sipIsErr, params, nr_params);
#line 6108 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetTexEnviv, doc_QOpenGLFunctions_2_1_glGetTexEnviv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetTexEnvfv, "glGetTexEnvfv(self, target: int, pname: int) -> Optional[Union[float, tuple[float, float, float, float]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetTexEnvfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetTexEnvfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 1112 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLfloat params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_TEXTURE_ENV_COLOR:
            nr_params = 4;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetTexEnvfv(a0, a1, params);
        
        a2 = qpyopengl_from_GLfloat(&sipIsErr, params, nr_params);
#line 6157 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetTexEnvfv, doc_QOpenGLFunctions_2_1_glGetTexEnvfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetMaterialiv, "glGetMaterialiv(self, face: int, pname: int) -> Optional[Union[int, tuple[int, int, int], tuple[int, int, int, int]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetMaterialiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetMaterialiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 1132 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_SHININESS:
            nr_params = 1;
            break;
        
        case GL_COLOR_INDEXES:
            nr_params = 3;
            break;
        
        default:
            nr_params = 4;
        }
        
        sipCpp->glGetMaterialiv(a0, a1, params);
        
        a2 = qpyopengl_from_GLint(&sipIsErr, params, nr_params);
#line 6210 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetMaterialiv, doc_QOpenGLFunctions_2_1_glGetMaterialiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetMaterialfv, "glGetMaterialfv(self, face: int, pname: int) -> Optional[Union[float, tuple[float, float, float], tuple[float, float, float, float]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetMaterialfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetMaterialfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 1156 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLfloat params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_SHININESS:
            nr_params = 1;
            break;
        
        case GL_COLOR_INDEXES:
            nr_params = 3;
            break;
        
        default:
            nr_params = 4;
        }
        
        sipCpp->glGetMaterialfv(a0, a1, params);
        
        a2 = qpyopengl_from_GLfloat(&sipIsErr, params, nr_params);
#line 6263 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetMaterialfv, doc_QOpenGLFunctions_2_1_glGetMaterialfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetLightiv, "glGetLightiv(self, light: int, pname: int) -> Optional[Union[int, tuple[int, int, int], tuple[int, int, int, int]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetLightiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetLightiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 1180 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_AMBIENT:
        case GL_DIFFUSE:
        case GL_SPECULAR:
        case GL_POSITION:
            nr_params = 4;
            break;
        
        case GL_SPOT_DIRECTION:
            nr_params = 3;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetLightiv(a0, a1, params);
        
        a2 = qpyopengl_from_GLint(&sipIsErr, params, nr_params);
#line 6319 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetLightiv, doc_QOpenGLFunctions_2_1_glGetLightiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetLightfv, "glGetLightfv(self, light: int, pname: int) -> Optional[Union[float, tuple[float, float, float], tuple[float, float, float, float]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetLightfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetLightfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 1207 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLfloat params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_AMBIENT:
        case GL_DIFFUSE:
        case GL_SPECULAR:
        case GL_POSITION:
            nr_params = 4;
            break;
        
        case GL_SPOT_DIRECTION:
            nr_params = 3;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetLightfv(a0, a1, params);
        
        a2 = qpyopengl_from_GLfloat(&sipIsErr, params, nr_params);
#line 6375 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetLightfv, doc_QOpenGLFunctions_2_1_glGetLightfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetClipPlane, "glGetClipPlane(self, plane: int) -> Optional[tuple[float, float, float, float]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetClipPlane(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetClipPlane(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            int sipIsErr = 0;

#line 1234 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLdouble params[4];
        
        sipCpp->glGetClipPlane(a0, params);
        
        a1 = qpyopengl_from_GLdouble(&sipIsErr, params, 4);
#line 6412 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a1;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetClipPlane, doc_QOpenGLFunctions_2_1_glGetClipPlane);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDrawPixels, "glDrawPixels(self, width: int, height: int, format: int, type: int, pixels: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDrawPixels(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDrawPixels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        ::GLsizei a1;
        ::GLenum a2;
        ::GLenum a3;
        PyObject * a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipErrorState sipError = sipErrorNone;

#line 1243 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a4, a3, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glDrawPixels(a0, a1, a2, a3, array);
#line 6451 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDrawPixels, doc_QOpenGLFunctions_2_1_glDrawPixels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCopyPixels, "glCopyPixels(self, x: int, y: int, width: int, height: int, type: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCopyPixels(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCopyPixels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLsizei a2;
        ::GLsizei a3;
        ::GLenum a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiiiu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glCopyPixels(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCopyPixels, doc_QOpenGLFunctions_2_1_glCopyPixels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPixelMapusv, "glPixelMapusv(self, map: int, mapsize: int, values: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPixelMapusv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPixelMapusv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 1252 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_UNSIGNED_SHORT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glPixelMapusv(a0, a1, reinterpret_cast<const GLushort *>(array));
#line 6525 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPixelMapusv, doc_QOpenGLFunctions_2_1_glPixelMapusv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPixelMapuiv, "glPixelMapuiv(self, map: int, mapsize: int, values: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPixelMapuiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPixelMapuiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 1261 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_UNSIGNED_INT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glPixelMapuiv(a0, a1, reinterpret_cast<const GLuint *>(array));
#line 6569 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPixelMapuiv, doc_QOpenGLFunctions_2_1_glPixelMapuiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPixelMapfv, "glPixelMapfv(self, map: int, mapsize: int, values: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPixelMapfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPixelMapfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 1270 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glPixelMapfv(a0, a1, reinterpret_cast<const GLfloat *>(array));
#line 6612 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPixelMapfv, doc_QOpenGLFunctions_2_1_glPixelMapfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPixelTransferi, "glPixelTransferi(self, pname: int, param: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPixelTransferi(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPixelTransferi(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bui", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glPixelTransferi(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPixelTransferi, doc_QOpenGLFunctions_2_1_glPixelTransferi);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPixelTransferf, "glPixelTransferf(self, pname: int, param: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPixelTransferf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPixelTransferf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glPixelTransferf(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPixelTransferf, doc_QOpenGLFunctions_2_1_glPixelTransferf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPixelZoom, "glPixelZoom(self, xfactor: float, yfactor: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPixelZoom(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPixelZoom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glPixelZoom(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPixelZoom, doc_QOpenGLFunctions_2_1_glPixelZoom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glAlphaFunc, "glAlphaFunc(self, func: int, ref: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glAlphaFunc(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glAlphaFunc(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glAlphaFunc(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glAlphaFunc, doc_QOpenGLFunctions_2_1_glAlphaFunc);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEvalPoint2, "glEvalPoint2(self, i: int, j: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEvalPoint2(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEvalPoint2(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glEvalPoint2(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEvalPoint2, doc_QOpenGLFunctions_2_1_glEvalPoint2);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEvalMesh2, "glEvalMesh2(self, mode: int, i1: int, i2: int, j1: int, j2: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEvalMesh2(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEvalMesh2(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glEvalMesh2(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEvalMesh2, doc_QOpenGLFunctions_2_1_glEvalMesh2);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEvalPoint1, "glEvalPoint1(self, i: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEvalPoint1(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEvalPoint1(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glEvalPoint1(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEvalPoint1, doc_QOpenGLFunctions_2_1_glEvalPoint1);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEvalMesh1, "glEvalMesh1(self, mode: int, i1: int, i2: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEvalMesh1(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEvalMesh1(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glEvalMesh1(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEvalMesh1, doc_QOpenGLFunctions_2_1_glEvalMesh1);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEvalCoord2fv, "glEvalCoord2fv(self, u: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord2fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord2fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1286 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glEvalCoord2fv(reinterpret_cast<const GLfloat *>(array));
#line 6872 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEvalCoord2fv, doc_QOpenGLFunctions_2_1_glEvalCoord2fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEvalCoord2f, "glEvalCoord2f(self, u: float, v: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord2f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord2f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glEvalCoord2f(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEvalCoord2f, doc_QOpenGLFunctions_2_1_glEvalCoord2f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEvalCoord2dv, "glEvalCoord2dv(self, u: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord2dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord2dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1295 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glEvalCoord2dv(reinterpret_cast<const GLdouble *>(array));
#line 6940 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEvalCoord2dv, doc_QOpenGLFunctions_2_1_glEvalCoord2dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEvalCoord2d, "glEvalCoord2d(self, u: float, v: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord2d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord2d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glEvalCoord2d(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEvalCoord2d, doc_QOpenGLFunctions_2_1_glEvalCoord2d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEvalCoord1fv, "glEvalCoord1fv(self, u: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord1fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord1fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1304 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glEvalCoord1fv(reinterpret_cast<const GLfloat *>(array));
#line 7008 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEvalCoord1fv, doc_QOpenGLFunctions_2_1_glEvalCoord1fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEvalCoord1f, "glEvalCoord1f(self, u: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord1f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord1f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glEvalCoord1f(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEvalCoord1f, doc_QOpenGLFunctions_2_1_glEvalCoord1f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEvalCoord1dv, "glEvalCoord1dv(self, u: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord1dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord1dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1313 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glEvalCoord1dv(reinterpret_cast<const GLdouble *>(array));
#line 7075 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEvalCoord1dv, doc_QOpenGLFunctions_2_1_glEvalCoord1dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEvalCoord1d, "glEvalCoord1d(self, u: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord1d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEvalCoord1d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glEvalCoord1d(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEvalCoord1d, doc_QOpenGLFunctions_2_1_glEvalCoord1d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMapGrid2f, "glMapGrid2f(self, un: int, u1: float, u2: float, vn: int, v1: float, v2: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMapGrid2f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMapGrid2f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLint a3;
        ::GLfloat a4;
        ::GLfloat a5;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biffiff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->glMapGrid2f(a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMapGrid2f, doc_QOpenGLFunctions_2_1_glMapGrid2f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMapGrid2d, "glMapGrid2d(self, un: int, u1: float, u2: float, vn: int, v1: float, v2: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMapGrid2d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMapGrid2d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLint a3;
        ::GLdouble a4;
        ::GLdouble a5;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biddidd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->glMapGrid2d(a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMapGrid2d, doc_QOpenGLFunctions_2_1_glMapGrid2d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMapGrid1f, "glMapGrid1f(self, un: int, u1: float, u2: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMapGrid1f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMapGrid1f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glMapGrid1f(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMapGrid1f, doc_QOpenGLFunctions_2_1_glMapGrid1f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMapGrid1d, "glMapGrid1d(self, un: int, u1: float, u2: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMapGrid1d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMapGrid1d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bidd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glMapGrid1d(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMapGrid1d, doc_QOpenGLFunctions_2_1_glMapGrid1d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMap2f, "glMap2f(self, target: int, u1: float, u2: float, ustride: int, uorder: int, v1: float, v2: float, vstride: int, vorder: int, points: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMap2f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMap2f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLint a3;
        ::GLint a4;
        ::GLfloat a5;
        ::GLfloat a6;
        ::GLint a7;
        ::GLint a8;
        PyObject * a9;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuffiiffiiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8, &a9))
        {
            sipErrorState sipError = sipErrorNone;

#line 1326 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a9, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMap2f(a0, a1, a2, a3, a4, a5, a6, a7, a8,
                    reinterpret_cast<const GLfloat *>(array));
#line 7270 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMap2f, doc_QOpenGLFunctions_2_1_glMap2f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMap2d, "glMap2d(self, target: int, u1: float, u2: float, ustride: int, uorder: int, v1: float, v2: float, vstride: int, vorder: int, points: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMap2d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMap2d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLint a3;
        ::GLint a4;
        ::GLdouble a5;
        ::GLdouble a6;
        ::GLint a7;
        ::GLint a8;
        PyObject * a9;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuddiiddiiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6, &a7, &a8, &a9))
        {
            sipErrorState sipError = sipErrorNone;

#line 1335 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a9, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMap2d(a0, a1, a2, a3, a4, a5, a6, a7, a8,
                    reinterpret_cast<const GLdouble *>(array));
#line 7321 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMap2d, doc_QOpenGLFunctions_2_1_glMap2d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMap1f, "glMap1f(self, target: int, u1: float, u2: float, stride: int, order: int, points: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMap1f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMap1f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLint a3;
        ::GLint a4;
        PyObject * a5;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuffiiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipErrorState sipError = sipErrorNone;

#line 1344 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a5, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMap1f(a0, a1, a2, a3, a4,
                    reinterpret_cast<const GLfloat *>(array));
#line 7368 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMap1f, doc_QOpenGLFunctions_2_1_glMap1f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMap1d, "glMap1d(self, target: int, u1: float, u2: float, stride: int, order: int, points: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMap1d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMap1d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLint a3;
        ::GLint a4;
        PyObject * a5;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuddiiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipErrorState sipError = sipErrorNone;

#line 1353 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a5, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMap1d(a0, a1, a2, a3, a4,
                    reinterpret_cast<const GLdouble *>(array));
#line 7415 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMap1d, doc_QOpenGLFunctions_2_1_glMap1d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPushAttrib, "glPushAttrib(self, mask: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPushAttrib(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPushAttrib(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLbitfield a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glPushAttrib(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPushAttrib, doc_QOpenGLFunctions_2_1_glPushAttrib);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPopAttrib, "glPopAttrib(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPopAttrib(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPopAttrib(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp))
        {
            sipCpp->glPopAttrib();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPopAttrib, doc_QOpenGLFunctions_2_1_glPopAttrib);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glAccum, "glAccum(self, op: int, value: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glAccum(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glAccum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glAccum(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glAccum, doc_QOpenGLFunctions_2_1_glAccum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIndexMask, "glIndexMask(self, mask: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIndexMask(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIndexMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glIndexMask(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIndexMask, doc_QOpenGLFunctions_2_1_glIndexMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glClearIndex, "glClearIndex(self, c: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glClearIndex(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glClearIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glClearIndex(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glClearIndex, doc_QOpenGLFunctions_2_1_glClearIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glClearAccum, "glClearAccum(self, red: float, green: float, blue: float, alpha: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glClearAccum(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glClearAccum(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bffff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glClearAccum(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glClearAccum, doc_QOpenGLFunctions_2_1_glClearAccum);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPushName, "glPushName(self, name: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPushName(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPushName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glPushName(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPushName, doc_QOpenGLFunctions_2_1_glPushName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPopName, "glPopName(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPopName(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPopName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp))
        {
            sipCpp->glPopName();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPopName, doc_QOpenGLFunctions_2_1_glPopName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPassThrough, "glPassThrough(self, token: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPassThrough(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPassThrough(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glPassThrough(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPassThrough, doc_QOpenGLFunctions_2_1_glPassThrough);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLoadName, "glLoadName(self, name: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLoadName(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLoadName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glLoadName(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLoadName, doc_QOpenGLFunctions_2_1_glLoadName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glInitNames, "glInitNames(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glInitNames(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glInitNames(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp))
        {
            sipCpp->glInitNames();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glInitNames, doc_QOpenGLFunctions_2_1_glInitNames);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRenderMode, "glRenderMode(self, mode: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRenderMode(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRenderMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            ::GLint sipRes;

            sipRes = sipCpp->glRenderMode(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRenderMode, doc_QOpenGLFunctions_2_1_glRenderMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexGeniv, "glTexGeniv(self, coord: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexGeniv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexGeniv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 1374 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexGeniv(a0, a1, reinterpret_cast<const GLint *>(array));
#line 7772 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexGeniv, doc_QOpenGLFunctions_2_1_glTexGeniv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexGeni, "glTexGeni(self, coord: int, pname: int, param: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexGeni(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexGeni(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buui", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTexGeni(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexGeni, doc_QOpenGLFunctions_2_1_glTexGeni);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexGenfv, "glTexGenfv(self, coord: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexGenfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexGenfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 1383 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexGenfv(a0, a1, reinterpret_cast<const GLfloat *>(array));
#line 7843 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexGenfv, doc_QOpenGLFunctions_2_1_glTexGenfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexGenf, "glTexGenf(self, coord: int, pname: int, param: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexGenf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexGenf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTexGenf(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexGenf, doc_QOpenGLFunctions_2_1_glTexGenf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexGendv, "glTexGendv(self, coord: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexGendv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexGendv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 1392 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexGendv(a0, a1, reinterpret_cast<const GLdouble *>(array));
#line 7914 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexGendv, doc_QOpenGLFunctions_2_1_glTexGendv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexGend, "glTexGend(self, coord: int, pname: int, param: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexGend(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexGend(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buud", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTexGend(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexGend, doc_QOpenGLFunctions_2_1_glTexGend);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexEnviv, "glTexEnviv(self, target: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexEnviv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexEnviv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 1401 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexEnviv(a0, a1, reinterpret_cast<const GLint *>(array));
#line 7985 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexEnviv, doc_QOpenGLFunctions_2_1_glTexEnviv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexEnvi, "glTexEnvi(self, target: int, pname: int, param: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexEnvi(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexEnvi(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buui", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTexEnvi(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexEnvi, doc_QOpenGLFunctions_2_1_glTexEnvi);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexEnvfv, "glTexEnvfv(self, target: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexEnvfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexEnvfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 1410 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexEnvfv(a0, a1, reinterpret_cast<const GLfloat *>(array));
#line 8056 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexEnvfv, doc_QOpenGLFunctions_2_1_glTexEnvfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexEnvf, "glTexEnvf(self, target: int, pname: int, param: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexEnvf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexEnvf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTexEnvf(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexEnvf, doc_QOpenGLFunctions_2_1_glTexEnvf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glShadeModel, "glShadeModel(self, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glShadeModel(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glShadeModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glShadeModel(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glShadeModel, doc_QOpenGLFunctions_2_1_glShadeModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPolygonStipple, "glPolygonStipple(self, mask: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPolygonStipple(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPolygonStipple(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1420 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glPolygonStipple(reinterpret_cast<const GLubyte *>(array));
#line 8152 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPolygonStipple, doc_QOpenGLFunctions_2_1_glPolygonStipple);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMaterialiv, "glMaterialiv(self, face: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMaterialiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMaterialiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 1429 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMaterialiv(a0, a1, reinterpret_cast<const GLint *>(array));
#line 8195 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMaterialiv, doc_QOpenGLFunctions_2_1_glMaterialiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMateriali, "glMateriali(self, face: int, pname: int, param: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMateriali(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMateriali(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buui", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glMateriali(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMateriali, doc_QOpenGLFunctions_2_1_glMateriali);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMaterialfv, "glMaterialfv(self, face: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMaterialfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMaterialfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 1438 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMaterialfv(a0, a1, reinterpret_cast<const GLfloat *>(array));
#line 8266 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMaterialfv, doc_QOpenGLFunctions_2_1_glMaterialfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMaterialf, "glMaterialf(self, face: int, pname: int, param: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMaterialf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMaterialf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glMaterialf(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMaterialf, doc_QOpenGLFunctions_2_1_glMaterialf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLineStipple, "glLineStipple(self, factor: int, pattern: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLineStipple(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLineStipple(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLushort a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bit", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glLineStipple(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLineStipple, doc_QOpenGLFunctions_2_1_glLineStipple);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLightModeliv, "glLightModeliv(self, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLightModeliv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLightModeliv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 1448 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glLightModeliv(a0, reinterpret_cast<const GLint *>(array));
#line 8363 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLightModeliv, doc_QOpenGLFunctions_2_1_glLightModeliv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLightModeli, "glLightModeli(self, pname: int, param: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLightModeli(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLightModeli(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bui", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glLightModeli(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLightModeli, doc_QOpenGLFunctions_2_1_glLightModeli);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLightModelfv, "glLightModelfv(self, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLightModelfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLightModelfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 1457 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glLightModelfv(a0, reinterpret_cast<const GLfloat *>(array));
#line 8432 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLightModelfv, doc_QOpenGLFunctions_2_1_glLightModelfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLightModelf, "glLightModelf(self, pname: int, param: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLightModelf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLightModelf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glLightModelf(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLightModelf, doc_QOpenGLFunctions_2_1_glLightModelf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLightiv, "glLightiv(self, light: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLightiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLightiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 1466 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glLightiv(a0, a1, reinterpret_cast<const GLint *>(array));
#line 8502 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLightiv, doc_QOpenGLFunctions_2_1_glLightiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLighti, "glLighti(self, light: int, pname: int, param: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLighti(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLighti(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buui", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glLighti(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLighti, doc_QOpenGLFunctions_2_1_glLighti);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLightfv, "glLightfv(self, light: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLightfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLightfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 1475 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glLightfv(a0, a1, reinterpret_cast<const GLfloat *>(array));
#line 8573 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLightfv, doc_QOpenGLFunctions_2_1_glLightfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLightf, "glLightf(self, light: int, pname: int, param: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLightf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLightf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glLightf(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLightf, doc_QOpenGLFunctions_2_1_glLightf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glFogiv, "glFogiv(self, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glFogiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glFogiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 1484 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glFogiv(a0, reinterpret_cast<const GLint *>(array));
#line 8643 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glFogiv, doc_QOpenGLFunctions_2_1_glFogiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glFogi, "glFogi(self, pname: int, param: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glFogi(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glFogi(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bui", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glFogi(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glFogi, doc_QOpenGLFunctions_2_1_glFogi);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glFogfv, "glFogfv(self, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glFogfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glFogfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 1493 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glFogfv(a0, reinterpret_cast<const GLfloat *>(array));
#line 8712 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glFogfv, doc_QOpenGLFunctions_2_1_glFogfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glFogf, "glFogf(self, pname: int, param: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glFogf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glFogf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glFogf(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glFogf, doc_QOpenGLFunctions_2_1_glFogf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColorMaterial, "glColorMaterial(self, face: int, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColorMaterial(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColorMaterial(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glColorMaterial(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColorMaterial, doc_QOpenGLFunctions_2_1_glColorMaterial);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glClipPlane, "glClipPlane(self, plane: int, equation: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glClipPlane(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glClipPlane(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 1503 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glClipPlane(a0, reinterpret_cast<const GLdouble *>(array));
#line 8808 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glClipPlane, doc_QOpenGLFunctions_2_1_glClipPlane);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex4sv, "glVertex4sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex4sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex4sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1511 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertex4sv(reinterpret_cast<const GLshort *>(array));
#line 8849 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex4sv, doc_QOpenGLFunctions_2_1_glVertex4sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex4s, "glVertex4s(self, x: int, y: int, z: int, w: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex4s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex4s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::GLshort a2;
        ::GLshort a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glVertex4s(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex4s, doc_QOpenGLFunctions_2_1_glVertex4s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex4iv, "glVertex4iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex4iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex4iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1520 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertex4iv(reinterpret_cast<const GLint *>(array));
#line 8919 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex4iv, doc_QOpenGLFunctions_2_1_glVertex4iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex4i, "glVertex4i(self, x: int, y: int, z: int, w: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex4i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex4i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glVertex4i(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex4i, doc_QOpenGLFunctions_2_1_glVertex4i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex4fv, "glVertex4fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex4fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex4fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1529 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertex4fv(reinterpret_cast<const GLfloat *>(array));
#line 8989 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex4fv, doc_QOpenGLFunctions_2_1_glVertex4fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex4f, "glVertex4f(self, x: float, y: float, z: float, w: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex4f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex4f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bffff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glVertex4f(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex4f, doc_QOpenGLFunctions_2_1_glVertex4f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex4dv, "glVertex4dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex4dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex4dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1538 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertex4dv(reinterpret_cast<const GLdouble *>(array));
#line 9059 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex4dv, doc_QOpenGLFunctions_2_1_glVertex4dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex4d, "glVertex4d(self, x: float, y: float, z: float, w: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex4d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex4d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glVertex4d(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex4d, doc_QOpenGLFunctions_2_1_glVertex4d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex3sv, "glVertex3sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex3sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex3sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1547 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertex3sv(reinterpret_cast<const GLshort *>(array));
#line 9129 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex3sv, doc_QOpenGLFunctions_2_1_glVertex3sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex3s, "glVertex3s(self, x: int, y: int, z: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex3s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex3s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::GLshort a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glVertex3s(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex3s, doc_QOpenGLFunctions_2_1_glVertex3s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex3iv, "glVertex3iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex3iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex3iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1556 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertex3iv(reinterpret_cast<const GLint *>(array));
#line 9198 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex3iv, doc_QOpenGLFunctions_2_1_glVertex3iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex3i, "glVertex3i(self, x: int, y: int, z: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex3i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex3i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glVertex3i(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex3i, doc_QOpenGLFunctions_2_1_glVertex3i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex3fv, "glVertex3fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex3fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex3fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1565 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertex3fv(reinterpret_cast<const GLfloat *>(array));
#line 9267 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex3fv, doc_QOpenGLFunctions_2_1_glVertex3fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex3f, "glVertex3f(self, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex3f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex3f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bfff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glVertex3f(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex3f, doc_QOpenGLFunctions_2_1_glVertex3f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex3dv, "glVertex3dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex3dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex3dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1574 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertex3dv(reinterpret_cast<const GLdouble *>(array));
#line 9336 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex3dv, doc_QOpenGLFunctions_2_1_glVertex3dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex3d, "glVertex3d(self, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex3d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex3d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glVertex3d(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex3d, doc_QOpenGLFunctions_2_1_glVertex3d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex2sv, "glVertex2sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex2sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex2sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1583 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertex2sv(reinterpret_cast<const GLshort *>(array));
#line 9405 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex2sv, doc_QOpenGLFunctions_2_1_glVertex2sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex2s, "glVertex2s(self, x: int, y: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex2s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex2s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glVertex2s(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex2s, doc_QOpenGLFunctions_2_1_glVertex2s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex2iv, "glVertex2iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex2iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex2iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1592 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertex2iv(reinterpret_cast<const GLint *>(array));
#line 9473 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex2iv, doc_QOpenGLFunctions_2_1_glVertex2iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex2i, "glVertex2i(self, x: int, y: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex2i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex2i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glVertex2i(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex2i, doc_QOpenGLFunctions_2_1_glVertex2i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex2fv, "glVertex2fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex2fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex2fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1601 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertex2fv(reinterpret_cast<const GLfloat *>(array));
#line 9541 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex2fv, doc_QOpenGLFunctions_2_1_glVertex2fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex2f, "glVertex2f(self, x: float, y: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex2f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex2f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glVertex2f(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex2f, doc_QOpenGLFunctions_2_1_glVertex2f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex2dv, "glVertex2dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex2dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex2dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1610 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertex2dv(reinterpret_cast<const GLdouble *>(array));
#line 9609 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex2dv, doc_QOpenGLFunctions_2_1_glVertex2dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertex2d, "glVertex2d(self, x: float, y: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertex2d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertex2d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glVertex2d(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertex2d, doc_QOpenGLFunctions_2_1_glVertex2d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord4sv, "glTexCoord4sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1619 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord4sv(reinterpret_cast<const GLshort *>(array));
#line 9677 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord4sv, doc_QOpenGLFunctions_2_1_glTexCoord4sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord4s, "glTexCoord4s(self, s: int, t: int, r: int, q: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::GLshort a2;
        ::GLshort a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glTexCoord4s(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord4s, doc_QOpenGLFunctions_2_1_glTexCoord4s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord4iv, "glTexCoord4iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1628 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord4iv(reinterpret_cast<const GLint *>(array));
#line 9747 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord4iv, doc_QOpenGLFunctions_2_1_glTexCoord4iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord4i, "glTexCoord4i(self, s: int, t: int, r: int, q: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glTexCoord4i(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord4i, doc_QOpenGLFunctions_2_1_glTexCoord4i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord4fv, "glTexCoord4fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1637 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord4fv(reinterpret_cast<const GLfloat *>(array));
#line 9817 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord4fv, doc_QOpenGLFunctions_2_1_glTexCoord4fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord4f, "glTexCoord4f(self, s: float, t: float, r: float, q: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bffff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glTexCoord4f(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord4f, doc_QOpenGLFunctions_2_1_glTexCoord4f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord4dv, "glTexCoord4dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1646 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord4dv(reinterpret_cast<const GLdouble *>(array));
#line 9887 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord4dv, doc_QOpenGLFunctions_2_1_glTexCoord4dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord4d, "glTexCoord4d(self, s: float, t: float, r: float, q: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord4d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glTexCoord4d(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord4d, doc_QOpenGLFunctions_2_1_glTexCoord4d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord3sv, "glTexCoord3sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1655 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord3sv(reinterpret_cast<const GLshort *>(array));
#line 9957 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord3sv, doc_QOpenGLFunctions_2_1_glTexCoord3sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord3s, "glTexCoord3s(self, s: int, t: int, r: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::GLshort a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTexCoord3s(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord3s, doc_QOpenGLFunctions_2_1_glTexCoord3s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord3iv, "glTexCoord3iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1664 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord3iv(reinterpret_cast<const GLint *>(array));
#line 10026 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord3iv, doc_QOpenGLFunctions_2_1_glTexCoord3iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord3i, "glTexCoord3i(self, s: int, t: int, r: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTexCoord3i(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord3i, doc_QOpenGLFunctions_2_1_glTexCoord3i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord3fv, "glTexCoord3fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1673 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord3fv(reinterpret_cast<const GLfloat *>(array));
#line 10095 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord3fv, doc_QOpenGLFunctions_2_1_glTexCoord3fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord3f, "glTexCoord3f(self, s: float, t: float, r: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bfff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTexCoord3f(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord3f, doc_QOpenGLFunctions_2_1_glTexCoord3f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord3dv, "glTexCoord3dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1682 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord3dv(reinterpret_cast<const GLdouble *>(array));
#line 10164 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord3dv, doc_QOpenGLFunctions_2_1_glTexCoord3dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord3d, "glTexCoord3d(self, s: float, t: float, r: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord3d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glTexCoord3d(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord3d, doc_QOpenGLFunctions_2_1_glTexCoord3d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord2sv, "glTexCoord2sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1691 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord2sv(reinterpret_cast<const GLshort *>(array));
#line 10233 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord2sv, doc_QOpenGLFunctions_2_1_glTexCoord2sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord2s, "glTexCoord2s(self, s: int, t: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glTexCoord2s(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord2s, doc_QOpenGLFunctions_2_1_glTexCoord2s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord2iv, "glTexCoord2iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1700 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord2iv(reinterpret_cast<const GLint *>(array));
#line 10301 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord2iv, doc_QOpenGLFunctions_2_1_glTexCoord2iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord2i, "glTexCoord2i(self, s: int, t: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glTexCoord2i(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord2i, doc_QOpenGLFunctions_2_1_glTexCoord2i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord2fv, "glTexCoord2fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1709 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord2fv(reinterpret_cast<const GLfloat *>(array));
#line 10369 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord2fv, doc_QOpenGLFunctions_2_1_glTexCoord2fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord2f, "glTexCoord2f(self, s: float, t: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glTexCoord2f(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord2f, doc_QOpenGLFunctions_2_1_glTexCoord2f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord2dv, "glTexCoord2dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1718 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord2dv(reinterpret_cast<const GLdouble *>(array));
#line 10437 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord2dv, doc_QOpenGLFunctions_2_1_glTexCoord2dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord2d, "glTexCoord2d(self, s: float, t: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord2d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glTexCoord2d(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord2d, doc_QOpenGLFunctions_2_1_glTexCoord2d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord1sv, "glTexCoord1sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1727 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord1sv(reinterpret_cast<const GLshort *>(array));
#line 10505 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord1sv, doc_QOpenGLFunctions_2_1_glTexCoord1sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord1s, "glTexCoord1s(self, s: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glTexCoord1s(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord1s, doc_QOpenGLFunctions_2_1_glTexCoord1s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord1iv, "glTexCoord1iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1736 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord1iv(reinterpret_cast<const GLint *>(array));
#line 10572 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord1iv, doc_QOpenGLFunctions_2_1_glTexCoord1iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord1i, "glTexCoord1i(self, s: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glTexCoord1i(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord1i, doc_QOpenGLFunctions_2_1_glTexCoord1i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord1fv, "glTexCoord1fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1745 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord1fv(reinterpret_cast<const GLfloat *>(array));
#line 10639 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord1fv, doc_QOpenGLFunctions_2_1_glTexCoord1fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord1f, "glTexCoord1f(self, s: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glTexCoord1f(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord1f, doc_QOpenGLFunctions_2_1_glTexCoord1f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord1dv, "glTexCoord1dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1754 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoord1dv(reinterpret_cast<const GLdouble *>(array));
#line 10706 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord1dv, doc_QOpenGLFunctions_2_1_glTexCoord1dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoord1d, "glTexCoord1d(self, s: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoord1d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glTexCoord1d(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoord1d, doc_QOpenGLFunctions_2_1_glTexCoord1d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRects, "glRects(self, x1: int, y1: int, x2: int, y2: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRects(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRects(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::GLshort a2;
        ::GLshort a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glRects(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRects, doc_QOpenGLFunctions_2_1_glRects);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRecti, "glRecti(self, x1: int, y1: int, x2: int, y2: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRecti(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRecti(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glRecti(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRecti, doc_QOpenGLFunctions_2_1_glRecti);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRectf, "glRectf(self, x1: float, y1: float, x2: float, y2: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRectf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRectf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bffff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glRectf(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRectf, doc_QOpenGLFunctions_2_1_glRectf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRectd, "glRectd(self, x1: float, y1: float, x2: float, y2: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRectd(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRectd(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glRectd(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRectd, doc_QOpenGLFunctions_2_1_glRectd);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos4sv, "glRasterPos4sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1767 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glRasterPos4sv(reinterpret_cast<const GLshort *>(array));
#line 10889 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos4sv, doc_QOpenGLFunctions_2_1_glRasterPos4sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos4s, "glRasterPos4s(self, x: int, y: int, z: int, w: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::GLshort a2;
        ::GLshort a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glRasterPos4s(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos4s, doc_QOpenGLFunctions_2_1_glRasterPos4s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos4iv, "glRasterPos4iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1776 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glRasterPos4iv(reinterpret_cast<const GLint *>(array));
#line 10959 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos4iv, doc_QOpenGLFunctions_2_1_glRasterPos4iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos4i, "glRasterPos4i(self, x: int, y: int, z: int, w: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glRasterPos4i(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos4i, doc_QOpenGLFunctions_2_1_glRasterPos4i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos4fv, "glRasterPos4fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1785 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glRasterPos4fv(reinterpret_cast<const GLfloat *>(array));
#line 11029 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos4fv, doc_QOpenGLFunctions_2_1_glRasterPos4fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos4f, "glRasterPos4f(self, x: float, y: float, z: float, w: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bffff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glRasterPos4f(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos4f, doc_QOpenGLFunctions_2_1_glRasterPos4f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos4dv, "glRasterPos4dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1794 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glRasterPos4dv(reinterpret_cast<const GLdouble *>(array));
#line 11099 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos4dv, doc_QOpenGLFunctions_2_1_glRasterPos4dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos4d, "glRasterPos4d(self, x: float, y: float, z: float, w: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos4d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glRasterPos4d(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos4d, doc_QOpenGLFunctions_2_1_glRasterPos4d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos3sv, "glRasterPos3sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1803 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glRasterPos3sv(reinterpret_cast<const GLshort *>(array));
#line 11169 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos3sv, doc_QOpenGLFunctions_2_1_glRasterPos3sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos3s, "glRasterPos3s(self, x: int, y: int, z: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::GLshort a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glRasterPos3s(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos3s, doc_QOpenGLFunctions_2_1_glRasterPos3s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos3iv, "glRasterPos3iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1812 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glRasterPos3iv(reinterpret_cast<const GLint *>(array));
#line 11238 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos3iv, doc_QOpenGLFunctions_2_1_glRasterPos3iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos3i, "glRasterPos3i(self, x: int, y: int, z: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glRasterPos3i(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos3i, doc_QOpenGLFunctions_2_1_glRasterPos3i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos3fv, "glRasterPos3fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1821 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glRasterPos3fv(reinterpret_cast<const GLfloat *>(array));
#line 11307 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos3fv, doc_QOpenGLFunctions_2_1_glRasterPos3fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos3f, "glRasterPos3f(self, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bfff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glRasterPos3f(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos3f, doc_QOpenGLFunctions_2_1_glRasterPos3f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos3dv, "glRasterPos3dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1830 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glRasterPos3dv(reinterpret_cast<const GLdouble *>(array));
#line 11376 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos3dv, doc_QOpenGLFunctions_2_1_glRasterPos3dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos3d, "glRasterPos3d(self, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos3d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glRasterPos3d(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos3d, doc_QOpenGLFunctions_2_1_glRasterPos3d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos2sv, "glRasterPos2sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1839 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glRasterPos2sv(reinterpret_cast<const GLshort *>(array));
#line 11445 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos2sv, doc_QOpenGLFunctions_2_1_glRasterPos2sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos2s, "glRasterPos2s(self, x: int, y: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glRasterPos2s(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos2s, doc_QOpenGLFunctions_2_1_glRasterPos2s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos2iv, "glRasterPos2iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1848 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glRasterPos2iv(reinterpret_cast<const GLint *>(array));
#line 11513 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos2iv, doc_QOpenGLFunctions_2_1_glRasterPos2iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos2i, "glRasterPos2i(self, x: int, y: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glRasterPos2i(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos2i, doc_QOpenGLFunctions_2_1_glRasterPos2i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos2fv, "glRasterPos2fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1857 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glRasterPos2fv(reinterpret_cast<const GLfloat *>(array));
#line 11581 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos2fv, doc_QOpenGLFunctions_2_1_glRasterPos2fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos2f, "glRasterPos2f(self, x: float, y: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glRasterPos2f(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos2f, doc_QOpenGLFunctions_2_1_glRasterPos2f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos2dv, "glRasterPos2dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1866 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glRasterPos2dv(reinterpret_cast<const GLdouble *>(array));
#line 11649 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos2dv, doc_QOpenGLFunctions_2_1_glRasterPos2dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glRasterPos2d, "glRasterPos2d(self, x: float, y: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glRasterPos2d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glRasterPos2d(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glRasterPos2d, doc_QOpenGLFunctions_2_1_glRasterPos2d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glNormal3sv, "glNormal3sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glNormal3sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glNormal3sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1875 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glNormal3sv(reinterpret_cast<const GLshort *>(array));
#line 11717 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glNormal3sv, doc_QOpenGLFunctions_2_1_glNormal3sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glNormal3s, "glNormal3s(self, nx: int, ny: int, nz: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glNormal3s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glNormal3s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::GLshort a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glNormal3s(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glNormal3s, doc_QOpenGLFunctions_2_1_glNormal3s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glNormal3iv, "glNormal3iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glNormal3iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glNormal3iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1884 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glNormal3iv(reinterpret_cast<const GLint *>(array));
#line 11786 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glNormal3iv, doc_QOpenGLFunctions_2_1_glNormal3iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glNormal3i, "glNormal3i(self, nx: int, ny: int, nz: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glNormal3i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glNormal3i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glNormal3i(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glNormal3i, doc_QOpenGLFunctions_2_1_glNormal3i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glNormal3fv, "glNormal3fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glNormal3fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glNormal3fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1893 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glNormal3fv(reinterpret_cast<const GLfloat *>(array));
#line 11855 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glNormal3fv, doc_QOpenGLFunctions_2_1_glNormal3fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glNormal3f, "glNormal3f(self, nx: float, ny: float, nz: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glNormal3f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glNormal3f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bfff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glNormal3f(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glNormal3f, doc_QOpenGLFunctions_2_1_glNormal3f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glNormal3dv, "glNormal3dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glNormal3dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glNormal3dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1902 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glNormal3dv(reinterpret_cast<const GLdouble *>(array));
#line 11924 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glNormal3dv, doc_QOpenGLFunctions_2_1_glNormal3dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glNormal3d, "glNormal3d(self, nx: float, ny: float, nz: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glNormal3d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glNormal3d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glNormal3d(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glNormal3d, doc_QOpenGLFunctions_2_1_glNormal3d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glNormal3bv, "glNormal3bv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glNormal3bv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glNormal3bv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1911 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_BYTE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glNormal3bv(reinterpret_cast<const GLbyte *>(array));
#line 11993 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glNormal3bv, doc_QOpenGLFunctions_2_1_glNormal3bv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glNormal3b, "glNormal3b(self, nx: int, ny: int, nz: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glNormal3b(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glNormal3b(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLbyte a0;
        ::GLbyte a1;
        ::GLbyte a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BLLL", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glNormal3b(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glNormal3b, doc_QOpenGLFunctions_2_1_glNormal3b);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIndexsv, "glIndexsv(self, c: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIndexsv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIndexsv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1920 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glIndexsv(reinterpret_cast<const GLshort *>(array));
#line 12062 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIndexsv, doc_QOpenGLFunctions_2_1_glIndexsv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIndexs, "glIndexs(self, c: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIndexs(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIndexs(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glIndexs(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIndexs, doc_QOpenGLFunctions_2_1_glIndexs);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIndexiv, "glIndexiv(self, c: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIndexiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIndexiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1929 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glIndexiv(reinterpret_cast<const GLint *>(array));
#line 12129 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIndexiv, doc_QOpenGLFunctions_2_1_glIndexiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIndexi, "glIndexi(self, c: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIndexi(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIndexi(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glIndexi(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIndexi, doc_QOpenGLFunctions_2_1_glIndexi);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIndexfv, "glIndexfv(self, c: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIndexfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIndexfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1938 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glIndexfv(reinterpret_cast<const GLfloat *>(array));
#line 12196 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIndexfv, doc_QOpenGLFunctions_2_1_glIndexfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIndexf, "glIndexf(self, c: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIndexf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIndexf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glIndexf(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIndexf, doc_QOpenGLFunctions_2_1_glIndexf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIndexdv, "glIndexdv(self, c: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIndexdv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIndexdv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1947 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glIndexdv(reinterpret_cast<const GLdouble *>(array));
#line 12263 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIndexdv, doc_QOpenGLFunctions_2_1_glIndexdv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIndexd, "glIndexd(self, c: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIndexd(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIndexd(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glIndexd(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIndexd, doc_QOpenGLFunctions_2_1_glIndexd);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEnd, "glEnd(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEnd(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEnd(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp))
        {
            sipCpp->glEnd();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEnd, doc_QOpenGLFunctions_2_1_glEnd);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEdgeFlagv, "glEdgeFlagv(self, flag: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEdgeFlagv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEdgeFlagv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1957 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glEdgeFlagv(reinterpret_cast<const GLboolean *>(array));
#line 12356 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEdgeFlagv, doc_QOpenGLFunctions_2_1_glEdgeFlagv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEdgeFlag, "glEdgeFlag(self, flag: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEdgeFlag(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEdgeFlag(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLboolean a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BM", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glEdgeFlag(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEdgeFlag, doc_QOpenGLFunctions_2_1_glEdgeFlag);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4usv, "glColor4usv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4usv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4usv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1967 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_UNSIGNED_SHORT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor4usv(reinterpret_cast<const GLushort *>(array));
#line 12424 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4usv, doc_QOpenGLFunctions_2_1_glColor4usv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4us, "glColor4us(self, red: int, green: int, blue: int, alpha: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4us(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4us(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLushort a0;
        ::GLushort a1;
        ::GLushort a2;
        ::GLushort a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Btttt", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glColor4us(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4us, doc_QOpenGLFunctions_2_1_glColor4us);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4uiv, "glColor4uiv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4uiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4uiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1977 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_UNSIGNED_INT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor4uiv(reinterpret_cast<const GLuint *>(array));
#line 12495 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4uiv, doc_QOpenGLFunctions_2_1_glColor4uiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4ui, "glColor4ui(self, red: int, green: int, blue: int, alpha: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4ui(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4ui(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        ::GLuint a2;
        ::GLuint a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuuu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glColor4ui(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4ui, doc_QOpenGLFunctions_2_1_glColor4ui);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4ubv, "glColor4ubv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4ubv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4ubv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1987 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor4ubv(reinterpret_cast<const GLubyte *>(array));
#line 12566 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4ubv, doc_QOpenGLFunctions_2_1_glColor4ubv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4ub, "glColor4ub(self, red: int, green: int, blue: int, alpha: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4ub(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4ub(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLubyte a0;
        ::GLubyte a1;
        ::GLubyte a2;
        ::GLubyte a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BMMMM", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glColor4ub(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4ub, doc_QOpenGLFunctions_2_1_glColor4ub);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4sv, "glColor4sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 1997 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor4sv(reinterpret_cast<const GLshort *>(array));
#line 12636 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4sv, doc_QOpenGLFunctions_2_1_glColor4sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4s, "glColor4s(self, red: int, green: int, blue: int, alpha: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::GLshort a2;
        ::GLshort a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glColor4s(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4s, doc_QOpenGLFunctions_2_1_glColor4s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4iv, "glColor4iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2006 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor4iv(reinterpret_cast<const GLint *>(array));
#line 12706 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4iv, doc_QOpenGLFunctions_2_1_glColor4iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4i, "glColor4i(self, red: int, green: int, blue: int, alpha: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glColor4i(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4i, doc_QOpenGLFunctions_2_1_glColor4i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4fv, "glColor4fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2015 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor4fv(reinterpret_cast<const GLfloat *>(array));
#line 12776 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4fv, doc_QOpenGLFunctions_2_1_glColor4fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4f, "glColor4f(self, red: float, green: float, blue: float, alpha: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bffff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glColor4f(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4f, doc_QOpenGLFunctions_2_1_glColor4f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4dv, "glColor4dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2024 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor4dv(reinterpret_cast<const GLdouble *>(array));
#line 12846 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4dv, doc_QOpenGLFunctions_2_1_glColor4dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4d, "glColor4d(self, red: float, green: float, blue: float, alpha: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glColor4d(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4d, doc_QOpenGLFunctions_2_1_glColor4d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4bv, "glColor4bv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4bv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4bv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2033 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_BYTE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor4bv(reinterpret_cast<const GLbyte *>(array));
#line 12916 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4bv, doc_QOpenGLFunctions_2_1_glColor4bv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor4b, "glColor4b(self, red: int, green: int, blue: int, alpha: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor4b(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor4b(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLbyte a0;
        ::GLbyte a1;
        ::GLbyte a2;
        ::GLbyte a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BLLLL", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glColor4b(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor4b, doc_QOpenGLFunctions_2_1_glColor4b);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3usv, "glColor3usv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3usv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3usv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2042 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_UNSIGNED_SHORT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor3usv(reinterpret_cast<const GLushort *>(array));
#line 12987 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3usv, doc_QOpenGLFunctions_2_1_glColor3usv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3us, "glColor3us(self, red: int, green: int, blue: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3us(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3us(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLushort a0;
        ::GLushort a1;
        ::GLushort a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bttt", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glColor3us(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3us, doc_QOpenGLFunctions_2_1_glColor3us);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3uiv, "glColor3uiv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3uiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3uiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2052 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_UNSIGNED_INT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor3uiv(reinterpret_cast<const GLuint *>(array));
#line 13057 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3uiv, doc_QOpenGLFunctions_2_1_glColor3uiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3ui, "glColor3ui(self, red: int, green: int, blue: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3ui(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3ui(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        ::GLuint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glColor3ui(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3ui, doc_QOpenGLFunctions_2_1_glColor3ui);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3ubv, "glColor3ubv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3ubv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3ubv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2062 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor3ubv(reinterpret_cast<const GLubyte *>(array));
#line 13127 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3ubv, doc_QOpenGLFunctions_2_1_glColor3ubv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3ub, "glColor3ub(self, red: int, green: int, blue: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3ub(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3ub(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLubyte a0;
        ::GLubyte a1;
        ::GLubyte a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BMMM", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glColor3ub(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3ub, doc_QOpenGLFunctions_2_1_glColor3ub);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3sv, "glColor3sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2072 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor3sv(reinterpret_cast<const GLshort *>(array));
#line 13196 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3sv, doc_QOpenGLFunctions_2_1_glColor3sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3s, "glColor3s(self, red: int, green: int, blue: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::GLshort a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glColor3s(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3s, doc_QOpenGLFunctions_2_1_glColor3s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3iv, "glColor3iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2081 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor3iv(reinterpret_cast<const GLint *>(array));
#line 13265 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3iv, doc_QOpenGLFunctions_2_1_glColor3iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3i, "glColor3i(self, red: int, green: int, blue: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glColor3i(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3i, doc_QOpenGLFunctions_2_1_glColor3i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3fv, "glColor3fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2090 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor3fv(reinterpret_cast<const GLfloat *>(array));
#line 13334 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3fv, doc_QOpenGLFunctions_2_1_glColor3fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3f, "glColor3f(self, red: float, green: float, blue: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bfff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glColor3f(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3f, doc_QOpenGLFunctions_2_1_glColor3f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3dv, "glColor3dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2099 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor3dv(reinterpret_cast<const GLdouble *>(array));
#line 13403 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3dv, doc_QOpenGLFunctions_2_1_glColor3dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3d, "glColor3d(self, red: float, green: float, blue: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glColor3d(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3d, doc_QOpenGLFunctions_2_1_glColor3d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3bv, "glColor3bv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3bv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3bv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2108 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_BYTE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColor3bv(reinterpret_cast<const GLbyte *>(array));
#line 13472 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3bv, doc_QOpenGLFunctions_2_1_glColor3bv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColor3b, "glColor3b(self, red: int, green: int, blue: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColor3b(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColor3b(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLbyte a0;
        ::GLbyte a1;
        ::GLbyte a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BLLL", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glColor3b(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColor3b, doc_QOpenGLFunctions_2_1_glColor3b);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glBitmap, "glBitmap(self, width: int, height: int, xorig: float, yorig: float, xmove: float, ymove: float, bitmap: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glBitmap(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glBitmap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        ::GLsizei a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::GLfloat a4;
        ::GLfloat a5;
        PyObject * a6;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiffffP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6))
        {
            sipErrorState sipError = sipErrorNone;

#line 2117 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a6, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glBitmap(a0, a1, a2, a3, a4, a5,
                    reinterpret_cast<const GLubyte *>(array));
#line 13549 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glBitmap, doc_QOpenGLFunctions_2_1_glBitmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glBegin, "glBegin(self, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glBegin(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glBegin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glBegin(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glBegin, doc_QOpenGLFunctions_2_1_glBegin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glListBase, "glListBase(self, base: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glListBase(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glListBase(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glListBase(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glListBase, doc_QOpenGLFunctions_2_1_glListBase);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGenLists, "glGenLists(self, range: int) -> int");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGenLists(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGenLists(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            ::GLuint sipRes;

            sipRes = sipCpp->glGenLists(a0);

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGenLists, doc_QOpenGLFunctions_2_1_glGenLists);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDeleteLists, "glDeleteLists(self, list: int, range: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDeleteLists(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDeleteLists(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLsizei a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bui", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glDeleteLists(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDeleteLists, doc_QOpenGLFunctions_2_1_glDeleteLists);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCallList, "glCallList(self, list: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCallList(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCallList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glCallList(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCallList, doc_QOpenGLFunctions_2_1_glCallList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEndList, "glEndList(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEndList(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEndList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp))
        {
            sipCpp->glEndList();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEndList, doc_QOpenGLFunctions_2_1_glEndList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glNewList, "glNewList(self, list: int, mode: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glNewList(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glNewList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLenum a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glNewList(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glNewList, doc_QOpenGLFunctions_2_1_glNewList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPushClientAttrib, "glPushClientAttrib(self, mask: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPushClientAttrib(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPushClientAttrib(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLbitfield a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glPushClientAttrib(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPushClientAttrib, doc_QOpenGLFunctions_2_1_glPushClientAttrib);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glPopClientAttrib, "glPopClientAttrib(self)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glPopClientAttrib(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glPopClientAttrib(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp))
        {
            sipCpp->glPopClientAttrib();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glPopClientAttrib, doc_QOpenGLFunctions_2_1_glPopClientAttrib);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexPointer, "glVertexPointer(self, size: int, type: int, stride: int, pointer: PYQT_OPENGL_BOUND_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexPointer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexPointer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLenum a1;
        ::GLsizei a2;
        PyObject * a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiuiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 2136 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array_cached(&sipError, a3, a1, sipSelf,
                "VertexPointer", 0);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexPointer(a0, a1, a2, array);
#line 13829 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexPointer, doc_QOpenGLFunctions_2_1_glVertexPointer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glTexCoordPointer, "glTexCoordPointer(self, size: int, type: int, stride: int, pointer: PYQT_OPENGL_BOUND_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glTexCoordPointer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glTexCoordPointer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLenum a1;
        ::GLsizei a2;
        PyObject * a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiuiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 2145 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array_cached(&sipError, a3, a1, sipSelf,
                "TexCoordPointer", 0);
        
        if (sipError == sipErrorNone)
            sipCpp->glTexCoordPointer(a0, a1, a2, array);
#line 13874 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glTexCoordPointer, doc_QOpenGLFunctions_2_1_glTexCoordPointer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glNormalPointer, "glNormalPointer(self, type: int, stride: int, pointer: PYQT_OPENGL_BOUND_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glNormalPointer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glNormalPointer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 2154 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array_cached(&sipError, a2, a0, sipSelf,
                "NormalPointer", 0);
        
        if (sipError == sipErrorNone)
            sipCpp->glNormalPointer(a0, a1, array);
#line 13918 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glNormalPointer, doc_QOpenGLFunctions_2_1_glNormalPointer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glIndexPointer, "glIndexPointer(self, type: int, stride: int, pointer: PYQT_OPENGL_BOUND_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glIndexPointer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glIndexPointer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 2163 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array_cached(&sipError, a2, a0, sipSelf,
                "IndexPointer", 0);
        
        if (sipError == sipErrorNone)
            sipCpp->glIndexPointer(a0, a1, array);
#line 13962 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glIndexPointer, doc_QOpenGLFunctions_2_1_glIndexPointer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEnableClientState, "glEnableClientState(self, array: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEnableClientState(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEnableClientState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glEnableClientState(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEnableClientState, doc_QOpenGLFunctions_2_1_glEnableClientState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glEdgeFlagPointer, "glEdgeFlagPointer(self, stride: int, pointer: PYQT_OPENGL_BOUND_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glEdgeFlagPointer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glEdgeFlagPointer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLsizei a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2173 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array_cached(&sipError, a1,
                GL_UNSIGNED_BYTE, sipSelf, "EdgeFlagPointer", 0);
        
        if (sipError == sipErrorNone)
            sipCpp->glEdgeFlagPointer(a0, array);
#line 14031 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glEdgeFlagPointer, doc_QOpenGLFunctions_2_1_glEdgeFlagPointer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glDisableClientState, "glDisableClientState(self, array: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glDisableClientState(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glDisableClientState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glDisableClientState(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glDisableClientState, doc_QOpenGLFunctions_2_1_glDisableClientState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColorPointer, "glColorPointer(self, size: int, type: int, stride: int, pointer: PYQT_OPENGL_BOUND_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColorPointer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColorPointer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLenum a1;
        ::GLsizei a2;
        PyObject * a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiuiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 2183 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array_cached(&sipError, a3, a1, sipSelf,
                "ColorPointer", 0);
        
        if (sipError == sipErrorNone)
            sipCpp->glColorPointer(a0, a1, a2, array);
#line 14102 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColorPointer, doc_QOpenGLFunctions_2_1_glColorPointer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glArrayElement, "glArrayElement(self, i: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glArrayElement(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glArrayElement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glArrayElement(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glArrayElement, doc_QOpenGLFunctions_2_1_glArrayElement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glResetMinmax, "glResetMinmax(self, target: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glResetMinmax(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glResetMinmax(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glResetMinmax(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glResetMinmax, doc_QOpenGLFunctions_2_1_glResetMinmax);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glResetHistogram, "glResetHistogram(self, target: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glResetHistogram(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glResetHistogram(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glResetHistogram(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glResetHistogram, doc_QOpenGLFunctions_2_1_glResetHistogram);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMinmax, "glMinmax(self, target: int, internalformat: int, sink: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMinmax(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMinmax(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLboolean a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuM", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glMinmax(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMinmax, doc_QOpenGLFunctions_2_1_glMinmax);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glHistogram, "glHistogram(self, target: int, width: int, internalformat: int, sink: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glHistogram(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glHistogram(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLsizei a1;
        ::GLenum a2;
        ::GLboolean a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiuM", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glHistogram(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glHistogram, doc_QOpenGLFunctions_2_1_glHistogram);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetConvolutionParameteriv, "glGetConvolutionParameteriv(self, target: int, pname: int) -> Optional[Union[int, tuple[int, int, int, int]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetConvolutionParameteriv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetConvolutionParameteriv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 2197 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_CONVOLUTION_BORDER_COLOR:
        case GL_CONVOLUTION_FILTER_SCALE:
        case GL_CONVOLUTION_FILTER_BIAS:
            nr_params = 4;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetConvolutionParameteriv(a0, a1, params);
        
        a2 = qpyopengl_from_GLint(&sipIsErr, params, nr_params);
#line 14294 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetConvolutionParameteriv, doc_QOpenGLFunctions_2_1_glGetConvolutionParameteriv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetConvolutionParameterfv, "glGetConvolutionParameterfv(self, target: int, pname: int) -> Optional[Union[float, tuple[float, float, float, float]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetConvolutionParameterfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetConvolutionParameterfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 2219 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLfloat params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_CONVOLUTION_BORDER_COLOR:
        case GL_CONVOLUTION_FILTER_SCALE:
        case GL_CONVOLUTION_FILTER_BIAS:
            nr_params = 4;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetConvolutionParameterfv(a0, a1, params);
        
        a2 = qpyopengl_from_GLfloat(&sipIsErr, params, nr_params);
#line 14345 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetConvolutionParameterfv, doc_QOpenGLFunctions_2_1_glGetConvolutionParameterfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCopyConvolutionFilter2D, "glCopyConvolutionFilter2D(self, target: int, internalformat: int, x: int, y: int, width: int, height: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCopyConvolutionFilter2D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCopyConvolutionFilter2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::GLint a3;
        ::GLsizei a4;
        ::GLsizei a5;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuiiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->glCopyConvolutionFilter2D(a0, a1, a2, a3, a4, a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCopyConvolutionFilter2D, doc_QOpenGLFunctions_2_1_glCopyConvolutionFilter2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCopyConvolutionFilter1D, "glCopyConvolutionFilter1D(self, target: int, internalformat: int, x: int, y: int, width: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCopyConvolutionFilter1D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCopyConvolutionFilter1D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::GLint a3;
        ::GLsizei a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glCopyConvolutionFilter1D(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCopyConvolutionFilter1D, doc_QOpenGLFunctions_2_1_glCopyConvolutionFilter1D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glConvolutionParameteriv, "glConvolutionParameteriv(self, target: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glConvolutionParameteriv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glConvolutionParameteriv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 2243 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glConvolutionParameteriv(a0, a1,
                    reinterpret_cast<const GLint *>(array));
#line 14444 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glConvolutionParameteriv, doc_QOpenGLFunctions_2_1_glConvolutionParameteriv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glConvolutionParameteri, "glConvolutionParameteri(self, target: int, pname: int, params: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glConvolutionParameteri(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glConvolutionParameteri(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buui", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glConvolutionParameteri(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glConvolutionParameteri, doc_QOpenGLFunctions_2_1_glConvolutionParameteri);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glConvolutionParameterfv, "glConvolutionParameterfv(self, target: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glConvolutionParameterfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glConvolutionParameterfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 2253 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glConvolutionParameterfv(a0, a1,
                    reinterpret_cast<const GLfloat *>(array));
#line 14516 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glConvolutionParameterfv, doc_QOpenGLFunctions_2_1_glConvolutionParameterfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glConvolutionParameterf, "glConvolutionParameterf(self, target: int, pname: int, params: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glConvolutionParameterf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glConvolutionParameterf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glConvolutionParameterf(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glConvolutionParameterf, doc_QOpenGLFunctions_2_1_glConvolutionParameterf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glConvolutionFilter2D, "glConvolutionFilter2D(self, target: int, internalformat: int, width: int, height: int, format: int, type: int, image: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glConvolutionFilter2D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glConvolutionFilter2D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLsizei a2;
        ::GLsizei a3;
        ::GLenum a4;
        ::GLenum a5;
        PyObject * a6;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuiiuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, &a6))
        {
            sipErrorState sipError = sipErrorNone;

#line 2263 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a6, a5, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glConvolutionFilter2D(a0, a1, a2, a3, a4, a5, array);
#line 14591 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glConvolutionFilter2D, doc_QOpenGLFunctions_2_1_glConvolutionFilter2D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glConvolutionFilter1D, "glConvolutionFilter1D(self, target: int, internalformat: int, width: int, format: int, type: int, image: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glConvolutionFilter1D(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glConvolutionFilter1D(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLsizei a2;
        ::GLenum a3;
        ::GLenum a4;
        PyObject * a5;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuiuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipErrorState sipError = sipErrorNone;

#line 2271 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a5, a4, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glConvolutionFilter1D(a0, a1, a2, a3, a4, array);
#line 14637 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glConvolutionFilter1D, doc_QOpenGLFunctions_2_1_glConvolutionFilter1D);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCopyColorSubTable, "glCopyColorSubTable(self, target: int, start: int, x: int, y: int, width: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCopyColorSubTable(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCopyColorSubTable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLsizei a1;
        ::GLint a2;
        ::GLint a3;
        ::GLsizei a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glCopyColorSubTable(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCopyColorSubTable, doc_QOpenGLFunctions_2_1_glCopyColorSubTable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColorSubTable, "glColorSubTable(self, target: int, start: int, count: int, format: int, type: int, data: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColorSubTable(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColorSubTable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLsizei a1;
        ::GLsizei a2;
        ::GLenum a3;
        ::GLenum a4;
        PyObject * a5;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiiuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipErrorState sipError = sipErrorNone;

#line 2280 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a5, a4, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColorSubTable(a0, a1, a2, a3, a4, array);
#line 14713 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColorSubTable, doc_QOpenGLFunctions_2_1_glColorSubTable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetColorTableParameteriv, "glGetColorTableParameteriv(self, target: int, pname: int) -> Optional[Union[int, tuple[int, int, int, int]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetColorTableParameteriv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetColorTableParameteriv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 2288 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLint params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_COLOR_TABLE:
        case GL_POST_CONVOLUTION_COLOR_TABLE:
        case GL_POST_COLOR_MATRIX_COLOR_TABLE:
            nr_params = 4;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetColorTableParameteriv(a0, a1, params);
        
        a2 = qpyopengl_from_GLint(&sipIsErr, params, nr_params);
#line 14770 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetColorTableParameteriv, doc_QOpenGLFunctions_2_1_glGetColorTableParameteriv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glGetColorTableParameterfv, "glGetColorTableParameterfv(self, target: int, pname: int) -> Optional[Union[float, tuple[float, float, float, float]]]");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glGetColorTableParameterfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glGetColorTableParameterfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            int sipIsErr = 0;

#line 2310 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        GLfloat params[4];
        Py_ssize_t nr_params;
        
        switch (a1)
        {
        case GL_COLOR_TABLE:
        case GL_POST_CONVOLUTION_COLOR_TABLE:
        case GL_POST_COLOR_MATRIX_COLOR_TABLE:
            nr_params = 4;
            break;
        
        default:
            nr_params = 1;
        }
        
        sipCpp->glGetColorTableParameterfv(a0, a1, params);
        
        a2 = qpyopengl_from_GLfloat(&sipIsErr, params, nr_params);
#line 14821 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipIsErr)
                return 0;

            return a2;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glGetColorTableParameterfv, doc_QOpenGLFunctions_2_1_glGetColorTableParameterfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glCopyColorTable, "glCopyColorTable(self, target: int, internalformat: int, x: int, y: int, width: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glCopyColorTable(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glCopyColorTable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLint a2;
        ::GLint a3;
        ::GLsizei a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glCopyColorTable(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glCopyColorTable, doc_QOpenGLFunctions_2_1_glCopyColorTable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColorTableParameteriv, "glColorTableParameteriv(self, target: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColorTableParameteriv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColorTableParameteriv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 2333 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColorTableParameteriv(a0, a1,
                    reinterpret_cast<const GLint *>(array));
#line 14889 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColorTableParameteriv, doc_QOpenGLFunctions_2_1_glColorTableParameteriv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColorTableParameterfv, "glColorTableParameterfv(self, target: int, pname: int, params: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColorTableParameterfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColorTableParameterfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 2342 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColorTableParameterfv(a0, a1,
                    reinterpret_cast<const GLfloat *>(array));
#line 14933 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColorTableParameterfv, doc_QOpenGLFunctions_2_1_glColorTableParameterfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glColorTable, "glColorTable(self, target: int, internalformat: int, width: int, format: int, type: int, table: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glColorTable(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glColorTable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLenum a1;
        ::GLsizei a2;
        ::GLenum a3;
        ::GLenum a4;
        PyObject * a5;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuuiuuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipErrorState sipError = sipErrorNone;

#line 2351 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a5, a4, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glColorTable(a0, a1, a2, a3, a4, array);
#line 14979 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glColorTable, doc_QOpenGLFunctions_2_1_glColorTable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultTransposeMatrixd, "glMultTransposeMatrixd(self, m: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultTransposeMatrixd(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultTransposeMatrixd(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2359 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultTransposeMatrixd(reinterpret_cast<const GLdouble *>(array));
#line 15020 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultTransposeMatrixd, doc_QOpenGLFunctions_2_1_glMultTransposeMatrixd);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultTransposeMatrixf, "glMultTransposeMatrixf(self, m: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultTransposeMatrixf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultTransposeMatrixf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2367 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultTransposeMatrixf(reinterpret_cast<const GLfloat *>(array));
#line 15061 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultTransposeMatrixf, doc_QOpenGLFunctions_2_1_glMultTransposeMatrixf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLoadTransposeMatrixd, "glLoadTransposeMatrixd(self, m: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLoadTransposeMatrixd(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLoadTransposeMatrixd(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2375 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glLoadTransposeMatrixd(reinterpret_cast<const GLdouble *>(array));
#line 15102 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLoadTransposeMatrixd, doc_QOpenGLFunctions_2_1_glLoadTransposeMatrixd);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glLoadTransposeMatrixf, "glLoadTransposeMatrixf(self, m: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glLoadTransposeMatrixf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glLoadTransposeMatrixf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2383 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glLoadTransposeMatrixf(reinterpret_cast<const GLfloat *>(array));
#line 15143 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glLoadTransposeMatrixf, doc_QOpenGLFunctions_2_1_glLoadTransposeMatrixf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord4sv, "glMultiTexCoord4sv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2391 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord4sv(a0, reinterpret_cast<const GLshort *>(array));
#line 15185 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord4sv, doc_QOpenGLFunctions_2_1_glMultiTexCoord4sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord4s, "glMultiTexCoord4s(self, target: int, s: int, t: int, r: int, q: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLshort a1;
        ::GLshort a2;
        ::GLshort a3;
        ::GLshort a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buhhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glMultiTexCoord4s(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord4s, doc_QOpenGLFunctions_2_1_glMultiTexCoord4s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord4iv, "glMultiTexCoord4iv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2400 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord4iv(a0, reinterpret_cast<const GLint *>(array));
#line 15257 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord4iv, doc_QOpenGLFunctions_2_1_glMultiTexCoord4iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord4i, "glMultiTexCoord4i(self, target: int, s: int, t: int, r: int, q: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::GLint a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glMultiTexCoord4i(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord4i, doc_QOpenGLFunctions_2_1_glMultiTexCoord4i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord4fv, "glMultiTexCoord4fv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2409 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord4fv(a0, reinterpret_cast<const GLfloat *>(array));
#line 15329 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord4fv, doc_QOpenGLFunctions_2_1_glMultiTexCoord4fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord4f, "glMultiTexCoord4f(self, target: int, s: float, t: float, r: float, q: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::GLfloat a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buffff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glMultiTexCoord4f(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord4f, doc_QOpenGLFunctions_2_1_glMultiTexCoord4f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord4dv, "glMultiTexCoord4dv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2418 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord4dv(a0, reinterpret_cast<const GLdouble *>(array));
#line 15401 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord4dv, doc_QOpenGLFunctions_2_1_glMultiTexCoord4dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord4d, "glMultiTexCoord4d(self, target: int, s: float, t: float, r: float, q: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord4d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::GLdouble a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Budddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glMultiTexCoord4d(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord4d, doc_QOpenGLFunctions_2_1_glMultiTexCoord4d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord3sv, "glMultiTexCoord3sv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2427 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord3sv(a0, reinterpret_cast<const GLshort *>(array));
#line 15473 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord3sv, doc_QOpenGLFunctions_2_1_glMultiTexCoord3sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord3s, "glMultiTexCoord3s(self, target: int, s: int, t: int, r: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLshort a1;
        ::GLshort a2;
        ::GLshort a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glMultiTexCoord3s(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord3s, doc_QOpenGLFunctions_2_1_glMultiTexCoord3s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord3iv, "glMultiTexCoord3iv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2436 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord3iv(a0, reinterpret_cast<const GLint *>(array));
#line 15544 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord3iv, doc_QOpenGLFunctions_2_1_glMultiTexCoord3iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord3i, "glMultiTexCoord3i(self, target: int, s: int, t: int, r: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::GLint a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buiii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glMultiTexCoord3i(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord3i, doc_QOpenGLFunctions_2_1_glMultiTexCoord3i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord3fv, "glMultiTexCoord3fv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2445 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord3fv(a0, reinterpret_cast<const GLfloat *>(array));
#line 15615 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord3fv, doc_QOpenGLFunctions_2_1_glMultiTexCoord3fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord3f, "glMultiTexCoord3f(self, target: int, s: float, t: float, r: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bufff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glMultiTexCoord3f(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord3f, doc_QOpenGLFunctions_2_1_glMultiTexCoord3f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord3dv, "glMultiTexCoord3dv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2454 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord3dv(a0, reinterpret_cast<const GLdouble *>(array));
#line 15686 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord3dv, doc_QOpenGLFunctions_2_1_glMultiTexCoord3dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord3d, "glMultiTexCoord3d(self, target: int, s: float, t: float, r: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord3d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glMultiTexCoord3d(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord3d, doc_QOpenGLFunctions_2_1_glMultiTexCoord3d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord2sv, "glMultiTexCoord2sv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2463 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord2sv(a0, reinterpret_cast<const GLshort *>(array));
#line 15757 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord2sv, doc_QOpenGLFunctions_2_1_glMultiTexCoord2sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord2s, "glMultiTexCoord2s(self, target: int, s: int, t: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLshort a1;
        ::GLshort a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glMultiTexCoord2s(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord2s, doc_QOpenGLFunctions_2_1_glMultiTexCoord2s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord2iv, "glMultiTexCoord2iv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2472 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord2iv(a0, reinterpret_cast<const GLint *>(array));
#line 15827 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord2iv, doc_QOpenGLFunctions_2_1_glMultiTexCoord2iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord2i, "glMultiTexCoord2i(self, target: int, s: int, t: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glMultiTexCoord2i(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord2i, doc_QOpenGLFunctions_2_1_glMultiTexCoord2i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord2fv, "glMultiTexCoord2fv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2481 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord2fv(a0, reinterpret_cast<const GLfloat *>(array));
#line 15897 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord2fv, doc_QOpenGLFunctions_2_1_glMultiTexCoord2fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord2f, "glMultiTexCoord2f(self, target: int, s: float, t: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glMultiTexCoord2f(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord2f, doc_QOpenGLFunctions_2_1_glMultiTexCoord2f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord2dv, "glMultiTexCoord2dv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2490 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord2dv(a0, reinterpret_cast<const GLdouble *>(array));
#line 15967 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord2dv, doc_QOpenGLFunctions_2_1_glMultiTexCoord2dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord2d, "glMultiTexCoord2d(self, target: int, s: float, t: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord2d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Budd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glMultiTexCoord2d(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord2d, doc_QOpenGLFunctions_2_1_glMultiTexCoord2d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord1sv, "glMultiTexCoord1sv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2499 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord1sv(a0, reinterpret_cast<const GLshort *>(array));
#line 16037 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord1sv, doc_QOpenGLFunctions_2_1_glMultiTexCoord1sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord1s, "glMultiTexCoord1s(self, target: int, s: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLshort a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glMultiTexCoord1s(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord1s, doc_QOpenGLFunctions_2_1_glMultiTexCoord1s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord1iv, "glMultiTexCoord1iv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2508 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord1iv(a0, reinterpret_cast<const GLint *>(array));
#line 16106 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord1iv, doc_QOpenGLFunctions_2_1_glMultiTexCoord1iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord1i, "glMultiTexCoord1i(self, target: int, s: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bui", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glMultiTexCoord1i(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord1i, doc_QOpenGLFunctions_2_1_glMultiTexCoord1i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord1fv, "glMultiTexCoord1fv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2517 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord1fv(a0, reinterpret_cast<const GLfloat *>(array));
#line 16175 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord1fv, doc_QOpenGLFunctions_2_1_glMultiTexCoord1fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord1f, "glMultiTexCoord1f(self, target: int, s: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glMultiTexCoord1f(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord1f, doc_QOpenGLFunctions_2_1_glMultiTexCoord1f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord1dv, "glMultiTexCoord1dv(self, target: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2526 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glMultiTexCoord1dv(a0, reinterpret_cast<const GLdouble *>(array));
#line 16244 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord1dv, doc_QOpenGLFunctions_2_1_glMultiTexCoord1dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glMultiTexCoord1d, "glMultiTexCoord1d(self, target: int, s: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glMultiTexCoord1d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLdouble a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bud", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glMultiTexCoord1d(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glMultiTexCoord1d, doc_QOpenGLFunctions_2_1_glMultiTexCoord1d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glClientActiveTexture, "glClientActiveTexture(self, texture: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glClientActiveTexture(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glClientActiveTexture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glClientActiveTexture(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glClientActiveTexture, doc_QOpenGLFunctions_2_1_glClientActiveTexture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos3sv, "glWindowPos3sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2536 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glWindowPos3sv(reinterpret_cast<const GLshort *>(array));
#line 16338 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos3sv, doc_QOpenGLFunctions_2_1_glWindowPos3sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos3s, "glWindowPos3s(self, x: int, y: int, z: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::GLshort a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glWindowPos3s(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos3s, doc_QOpenGLFunctions_2_1_glWindowPos3s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos3iv, "glWindowPos3iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2545 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glWindowPos3iv(reinterpret_cast<const GLint *>(array));
#line 16407 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos3iv, doc_QOpenGLFunctions_2_1_glWindowPos3iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos3i, "glWindowPos3i(self, x: int, y: int, z: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glWindowPos3i(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos3i, doc_QOpenGLFunctions_2_1_glWindowPos3i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos3fv, "glWindowPos3fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2554 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glWindowPos3fv(reinterpret_cast<const GLfloat *>(array));
#line 16476 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos3fv, doc_QOpenGLFunctions_2_1_glWindowPos3fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos3f, "glWindowPos3f(self, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bfff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glWindowPos3f(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos3f, doc_QOpenGLFunctions_2_1_glWindowPos3f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos3dv, "glWindowPos3dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2563 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glWindowPos3dv(reinterpret_cast<const GLdouble *>(array));
#line 16545 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos3dv, doc_QOpenGLFunctions_2_1_glWindowPos3dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos3d, "glWindowPos3d(self, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos3d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glWindowPos3d(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos3d, doc_QOpenGLFunctions_2_1_glWindowPos3d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos2sv, "glWindowPos2sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2572 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glWindowPos2sv(reinterpret_cast<const GLshort *>(array));
#line 16614 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos2sv, doc_QOpenGLFunctions_2_1_glWindowPos2sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos2s, "glWindowPos2s(self, x: int, y: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glWindowPos2s(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos2s, doc_QOpenGLFunctions_2_1_glWindowPos2s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos2iv, "glWindowPos2iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2581 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glWindowPos2iv(reinterpret_cast<const GLint *>(array));
#line 16682 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos2iv, doc_QOpenGLFunctions_2_1_glWindowPos2iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos2i, "glWindowPos2i(self, x: int, y: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glWindowPos2i(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos2i, doc_QOpenGLFunctions_2_1_glWindowPos2i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos2fv, "glWindowPos2fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2590 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glWindowPos2fv(reinterpret_cast<const GLfloat *>(array));
#line 16750 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos2fv, doc_QOpenGLFunctions_2_1_glWindowPos2fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos2f, "glWindowPos2f(self, x: float, y: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glWindowPos2f(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos2f, doc_QOpenGLFunctions_2_1_glWindowPos2f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos2dv, "glWindowPos2dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2599 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glWindowPos2dv(reinterpret_cast<const GLdouble *>(array));
#line 16818 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos2dv, doc_QOpenGLFunctions_2_1_glWindowPos2dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glWindowPos2d, "glWindowPos2d(self, x: float, y: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glWindowPos2d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glWindowPos2d(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glWindowPos2d, doc_QOpenGLFunctions_2_1_glWindowPos2d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColorPointer, "glSecondaryColorPointer(self, size: int, type: int, stride: int, pointer: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColorPointer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColorPointer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLenum a1;
        ::GLsizei a2;
        PyObject * a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiuiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipErrorState sipError = sipErrorNone;

#line 2608 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a3, a1, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glSecondaryColorPointer(a0, a1, a2, array);
#line 16889 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColorPointer, doc_QOpenGLFunctions_2_1_glSecondaryColorPointer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3usv, "glSecondaryColor3usv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3usv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3usv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2616 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_UNSIGNED_SHORT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glSecondaryColor3usv(reinterpret_cast<const GLushort *>(array));
#line 16931 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3usv, doc_QOpenGLFunctions_2_1_glSecondaryColor3usv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3us, "glSecondaryColor3us(self, red: int, green: int, blue: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3us(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3us(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLushort a0;
        ::GLushort a1;
        ::GLushort a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bttt", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glSecondaryColor3us(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3us, doc_QOpenGLFunctions_2_1_glSecondaryColor3us);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3uiv, "glSecondaryColor3uiv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3uiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3uiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2626 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_UNSIGNED_INT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glSecondaryColor3uiv(reinterpret_cast<const GLuint *>(array));
#line 17001 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3uiv, doc_QOpenGLFunctions_2_1_glSecondaryColor3uiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3ui, "glSecondaryColor3ui(self, red: int, green: int, blue: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3ui(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3ui(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLuint a1;
        ::GLuint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buuu", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glSecondaryColor3ui(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3ui, doc_QOpenGLFunctions_2_1_glSecondaryColor3ui);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3ubv, "glSecondaryColor3ubv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3ubv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3ubv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2636 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glSecondaryColor3ubv(reinterpret_cast<const GLubyte *>(array));
#line 17071 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3ubv, doc_QOpenGLFunctions_2_1_glSecondaryColor3ubv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3ub, "glSecondaryColor3ub(self, red: int, green: int, blue: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3ub(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3ub(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLubyte a0;
        ::GLubyte a1;
        ::GLubyte a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BMMM", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glSecondaryColor3ub(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3ub, doc_QOpenGLFunctions_2_1_glSecondaryColor3ub);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3sv, "glSecondaryColor3sv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B!", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2646 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glSecondaryColor3sv(reinterpret_cast<const GLshort *>(array));
#line 17140 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3sv, doc_QOpenGLFunctions_2_1_glSecondaryColor3sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3s, "glSecondaryColor3s(self, red: int, green: int, blue: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLshort a0;
        ::GLshort a1;
        ::GLshort a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glSecondaryColor3s(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3s, doc_QOpenGLFunctions_2_1_glSecondaryColor3s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3iv, "glSecondaryColor3iv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2655 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glSecondaryColor3iv(reinterpret_cast<const GLint *>(array));
#line 17209 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3iv, doc_QOpenGLFunctions_2_1_glSecondaryColor3iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3i, "glSecondaryColor3i(self, red: int, green: int, blue: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3i(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3i(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLint a0;
        ::GLint a1;
        ::GLint a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biii", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glSecondaryColor3i(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3i, doc_QOpenGLFunctions_2_1_glSecondaryColor3i);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3fv, "glSecondaryColor3fv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2664 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glSecondaryColor3fv(reinterpret_cast<const GLfloat *>(array));
#line 17278 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3fv, doc_QOpenGLFunctions_2_1_glSecondaryColor3fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3f, "glSecondaryColor3f(self, red: float, green: float, blue: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bfff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glSecondaryColor3f(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3f, doc_QOpenGLFunctions_2_1_glSecondaryColor3f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3dv, "glSecondaryColor3dv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2673 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glSecondaryColor3dv(reinterpret_cast<const GLdouble *>(array));
#line 17347 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3dv, doc_QOpenGLFunctions_2_1_glSecondaryColor3dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3d, "glSecondaryColor3d(self, red: float, green: float, blue: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glSecondaryColor3d(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3d, doc_QOpenGLFunctions_2_1_glSecondaryColor3d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3bv, "glSecondaryColor3bv(self, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3bv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3bv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2682 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_BYTE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glSecondaryColor3bv(reinterpret_cast<const GLbyte *>(array));
#line 17416 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3bv, doc_QOpenGLFunctions_2_1_glSecondaryColor3bv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glSecondaryColor3b, "glSecondaryColor3b(self, red: int, green: int, blue: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3b(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glSecondaryColor3b(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLbyte a0;
        ::GLbyte a1;
        ::GLbyte a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BLLL", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glSecondaryColor3b(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glSecondaryColor3b, doc_QOpenGLFunctions_2_1_glSecondaryColor3b);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glFogCoordPointer, "glFogCoordPointer(self, type: int, stride: int, pointer: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glFogCoordPointer(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glFogCoordPointer(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLenum a0;
        ::GLsizei a1;
        PyObject * a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuiP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipErrorState sipError = sipErrorNone;

#line 2691 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a2, a0, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glFogCoordPointer(a0, a1, array);
#line 17487 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glFogCoordPointer, doc_QOpenGLFunctions_2_1_glFogCoordPointer);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glFogCoorddv, "glFogCoorddv(self, coord: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glFogCoorddv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glFogCoorddv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2699 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glFogCoorddv(reinterpret_cast<const GLdouble *>(array));
#line 17528 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glFogCoorddv, doc_QOpenGLFunctions_2_1_glFogCoorddv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glFogCoordd, "glFogCoordd(self, coord: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glFogCoordd(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glFogCoordd(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLdouble a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glFogCoordd(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glFogCoordd, doc_QOpenGLFunctions_2_1_glFogCoordd);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glFogCoordfv, "glFogCoordfv(self, coord: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glFogCoordfv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glFogCoordfv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipErrorState sipError = sipErrorNone;

#line 2708 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a0, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glFogCoordfv(reinterpret_cast<const GLfloat *>(array));
#line 17595 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glFogCoordfv, doc_QOpenGLFunctions_2_1_glFogCoordfv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glFogCoordf, "glFogCoordf(self, coord: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glFogCoordf(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glFogCoordf(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLfloat a0;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0))
        {
            sipCpp->glFogCoordf(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glFogCoordf, doc_QOpenGLFunctions_2_1_glFogCoordf);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4usv, "glVertexAttrib4usv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4usv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4usv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2717 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_UNSIGNED_SHORT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib4usv(a0, reinterpret_cast<const GLushort *>(array));
#line 17664 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4usv, doc_QOpenGLFunctions_2_1_glVertexAttrib4usv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4uiv, "glVertexAttrib4uiv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4uiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4uiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2726 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_UNSIGNED_INT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib4uiv(a0, reinterpret_cast<const GLuint *>(array));
#line 17707 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4uiv, doc_QOpenGLFunctions_2_1_glVertexAttrib4uiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4ubv, "glVertexAttrib4ubv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4ubv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4ubv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2735 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib4ubv(a0, reinterpret_cast<const GLubyte *>(array));
#line 17750 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4ubv, doc_QOpenGLFunctions_2_1_glVertexAttrib4ubv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4sv, "glVertexAttrib4sv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2744 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib4sv(a0, reinterpret_cast<const GLshort *>(array));
#line 17792 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4sv, doc_QOpenGLFunctions_2_1_glVertexAttrib4sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4s, "glVertexAttrib4s(self, index: int, x: int, y: int, z: int, w: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLshort a1;
        ::GLshort a2;
        ::GLshort a3;
        ::GLshort a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buhhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glVertexAttrib4s(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4s, doc_QOpenGLFunctions_2_1_glVertexAttrib4s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4iv, "glVertexAttrib4iv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4iv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4iv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2753 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib4iv(a0, reinterpret_cast<const GLint *>(array));
#line 17864 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4iv, doc_QOpenGLFunctions_2_1_glVertexAttrib4iv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4fv, "glVertexAttrib4fv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2761 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib4fv(a0, reinterpret_cast<const GLfloat *>(array));
#line 17906 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4fv, doc_QOpenGLFunctions_2_1_glVertexAttrib4fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4f, "glVertexAttrib4f(self, index: int, x: float, y: float, z: float, w: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::GLfloat a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buffff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glVertexAttrib4f(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4f, doc_QOpenGLFunctions_2_1_glVertexAttrib4f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4dv, "glVertexAttrib4dv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2770 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib4dv(a0, reinterpret_cast<const GLdouble *>(array));
#line 17978 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4dv, doc_QOpenGLFunctions_2_1_glVertexAttrib4dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4d, "glVertexAttrib4d(self, index: int, x: float, y: float, z: float, w: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::GLdouble a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Budddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glVertexAttrib4d(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4d, doc_QOpenGLFunctions_2_1_glVertexAttrib4d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4bv, "glVertexAttrib4bv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4bv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4bv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2779 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_BYTE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib4bv(a0, reinterpret_cast<const GLbyte *>(array));
#line 18050 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4bv, doc_QOpenGLFunctions_2_1_glVertexAttrib4bv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4Nusv, "glVertexAttrib4Nusv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4Nusv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4Nusv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2787 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_UNSIGNED_SHORT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib4Nusv(a0, reinterpret_cast<const GLushort *>(array));
#line 18093 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4Nusv, doc_QOpenGLFunctions_2_1_glVertexAttrib4Nusv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4Nuiv, "glVertexAttrib4Nuiv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4Nuiv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4Nuiv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2796 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_UNSIGNED_INT,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib4Nuiv(a0, reinterpret_cast<const GLuint *>(array));
#line 18136 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4Nuiv, doc_QOpenGLFunctions_2_1_glVertexAttrib4Nuiv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4Nubv, "glVertexAttrib4Nubv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4Nubv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4Nubv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2805 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_UNSIGNED_BYTE,
                sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib4Nubv(a0, reinterpret_cast<const GLubyte *>(array));
#line 18179 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4Nubv, doc_QOpenGLFunctions_2_1_glVertexAttrib4Nubv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4Nub, "glVertexAttrib4Nub(self, index: int, x: int, y: int, z: int, w: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4Nub(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4Nub(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLubyte a1;
        ::GLubyte a2;
        ::GLubyte a3;
        ::GLubyte a4;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuMMMM", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->glVertexAttrib4Nub(a0, a1, a2, a3, a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4Nub, doc_QOpenGLFunctions_2_1_glVertexAttrib4Nub);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4Nsv, "glVertexAttrib4Nsv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4Nsv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4Nsv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2815 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib4Nsv(a0, reinterpret_cast<const GLshort *>(array));
#line 18251 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4Nsv, doc_QOpenGLFunctions_2_1_glVertexAttrib4Nsv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4Niv, "glVertexAttrib4Niv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4Niv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4Niv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2823 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_INT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib4Niv(a0, reinterpret_cast<const GLint *>(array));
#line 18293 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4Niv, doc_QOpenGLFunctions_2_1_glVertexAttrib4Niv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib4Nbv, "glVertexAttrib4Nbv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4Nbv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib4Nbv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2831 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_BYTE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib4Nbv(a0, reinterpret_cast<const GLbyte *>(array));
#line 18335 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib4Nbv, doc_QOpenGLFunctions_2_1_glVertexAttrib4Nbv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib3sv, "glVertexAttrib3sv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib3sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib3sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2839 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib3sv(a0, reinterpret_cast<const GLshort *>(array));
#line 18377 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib3sv, doc_QOpenGLFunctions_2_1_glVertexAttrib3sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib3s, "glVertexAttrib3s(self, index: int, x: int, y: int, z: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib3s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib3s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLshort a1;
        ::GLshort a2;
        ::GLshort a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buhhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glVertexAttrib3s(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib3s, doc_QOpenGLFunctions_2_1_glVertexAttrib3s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib3fv, "glVertexAttrib3fv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib3fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib3fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2848 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib3fv(a0, reinterpret_cast<const GLfloat *>(array));
#line 18448 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib3fv, doc_QOpenGLFunctions_2_1_glVertexAttrib3fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib3f, "glVertexAttrib3f(self, index: int, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib3f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib3f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::GLfloat a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bufff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glVertexAttrib3f(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib3f, doc_QOpenGLFunctions_2_1_glVertexAttrib3f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib3dv, "glVertexAttrib3dv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib3dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib3dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2857 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib3dv(a0, reinterpret_cast<const GLdouble *>(array));
#line 18519 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib3dv, doc_QOpenGLFunctions_2_1_glVertexAttrib3dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib3d, "glVertexAttrib3d(self, index: int, x: float, y: float, z: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib3d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib3d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::GLdouble a3;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buddd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->glVertexAttrib3d(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib3d, doc_QOpenGLFunctions_2_1_glVertexAttrib3d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib2sv, "glVertexAttrib2sv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib2sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib2sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2866 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib2sv(a0, reinterpret_cast<const GLshort *>(array));
#line 18590 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib2sv, doc_QOpenGLFunctions_2_1_glVertexAttrib2sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib2s, "glVertexAttrib2s(self, index: int, x: int, y: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib2s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib2s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLshort a1;
        ::GLshort a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buhh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glVertexAttrib2s(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib2s, doc_QOpenGLFunctions_2_1_glVertexAttrib2s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib2fv, "glVertexAttrib2fv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib2fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib2fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2875 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib2fv(a0, reinterpret_cast<const GLfloat *>(array));
#line 18660 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib2fv, doc_QOpenGLFunctions_2_1_glVertexAttrib2fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib2f, "glVertexAttrib2f(self, index: int, x: float, y: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib2f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib2f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLfloat a1;
        ::GLfloat a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buff", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glVertexAttrib2f(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib2f, doc_QOpenGLFunctions_2_1_glVertexAttrib2f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib2dv, "glVertexAttrib2dv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib2dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib2dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2884 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib2dv(a0, reinterpret_cast<const GLdouble *>(array));
#line 18730 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib2dv, doc_QOpenGLFunctions_2_1_glVertexAttrib2dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib2d, "glVertexAttrib2d(self, index: int, x: float, y: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib2d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib2d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLdouble a1;
        ::GLdouble a2;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Budd", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->glVertexAttrib2d(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib2d, doc_QOpenGLFunctions_2_1_glVertexAttrib2d);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib1sv, "glVertexAttrib1sv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib1sv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib1sv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2893 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_SHORT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib1sv(a0, reinterpret_cast<const GLshort *>(array));
#line 18800 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib1sv, doc_QOpenGLFunctions_2_1_glVertexAttrib1sv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib1s, "glVertexAttrib1s(self, index: int, x: int)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib1s(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib1s(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLshort a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buh", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glVertexAttrib1s(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib1s, doc_QOpenGLFunctions_2_1_glVertexAttrib1s);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib1fv, "glVertexAttrib1fv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib1fv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib1fv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2902 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_FLOAT, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib1fv(a0, reinterpret_cast<const GLfloat *>(array));
#line 18869 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib1fv, doc_QOpenGLFunctions_2_1_glVertexAttrib1fv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib1f, "glVertexAttrib1f(self, index: int, x: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib1f(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib1f(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLfloat a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Buf", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glVertexAttrib1f(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib1f, doc_QOpenGLFunctions_2_1_glVertexAttrib1f);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib1dv, "glVertexAttrib1dv(self, index: int, v: PYQT_OPENGL_ARRAY)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib1dv(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib1dv(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        PyObject * a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BuP0", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipErrorState sipError = sipErrorNone;

#line 2911 "/build/pyqt5/src/PyQt5-5.15.11/sip/_QOpenGLFunctions_2_1/qopenglfunctions_2_1.sip"
        const GLvoid *array = qpyopengl_value_array(&sipError, a1, GL_DOUBLE, sipSelf);
        
        if (sipError == sipErrorNone)
            sipCpp->glVertexAttrib1dv(a0, reinterpret_cast<const GLdouble *>(array));
#line 18938 "/build/pyqt5/src/PyQt5-5.15.11/build/_QOpenGLFunctions_2_1/sip_QOpenGLFunctions_2_1QOpenGLFunctions_2_1.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            Py_INCREF(Py_None);
            return Py_None;
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib1dv, doc_QOpenGLFunctions_2_1_glVertexAttrib1dv);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOpenGLFunctions_2_1_glVertexAttrib1d, "glVertexAttrib1d(self, index: int, x: float)");

extern "C" {static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib1d(PyObject *, PyObject *);}
static PyObject *meth_QOpenGLFunctions_2_1_glVertexAttrib1d(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::GLuint a0;
        ::GLdouble a1;
        ::QOpenGLFunctions_2_1 *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bud", &sipSelf, sipType_QOpenGLFunctions_2_1, &sipCpp, &a0, &a1))
        {
            sipCpp->glVertexAttrib1d(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOpenGLFunctions_2_1, sipName_glVertexAttrib1d, doc_QOpenGLFunctions_2_1_glVertexAttrib1d);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QOpenGLFunctions_2_1(void *, const sipTypeDef *);}
static void *cast_QOpenGLFunctions_2_1(void *sipCppV, const sipTypeDef *targetType)
{
    ::QOpenGLFunctions_2_1 *sipCpp = reinterpret_cast< ::QOpenGLFunctions_2_1 *>(sipCppV);

    if (targetType == sipType_QOpenGLFunctions_2_1)
        return sipCppV;

    if (targetType == sipType_QAbstractOpenGLFunctions)
        return static_cast< ::QAbstractOpenGLFunctions *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QOpenGLFunctions_2_1(void *, int);}
static void release_QOpenGLFunctions_2_1(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQOpenGLFunctions_2_1 *>(sipCppV);
    else
        delete reinterpret_cast< ::QOpenGLFunctions_2_1 *>(sipCppV);
}


extern "C" {static void *array_QOpenGLFunctions_2_1(Py_ssize_t);}
static void *array_QOpenGLFunctions_2_1(Py_ssize_t sipNrElem)
{
    return new ::QOpenGLFunctions_2_1[sipNrElem];
}


extern "C" {static void array_delete_QOpenGLFunctions_2_1(void *);}
static void array_delete_QOpenGLFunctions_2_1(void *sipCpp)
{
    delete[] reinterpret_cast< ::QOpenGLFunctions_2_1 *>(sipCpp);
}


extern "C" {static void dealloc_QOpenGLFunctions_2_1(sipSimpleWrapper *);}
static void dealloc_QOpenGLFunctions_2_1(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQOpenGLFunctions_2_1 *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QOpenGLFunctions_2_1(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QOpenGLFunctions_2_1(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QOpenGLFunctions_2_1(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQOpenGLFunctions_2_1 *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQOpenGLFunctions_2_1();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QOpenGLFunctions_2_1[] = {{0, 1, 1}};


static PyMethodDef methods_QOpenGLFunctions_2_1[] = {
    {sipName_glAccum, meth_QOpenGLFunctions_2_1_glAccum, METH_VARARGS, doc_QOpenGLFunctions_2_1_glAccum},
    {sipName_glActiveTexture, meth_QOpenGLFunctions_2_1_glActiveTexture, METH_VARARGS, doc_QOpenGLFunctions_2_1_glActiveTexture},
    {sipName_glAlphaFunc, meth_QOpenGLFunctions_2_1_glAlphaFunc, METH_VARARGS, doc_QOpenGLFunctions_2_1_glAlphaFunc},
    {sipName_glArrayElement, meth_QOpenGLFunctions_2_1_glArrayElement, METH_VARARGS, doc_QOpenGLFunctions_2_1_glArrayElement},
    {sipName_glAttachShader, meth_QOpenGLFunctions_2_1_glAttachShader, METH_VARARGS, doc_QOpenGLFunctions_2_1_glAttachShader},
    {sipName_glBegin, meth_QOpenGLFunctions_2_1_glBegin, METH_VARARGS, doc_QOpenGLFunctions_2_1_glBegin},
    {sipName_glBeginQuery, meth_QOpenGLFunctions_2_1_glBeginQuery, METH_VARARGS, doc_QOpenGLFunctions_2_1_glBeginQuery},
    {sipName_glBindAttribLocation, meth_QOpenGLFunctions_2_1_glBindAttribLocation, METH_VARARGS, doc_QOpenGLFunctions_2_1_glBindAttribLocation},
    {sipName_glBindBuffer, meth_QOpenGLFunctions_2_1_glBindBuffer, METH_VARARGS, doc_QOpenGLFunctions_2_1_glBindBuffer},
    {sipName_glBindTexture, meth_QOpenGLFunctions_2_1_glBindTexture, METH_VARARGS, doc_QOpenGLFunctions_2_1_glBindTexture},
    {sipName_glBitmap, meth_QOpenGLFunctions_2_1_glBitmap, METH_VARARGS, doc_QOpenGLFunctions_2_1_glBitmap},
    {sipName_glBlendColor, meth_QOpenGLFunctions_2_1_glBlendColor, METH_VARARGS, doc_QOpenGLFunctions_2_1_glBlendColor},
    {sipName_glBlendEquation, meth_QOpenGLFunctions_2_1_glBlendEquation, METH_VARARGS, doc_QOpenGLFunctions_2_1_glBlendEquation},
    {sipName_glBlendEquationSeparate, meth_QOpenGLFunctions_2_1_glBlendEquationSeparate, METH_VARARGS, doc_QOpenGLFunctions_2_1_glBlendEquationSeparate},
    {sipName_glBlendFunc, meth_QOpenGLFunctions_2_1_glBlendFunc, METH_VARARGS, doc_QOpenGLFunctions_2_1_glBlendFunc},
    {sipName_glBlendFuncSeparate, meth_QOpenGLFunctions_2_1_glBlendFuncSeparate, METH_VARARGS, doc_QOpenGLFunctions_2_1_glBlendFuncSeparate},
    {sipName_glBufferData, meth_QOpenGLFunctions_2_1_glBufferData, METH_VARARGS, doc_QOpenGLFunctions_2_1_glBufferData},
    {sipName_glBufferSubData, meth_QOpenGLFunctions_2_1_glBufferSubData, METH_VARARGS, doc_QOpenGLFunctions_2_1_glBufferSubData},
    {sipName_glCallList, meth_QOpenGLFunctions_2_1_glCallList, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCallList},
    {sipName_glClear, meth_QOpenGLFunctions_2_1_glClear, METH_VARARGS, doc_QOpenGLFunctions_2_1_glClear},
    {sipName_glClearAccum, meth_QOpenGLFunctions_2_1_glClearAccum, METH_VARARGS, doc_QOpenGLFunctions_2_1_glClearAccum},
    {sipName_glClearColor, meth_QOpenGLFunctions_2_1_glClearColor, METH_VARARGS, doc_QOpenGLFunctions_2_1_glClearColor},
    {sipName_glClearDepth, meth_QOpenGLFunctions_2_1_glClearDepth, METH_VARARGS, doc_QOpenGLFunctions_2_1_glClearDepth},
    {sipName_glClearIndex, meth_QOpenGLFunctions_2_1_glClearIndex, METH_VARARGS, doc_QOpenGLFunctions_2_1_glClearIndex},
    {sipName_glClearStencil, meth_QOpenGLFunctions_2_1_glClearStencil, METH_VARARGS, doc_QOpenGLFunctions_2_1_glClearStencil},
    {sipName_glClientActiveTexture, meth_QOpenGLFunctions_2_1_glClientActiveTexture, METH_VARARGS, doc_QOpenGLFunctions_2_1_glClientActiveTexture},
    {sipName_glClipPlane, meth_QOpenGLFunctions_2_1_glClipPlane, METH_VARARGS, doc_QOpenGLFunctions_2_1_glClipPlane},
    {sipName_glColor3b, meth_QOpenGLFunctions_2_1_glColor3b, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3b},
    {sipName_glColor3bv, meth_QOpenGLFunctions_2_1_glColor3bv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3bv},
    {sipName_glColor3d, meth_QOpenGLFunctions_2_1_glColor3d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3d},
    {sipName_glColor3dv, meth_QOpenGLFunctions_2_1_glColor3dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3dv},
    {sipName_glColor3f, meth_QOpenGLFunctions_2_1_glColor3f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3f},
    {sipName_glColor3fv, meth_QOpenGLFunctions_2_1_glColor3fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3fv},
    {sipName_glColor3i, meth_QOpenGLFunctions_2_1_glColor3i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3i},
    {sipName_glColor3iv, meth_QOpenGLFunctions_2_1_glColor3iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3iv},
    {sipName_glColor3s, meth_QOpenGLFunctions_2_1_glColor3s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3s},
    {sipName_glColor3sv, meth_QOpenGLFunctions_2_1_glColor3sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3sv},
    {sipName_glColor3ub, meth_QOpenGLFunctions_2_1_glColor3ub, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3ub},
    {sipName_glColor3ubv, meth_QOpenGLFunctions_2_1_glColor3ubv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3ubv},
    {sipName_glColor3ui, meth_QOpenGLFunctions_2_1_glColor3ui, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3ui},
    {sipName_glColor3uiv, meth_QOpenGLFunctions_2_1_glColor3uiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3uiv},
    {sipName_glColor3us, meth_QOpenGLFunctions_2_1_glColor3us, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3us},
    {sipName_glColor3usv, meth_QOpenGLFunctions_2_1_glColor3usv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor3usv},
    {sipName_glColor4b, meth_QOpenGLFunctions_2_1_glColor4b, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4b},
    {sipName_glColor4bv, meth_QOpenGLFunctions_2_1_glColor4bv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4bv},
    {sipName_glColor4d, meth_QOpenGLFunctions_2_1_glColor4d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4d},
    {sipName_glColor4dv, meth_QOpenGLFunctions_2_1_glColor4dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4dv},
    {sipName_glColor4f, meth_QOpenGLFunctions_2_1_glColor4f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4f},
    {sipName_glColor4fv, meth_QOpenGLFunctions_2_1_glColor4fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4fv},
    {sipName_glColor4i, meth_QOpenGLFunctions_2_1_glColor4i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4i},
    {sipName_glColor4iv, meth_QOpenGLFunctions_2_1_glColor4iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4iv},
    {sipName_glColor4s, meth_QOpenGLFunctions_2_1_glColor4s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4s},
    {sipName_glColor4sv, meth_QOpenGLFunctions_2_1_glColor4sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4sv},
    {sipName_glColor4ub, meth_QOpenGLFunctions_2_1_glColor4ub, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4ub},
    {sipName_glColor4ubv, meth_QOpenGLFunctions_2_1_glColor4ubv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4ubv},
    {sipName_glColor4ui, meth_QOpenGLFunctions_2_1_glColor4ui, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4ui},
    {sipName_glColor4uiv, meth_QOpenGLFunctions_2_1_glColor4uiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4uiv},
    {sipName_glColor4us, meth_QOpenGLFunctions_2_1_glColor4us, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4us},
    {sipName_glColor4usv, meth_QOpenGLFunctions_2_1_glColor4usv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColor4usv},
    {sipName_glColorMask, meth_QOpenGLFunctions_2_1_glColorMask, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColorMask},
    {sipName_glColorMaterial, meth_QOpenGLFunctions_2_1_glColorMaterial, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColorMaterial},
    {sipName_glColorPointer, meth_QOpenGLFunctions_2_1_glColorPointer, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColorPointer},
    {sipName_glColorSubTable, meth_QOpenGLFunctions_2_1_glColorSubTable, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColorSubTable},
    {sipName_glColorTable, meth_QOpenGLFunctions_2_1_glColorTable, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColorTable},
    {sipName_glColorTableParameterfv, meth_QOpenGLFunctions_2_1_glColorTableParameterfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColorTableParameterfv},
    {sipName_glColorTableParameteriv, meth_QOpenGLFunctions_2_1_glColorTableParameteriv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glColorTableParameteriv},
    {sipName_glCompileShader, meth_QOpenGLFunctions_2_1_glCompileShader, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCompileShader},
    {sipName_glCompressedTexImage1D, meth_QOpenGLFunctions_2_1_glCompressedTexImage1D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCompressedTexImage1D},
    {sipName_glCompressedTexImage2D, meth_QOpenGLFunctions_2_1_glCompressedTexImage2D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCompressedTexImage2D},
    {sipName_glCompressedTexImage3D, meth_QOpenGLFunctions_2_1_glCompressedTexImage3D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCompressedTexImage3D},
    {sipName_glCompressedTexSubImage1D, meth_QOpenGLFunctions_2_1_glCompressedTexSubImage1D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCompressedTexSubImage1D},
    {sipName_glCompressedTexSubImage2D, meth_QOpenGLFunctions_2_1_glCompressedTexSubImage2D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCompressedTexSubImage2D},
    {sipName_glCompressedTexSubImage3D, meth_QOpenGLFunctions_2_1_glCompressedTexSubImage3D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCompressedTexSubImage3D},
    {sipName_glConvolutionFilter1D, meth_QOpenGLFunctions_2_1_glConvolutionFilter1D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glConvolutionFilter1D},
    {sipName_glConvolutionFilter2D, meth_QOpenGLFunctions_2_1_glConvolutionFilter2D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glConvolutionFilter2D},
    {sipName_glConvolutionParameterf, meth_QOpenGLFunctions_2_1_glConvolutionParameterf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glConvolutionParameterf},
    {sipName_glConvolutionParameterfv, meth_QOpenGLFunctions_2_1_glConvolutionParameterfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glConvolutionParameterfv},
    {sipName_glConvolutionParameteri, meth_QOpenGLFunctions_2_1_glConvolutionParameteri, METH_VARARGS, doc_QOpenGLFunctions_2_1_glConvolutionParameteri},
    {sipName_glConvolutionParameteriv, meth_QOpenGLFunctions_2_1_glConvolutionParameteriv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glConvolutionParameteriv},
    {sipName_glCopyColorSubTable, meth_QOpenGLFunctions_2_1_glCopyColorSubTable, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCopyColorSubTable},
    {sipName_glCopyColorTable, meth_QOpenGLFunctions_2_1_glCopyColorTable, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCopyColorTable},
    {sipName_glCopyConvolutionFilter1D, meth_QOpenGLFunctions_2_1_glCopyConvolutionFilter1D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCopyConvolutionFilter1D},
    {sipName_glCopyConvolutionFilter2D, meth_QOpenGLFunctions_2_1_glCopyConvolutionFilter2D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCopyConvolutionFilter2D},
    {sipName_glCopyPixels, meth_QOpenGLFunctions_2_1_glCopyPixels, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCopyPixels},
    {sipName_glCopyTexImage1D, meth_QOpenGLFunctions_2_1_glCopyTexImage1D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCopyTexImage1D},
    {sipName_glCopyTexImage2D, meth_QOpenGLFunctions_2_1_glCopyTexImage2D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCopyTexImage2D},
    {sipName_glCopyTexSubImage1D, meth_QOpenGLFunctions_2_1_glCopyTexSubImage1D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCopyTexSubImage1D},
    {sipName_glCopyTexSubImage2D, meth_QOpenGLFunctions_2_1_glCopyTexSubImage2D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCopyTexSubImage2D},
    {sipName_glCopyTexSubImage3D, meth_QOpenGLFunctions_2_1_glCopyTexSubImage3D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCopyTexSubImage3D},
    {sipName_glCreateProgram, meth_QOpenGLFunctions_2_1_glCreateProgram, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCreateProgram},
    {sipName_glCreateShader, meth_QOpenGLFunctions_2_1_glCreateShader, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCreateShader},
    {sipName_glCullFace, meth_QOpenGLFunctions_2_1_glCullFace, METH_VARARGS, doc_QOpenGLFunctions_2_1_glCullFace},
    {sipName_glDeleteBuffers, meth_QOpenGLFunctions_2_1_glDeleteBuffers, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDeleteBuffers},
    {sipName_glDeleteLists, meth_QOpenGLFunctions_2_1_glDeleteLists, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDeleteLists},
    {sipName_glDeleteProgram, meth_QOpenGLFunctions_2_1_glDeleteProgram, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDeleteProgram},
    {sipName_glDeleteQueries, meth_QOpenGLFunctions_2_1_glDeleteQueries, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDeleteQueries},
    {sipName_glDeleteShader, meth_QOpenGLFunctions_2_1_glDeleteShader, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDeleteShader},
    {sipName_glDeleteTextures, meth_QOpenGLFunctions_2_1_glDeleteTextures, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDeleteTextures},
    {sipName_glDepthFunc, meth_QOpenGLFunctions_2_1_glDepthFunc, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDepthFunc},
    {sipName_glDepthMask, meth_QOpenGLFunctions_2_1_glDepthMask, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDepthMask},
    {sipName_glDepthRange, meth_QOpenGLFunctions_2_1_glDepthRange, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDepthRange},
    {sipName_glDetachShader, meth_QOpenGLFunctions_2_1_glDetachShader, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDetachShader},
    {sipName_glDisable, meth_QOpenGLFunctions_2_1_glDisable, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDisable},
    {sipName_glDisableClientState, meth_QOpenGLFunctions_2_1_glDisableClientState, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDisableClientState},
    {sipName_glDisableVertexAttribArray, meth_QOpenGLFunctions_2_1_glDisableVertexAttribArray, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDisableVertexAttribArray},
    {sipName_glDrawArrays, meth_QOpenGLFunctions_2_1_glDrawArrays, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDrawArrays},
    {sipName_glDrawBuffer, meth_QOpenGLFunctions_2_1_glDrawBuffer, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDrawBuffer},
    {sipName_glDrawBuffers, meth_QOpenGLFunctions_2_1_glDrawBuffers, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDrawBuffers},
    {sipName_glDrawElements, meth_QOpenGLFunctions_2_1_glDrawElements, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDrawElements},
    {sipName_glDrawPixels, meth_QOpenGLFunctions_2_1_glDrawPixels, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDrawPixels},
    {sipName_glDrawRangeElements, meth_QOpenGLFunctions_2_1_glDrawRangeElements, METH_VARARGS, doc_QOpenGLFunctions_2_1_glDrawRangeElements},
    {sipName_glEdgeFlag, meth_QOpenGLFunctions_2_1_glEdgeFlag, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEdgeFlag},
    {sipName_glEdgeFlagPointer, meth_QOpenGLFunctions_2_1_glEdgeFlagPointer, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEdgeFlagPointer},
    {sipName_glEdgeFlagv, meth_QOpenGLFunctions_2_1_glEdgeFlagv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEdgeFlagv},
    {sipName_glEnable, meth_QOpenGLFunctions_2_1_glEnable, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEnable},
    {sipName_glEnableClientState, meth_QOpenGLFunctions_2_1_glEnableClientState, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEnableClientState},
    {sipName_glEnableVertexAttribArray, meth_QOpenGLFunctions_2_1_glEnableVertexAttribArray, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEnableVertexAttribArray},
    {sipName_glEnd, meth_QOpenGLFunctions_2_1_glEnd, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEnd},
    {sipName_glEndList, meth_QOpenGLFunctions_2_1_glEndList, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEndList},
    {sipName_glEndQuery, meth_QOpenGLFunctions_2_1_glEndQuery, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEndQuery},
    {sipName_glEvalCoord1d, meth_QOpenGLFunctions_2_1_glEvalCoord1d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEvalCoord1d},
    {sipName_glEvalCoord1dv, meth_QOpenGLFunctions_2_1_glEvalCoord1dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEvalCoord1dv},
    {sipName_glEvalCoord1f, meth_QOpenGLFunctions_2_1_glEvalCoord1f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEvalCoord1f},
    {sipName_glEvalCoord1fv, meth_QOpenGLFunctions_2_1_glEvalCoord1fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEvalCoord1fv},
    {sipName_glEvalCoord2d, meth_QOpenGLFunctions_2_1_glEvalCoord2d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEvalCoord2d},
    {sipName_glEvalCoord2dv, meth_QOpenGLFunctions_2_1_glEvalCoord2dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEvalCoord2dv},
    {sipName_glEvalCoord2f, meth_QOpenGLFunctions_2_1_glEvalCoord2f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEvalCoord2f},
    {sipName_glEvalCoord2fv, meth_QOpenGLFunctions_2_1_glEvalCoord2fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEvalCoord2fv},
    {sipName_glEvalMesh1, meth_QOpenGLFunctions_2_1_glEvalMesh1, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEvalMesh1},
    {sipName_glEvalMesh2, meth_QOpenGLFunctions_2_1_glEvalMesh2, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEvalMesh2},
    {sipName_glEvalPoint1, meth_QOpenGLFunctions_2_1_glEvalPoint1, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEvalPoint1},
    {sipName_glEvalPoint2, meth_QOpenGLFunctions_2_1_glEvalPoint2, METH_VARARGS, doc_QOpenGLFunctions_2_1_glEvalPoint2},
    {sipName_glFinish, meth_QOpenGLFunctions_2_1_glFinish, METH_VARARGS, doc_QOpenGLFunctions_2_1_glFinish},
    {sipName_glFlush, meth_QOpenGLFunctions_2_1_glFlush, METH_VARARGS, doc_QOpenGLFunctions_2_1_glFlush},
    {sipName_glFogCoordPointer, meth_QOpenGLFunctions_2_1_glFogCoordPointer, METH_VARARGS, doc_QOpenGLFunctions_2_1_glFogCoordPointer},
    {sipName_glFogCoordd, meth_QOpenGLFunctions_2_1_glFogCoordd, METH_VARARGS, doc_QOpenGLFunctions_2_1_glFogCoordd},
    {sipName_glFogCoorddv, meth_QOpenGLFunctions_2_1_glFogCoorddv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glFogCoorddv},
    {sipName_glFogCoordf, meth_QOpenGLFunctions_2_1_glFogCoordf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glFogCoordf},
    {sipName_glFogCoordfv, meth_QOpenGLFunctions_2_1_glFogCoordfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glFogCoordfv},
    {sipName_glFogf, meth_QOpenGLFunctions_2_1_glFogf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glFogf},
    {sipName_glFogfv, meth_QOpenGLFunctions_2_1_glFogfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glFogfv},
    {sipName_glFogi, meth_QOpenGLFunctions_2_1_glFogi, METH_VARARGS, doc_QOpenGLFunctions_2_1_glFogi},
    {sipName_glFogiv, meth_QOpenGLFunctions_2_1_glFogiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glFogiv},
    {sipName_glFrontFace, meth_QOpenGLFunctions_2_1_glFrontFace, METH_VARARGS, doc_QOpenGLFunctions_2_1_glFrontFace},
    {sipName_glFrustum, meth_QOpenGLFunctions_2_1_glFrustum, METH_VARARGS, doc_QOpenGLFunctions_2_1_glFrustum},
    {sipName_glGenBuffers, meth_QOpenGLFunctions_2_1_glGenBuffers, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGenBuffers},
    {sipName_glGenLists, meth_QOpenGLFunctions_2_1_glGenLists, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGenLists},
    {sipName_glGenQueries, meth_QOpenGLFunctions_2_1_glGenQueries, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGenQueries},
    {sipName_glGenTextures, meth_QOpenGLFunctions_2_1_glGenTextures, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGenTextures},
    {sipName_glGetActiveAttrib, meth_QOpenGLFunctions_2_1_glGetActiveAttrib, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetActiveAttrib},
    {sipName_glGetActiveUniform, meth_QOpenGLFunctions_2_1_glGetActiveUniform, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetActiveUniform},
    {sipName_glGetAttachedShaders, meth_QOpenGLFunctions_2_1_glGetAttachedShaders, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetAttachedShaders},
    {sipName_glGetAttribLocation, meth_QOpenGLFunctions_2_1_glGetAttribLocation, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetAttribLocation},
    {sipName_glGetBooleanv, meth_QOpenGLFunctions_2_1_glGetBooleanv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetBooleanv},
    {sipName_glGetBufferParameteriv, meth_QOpenGLFunctions_2_1_glGetBufferParameteriv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetBufferParameteriv},
    {sipName_glGetClipPlane, meth_QOpenGLFunctions_2_1_glGetClipPlane, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetClipPlane},
    {sipName_glGetColorTableParameterfv, meth_QOpenGLFunctions_2_1_glGetColorTableParameterfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetColorTableParameterfv},
    {sipName_glGetColorTableParameteriv, meth_QOpenGLFunctions_2_1_glGetColorTableParameteriv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetColorTableParameteriv},
    {sipName_glGetConvolutionParameterfv, meth_QOpenGLFunctions_2_1_glGetConvolutionParameterfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetConvolutionParameterfv},
    {sipName_glGetConvolutionParameteriv, meth_QOpenGLFunctions_2_1_glGetConvolutionParameteriv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetConvolutionParameteriv},
    {sipName_glGetDoublev, meth_QOpenGLFunctions_2_1_glGetDoublev, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetDoublev},
    {sipName_glGetError, meth_QOpenGLFunctions_2_1_glGetError, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetError},
    {sipName_glGetFloatv, meth_QOpenGLFunctions_2_1_glGetFloatv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetFloatv},
    {sipName_glGetIntegerv, meth_QOpenGLFunctions_2_1_glGetIntegerv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetIntegerv},
    {sipName_glGetLightfv, meth_QOpenGLFunctions_2_1_glGetLightfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetLightfv},
    {sipName_glGetLightiv, meth_QOpenGLFunctions_2_1_glGetLightiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetLightiv},
    {sipName_glGetMaterialfv, meth_QOpenGLFunctions_2_1_glGetMaterialfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetMaterialfv},
    {sipName_glGetMaterialiv, meth_QOpenGLFunctions_2_1_glGetMaterialiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetMaterialiv},
    {sipName_glGetProgramInfoLog, meth_QOpenGLFunctions_2_1_glGetProgramInfoLog, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetProgramInfoLog},
    {sipName_glGetProgramiv, meth_QOpenGLFunctions_2_1_glGetProgramiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetProgramiv},
    {sipName_glGetQueryiv, meth_QOpenGLFunctions_2_1_glGetQueryiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetQueryiv},
    {sipName_glGetShaderInfoLog, meth_QOpenGLFunctions_2_1_glGetShaderInfoLog, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetShaderInfoLog},
    {sipName_glGetShaderSource, meth_QOpenGLFunctions_2_1_glGetShaderSource, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetShaderSource},
    {sipName_glGetShaderiv, meth_QOpenGLFunctions_2_1_glGetShaderiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetShaderiv},
    {sipName_glGetString, meth_QOpenGLFunctions_2_1_glGetString, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetString},
    {sipName_glGetTexEnvfv, meth_QOpenGLFunctions_2_1_glGetTexEnvfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetTexEnvfv},
    {sipName_glGetTexEnviv, meth_QOpenGLFunctions_2_1_glGetTexEnviv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetTexEnviv},
    {sipName_glGetTexGendv, meth_QOpenGLFunctions_2_1_glGetTexGendv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetTexGendv},
    {sipName_glGetTexGenfv, meth_QOpenGLFunctions_2_1_glGetTexGenfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetTexGenfv},
    {sipName_glGetTexGeniv, meth_QOpenGLFunctions_2_1_glGetTexGeniv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetTexGeniv},
    {sipName_glGetTexLevelParameterfv, meth_QOpenGLFunctions_2_1_glGetTexLevelParameterfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetTexLevelParameterfv},
    {sipName_glGetTexLevelParameteriv, meth_QOpenGLFunctions_2_1_glGetTexLevelParameteriv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetTexLevelParameteriv},
    {sipName_glGetTexParameterfv, meth_QOpenGLFunctions_2_1_glGetTexParameterfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetTexParameterfv},
    {sipName_glGetTexParameteriv, meth_QOpenGLFunctions_2_1_glGetTexParameteriv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetTexParameteriv},
    {sipName_glGetUniformLocation, meth_QOpenGLFunctions_2_1_glGetUniformLocation, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetUniformLocation},
    {sipName_glGetVertexAttribdv, meth_QOpenGLFunctions_2_1_glGetVertexAttribdv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetVertexAttribdv},
    {sipName_glGetVertexAttribfv, meth_QOpenGLFunctions_2_1_glGetVertexAttribfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetVertexAttribfv},
    {sipName_glGetVertexAttribiv, meth_QOpenGLFunctions_2_1_glGetVertexAttribiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glGetVertexAttribiv},
    {sipName_glHint, meth_QOpenGLFunctions_2_1_glHint, METH_VARARGS, doc_QOpenGLFunctions_2_1_glHint},
    {sipName_glHistogram, meth_QOpenGLFunctions_2_1_glHistogram, METH_VARARGS, doc_QOpenGLFunctions_2_1_glHistogram},
    {sipName_glIndexMask, meth_QOpenGLFunctions_2_1_glIndexMask, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIndexMask},
    {sipName_glIndexPointer, meth_QOpenGLFunctions_2_1_glIndexPointer, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIndexPointer},
    {sipName_glIndexd, meth_QOpenGLFunctions_2_1_glIndexd, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIndexd},
    {sipName_glIndexdv, meth_QOpenGLFunctions_2_1_glIndexdv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIndexdv},
    {sipName_glIndexf, meth_QOpenGLFunctions_2_1_glIndexf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIndexf},
    {sipName_glIndexfv, meth_QOpenGLFunctions_2_1_glIndexfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIndexfv},
    {sipName_glIndexi, meth_QOpenGLFunctions_2_1_glIndexi, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIndexi},
    {sipName_glIndexiv, meth_QOpenGLFunctions_2_1_glIndexiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIndexiv},
    {sipName_glIndexs, meth_QOpenGLFunctions_2_1_glIndexs, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIndexs},
    {sipName_glIndexsv, meth_QOpenGLFunctions_2_1_glIndexsv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIndexsv},
    {sipName_glIndexub, meth_QOpenGLFunctions_2_1_glIndexub, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIndexub},
    {sipName_glIndexubv, meth_QOpenGLFunctions_2_1_glIndexubv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIndexubv},
    {sipName_glInitNames, meth_QOpenGLFunctions_2_1_glInitNames, METH_VARARGS, doc_QOpenGLFunctions_2_1_glInitNames},
    {sipName_glIsBuffer, meth_QOpenGLFunctions_2_1_glIsBuffer, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIsBuffer},
    {sipName_glIsEnabled, meth_QOpenGLFunctions_2_1_glIsEnabled, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIsEnabled},
    {sipName_glIsList, meth_QOpenGLFunctions_2_1_glIsList, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIsList},
    {sipName_glIsProgram, meth_QOpenGLFunctions_2_1_glIsProgram, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIsProgram},
    {sipName_glIsQuery, meth_QOpenGLFunctions_2_1_glIsQuery, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIsQuery},
    {sipName_glIsShader, meth_QOpenGLFunctions_2_1_glIsShader, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIsShader},
    {sipName_glIsTexture, meth_QOpenGLFunctions_2_1_glIsTexture, METH_VARARGS, doc_QOpenGLFunctions_2_1_glIsTexture},
    {sipName_glLightModelf, meth_QOpenGLFunctions_2_1_glLightModelf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLightModelf},
    {sipName_glLightModelfv, meth_QOpenGLFunctions_2_1_glLightModelfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLightModelfv},
    {sipName_glLightModeli, meth_QOpenGLFunctions_2_1_glLightModeli, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLightModeli},
    {sipName_glLightModeliv, meth_QOpenGLFunctions_2_1_glLightModeliv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLightModeliv},
    {sipName_glLightf, meth_QOpenGLFunctions_2_1_glLightf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLightf},
    {sipName_glLightfv, meth_QOpenGLFunctions_2_1_glLightfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLightfv},
    {sipName_glLighti, meth_QOpenGLFunctions_2_1_glLighti, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLighti},
    {sipName_glLightiv, meth_QOpenGLFunctions_2_1_glLightiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLightiv},
    {sipName_glLineStipple, meth_QOpenGLFunctions_2_1_glLineStipple, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLineStipple},
    {sipName_glLineWidth, meth_QOpenGLFunctions_2_1_glLineWidth, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLineWidth},
    {sipName_glLinkProgram, meth_QOpenGLFunctions_2_1_glLinkProgram, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLinkProgram},
    {sipName_glListBase, meth_QOpenGLFunctions_2_1_glListBase, METH_VARARGS, doc_QOpenGLFunctions_2_1_glListBase},
    {sipName_glLoadIdentity, meth_QOpenGLFunctions_2_1_glLoadIdentity, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLoadIdentity},
    {sipName_glLoadMatrixd, meth_QOpenGLFunctions_2_1_glLoadMatrixd, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLoadMatrixd},
    {sipName_glLoadMatrixf, meth_QOpenGLFunctions_2_1_glLoadMatrixf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLoadMatrixf},
    {sipName_glLoadName, meth_QOpenGLFunctions_2_1_glLoadName, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLoadName},
    {sipName_glLoadTransposeMatrixd, meth_QOpenGLFunctions_2_1_glLoadTransposeMatrixd, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLoadTransposeMatrixd},
    {sipName_glLoadTransposeMatrixf, meth_QOpenGLFunctions_2_1_glLoadTransposeMatrixf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLoadTransposeMatrixf},
    {sipName_glLogicOp, meth_QOpenGLFunctions_2_1_glLogicOp, METH_VARARGS, doc_QOpenGLFunctions_2_1_glLogicOp},
    {sipName_glMap1d, meth_QOpenGLFunctions_2_1_glMap1d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMap1d},
    {sipName_glMap1f, meth_QOpenGLFunctions_2_1_glMap1f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMap1f},
    {sipName_glMap2d, meth_QOpenGLFunctions_2_1_glMap2d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMap2d},
    {sipName_glMap2f, meth_QOpenGLFunctions_2_1_glMap2f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMap2f},
    {sipName_glMapGrid1d, meth_QOpenGLFunctions_2_1_glMapGrid1d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMapGrid1d},
    {sipName_glMapGrid1f, meth_QOpenGLFunctions_2_1_glMapGrid1f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMapGrid1f},
    {sipName_glMapGrid2d, meth_QOpenGLFunctions_2_1_glMapGrid2d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMapGrid2d},
    {sipName_glMapGrid2f, meth_QOpenGLFunctions_2_1_glMapGrid2f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMapGrid2f},
    {sipName_glMaterialf, meth_QOpenGLFunctions_2_1_glMaterialf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMaterialf},
    {sipName_glMaterialfv, meth_QOpenGLFunctions_2_1_glMaterialfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMaterialfv},
    {sipName_glMateriali, meth_QOpenGLFunctions_2_1_glMateriali, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMateriali},
    {sipName_glMaterialiv, meth_QOpenGLFunctions_2_1_glMaterialiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMaterialiv},
    {sipName_glMatrixMode, meth_QOpenGLFunctions_2_1_glMatrixMode, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMatrixMode},
    {sipName_glMinmax, meth_QOpenGLFunctions_2_1_glMinmax, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMinmax},
    {sipName_glMultMatrixd, meth_QOpenGLFunctions_2_1_glMultMatrixd, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultMatrixd},
    {sipName_glMultMatrixf, meth_QOpenGLFunctions_2_1_glMultMatrixf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultMatrixf},
    {sipName_glMultTransposeMatrixd, meth_QOpenGLFunctions_2_1_glMultTransposeMatrixd, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultTransposeMatrixd},
    {sipName_glMultTransposeMatrixf, meth_QOpenGLFunctions_2_1_glMultTransposeMatrixf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultTransposeMatrixf},
    {sipName_glMultiTexCoord1d, meth_QOpenGLFunctions_2_1_glMultiTexCoord1d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord1d},
    {sipName_glMultiTexCoord1dv, meth_QOpenGLFunctions_2_1_glMultiTexCoord1dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord1dv},
    {sipName_glMultiTexCoord1f, meth_QOpenGLFunctions_2_1_glMultiTexCoord1f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord1f},
    {sipName_glMultiTexCoord1fv, meth_QOpenGLFunctions_2_1_glMultiTexCoord1fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord1fv},
    {sipName_glMultiTexCoord1i, meth_QOpenGLFunctions_2_1_glMultiTexCoord1i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord1i},
    {sipName_glMultiTexCoord1iv, meth_QOpenGLFunctions_2_1_glMultiTexCoord1iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord1iv},
    {sipName_glMultiTexCoord1s, meth_QOpenGLFunctions_2_1_glMultiTexCoord1s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord1s},
    {sipName_glMultiTexCoord1sv, meth_QOpenGLFunctions_2_1_glMultiTexCoord1sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord1sv},
    {sipName_glMultiTexCoord2d, meth_QOpenGLFunctions_2_1_glMultiTexCoord2d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord2d},
    {sipName_glMultiTexCoord2dv, meth_QOpenGLFunctions_2_1_glMultiTexCoord2dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord2dv},
    {sipName_glMultiTexCoord2f, meth_QOpenGLFunctions_2_1_glMultiTexCoord2f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord2f},
    {sipName_glMultiTexCoord2fv, meth_QOpenGLFunctions_2_1_glMultiTexCoord2fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord2fv},
    {sipName_glMultiTexCoord2i, meth_QOpenGLFunctions_2_1_glMultiTexCoord2i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord2i},
    {sipName_glMultiTexCoord2iv, meth_QOpenGLFunctions_2_1_glMultiTexCoord2iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord2iv},
    {sipName_glMultiTexCoord2s, meth_QOpenGLFunctions_2_1_glMultiTexCoord2s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord2s},
    {sipName_glMultiTexCoord2sv, meth_QOpenGLFunctions_2_1_glMultiTexCoord2sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord2sv},
    {sipName_glMultiTexCoord3d, meth_QOpenGLFunctions_2_1_glMultiTexCoord3d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord3d},
    {sipName_glMultiTexCoord3dv, meth_QOpenGLFunctions_2_1_glMultiTexCoord3dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord3dv},
    {sipName_glMultiTexCoord3f, meth_QOpenGLFunctions_2_1_glMultiTexCoord3f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord3f},
    {sipName_glMultiTexCoord3fv, meth_QOpenGLFunctions_2_1_glMultiTexCoord3fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord3fv},
    {sipName_glMultiTexCoord3i, meth_QOpenGLFunctions_2_1_glMultiTexCoord3i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord3i},
    {sipName_glMultiTexCoord3iv, meth_QOpenGLFunctions_2_1_glMultiTexCoord3iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord3iv},
    {sipName_glMultiTexCoord3s, meth_QOpenGLFunctions_2_1_glMultiTexCoord3s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord3s},
    {sipName_glMultiTexCoord3sv, meth_QOpenGLFunctions_2_1_glMultiTexCoord3sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord3sv},
    {sipName_glMultiTexCoord4d, meth_QOpenGLFunctions_2_1_glMultiTexCoord4d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord4d},
    {sipName_glMultiTexCoord4dv, meth_QOpenGLFunctions_2_1_glMultiTexCoord4dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord4dv},
    {sipName_glMultiTexCoord4f, meth_QOpenGLFunctions_2_1_glMultiTexCoord4f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord4f},
    {sipName_glMultiTexCoord4fv, meth_QOpenGLFunctions_2_1_glMultiTexCoord4fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord4fv},
    {sipName_glMultiTexCoord4i, meth_QOpenGLFunctions_2_1_glMultiTexCoord4i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord4i},
    {sipName_glMultiTexCoord4iv, meth_QOpenGLFunctions_2_1_glMultiTexCoord4iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord4iv},
    {sipName_glMultiTexCoord4s, meth_QOpenGLFunctions_2_1_glMultiTexCoord4s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord4s},
    {sipName_glMultiTexCoord4sv, meth_QOpenGLFunctions_2_1_glMultiTexCoord4sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glMultiTexCoord4sv},
    {sipName_glNewList, meth_QOpenGLFunctions_2_1_glNewList, METH_VARARGS, doc_QOpenGLFunctions_2_1_glNewList},
    {sipName_glNormal3b, meth_QOpenGLFunctions_2_1_glNormal3b, METH_VARARGS, doc_QOpenGLFunctions_2_1_glNormal3b},
    {sipName_glNormal3bv, meth_QOpenGLFunctions_2_1_glNormal3bv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glNormal3bv},
    {sipName_glNormal3d, meth_QOpenGLFunctions_2_1_glNormal3d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glNormal3d},
    {sipName_glNormal3dv, meth_QOpenGLFunctions_2_1_glNormal3dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glNormal3dv},
    {sipName_glNormal3f, meth_QOpenGLFunctions_2_1_glNormal3f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glNormal3f},
    {sipName_glNormal3fv, meth_QOpenGLFunctions_2_1_glNormal3fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glNormal3fv},
    {sipName_glNormal3i, meth_QOpenGLFunctions_2_1_glNormal3i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glNormal3i},
    {sipName_glNormal3iv, meth_QOpenGLFunctions_2_1_glNormal3iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glNormal3iv},
    {sipName_glNormal3s, meth_QOpenGLFunctions_2_1_glNormal3s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glNormal3s},
    {sipName_glNormal3sv, meth_QOpenGLFunctions_2_1_glNormal3sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glNormal3sv},
    {sipName_glNormalPointer, meth_QOpenGLFunctions_2_1_glNormalPointer, METH_VARARGS, doc_QOpenGLFunctions_2_1_glNormalPointer},
    {sipName_glOrtho, meth_QOpenGLFunctions_2_1_glOrtho, METH_VARARGS, doc_QOpenGLFunctions_2_1_glOrtho},
    {sipName_glPassThrough, meth_QOpenGLFunctions_2_1_glPassThrough, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPassThrough},
    {sipName_glPixelMapfv, meth_QOpenGLFunctions_2_1_glPixelMapfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPixelMapfv},
    {sipName_glPixelMapuiv, meth_QOpenGLFunctions_2_1_glPixelMapuiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPixelMapuiv},
    {sipName_glPixelMapusv, meth_QOpenGLFunctions_2_1_glPixelMapusv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPixelMapusv},
    {sipName_glPixelStoref, meth_QOpenGLFunctions_2_1_glPixelStoref, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPixelStoref},
    {sipName_glPixelStorei, meth_QOpenGLFunctions_2_1_glPixelStorei, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPixelStorei},
    {sipName_glPixelTransferf, meth_QOpenGLFunctions_2_1_glPixelTransferf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPixelTransferf},
    {sipName_glPixelTransferi, meth_QOpenGLFunctions_2_1_glPixelTransferi, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPixelTransferi},
    {sipName_glPixelZoom, meth_QOpenGLFunctions_2_1_glPixelZoom, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPixelZoom},
    {sipName_glPointParameterf, meth_QOpenGLFunctions_2_1_glPointParameterf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPointParameterf},
    {sipName_glPointParameterfv, meth_QOpenGLFunctions_2_1_glPointParameterfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPointParameterfv},
    {sipName_glPointParameteri, meth_QOpenGLFunctions_2_1_glPointParameteri, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPointParameteri},
    {sipName_glPointParameteriv, meth_QOpenGLFunctions_2_1_glPointParameteriv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPointParameteriv},
    {sipName_glPointSize, meth_QOpenGLFunctions_2_1_glPointSize, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPointSize},
    {sipName_glPolygonMode, meth_QOpenGLFunctions_2_1_glPolygonMode, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPolygonMode},
    {sipName_glPolygonOffset, meth_QOpenGLFunctions_2_1_glPolygonOffset, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPolygonOffset},
    {sipName_glPolygonStipple, meth_QOpenGLFunctions_2_1_glPolygonStipple, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPolygonStipple},
    {sipName_glPopAttrib, meth_QOpenGLFunctions_2_1_glPopAttrib, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPopAttrib},
    {sipName_glPopClientAttrib, meth_QOpenGLFunctions_2_1_glPopClientAttrib, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPopClientAttrib},
    {sipName_glPopMatrix, meth_QOpenGLFunctions_2_1_glPopMatrix, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPopMatrix},
    {sipName_glPopName, meth_QOpenGLFunctions_2_1_glPopName, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPopName},
    {sipName_glPushAttrib, meth_QOpenGLFunctions_2_1_glPushAttrib, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPushAttrib},
    {sipName_glPushClientAttrib, meth_QOpenGLFunctions_2_1_glPushClientAttrib, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPushClientAttrib},
    {sipName_glPushMatrix, meth_QOpenGLFunctions_2_1_glPushMatrix, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPushMatrix},
    {sipName_glPushName, meth_QOpenGLFunctions_2_1_glPushName, METH_VARARGS, doc_QOpenGLFunctions_2_1_glPushName},
    {sipName_glRasterPos2d, meth_QOpenGLFunctions_2_1_glRasterPos2d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos2d},
    {sipName_glRasterPos2dv, meth_QOpenGLFunctions_2_1_glRasterPos2dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos2dv},
    {sipName_glRasterPos2f, meth_QOpenGLFunctions_2_1_glRasterPos2f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos2f},
    {sipName_glRasterPos2fv, meth_QOpenGLFunctions_2_1_glRasterPos2fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos2fv},
    {sipName_glRasterPos2i, meth_QOpenGLFunctions_2_1_glRasterPos2i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos2i},
    {sipName_glRasterPos2iv, meth_QOpenGLFunctions_2_1_glRasterPos2iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos2iv},
    {sipName_glRasterPos2s, meth_QOpenGLFunctions_2_1_glRasterPos2s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos2s},
    {sipName_glRasterPos2sv, meth_QOpenGLFunctions_2_1_glRasterPos2sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos2sv},
    {sipName_glRasterPos3d, meth_QOpenGLFunctions_2_1_glRasterPos3d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos3d},
    {sipName_glRasterPos3dv, meth_QOpenGLFunctions_2_1_glRasterPos3dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos3dv},
    {sipName_glRasterPos3f, meth_QOpenGLFunctions_2_1_glRasterPos3f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos3f},
    {sipName_glRasterPos3fv, meth_QOpenGLFunctions_2_1_glRasterPos3fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos3fv},
    {sipName_glRasterPos3i, meth_QOpenGLFunctions_2_1_glRasterPos3i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos3i},
    {sipName_glRasterPos3iv, meth_QOpenGLFunctions_2_1_glRasterPos3iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos3iv},
    {sipName_glRasterPos3s, meth_QOpenGLFunctions_2_1_glRasterPos3s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos3s},
    {sipName_glRasterPos3sv, meth_QOpenGLFunctions_2_1_glRasterPos3sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos3sv},
    {sipName_glRasterPos4d, meth_QOpenGLFunctions_2_1_glRasterPos4d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos4d},
    {sipName_glRasterPos4dv, meth_QOpenGLFunctions_2_1_glRasterPos4dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos4dv},
    {sipName_glRasterPos4f, meth_QOpenGLFunctions_2_1_glRasterPos4f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos4f},
    {sipName_glRasterPos4fv, meth_QOpenGLFunctions_2_1_glRasterPos4fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos4fv},
    {sipName_glRasterPos4i, meth_QOpenGLFunctions_2_1_glRasterPos4i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos4i},
    {sipName_glRasterPos4iv, meth_QOpenGLFunctions_2_1_glRasterPos4iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos4iv},
    {sipName_glRasterPos4s, meth_QOpenGLFunctions_2_1_glRasterPos4s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos4s},
    {sipName_glRasterPos4sv, meth_QOpenGLFunctions_2_1_glRasterPos4sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRasterPos4sv},
    {sipName_glReadBuffer, meth_QOpenGLFunctions_2_1_glReadBuffer, METH_VARARGS, doc_QOpenGLFunctions_2_1_glReadBuffer},
    {sipName_glReadPixels, meth_QOpenGLFunctions_2_1_glReadPixels, METH_VARARGS, doc_QOpenGLFunctions_2_1_glReadPixels},
    {sipName_glRectd, meth_QOpenGLFunctions_2_1_glRectd, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRectd},
    {sipName_glRectf, meth_QOpenGLFunctions_2_1_glRectf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRectf},
    {sipName_glRecti, meth_QOpenGLFunctions_2_1_glRecti, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRecti},
    {sipName_glRects, meth_QOpenGLFunctions_2_1_glRects, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRects},
    {sipName_glRenderMode, meth_QOpenGLFunctions_2_1_glRenderMode, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRenderMode},
    {sipName_glResetHistogram, meth_QOpenGLFunctions_2_1_glResetHistogram, METH_VARARGS, doc_QOpenGLFunctions_2_1_glResetHistogram},
    {sipName_glResetMinmax, meth_QOpenGLFunctions_2_1_glResetMinmax, METH_VARARGS, doc_QOpenGLFunctions_2_1_glResetMinmax},
    {sipName_glRotated, meth_QOpenGLFunctions_2_1_glRotated, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRotated},
    {sipName_glRotatef, meth_QOpenGLFunctions_2_1_glRotatef, METH_VARARGS, doc_QOpenGLFunctions_2_1_glRotatef},
    {sipName_glSampleCoverage, meth_QOpenGLFunctions_2_1_glSampleCoverage, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSampleCoverage},
    {sipName_glScaled, meth_QOpenGLFunctions_2_1_glScaled, METH_VARARGS, doc_QOpenGLFunctions_2_1_glScaled},
    {sipName_glScalef, meth_QOpenGLFunctions_2_1_glScalef, METH_VARARGS, doc_QOpenGLFunctions_2_1_glScalef},
    {sipName_glScissor, meth_QOpenGLFunctions_2_1_glScissor, METH_VARARGS, doc_QOpenGLFunctions_2_1_glScissor},
    {sipName_glSecondaryColor3b, meth_QOpenGLFunctions_2_1_glSecondaryColor3b, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3b},
    {sipName_glSecondaryColor3bv, meth_QOpenGLFunctions_2_1_glSecondaryColor3bv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3bv},
    {sipName_glSecondaryColor3d, meth_QOpenGLFunctions_2_1_glSecondaryColor3d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3d},
    {sipName_glSecondaryColor3dv, meth_QOpenGLFunctions_2_1_glSecondaryColor3dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3dv},
    {sipName_glSecondaryColor3f, meth_QOpenGLFunctions_2_1_glSecondaryColor3f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3f},
    {sipName_glSecondaryColor3fv, meth_QOpenGLFunctions_2_1_glSecondaryColor3fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3fv},
    {sipName_glSecondaryColor3i, meth_QOpenGLFunctions_2_1_glSecondaryColor3i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3i},
    {sipName_glSecondaryColor3iv, meth_QOpenGLFunctions_2_1_glSecondaryColor3iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3iv},
    {sipName_glSecondaryColor3s, meth_QOpenGLFunctions_2_1_glSecondaryColor3s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3s},
    {sipName_glSecondaryColor3sv, meth_QOpenGLFunctions_2_1_glSecondaryColor3sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3sv},
    {sipName_glSecondaryColor3ub, meth_QOpenGLFunctions_2_1_glSecondaryColor3ub, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3ub},
    {sipName_glSecondaryColor3ubv, meth_QOpenGLFunctions_2_1_glSecondaryColor3ubv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3ubv},
    {sipName_glSecondaryColor3ui, meth_QOpenGLFunctions_2_1_glSecondaryColor3ui, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3ui},
    {sipName_glSecondaryColor3uiv, meth_QOpenGLFunctions_2_1_glSecondaryColor3uiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3uiv},
    {sipName_glSecondaryColor3us, meth_QOpenGLFunctions_2_1_glSecondaryColor3us, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3us},
    {sipName_glSecondaryColor3usv, meth_QOpenGLFunctions_2_1_glSecondaryColor3usv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColor3usv},
    {sipName_glSecondaryColorPointer, meth_QOpenGLFunctions_2_1_glSecondaryColorPointer, METH_VARARGS, doc_QOpenGLFunctions_2_1_glSecondaryColorPointer},
    {sipName_glShadeModel, meth_QOpenGLFunctions_2_1_glShadeModel, METH_VARARGS, doc_QOpenGLFunctions_2_1_glShadeModel},
    {sipName_glStencilFunc, meth_QOpenGLFunctions_2_1_glStencilFunc, METH_VARARGS, doc_QOpenGLFunctions_2_1_glStencilFunc},
    {sipName_glStencilFuncSeparate, meth_QOpenGLFunctions_2_1_glStencilFuncSeparate, METH_VARARGS, doc_QOpenGLFunctions_2_1_glStencilFuncSeparate},
    {sipName_glStencilMask, meth_QOpenGLFunctions_2_1_glStencilMask, METH_VARARGS, doc_QOpenGLFunctions_2_1_glStencilMask},
    {sipName_glStencilMaskSeparate, meth_QOpenGLFunctions_2_1_glStencilMaskSeparate, METH_VARARGS, doc_QOpenGLFunctions_2_1_glStencilMaskSeparate},
    {sipName_glStencilOp, meth_QOpenGLFunctions_2_1_glStencilOp, METH_VARARGS, doc_QOpenGLFunctions_2_1_glStencilOp},
    {sipName_glStencilOpSeparate, meth_QOpenGLFunctions_2_1_glStencilOpSeparate, METH_VARARGS, doc_QOpenGLFunctions_2_1_glStencilOpSeparate},
    {sipName_glTexCoord1d, meth_QOpenGLFunctions_2_1_glTexCoord1d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord1d},
    {sipName_glTexCoord1dv, meth_QOpenGLFunctions_2_1_glTexCoord1dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord1dv},
    {sipName_glTexCoord1f, meth_QOpenGLFunctions_2_1_glTexCoord1f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord1f},
    {sipName_glTexCoord1fv, meth_QOpenGLFunctions_2_1_glTexCoord1fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord1fv},
    {sipName_glTexCoord1i, meth_QOpenGLFunctions_2_1_glTexCoord1i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord1i},
    {sipName_glTexCoord1iv, meth_QOpenGLFunctions_2_1_glTexCoord1iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord1iv},
    {sipName_glTexCoord1s, meth_QOpenGLFunctions_2_1_glTexCoord1s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord1s},
    {sipName_glTexCoord1sv, meth_QOpenGLFunctions_2_1_glTexCoord1sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord1sv},
    {sipName_glTexCoord2d, meth_QOpenGLFunctions_2_1_glTexCoord2d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord2d},
    {sipName_glTexCoord2dv, meth_QOpenGLFunctions_2_1_glTexCoord2dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord2dv},
    {sipName_glTexCoord2f, meth_QOpenGLFunctions_2_1_glTexCoord2f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord2f},
    {sipName_glTexCoord2fv, meth_QOpenGLFunctions_2_1_glTexCoord2fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord2fv},
    {sipName_glTexCoord2i, meth_QOpenGLFunctions_2_1_glTexCoord2i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord2i},
    {sipName_glTexCoord2iv, meth_QOpenGLFunctions_2_1_glTexCoord2iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord2iv},
    {sipName_glTexCoord2s, meth_QOpenGLFunctions_2_1_glTexCoord2s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord2s},
    {sipName_glTexCoord2sv, meth_QOpenGLFunctions_2_1_glTexCoord2sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord2sv},
    {sipName_glTexCoord3d, meth_QOpenGLFunctions_2_1_glTexCoord3d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord3d},
    {sipName_glTexCoord3dv, meth_QOpenGLFunctions_2_1_glTexCoord3dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord3dv},
    {sipName_glTexCoord3f, meth_QOpenGLFunctions_2_1_glTexCoord3f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord3f},
    {sipName_glTexCoord3fv, meth_QOpenGLFunctions_2_1_glTexCoord3fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord3fv},
    {sipName_glTexCoord3i, meth_QOpenGLFunctions_2_1_glTexCoord3i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord3i},
    {sipName_glTexCoord3iv, meth_QOpenGLFunctions_2_1_glTexCoord3iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord3iv},
    {sipName_glTexCoord3s, meth_QOpenGLFunctions_2_1_glTexCoord3s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord3s},
    {sipName_glTexCoord3sv, meth_QOpenGLFunctions_2_1_glTexCoord3sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord3sv},
    {sipName_glTexCoord4d, meth_QOpenGLFunctions_2_1_glTexCoord4d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord4d},
    {sipName_glTexCoord4dv, meth_QOpenGLFunctions_2_1_glTexCoord4dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord4dv},
    {sipName_glTexCoord4f, meth_QOpenGLFunctions_2_1_glTexCoord4f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord4f},
    {sipName_glTexCoord4fv, meth_QOpenGLFunctions_2_1_glTexCoord4fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord4fv},
    {sipName_glTexCoord4i, meth_QOpenGLFunctions_2_1_glTexCoord4i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord4i},
    {sipName_glTexCoord4iv, meth_QOpenGLFunctions_2_1_glTexCoord4iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord4iv},
    {sipName_glTexCoord4s, meth_QOpenGLFunctions_2_1_glTexCoord4s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord4s},
    {sipName_glTexCoord4sv, meth_QOpenGLFunctions_2_1_glTexCoord4sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoord4sv},
    {sipName_glTexCoordPointer, meth_QOpenGLFunctions_2_1_glTexCoordPointer, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexCoordPointer},
    {sipName_glTexEnvf, meth_QOpenGLFunctions_2_1_glTexEnvf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexEnvf},
    {sipName_glTexEnvfv, meth_QOpenGLFunctions_2_1_glTexEnvfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexEnvfv},
    {sipName_glTexEnvi, meth_QOpenGLFunctions_2_1_glTexEnvi, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexEnvi},
    {sipName_glTexEnviv, meth_QOpenGLFunctions_2_1_glTexEnviv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexEnviv},
    {sipName_glTexGend, meth_QOpenGLFunctions_2_1_glTexGend, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexGend},
    {sipName_glTexGendv, meth_QOpenGLFunctions_2_1_glTexGendv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexGendv},
    {sipName_glTexGenf, meth_QOpenGLFunctions_2_1_glTexGenf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexGenf},
    {sipName_glTexGenfv, meth_QOpenGLFunctions_2_1_glTexGenfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexGenfv},
    {sipName_glTexGeni, meth_QOpenGLFunctions_2_1_glTexGeni, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexGeni},
    {sipName_glTexGeniv, meth_QOpenGLFunctions_2_1_glTexGeniv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexGeniv},
    {sipName_glTexImage1D, meth_QOpenGLFunctions_2_1_glTexImage1D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexImage1D},
    {sipName_glTexImage2D, meth_QOpenGLFunctions_2_1_glTexImage2D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexImage2D},
    {sipName_glTexImage3D, meth_QOpenGLFunctions_2_1_glTexImage3D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexImage3D},
    {sipName_glTexParameterf, meth_QOpenGLFunctions_2_1_glTexParameterf, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexParameterf},
    {sipName_glTexParameterfv, meth_QOpenGLFunctions_2_1_glTexParameterfv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexParameterfv},
    {sipName_glTexParameteri, meth_QOpenGLFunctions_2_1_glTexParameteri, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexParameteri},
    {sipName_glTexParameteriv, meth_QOpenGLFunctions_2_1_glTexParameteriv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexParameteriv},
    {sipName_glTexSubImage1D, meth_QOpenGLFunctions_2_1_glTexSubImage1D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexSubImage1D},
    {sipName_glTexSubImage2D, meth_QOpenGLFunctions_2_1_glTexSubImage2D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexSubImage2D},
    {sipName_glTexSubImage3D, meth_QOpenGLFunctions_2_1_glTexSubImage3D, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTexSubImage3D},
    {sipName_glTranslated, meth_QOpenGLFunctions_2_1_glTranslated, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTranslated},
    {sipName_glTranslatef, meth_QOpenGLFunctions_2_1_glTranslatef, METH_VARARGS, doc_QOpenGLFunctions_2_1_glTranslatef},
    {sipName_glUniform1f, meth_QOpenGLFunctions_2_1_glUniform1f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform1f},
    {sipName_glUniform1fv, meth_QOpenGLFunctions_2_1_glUniform1fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform1fv},
    {sipName_glUniform1i, meth_QOpenGLFunctions_2_1_glUniform1i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform1i},
    {sipName_glUniform1iv, meth_QOpenGLFunctions_2_1_glUniform1iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform1iv},
    {sipName_glUniform2f, meth_QOpenGLFunctions_2_1_glUniform2f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform2f},
    {sipName_glUniform2fv, meth_QOpenGLFunctions_2_1_glUniform2fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform2fv},
    {sipName_glUniform2i, meth_QOpenGLFunctions_2_1_glUniform2i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform2i},
    {sipName_glUniform2iv, meth_QOpenGLFunctions_2_1_glUniform2iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform2iv},
    {sipName_glUniform3f, meth_QOpenGLFunctions_2_1_glUniform3f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform3f},
    {sipName_glUniform3fv, meth_QOpenGLFunctions_2_1_glUniform3fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform3fv},
    {sipName_glUniform3i, meth_QOpenGLFunctions_2_1_glUniform3i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform3i},
    {sipName_glUniform3iv, meth_QOpenGLFunctions_2_1_glUniform3iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform3iv},
    {sipName_glUniform4f, meth_QOpenGLFunctions_2_1_glUniform4f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform4f},
    {sipName_glUniform4fv, meth_QOpenGLFunctions_2_1_glUniform4fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform4fv},
    {sipName_glUniform4i, meth_QOpenGLFunctions_2_1_glUniform4i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform4i},
    {sipName_glUniform4iv, meth_QOpenGLFunctions_2_1_glUniform4iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniform4iv},
    {sipName_glUniformMatrix2fv, meth_QOpenGLFunctions_2_1_glUniformMatrix2fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniformMatrix2fv},
    {sipName_glUniformMatrix3fv, meth_QOpenGLFunctions_2_1_glUniformMatrix3fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniformMatrix3fv},
    {sipName_glUniformMatrix4fv, meth_QOpenGLFunctions_2_1_glUniformMatrix4fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUniformMatrix4fv},
    {sipName_glUnmapBuffer, meth_QOpenGLFunctions_2_1_glUnmapBuffer, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUnmapBuffer},
    {sipName_glUseProgram, meth_QOpenGLFunctions_2_1_glUseProgram, METH_VARARGS, doc_QOpenGLFunctions_2_1_glUseProgram},
    {sipName_glValidateProgram, meth_QOpenGLFunctions_2_1_glValidateProgram, METH_VARARGS, doc_QOpenGLFunctions_2_1_glValidateProgram},
    {sipName_glVertex2d, meth_QOpenGLFunctions_2_1_glVertex2d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex2d},
    {sipName_glVertex2dv, meth_QOpenGLFunctions_2_1_glVertex2dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex2dv},
    {sipName_glVertex2f, meth_QOpenGLFunctions_2_1_glVertex2f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex2f},
    {sipName_glVertex2fv, meth_QOpenGLFunctions_2_1_glVertex2fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex2fv},
    {sipName_glVertex2i, meth_QOpenGLFunctions_2_1_glVertex2i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex2i},
    {sipName_glVertex2iv, meth_QOpenGLFunctions_2_1_glVertex2iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex2iv},
    {sipName_glVertex2s, meth_QOpenGLFunctions_2_1_glVertex2s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex2s},
    {sipName_glVertex2sv, meth_QOpenGLFunctions_2_1_glVertex2sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex2sv},
    {sipName_glVertex3d, meth_QOpenGLFunctions_2_1_glVertex3d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex3d},
    {sipName_glVertex3dv, meth_QOpenGLFunctions_2_1_glVertex3dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex3dv},
    {sipName_glVertex3f, meth_QOpenGLFunctions_2_1_glVertex3f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex3f},
    {sipName_glVertex3fv, meth_QOpenGLFunctions_2_1_glVertex3fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex3fv},
    {sipName_glVertex3i, meth_QOpenGLFunctions_2_1_glVertex3i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex3i},
    {sipName_glVertex3iv, meth_QOpenGLFunctions_2_1_glVertex3iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex3iv},
    {sipName_glVertex3s, meth_QOpenGLFunctions_2_1_glVertex3s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex3s},
    {sipName_glVertex3sv, meth_QOpenGLFunctions_2_1_glVertex3sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex3sv},
    {sipName_glVertex4d, meth_QOpenGLFunctions_2_1_glVertex4d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex4d},
    {sipName_glVertex4dv, meth_QOpenGLFunctions_2_1_glVertex4dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex4dv},
    {sipName_glVertex4f, meth_QOpenGLFunctions_2_1_glVertex4f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex4f},
    {sipName_glVertex4fv, meth_QOpenGLFunctions_2_1_glVertex4fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex4fv},
    {sipName_glVertex4i, meth_QOpenGLFunctions_2_1_glVertex4i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex4i},
    {sipName_glVertex4iv, meth_QOpenGLFunctions_2_1_glVertex4iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex4iv},
    {sipName_glVertex4s, meth_QOpenGLFunctions_2_1_glVertex4s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex4s},
    {sipName_glVertex4sv, meth_QOpenGLFunctions_2_1_glVertex4sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertex4sv},
    {sipName_glVertexAttrib1d, meth_QOpenGLFunctions_2_1_glVertexAttrib1d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib1d},
    {sipName_glVertexAttrib1dv, meth_QOpenGLFunctions_2_1_glVertexAttrib1dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib1dv},
    {sipName_glVertexAttrib1f, meth_QOpenGLFunctions_2_1_glVertexAttrib1f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib1f},
    {sipName_glVertexAttrib1fv, meth_QOpenGLFunctions_2_1_glVertexAttrib1fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib1fv},
    {sipName_glVertexAttrib1s, meth_QOpenGLFunctions_2_1_glVertexAttrib1s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib1s},
    {sipName_glVertexAttrib1sv, meth_QOpenGLFunctions_2_1_glVertexAttrib1sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib1sv},
    {sipName_glVertexAttrib2d, meth_QOpenGLFunctions_2_1_glVertexAttrib2d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib2d},
    {sipName_glVertexAttrib2dv, meth_QOpenGLFunctions_2_1_glVertexAttrib2dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib2dv},
    {sipName_glVertexAttrib2f, meth_QOpenGLFunctions_2_1_glVertexAttrib2f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib2f},
    {sipName_glVertexAttrib2fv, meth_QOpenGLFunctions_2_1_glVertexAttrib2fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib2fv},
    {sipName_glVertexAttrib2s, meth_QOpenGLFunctions_2_1_glVertexAttrib2s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib2s},
    {sipName_glVertexAttrib2sv, meth_QOpenGLFunctions_2_1_glVertexAttrib2sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib2sv},
    {sipName_glVertexAttrib3d, meth_QOpenGLFunctions_2_1_glVertexAttrib3d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib3d},
    {sipName_glVertexAttrib3dv, meth_QOpenGLFunctions_2_1_glVertexAttrib3dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib3dv},
    {sipName_glVertexAttrib3f, meth_QOpenGLFunctions_2_1_glVertexAttrib3f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib3f},
    {sipName_glVertexAttrib3fv, meth_QOpenGLFunctions_2_1_glVertexAttrib3fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib3fv},
    {sipName_glVertexAttrib3s, meth_QOpenGLFunctions_2_1_glVertexAttrib3s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib3s},
    {sipName_glVertexAttrib3sv, meth_QOpenGLFunctions_2_1_glVertexAttrib3sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib3sv},
    {sipName_glVertexAttrib4Nbv, meth_QOpenGLFunctions_2_1_glVertexAttrib4Nbv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4Nbv},
    {sipName_glVertexAttrib4Niv, meth_QOpenGLFunctions_2_1_glVertexAttrib4Niv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4Niv},
    {sipName_glVertexAttrib4Nsv, meth_QOpenGLFunctions_2_1_glVertexAttrib4Nsv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4Nsv},
    {sipName_glVertexAttrib4Nub, meth_QOpenGLFunctions_2_1_glVertexAttrib4Nub, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4Nub},
    {sipName_glVertexAttrib4Nubv, meth_QOpenGLFunctions_2_1_glVertexAttrib4Nubv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4Nubv},
    {sipName_glVertexAttrib4Nuiv, meth_QOpenGLFunctions_2_1_glVertexAttrib4Nuiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4Nuiv},
    {sipName_glVertexAttrib4Nusv, meth_QOpenGLFunctions_2_1_glVertexAttrib4Nusv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4Nusv},
    {sipName_glVertexAttrib4bv, meth_QOpenGLFunctions_2_1_glVertexAttrib4bv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4bv},
    {sipName_glVertexAttrib4d, meth_QOpenGLFunctions_2_1_glVertexAttrib4d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4d},
    {sipName_glVertexAttrib4dv, meth_QOpenGLFunctions_2_1_glVertexAttrib4dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4dv},
    {sipName_glVertexAttrib4f, meth_QOpenGLFunctions_2_1_glVertexAttrib4f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4f},
    {sipName_glVertexAttrib4fv, meth_QOpenGLFunctions_2_1_glVertexAttrib4fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4fv},
    {sipName_glVertexAttrib4iv, meth_QOpenGLFunctions_2_1_glVertexAttrib4iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4iv},
    {sipName_glVertexAttrib4s, meth_QOpenGLFunctions_2_1_glVertexAttrib4s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4s},
    {sipName_glVertexAttrib4sv, meth_QOpenGLFunctions_2_1_glVertexAttrib4sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4sv},
    {sipName_glVertexAttrib4ubv, meth_QOpenGLFunctions_2_1_glVertexAttrib4ubv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4ubv},
    {sipName_glVertexAttrib4uiv, meth_QOpenGLFunctions_2_1_glVertexAttrib4uiv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4uiv},
    {sipName_glVertexAttrib4usv, meth_QOpenGLFunctions_2_1_glVertexAttrib4usv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttrib4usv},
    {sipName_glVertexAttribPointer, meth_QOpenGLFunctions_2_1_glVertexAttribPointer, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexAttribPointer},
    {sipName_glVertexPointer, meth_QOpenGLFunctions_2_1_glVertexPointer, METH_VARARGS, doc_QOpenGLFunctions_2_1_glVertexPointer},
    {sipName_glViewport, meth_QOpenGLFunctions_2_1_glViewport, METH_VARARGS, doc_QOpenGLFunctions_2_1_glViewport},
    {sipName_glWindowPos2d, meth_QOpenGLFunctions_2_1_glWindowPos2d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos2d},
    {sipName_glWindowPos2dv, meth_QOpenGLFunctions_2_1_glWindowPos2dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos2dv},
    {sipName_glWindowPos2f, meth_QOpenGLFunctions_2_1_glWindowPos2f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos2f},
    {sipName_glWindowPos2fv, meth_QOpenGLFunctions_2_1_glWindowPos2fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos2fv},
    {sipName_glWindowPos2i, meth_QOpenGLFunctions_2_1_glWindowPos2i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos2i},
    {sipName_glWindowPos2iv, meth_QOpenGLFunctions_2_1_glWindowPos2iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos2iv},
    {sipName_glWindowPos2s, meth_QOpenGLFunctions_2_1_glWindowPos2s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos2s},
    {sipName_glWindowPos2sv, meth_QOpenGLFunctions_2_1_glWindowPos2sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos2sv},
    {sipName_glWindowPos3d, meth_QOpenGLFunctions_2_1_glWindowPos3d, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos3d},
    {sipName_glWindowPos3dv, meth_QOpenGLFunctions_2_1_glWindowPos3dv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos3dv},
    {sipName_glWindowPos3f, meth_QOpenGLFunctions_2_1_glWindowPos3f, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos3f},
    {sipName_glWindowPos3fv, meth_QOpenGLFunctions_2_1_glWindowPos3fv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos3fv},
    {sipName_glWindowPos3i, meth_QOpenGLFunctions_2_1_glWindowPos3i, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos3i},
    {sipName_glWindowPos3iv, meth_QOpenGLFunctions_2_1_glWindowPos3iv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos3iv},
    {sipName_glWindowPos3s, meth_QOpenGLFunctions_2_1_glWindowPos3s, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos3s},
    {sipName_glWindowPos3sv, meth_QOpenGLFunctions_2_1_glWindowPos3sv, METH_VARARGS, doc_QOpenGLFunctions_2_1_glWindowPos3sv},
    {sipName_initializeOpenGLFunctions, meth_QOpenGLFunctions_2_1_initializeOpenGLFunctions, METH_VARARGS, doc_QOpenGLFunctions_2_1_initializeOpenGLFunctions}
};

PyDoc_STRVAR(doc_QOpenGLFunctions_2_1, "\1QOpenGLFunctions_2_1()");


static pyqt5ClassPluginDef plugin_QOpenGLFunctions_2_1 = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef__QOpenGLFunctions_2_1_QOpenGLFunctions_2_1 = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QOpenGLFunctions_2_1,
        SIP_NULLPTR,
        &plugin_QOpenGLFunctions_2_1,
    },
    {
        sipNameNr_QOpenGLFunctions_2_1,
        {0, 0, 1},
        537, methods_QOpenGLFunctions_2_1,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QOpenGLFunctions_2_1,
    -1,
    -1,
    supers_QOpenGLFunctions_2_1,
    SIP_NULLPTR,
    init_type_QOpenGLFunctions_2_1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QOpenGLFunctions_2_1,
    SIP_NULLPTR,
    array_QOpenGLFunctions_2_1,
    SIP_NULLPTR,
    release_QOpenGLFunctions_2_1,
    cast_QOpenGLFunctions_2_1,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QOpenGLFunctions_2_1,
    sizeof (::QOpenGLFunctions_2_1),
};
