/*
 * Module code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtMultimedia.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qabstractvideofilter.sip"
#include <qabstractvideofilter.h>
#line 32 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 35 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameraexposure.sip"
#include <qcameraexposure.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerafocus.sip"
#include <qcamerafocus.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameraimagecapture.sip"
#include <qcameraimagecapture.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qabstractvideobuffer.sip"
#include <qabstractvideobuffer.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qvideoframe.sip"
#include <qvideoframe.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qvideosurfaceformat.sip"
#include <qvideosurfaceformat.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qabstractvideofilter.sip"
#include <qabstractvideofilter.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qpymultimedia_qlist.sip"
#include <qvideoframe.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmultimedia.sip"
#include <qmultimedia.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaservice.sip"
#include <qmediaservice.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudiodecoder.sip"
#include <qaudiodecoder.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudioformat.sip"
#include <qaudioformat.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudiobuffer.sip"
#include <qaudiobuffer.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 646 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaencodersettings.sip"
#include <qmediaencodersettings.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaobject.sip"
#include <qmediaobject.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudio.sip"
#include <qaudio.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 344 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qpymultimedia_qlist.sip"
#include <qaudio.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameraimagecapture.sip"
#include <qcameraimagecapture.h>
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 122 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameracontrol.sip"
#include <qcameracontrol.h>
#line 125 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameraexposurecontrol.sip"
#include <qcameraexposurecontrol.h>
#line 128 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 131 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerafeedbackcontrol.sip"
#include <qcamerafeedbackcontrol.h>
#line 134 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameraexposure.sip"
#include <qcameraexposure.h>
#line 137 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerafocus.sip"
#include <qcamerafocus.h>
#line 140 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 143 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerafocus.sip"
#include <qcamerafocus.h>
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameraimageprocessingcontrol.sip"
#include <qcameraimageprocessingcontrol.h>
#line 152 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 155 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameraviewfindersettingscontrol.sip"
#include <qcameraviewfindersettingscontrol.h>
#line 158 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 161 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcameraviewfindersettings.sip"
#include <qcameraviewfindersettings.h>
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 167 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 170 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaencodersettings.sip"
#include <qmediaencodersettings.h>
#line 173 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediacontent.sip"
#include <qmediacontent.h>
#line 176 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 179 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qnetworkconfiguration.sip"
#include <qnetworkconfiguration.h>
#line 182 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaplayer.sip"
#include <qmediaplayer.h>
#line 185 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediatimerange.sip"
#include <qmediatimerange.h>
#line 188 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 191 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediarecorder.sip"
#include <qmediarecorder.h>
#line 194 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediacontrol.sip"
#include <qmediacontrol.h>
#line 197 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediastreamscontrol.sip"
#include <qmediastreamscontrol.h>
#line 200 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qradiodata.sip"
#include <qradiodata.h>
#line 203 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qradiotuner.sip"
#include <qradiotuner.h>
#line 206 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 250 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qpair.sip"
#include <qpair.h>
#line 209 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 57 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaencodersettings.sip"
#include <qmediaencodersettings.h>
#line 212 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 751 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 215 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qabstractvideosurface.sip"
#include <qabstractvideosurface.h>
#line 218 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 195 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 221 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 224 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 227 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudiodeviceinfo.sip"
#include <qaudiodeviceinfo.h>
#line 230 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudioinput.sip"
#include <qaudioinput.h>
#line 233 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudiooutput.sip"
#include <qaudiooutput.h>
#line 236 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudioprobe.sip"
#include <qaudioprobe.h>
#line 239 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qaudiorecorder.sip"
#include <qaudiorecorder.h>
#line 242 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 167 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamera.sip"
#include <qcamera.h>
#line 247 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qcamerainfo.sip"
#include <qcamerainfo.h>
#line 250 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaaudioprobecontrol.sip"
#include <qmediaaudioprobecontrol.h>
#line 253 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaplayer.sip"
#include <qmediaplayer.h>
#line 256 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaplaylist.sip"
#include <qmediaplaylist.h>
#line 259 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediaresource.sip"
#include <qmediaresource.h>
#line 262 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediatimerange.sip"
#include <qmediatimerange.h>
#line 265 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qmediavideoprobecontrol.sip"
#include <qmediavideoprobecontrol.h>
#line 268 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qsoundeffect.sip"
#include <qsoundeffect.h>
#line 271 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qvideoprobe.sip"
#include <qvideoprobe.h>
#line 274 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtMultimedia[] = {
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'C', 'o', 'n', 't', 'r', 'o', 'l', ':', ':', 'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'I', 'm', 'a', 'g', 'e', 'P', 'r', 'o', 'c', 'e', 's', 's', 'i', 'n', 'g', 'C', 'o', 'n', 't', 'r', 'o', 'l', ':', ':', 'P', 'r', 'o', 'c', 'e', 's', 's', 'i', 'n', 'g', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'C', 'o', 'n', 't', 'r', 'o', 'l', ':', ':', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'I', 'm', 'a', 'g', 'e', 'C', 'a', 'p', 't', 'u', 'r', 'e', ':', ':', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'I', 'm', 'a', 'g', 'e', 'P', 'r', 'o', 'c', 'e', 's', 's', 'i', 'n', 'g', ':', ':', 'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 'M', 'o', 'd', 'e', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'I', 'm', 'a', 'g', 'e', 'C', 'a', 'p', 't', 'u', 'r', 'e', ':', ':', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'Y', 'C', 'b', 'C', 'r', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'v', 'e', 'F', 'r', 'e', 'q', 'u', 'e', 'n', 'c', 'i', 'e', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'I', 'm', 'a', 'g', 'e', 'P', 'r', 'o', 'c', 'e', 's', 's', 'i', 'n', 'g', ':', ':', 'C', 'o', 'l', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'C', 'o', 'n', 't', 'r', 'o', 'l', ':', ':', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'F', 'r', 'a', 'm', 'e', 'R', 'a', 't', 'e', 'R', 'a', 'n', 'g', 'e', 's', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'B', 'u', 'f', 'f', 'e', 'r', 'F', 'o', 'r', 'm', 'a', 't', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'F', 'e', 'e', 'd', 'b', 'a', 'c', 'k', 'C', 'o', 'n', 't', 'r', 'o', 'l', ':', ':', 'E', 'v', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'F', 'o', 'c', 'u', 's', 'Z', 'o', 'n', 'e', ':', ':', 'F', 'o', 'c', 'u', 's', 'Z', 'o', 'n', 'e', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'C', 'o', 'n', 't', 'r', 'o', 'l', '2', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'V', 'i', 'd', 'e', 'o', 'B', 'u', 'f', 'f', 'e', 'r', ':', ':', 'H', 'a', 'n', 'd', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', '>', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'S', 't', 'r', 'e', 'a', 'm', 's', 'C', 'o', 'n', 't', 'r', 'o', 'l', ':', ':', 'S', 't', 'r', 'e', 'a', 'm', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'A', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'v', 'e', 'F', 'r', 'e', 'q', 'u', 'e', 'n', 'c', 'i', 'e', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'A', 'u', 'd', 'i', 'o', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'S', 'a', 'm', 'p', 'l', 'e', 'T', 'y', 'p', 'e', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'V', 'i', 'd', 'e', 'o', 'F', 'r', 'a', 'm', 'e', ':', ':', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', '>', 0,
    'Q', 'M', 'u', 'l', 't', 'i', 'm', 'e', 'd', 'i', 'a', ':', ':', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'i', 'l', 'i', 't', 'y', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'V', 'i', 'd', 'e', 'o', 'S', 'u', 'r', 'f', 'a', 'c', 'e', '*', '>', 0,
    'i', 's', 'A', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'v', 'e', 'F', 'r', 'e', 'q', 'u', 'e', 'n', 'c', 'i', 'e', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'I', 'm', 'a', 'g', 'e', 'C', 'a', 'p', 't', 'u', 'r', 'e', ':', ':', 'D', 'r', 'i', 'v', 'e', 'M', 'o', 'd', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'C', 'a', 'm', 'e', 'r', 'a', ':', ':', 'F', 'r', 'a', 'm', 'e', 'R', 'a', 't', 'e', 'R', 'a', 'n', 'g', 'e', '>', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'F', 'i', 'l', 't', 'e', 'r', 'R', 'u', 'n', 'n', 'a', 'b', 'l', 'e', ':', ':', 'R', 'u', 'n', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'P', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'R', 'a', 'n', 'g', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 's', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'R', 'G', 'B', '8', '5', '6', '5', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'B', 'G', 'R', 'A', '5', '6', '5', '8', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'V', 'i', 'd', 'e', 'o', 'B', 'u', 'f', 'f', 'e', 'r', ':', ':', 'M', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', ':', ':', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'M', 'o', 'd', 'e', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', ':', ':', 'M', 'e', 't', 'e', 'r', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'I', 'm', 'a', 'g', 'e', 'P', 'r', 'o', 'c', 'e', 's', 's', 'i', 'n', 'g', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'F', 'i', 'l', 't', 'e', 'r', 'R', 'u', 'n', 'n', 'a', 'b', 'l', 'e', ':', ':', 'R', 'u', 'n', 'F', 'l', 'a', 'g', 0,
    'i', 's', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'Y', 'U', 'V', '4', '4', '4', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'V', 'i', 'd', 'e', 'o', 'S', 'u', 'r', 'f', 'a', 'c', 'e', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'E', 'n', 'c', 'o', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'F', 'o', 'c', 'u', 's', ':', ':', 'F', 'o', 'c', 'u', 's', 'P', 'o', 'i', 'n', 't', 'M', 'o', 'd', 'e', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'G', 'a', 'p', 'l', 'e', 's', 's', 'P', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'l', 'i', 's', 't', ':', ':', 'P', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'M', 'o', 'd', 'e', 0,
    'Q', 'M', 'u', 'l', 't', 'i', 'm', 'e', 'd', 'i', 'a', ':', ':', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    'Q', 'M', 'u', 'l', 't', 'i', 'm', 'e', 'd', 'i', 'a', ':', ':', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'E', 's', 't', 'i', 'm', 'a', 't', 'e', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'E', 'n', 'c', 'o', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'R', 'G', 'B', '3', '2', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'B', 'G', 'R', 'A', '3', '2', '_', 'P', 'r', 'e', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'O', 'u', 't', 'p', 'u', 't', 'S', 'e', 'l', 'e', 'c', 't', 'o', 'r', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', ':', ':', 'F', 'l', 'a', 's', 'h', 'M', 'o', 'd', 'e', 's', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'A', 'u', 'd', 'i', 'o', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'E', 'n', 'd', 'i', 'a', 'n', '>', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'D', 'e', 'v', 'i', 'c', 'e', 'S', 'e', 'l', 'e', 'c', 't', 'o', 'r', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'A', 'u', 'd', 'i', 'o', 'I', 'n', 'p', 'u', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'e', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'C', 'o', 'm', 'p', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 'M', 'o', 'd', 'e', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'n', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 'D', 'i', 'g', 'i', 't', 'a', 'l', 'Z', 'o', 'o', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 'O', 'p', 't', 'i', 'c', 'a', 'l', 'Z', 'o', 'o', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'I', 'n', 'p', 'u', 't', 'S', 'e', 'l', 'e', 'c', 't', 'o', 'r', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', ':', ':', 'F', 'l', 'a', 's', 'h', 'M', 'o', 'd', 'e', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'I', 'm', 'a', 'g', 'e', 'C', 'a', 'p', 't', 'u', 'r', 'e', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'I', 'm', 'a', 'g', 'e', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'i', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 'F', 'r', 'o', 'm', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'p', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'F', 'r', 'o', 'm', 'I', 'm', 'a', 'g', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'E', 'x', 't', 'e', 'n', 'd', 'e', 'd', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 0,
    'F', 'l', 'a', 's', 'h', 'S', 'l', 'o', 'w', 'S', 'y', 'n', 'c', 'F', 'r', 'o', 'n', 't', 'C', 'u', 'r', 't', 'a', 'i', 'n', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', ':', ':', 'L', 'o', 'c', 'k', 'C', 'h', 'a', 'n', 'g', 'e', 'R', 'e', 'a', 's', 'o', 'n', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'M', 'e', 'd', 'i', 'a', 'T', 'i', 'm', 'e', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', '>', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'i', 'l', 'i', 't', 'y', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'e', 'r', ':', ':', 'M', 'e', 'd', 'i', 'a', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 'M', 'u', 'l', 't', 'i', 'm', 'e', 'd', 'i', 'a', ':', ':', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'c', 'a', 'p', 't', 'u', 'r', 'e', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'D', 'i', 'g', 'i', 't', 'a', 'l', 'Z', 'o', 'o', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'O', 'p', 't', 'i', 'c', 'a', 'l', 'Z', 'o', 'o', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'F', 'o', 'c', 'u', 's', 'P', 'o', 'i', 'n', 't', 'M', 'o', 'd', 'e', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'i', 's', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 'V', 'a', 'l', 'u', 'e', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'D', 'i', 'g', 'i', 't', 'a', 'l', 'Z', 'o', 'o', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'O', 'p', 't', 'i', 'c', 'a', 'l', 'Z', 'o', 'o', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'A', 'u', 'd', 'i', 'o', 'S', 'a', 'm', 'p', 'l', 'e', 'R', 'a', 't', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'C', 'u', 's', 't', 'o', 'm', 'A', 'u', 'd', 'i', 'o', 'R', 'o', 'l', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'I', 's', 'o', 'S', 'e', 'n', 's', 'i', 't', 'i', 'v', 'i', 't', 'i', 'e', 's', 0,
    'D', 'e', 'v', 'i', 'c', 'e', 'S', 'e', 't', 't', 'i', 'n', 'g', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'F', 'l', 'a', 's', 'h', 'S', 'l', 'o', 'w', 'S', 'y', 'n', 'c', 'R', 'e', 'a', 'r', 'C', 'u', 'r', 't', 'a', 'i', 'n', 0,
    'N', 'o', 't', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'S', 'a', 'm', 'p', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'F', 'o', 'c', 'u', 's', ':', ':', 'F', 'o', 'c', 'u', 's', 'M', 'o', 'd', 'e', 's', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'F', 'r', 'a', 'm', 'e', ':', ':', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'm', 'e', 't', 'a', 'D', 'a', 't', 'a', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 's', 0,
    's', 'h', 'u', 't', 't', 'e', 'r', 'S', 'p', 'e', 'e', 'd', 'R', 'a', 'n', 'g', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'o', 'n', 's', 't', 'a', 'n', 't', 'B', 'i', 't', 'R', 'a', 't', 'e', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 0,
    'C', 'o', 'n', 's', 't', 'a', 'n', 't', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 0,
    'F', 'o', 'c', 'u', 's', 'P', 'o', 'i', 'n', 't', 'F', 'a', 'c', 'e', 'D', 'e', 't', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'F', 'o', 'r', 'm', 'a', 't', 'N', 'o', 't', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', ':', ':', 'F', 'r', 'a', 'm', 'e', 'R', 'a', 't', 'e', 'R', 'a', 'n', 'g', 'e', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'F', 'o', 'c', 'u', 's', ':', ':', 'F', 'o', 'c', 'u', 's', 'M', 'o', 'd', 'e', 0,
    'Q', 'C', 'u', 's', 't', 'o', 'm', 'A', 'u', 'd', 'i', 'o', 'R', 'o', 'l', 'e', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'A', 'u', 'd', 'i', 'o', 'D', 'e', 'v', 'i', 'c', 'e', 'I', 'n', 'f', 'o', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'F', 'o', 'c', 'u', 's', 'Z', 'o', 'n', 'e', '>', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'A', 'u', 'd', 'i', 'o', 'P', 'r', 'o', 'b', 'e', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'B', 'i', 'n', 'd', 'a', 'b', 'l', 'e', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'V', 'i', 'd', 'e', 'o', 'P', 'r', 'o', 'b', 'e', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'R', 'a', 'd', 'i', 'o', 'D', 'a', 't', 'a', ':', ':', 'P', 'r', 'o', 'g', 'r', 'a', 'm', 'T', 'y', 'p', 'e', 0,
    'Q', 'R', 'a', 'd', 'i', 'o', 'T', 'u', 'n', 'e', 'r', ':', ':', 'S', 'e', 'a', 'r', 'c', 'h', 'M', 'o', 'd', 'e', 0,
    'Q', 'R', 'a', 'd', 'i', 'o', 'T', 'u', 'n', 'e', 'r', ':', ':', 'S', 't', 'e', 'r', 'e', 'o', 'M', 'o', 'd', 'e', 0,
    'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 'F', 'l', 'u', 'o', 'r', 'e', 's', 'c', 'e', 'n', 't', 0,
    'a', 'n', 't', 'e', 'n', 'n', 'a', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'O', 'u', 't', 'p', 'u', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'P', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'R', 'a', 'n', 'g', 'e', 's', 0,
    'c', 'u', 's', 't', 'o', 'm', 'F', 'o', 'c', 'u', 's', 'P', 'o', 'i', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'M', 'o', 'd', 'e', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'i', 's', 'M', 'e', 't', 'e', 'r', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'm', 'e', 't', 'a', 'D', 'a', 't', 'a', 'W', 'r', 'i', 't', 'a', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 'I', 's', 'o', 'S', 'e', 'n', 's', 'i', 't', 'i', 'v', 'i', 't', 'y', 0,
    's', 'e', 't', 'E', 'v', 'e', 'n', 't', 'F', 'e', 'e', 'd', 'b', 'a', 'c', 'k', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'C', 'o', 'm', 'p', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'M', 'a', 'n', 'u', 'a', 'l', 'I', 's', 'o', 'S', 'e', 'n', 's', 'i', 't', 'i', 'v', 'i', 't', 'y', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'F', 'o', 'r', 'm', 'a', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 'R', 'a', 'n', 'g', 'e', 0,
    'A', 'v', 'e', 'r', 'a', 'g', 'e', 'B', 'i', 't', 'R', 'a', 't', 'e', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 0,
    'L', 'o', 'g', 'a', 'r', 'i', 't', 'h', 'm', 'i', 'c', 'V', 'o', 'l', 'u', 'm', 'e', 'S', 'c', 'a', 'l', 'e', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'F', 'e', 'e', 'd', 'b', 'a', 'c', 'k', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'I', 'm', 'a', 'g', 'e', 'P', 'r', 'o', 'c', 'e', 's', 's', 'i', 'n', 'g', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'C', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'r', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'R', 'e', 'c', 'o', 'r', 'd', 'e', 'r', ':', ':', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 'M', 'e', 't', 'a', 'D', 'a', 't', 'a', 'R', 'e', 'a', 'd', 'e', 'r', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'M', 'e', 't', 'a', 'D', 'a', 't', 'a', 'W', 'r', 'i', 't', 'e', 'r', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'F', 'r', 'a', 'm', 'e', ':', ':', 'F', 'i', 'e', 'l', 'd', 'T', 'y', 'p', 'e', 0,
    'U', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'F', 'o', 'r', 'm', 'a', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'V', 'o', 'i', 'c', 'e', 'C', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'R', 'o', 'l', 'e', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'I', 'n', 'p', 'u', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 's', 't', 'o', 'm', 'A', 'u', 'd', 'i', 'o', 'R', 'o', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'm', 'a', 'g', 'e', 'M', 'e', 't', 'a', 'd', 'a', 't', 'a', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'M', 'o', 'd', 'e', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'i', 's', 'C', 'o', 'l', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'i', 's', 'E', 'v', 'e', 'n', 't', 'F', 'e', 'e', 'd', 'b', 'a', 'c', 'k', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'm', 'e', 'd', 'i', 'a', 'A', 'b', 'o', 'u', 't', 'T', 'o', 'B', 'e', 'I', 'n', 's', 'e', 'r', 't', 'e', 'd', 0,
    'p', 'r', 'o', 'g', 'r', 'a', 'm', 'T', 'y', 'p', 'e', 'N', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'a', 'd', 'y', 'F', 'o', 'r', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'B', 'u', 'f', 'f', 'e', 'r', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 'C', 'o', 'u', 'n', 't', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'S', 'h', 'u', 't', 't', 'e', 'r', 'S', 'p', 'e', 'e', 'd', 's', 0,
    'C', 'o', 'l', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 'B', 'l', 'a', 'c', 'k', 'b', 'o', 'a', 'r', 'd', 0,
    'C', 'o', 'l', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 'W', 'h', 'i', 't', 'e', 'b', 'o', 'a', 'r', 'd', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'L', 'a', 'r', 'g', 'e', 'A', 'p', 'e', 'r', 't', 'u', 'r', 'e', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'N', 'i', 'g', 'h', 't', 'P', 'o', 'r', 't', 'r', 'a', 'i', 't', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'S', 'm', 'a', 'l', 'l', 'A', 'p', 'e', 'r', 't', 'u', 'r', 'e', 0,
    'F', 'o', 'c', 'a', 'l', 'L', 'e', 'n', 'g', 't', 'h', 'I', 'n', '3', '5', 'm', 'm', 'F', 'i', 'l', 'm', 0,
    'I', 'm', 'a', 'g', 'e', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'V', 'i', 'd', 'e', 'o', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'E', 'n', 'c', 'o', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', ':', ':', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'M', 'o', 'd', 'e', 's', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'E', 'n', 'c', 'o', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'M', 'e', 'd', 'i', 'a', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', '>', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'l', 'i', 's', 't', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'R', 'e', 'c', 'o', 'r', 'd', 'e', 'r', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'R', 'e', 'c', 'o', 'r', 'd', 'e', 'r', ':', ':', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'R', 'e', 'c', 'o', 'r', 'd', 'e', 'r', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'E', 'n', 'c', 'o', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'V', 'i', 'd', 'e', 'o', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'a', 'c', 't', 'u', 'a', 'l', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'u', 'd', 'i', 'o', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'u', 'd', 'i', 'o', 'C', 'o', 'd', 'e', 'c', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'a', 'u', 'd', 'i', 'o', 'I', 'n', 'p', 'u', 't', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'f', 'o', 'c', 'u', 's', 'P', 'o', 'i', 'n', 't', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'm', 'a', 'g', 'e', 'C', 'o', 'd', 'e', 'c', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'i', 's', 'E', 'v', 'e', 'n', 't', 'F', 'e', 'e', 'd', 'b', 'a', 'c', 'k', 'L', 'o', 'c', 'k', 'e', 'd', 0,
    'i', 's', 'o', 'S', 'e', 'n', 's', 'i', 't', 'i', 'v', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'o', 'o', 'p', 's', 'R', 'e', 'm', 'a', 'i', 'n', 'i', 'n', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'e', 'd', 'i', 'a', 'A', 'b', 'o', 'u', 't', 'T', 'o', 'B', 'e', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'n', 'o', 't', 'i', 'f', 'y', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 'R', 'a', 'n', 'g', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 'S', 'h', 'u', 't', 't', 'e', 'r', 'S', 'p', 'e', 'e', 'd', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'D', 'e', 'v', 'i', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'I', 's', 'o', 'S', 'e', 'n', 's', 'i', 't', 'i', 'v', 'i', 't', 'y', 0,
    's', 'e', 't', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'E', 'v', 'e', 'n', 't', 'F', 'e', 'e', 'd', 'b', 'a', 'c', 'k', 'S', 'o', 'u', 'n', 'd', 0,
    's', 'e', 't', 'M', 'a', 'n', 'u', 'a', 'l', 'S', 'h', 'u', 't', 't', 'e', 'r', 'S', 'p', 'e', 'e', 'd', 0,
    's', 'e', 't', 'M', 'a', 'n', 'u', 'a', 'l', 'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    's', 'i', 'g', 'n', 'a', 'l', 'S', 't', 'r', 'e', 'n', 'g', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 's', 0,
    'v', 'i', 'd', 'e', 'o', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'i', 'd', 'e', 'o', 'C', 'o', 'd', 'e', 'c', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'B', 'r', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', 'A', 'd', 'j', 'u', 's', 't', 'm', 'e', 'n', 't', 0,
    'C', 'o', 'l', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 'G', 'r', 'a', 'y', 's', 'c', 'a', 'l', 'e', 0,
    'C', 'o', 'l', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 'P', 'o', 's', 't', 'e', 'r', 'i', 'z', 'e', 0,
    'F', 'l', 'a', 's', 'h', 'R', 'e', 'd', 'E', 'y', 'e', 'R', 'e', 'd', 'u', 'c', 't', 'i', 'o', 'n', 0,
    'I', 'n', 'c', 'o', 'r', 'r', 'e', 'c', 't', 'F', 'o', 'r', 'm', 'a', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'V', 'i', 'd', 'e', 'o', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'V', 'i', 'd', 'e', 'o', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'D', 'e', 'c', 'o', 'd', 'e', 'r', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'D', 'e', 'c', 'o', 'd', 'e', 'r', ':', ':', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'D', 'e', 'c', 'o', 'd', 'e', 'r', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'F', 'o', 'r', 'm', 'a', 't', ':', ':', 'E', 'n', 'd', 'i', 'a', 'n', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', ':', ':', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'M', 'o', 'd', 'e', 0,
    'Q', 'I', 'm', 'a', 'g', 'e', 'E', 'n', 'c', 'o', 'd', 'e', 'r', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'M', 'e', 'd', 'i', 'a', 'C', 'o', 'n', 't', 'e', 'n', 't', '>', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'S', 't', 'r', 'e', 'a', 'm', 's', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'S', 'o', 'u', 'n', 'd', 'E', 'f', 'f', 'e', 'c', 't', ':', ':', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'F', 'i', 'l', 't', 'e', 'r', 'R', 'u', 'n', 'n', 'a', 'b', 'l', 'e', 0,
    'S', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'A', 'd', 'j', 'u', 's', 't', 'm', 'e', 'n', 't', 0,
    'S', 'h', 'a', 'r', 'p', 'e', 'n', 'i', 'n', 'g', 'A', 'd', 'j', 'u', 's', 't', 'm', 'e', 'n', 't', 0,
    'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 'S', 'u', 'n', 'l', 'i', 'g', 'h', 't', 0,
    'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 'T', 'u', 'n', 'g', 's', 't', 'e', 'n', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'S', 't', 'r', 'e', 'a', 'm', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'p', 'e', 'r', 't', 'u', 'r', 'e', 'R', 'a', 'n', 'g', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'r', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'F', 'i', 'l', 't', 'e', 'r', 'R', 'u', 'n', 'n', 'a', 'b', 'l', 'e', 0,
    'c', 'r', 'o', 's', 's', 'f', 'a', 'd', 'e', 'T', 'i', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'e', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'C', 'o', 'm', 'p', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', 0,
    'i', 's', 'C', 'r', 'o', 's', 's', 'f', 'a', 'd', 'e', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'i', 's', 'F', 'l', 'a', 's', 'h', 'M', 'o', 'd', 'e', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'i', 's', 'F', 'o', 'c', 'u', 's', 'M', 'o', 'd', 'e', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'i', 's', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 'D', 'i', 'g', 'i', 't', 'a', 'l', 'Z', 'o', 'o', 'm', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 'O', 'p', 't', 'i', 'c', 'a', 'l', 'Z', 'o', 'o', 'm', 0,
    's', 'e', 't', 'S', 'c', 'a', 'n', 'L', 'i', 'n', 'e', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'p', 'o', 't', 'M', 'e', 't', 'e', 'r', 'i', 'n', 'g', 'P', 'o', 'i', 'n', 't', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'A', 'u', 'd', 'i', 'o', 'C', 'o', 'd', 'e', 'c', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'I', 'm', 'a', 'g', 'e', 'C', 'o', 'd', 'e', 'c', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'S', 'a', 'm', 'p', 'l', 'e', 'R', 'a', 't', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'S', 'a', 'm', 'p', 'l', 'e', 'S', 'i', 'z', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'S', 'a', 'm', 'p', 'l', 'e', 'T', 'y', 'p', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'V', 'i', 'd', 'e', 'o', 'C', 'o', 'd', 'e', 'c', 's', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'A', 'u', 't', 'o', 'F', 'o', 'c', 'u', 's', 'I', 'n', 'P', 'r', 'o', 'g', 'r', 'e', 's', 's', 0,
    'C', 'h', 'i', 'l', 'd', 'r', 'e', 'n', 's', 'P', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'e', 's', 0,
    'C', 'o', 'l', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 'N', 'e', 'g', 'a', 't', 'i', 'v', 'e', 0,
    'C', 'o', 'l', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 'S', 'o', 'l', 'a', 'r', 'i', 'z', 'e', 0,
    'D', 'e', 'n', 'o', 'i', 's', 'i', 'n', 'g', 'A', 'd', 'j', 'u', 's', 't', 'm', 'e', 'n', 't', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'C', 'a', 'n', 'd', 'l', 'e', 'l', 'i', 'g', 'h', 't', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'S', 't', 'e', 'a', 'd', 'y', 'P', 'h', 'o', 't', 'o', 0,
    'G', 'P', 'S', 'P', 'r', 'o', 'c', 'e', 's', 's', 'i', 'n', 'g', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'R', 'e', 'q', 'u', 'e', 's', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', ':', ':', 'V', 'o', 'l', 'u', 'm', 'e', 'S', 'c', 'a', 'l', 'e', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', ':', ':', 'L', 'o', 'c', 'k', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'F', 'l', 'a', 's', 'h', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'F', 'o', 'c', 'u', 's', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'I', 'm', 'a', 'g', 'e', 'C', 'a', 'p', 't', 'u', 'r', 'e', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'L', 'o', 'c', 'k', 's', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'A', 'u', 'd', 'i', 'o', ':', ':', 'R', 'o', 'l', 'e', '>', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'e', 'r', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'e', 'r', ':', ':', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'e', 'r', ':', ':', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'e', 'r', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'R', 'e', 'c', 'o', 'r', 'd', 'i', 'n', 'g', 'I', 'n', 'P', 'r', 'o', 'g', 'r', 'e', 's', 's', 0,
    'S', 'e', 'r', 'v', 'i', 'c', 'e', 'M', 'i', 's', 's', 'i', 'n', 'g', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 's', 'p', 'e', 'c', 'i', 'f', 'i', 'e', 'd', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'O', 'u', 't', 'p', 'u', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'd', 'v', 'a', 'n', 'c', 'e', 'd', 'T', 'o', 'N', 'e', 'x', 't', 'M', 'e', 'd', 'i', 'a', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'i', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 'F', 'o', 'r', 'm', 'a', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 'S', 't', 'a', 't', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'n', 'd', 'e', 'x', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'M', 'e', 'd', 'i', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'O', 'u', 't', 'p', 'u', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'i', 's', 'M', 'e', 't', 'a', 'D', 'a', 't', 'a', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'p', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'R', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'W', 'a', 't', 'c', 'h', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'S', 'h', 'u', 't', 't', 'e', 'r', 'S', 'p', 'e', 'e', 'd', 0,
    's', 'e', 't', 'C', 'u', 's', 't', 'o', 'm', 'F', 'o', 'c', 'u', 's', 'P', 'o', 'i', 'n', 't', 0,
    's', 'e', 't', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    's', 'e', 't', 'M', 'a', 'x', 'i', 'm', 'u', 'm', 'F', 'r', 'a', 'm', 'e', 'R', 'a', 't', 'e', 0,
    's', 'e', 't', 'M', 'i', 'n', 'i', 'm', 'u', 'm', 'F', 'r', 'a', 'm', 'e', 'R', 'a', 't', 'e', 0,
    's', 'e', 't', 'N', 'a', 't', 'i', 'v', 'e', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'i', 'x', 'e', 'l', 'A', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 0,
    's', 'e', 't', 'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 'M', 'o', 'd', 'e', 0,
    's', 'h', 'u', 't', 't', 'e', 'r', 'S', 'p', 'e', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 't', 'e', 'r', 'e', 'o', 'S', 't', 'a', 't', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'A', 'u', 'd', 'i', 'o', 'R', 'o', 'l', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'B', 'y', 't', 'e', 'O', 'r', 'd', 'e', 'r', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'C', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'r', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'F', 'r', 'a', 'm', 'e', 'R', 'a', 't', 'e', 's', 0,
    'v', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'M', 'a', 'n', 'u', 'f', 'a', 'c', 't', 'u', 'r', 'e', 'r', 0,
    'C', 'o', 'n', 't', 'r', 'a', 's', 't', 'A', 'd', 'j', 'u', 's', 't', 'm', 'e', 'n', 't', 0,
    'C', 'o', 'n', 't', 'r', 'i', 'b', 'u', 't', 'i', 'n', 'g', 'A', 'r', 't', 'i', 's', 't', 0,
    'D', 'e', 'c', 'i', 'b', 'e', 'l', 'V', 'o', 'l', 'u', 'm', 'e', 'S', 'c', 'a', 'l', 'e', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'M', 'o', 'd', 'e', 'V', 'e', 'n', 'd', 'o', 'r', 0,
    'G', 'P', 'S', 'A', 'r', 'e', 'a', 'I', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 0,
    'G', 'P', 'S', 'I', 'm', 'g', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'R', 'e', 'f', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', 'M', 'u', 'l', 't', 'i', 'm', 'e', 'd', 'i', 'a', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', ':', ':', 'L', 'o', 'c', 'k', 'T', 'y', 'p', 'e', 's', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'I', 'n', 'f', 'o', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'Z', 'o', 'o', 'm', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'V', 'i', 'd', 'e', 'o', 'I', 't', 'e', 'm', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'I', 'n', 'f', 'o', '>', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'e', 'r', ':', ':', 'F', 'l', 'a', 'g', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'T', 'i', 'm', 'e', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    'Q', 'R', 'a', 'd', 'i', 'o', 'T', 'u', 'n', 'e', 'r', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'R', 'a', 'd', 'i', 'o', 'T', 'u', 'n', 'e', 'r', ':', ':', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'R', 'a', 'd', 'i', 'o', 'T', 'u', 'n', 'e', 'r', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'S', 'o', 'u', 'n', 'd', 'E', 'f', 'f', 'e', 'c', 't', ':', ':', 'L', 'o', 'o', 'p', 0,
    'R', 'a', 't', 'i', 'n', 'g', 'O', 'r', 'g', 'a', 'n', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    'S', 'e', 'a', 'r', 'c', 'h', 'G', 'e', 't', 'S', 't', 'a', 't', 'i', 'o', 'n', 'I', 'd', 0,
    'S', 'i', 'n', 'g', 'l', 'e', 'I', 'm', 'a', 'g', 'e', 'C', 'a', 'p', 't', 'u', 'r', 'e', 0,
    'S', 'o', 'f', 't', 'R', 'h', 'y', 't', 'h', 'm', 'A', 'n', 'd', 'B', 'l', 'u', 'e', 's', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'M', 'e', 'd', 'i', 'a', 'S', 't', 'a', 't', 'u', 's', 0,
    'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 'C', 'l', 'o', 'u', 'd', 'y', 0,
    'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 'M', 'a', 'n', 'u', 'a', 'l', 0,
    'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 'P', 'r', 'e', 's', 'e', 't', 0,
    'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 'S', 'u', 'n', 's', 'e', 't', 0,
    'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 'V', 'e', 'n', 'd', 'o', 'r', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'I', 'n', 'p', 'u', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'c', 't', 'u', 'a', 'l', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'a', 'p', 't', 'u', 'r', 'e', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 0,
    'c', 'a', 'p', 't', 'u', 'r', 'e', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'D', 'i', 'g', 'i', 't', 'a', 'l', 'Z', 'o', 'o', 'm', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'O', 'p', 't', 'i', 'c', 'a', 'l', 'Z', 'o', 'o', 'm', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'I', 'n', 'p', 'u', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'd', 'i', 'g', 'i', 't', 'a', 'l', 'Z', 'o', 'o', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'A', 'n', 't', 'e', 'n', 'n', 'a', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', 0,
    'i', 's', 'M', 'e', 't', 'a', 'D', 'a', 't', 'a', 'W', 'r', 'i', 't', 'a', 'b', 'l', 'e', 0,
    'm', 'a', 'n', 'u', 'a', 'l', 'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'D', 'i', 'g', 'i', 't', 'a', 'l', 'Z', 'o', 'o', 'm', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'O', 'p', 't', 'i', 'c', 'a', 'l', 'Z', 'o', 'o', 'm', 0,
    'm', 'e', 'd', 'i', 'a', 'S', 't', 'a', 't', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'o', 'p', 't', 'i', 'c', 'a', 'l', 'Z', 'o', 'o', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'o', 'g', 'r', 'a', 'm', 'T', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 's', 'e', 't', 'E', 'v', 'e', 'n', 't', 'F', 'e', 'e', 'd', 'b', 'a', 'c', 'k', 0,
    's', 'e', 't', 'A', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'C', 'u', 's', 't', 'o', 'm', 'A', 'u', 'd', 'i', 'o', 'R', 'o', 'l', 'e', 0,
    's', 'e', 't', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'S', 'h', 'a', 'r', 'p', 'e', 'n', 'i', 'n', 'g', 'L', 'e', 'v', 'e', 'l', 0,
    's', 'e', 't', 'Y', 'C', 'b', 'C', 'r', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    's', 't', 'a', 't', 'i', 'o', 'n', 'N', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'A', 'p', 'e', 'r', 't', 'u', 'r', 'e', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'M', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 's', 0,
    'v', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'A', 'c', 'c', 'e', 's', 's', 'D', 'e', 'n', 'i', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'A', 'c', 'c', 'e', 's', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'R', 'o', 'l', 'e', 0,
    'C', 'a', 'p', 't', 'u', 'r', 'e', 'S', 't', 'i', 'l', 'l', 'I', 'm', 'a', 'g', 'e', 0,
    'C', 'a', 'p', 't', 'u', 'r', 'e', 'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 0,
    'C', 'o', 'l', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 'V', 'e', 'n', 'd', 'o', 'r', 0,
    'C', 'u', 'r', 'r', 'e', 'n', 't', 'I', 't', 'e', 'm', 'I', 'n', 'L', 'o', 'o', 'p', 0,
    'D', 'a', 't', 'e', 'T', 'i', 'm', 'e', 'D', 'i', 'g', 'i', 't', 'i', 'z', 'e', 'd', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'B', 'a', 'c', 'k', 'l', 'i', 'g', 'h', 't', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'B', 'i', 'a', 's', 'V', 'a', 'l', 'u', 'e', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'F', 'i', 'r', 'e', 'w', 'o', 'r', 'k', 's', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'L', 'a', 'n', 'd', 's', 'c', 'a', 'p', 'e', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'S', 'p', 'o', 't', 'l', 'i', 'g', 'h', 't', 0,
    'E', 'x', 't', 'e', 'n', 'd', 'e', 'd', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 0,
    'F', 'l', 'a', 's', 'h', 'C', 'o', 'm', 'p', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', 0,
    'L', 'i', 'n', 'e', 'a', 'r', 'V', 'o', 'l', 'u', 'm', 'e', 'S', 'c', 'a', 'l', 'e', 0,
    'L', 'o', 'c', 'k', 'T', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'y', 'L', 'o', 's', 't', 0,
    'P', 'r', 'o', 'b', 'a', 'b', 'l', 'y', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'R', 'o', 'l', 'e', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', ':', ':', 'L', 'o', 'c', 'k', 'T', 'y', 'p', 'e', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', ':', ':', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'Q', 'R', 'a', 'd', 'i', 'o', 'D', 'a', 't', 'a', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'R', 'a', 'd', 'i', 'o', 'D', 'a', 't', 'a', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'R', 'a', 'd', 'i', 'o', 'T', 'u', 'n', 'e', 'r', ':', ':', 'B', 'a', 'n', 'd', 0,
    'U', 'n', 'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'S', 't', 'a', 't', 'u', 's', 0,
    'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'S', 't', 'a', 'r', 't', 'e', 'd', 0,
    'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 'S', 't', 'o', 'p', 'p', 'e', 'd', 0,
    'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 'F', 'l', 'a', 's', 'h', 0,
    'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 'S', 'h', 'a', 'd', 'e', 0,
    'a', 'u', 'd', 'i', 'o', 'B', 'u', 'f', 'f', 'e', 'r', 'P', 'r', 'o', 'b', 'e', 'd', 0,
    'a', 'u', 'd', 'i', 'o', 'I', 'n', 'p', 'u', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'M', 'e', 't', 'a', 'D', 'a', 't', 'a', 0,
    'b', 'r', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'a', 'm', 'e', 'r', 'a', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'c', 'a', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    'c', 'a', 'n', 'o', 'n', 'i', 'c', 'a', 'l', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'A', 'u', 'd', 'i', 'o', 'I', 'n', 'p', 'u', 't', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'd', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'F', 'o', 'r', 'F', 'r', 'a', 'm', 'e', 's', 0,
    'f', 'o', 'c', 'u', 's', 'Z', 'o', 'n', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'r', 'a', 'm', 'e', 's', 'F', 'o', 'r', 'D', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'f', 'u', 'l', 'l', 'S', 'c', 'r', 'e', 'e', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'F', 'o', 'r', 'm', 'a', 't', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'i', 's', 'R', 'e', 'a', 'd', 'y', 'F', 'o', 'r', 'C', 'a', 'p', 't', 'u', 'r', 'e', 0,
    'l', 'o', 'c', 'k', 'S', 't', 'a', 't', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'o', 'u', 't', 'p', 'u', 't', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 'A', 'p', 'e', 'r', 't', 'u', 'r', 'e', 0,
    's', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'c', 'a', 'n', 'L', 'i', 'n', 'e', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'A', 'l', 'l', 'S', 't', 'a', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'C', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'D', 'e', 'n', 'o', 'i', 's', 'i', 'n', 'g', 'L', 'e', 'v', 'e', 'l', 0,
    's', 'e', 't', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 'O', 'p', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'F', 'o', 'c', 'u', 's', 'P', 'o', 'i', 'n', 't', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'M', 'a', 'n', 'u', 'a', 'l', 'A', 'p', 'e', 'r', 't', 'u', 'r', 'e', 0,
    's', 'e', 't', 'N', 'o', 't', 'i', 'f', 'y', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    's', 'e', 't', 'O', 'u', 't', 'p', 'u', 't', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'F', 'i', 'l', 'e', 'n', 'a', 'm', 'e', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    's', 'p', 'o', 't', 'M', 'e', 't', 'e', 'r', 'i', 'n', 'g', 'P', 'o', 'i', 'n', 't', 0,
    'C', 'o', 'l', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 'S', 'e', 'p', 'i', 'a', 0,
    'C', 'o', 'l', 'o', 'r', 'T', 'e', 'm', 'p', 'e', 'r', 'a', 't', 'u', 'r', 'e', 0,
    'C', 'o', 'v', 'e', 'r', 'A', 'r', 't', 'U', 'r', 'l', 'L', 'a', 'r', 'g', 'e', 0,
    'C', 'o', 'v', 'e', 'r', 'A', 'r', 't', 'U', 'r', 'l', 'S', 'm', 'a', 'l', 'l', 0,
    'C', 'u', 'b', 'i', 'c', 'V', 'o', 'l', 'u', 'm', 'e', 'S', 'c', 'a', 'l', 'e', 0,
    'D', 'a', 't', 'e', 'T', 'i', 'm', 'e', 'O', 'r', 'i', 'g', 'i', 'n', 'a', 'l', 0,
    'D', 'i', 'g', 'i', 't', 'a', 'l', 'Z', 'o', 'o', 'm', 'R', 'a', 't', 'i', 'o', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'P', 'o', 'r', 't', 'r', 'a', 'i', 't', 0,
    'F', 'i', 'n', 'a', 'l', 'i', 'z', 'i', 'n', 'g', 'S', 't', 'a', 't', 'u', 's', 0,
    'F', 'o', 'c', 'u', 's', 'P', 'o', 'i', 'n', 't', 'C', 'e', 'n', 't', 'e', 'r', 0,
    'F', 'o', 'c', 'u', 's', 'P', 'o', 'i', 'n', 't', 'C', 'u', 's', 't', 'o', 'm', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'C', 'a', 'm', 'e', 'r', 'a', 'R', 'a', 'w', 0,
    'I', 'n', 't', 'e', 'r', 'r', 'u', 'p', 't', 'e', 'd', 'S', 't', 'a', 't', 'e', 0,
    'L', 'o', 'c', 'k', 'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 0,
    'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'R', 'o', 'l', 'e', 0,
    'P', 'r', 'e', 'f', 'e', 'r', 'r', 'e', 'd', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 0,
    'P', 'r', 'o', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', 'F', 'r', 'a', 'm', 'e', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'D', 'e', 'v', 'i', 'c', 'e', 'I', 'n', 'f', 'o', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'F', 'o', 'c', 'u', 's', 'Z', 'o', 'n', 'e', 0,
    'R', 'e', 'c', 'o', 'r', 'd', 'i', 'n', 'g', 'S', 't', 'a', 'r', 't', 'e', 'd', 0,
    'R', 'e', 'c', 'o', 'r', 'd', 'i', 'n', 'g', 'S', 't', 'o', 'p', 'p', 'e', 'd', 0,
    'S', 'c', 'e', 'n', 'e', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'T', 'y', 'p', 'e', 0,
    'S', 'e', 'r', 'i', 'o', 'u', 's', 'C', 'l', 'a', 's', 's', 'i', 'c', 'a', 'l', 0,
    'S', 'o', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'R', 'o', 'l', 'e', 0,
    'S', 'u', 'b', 'P', 'i', 'c', 't', 'u', 'r', 'e', 'S', 't', 'r', 'e', 'a', 'm', 0,
    'W', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 'A', 'u', 't', 'o', 0,
    'X', 'v', 'S', 'h', 'm', 'I', 'm', 'a', 'g', 'e', 'H', 'a', 'n', 'd', 'l', 'e', 0,
    'a', 'd', 'd', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'W', 'a', 't', 'c', 'h', 0,
    'a', 'u', 'd', 'i', 'o', 'R', 'o', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'C', 'a', 'm', 'e', 'r', 'a', 's', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'D', 'e', 'v', 'i', 'c', 'e', 's', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'O', 'u', 't', 'p', 'u', 't', 's', 0,
    'b', 'y', 't', 'e', 's', 'F', 'o', 'r', 'D', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'c', 'a', 'n', 'o', 'n', 'i', 'c', 'a', 'l', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'c', 'o', 'd', 'e', 'c', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'c', 'u', 's', 't', 'o', 'm', 'F', 'o', 'c', 'u', 's', 'P', 'o', 'i', 'n', 't', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'd', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'F', 'o', 'r', 'B', 'y', 't', 'e', 's', 0,
    'e', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'f', 'o', 'c', 'u', 's', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'r', 'e', 'q', 'u', 'e', 'n', 'c', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 'p', 'u', 't', 'D', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'i', 's', 'A', 'u', 'd', 'i', 'o', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'V', 'i', 'd', 'e', 'o', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'l', 'o', 'o', 'p', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'x', 'i', 'm', 'u', 'm', 'F', 'r', 'a', 'm', 'e', 'R', 'a', 't', 'e', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'F', 'r', 'a', 'm', 'e', 'R', 'a', 't', 'e', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    'n', 'e', 'x', 't', 'M', 'e', 'd', 'i', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'i', 'x', 'e', 'l', 'A', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 0,
    'r', 'a', 'd', 'i', 'o', 'T', 'e', 'x', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'i', 'n', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'u', 'd', 'i', 'o', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    's', 'e', 't', 'C', 'r', 'o', 's', 's', 'f', 'a', 'd', 'e', 'T', 'i', 'm', 'e', 0,
    's', 'e', 't', 'I', 'm', 'a', 'g', 'e', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    's', 'e', 't', 'V', 'i', 'd', 'e', 'o', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    's', 't', 'a', 't', 'i', 'o', 'n', 'I', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'i', 'd', 'e', 'o', 'F', 'r', 'a', 'm', 'e', 'P', 'r', 'o', 'b', 'e', 'd', 0,
    'w', 'h', 'i', 't', 'e', 'B', 'a', 'l', 'a', 'n', 'c', 'e', 'M', 'o', 'd', 'e', 0,
    'A', 'u', 't', 'o', 'F', 'o', 'c', 'u', 's', 'F', 'a', 'i', 'l', 'e', 'd', 0,
    'A', 'u', 't', 'o', 'F', 'o', 'c', 'u', 's', 'L', 'o', 'c', 'k', 'e', 'd', 0,
    'C', 'a', 'p', 't', 'u', 'r', 'e', 'T', 'o', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'C', 'o', 'l', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 'A', 'q', 'u', 'a', 0,
    'C', 'o', 'l', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 'N', 'o', 'n', 'e', 0,
    'C', 'o', 'n', 't', 'i', 'n', 'u', 'o', 'u', 's', 'F', 'o', 'c', 'u', 's', 0,
    'C', 'o', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 'H', 'a', 'n', 'd', 'l', 'e', 0,
    'C', 'u', 'r', 'r', 'e', 'n', 't', 'I', 't', 'e', 'm', 'O', 'n', 'c', 'e', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'B', 'a', 'r', 'c', 'o', 'd', 'e', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'P', 'r', 'o', 'g', 'r', 'a', 'm', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'T', 'h', 'e', 'a', 't', 'r', 'e', 0,
    'F', 'l', 'a', 's', 'h', 'V', 'i', 'd', 'e', 'o', 'L', 'i', 'g', 'h', 't', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'd', 'o', 'b', 'e', 'D', 'n', 'g', 0,
    'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'H', 'a', 'n', 'd', 'l', 'e', 0,
    'G', 'P', 'S', 'I', 'm', 'g', 'D', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'H', 'y', 'p', 'e', 'r', 'f', 'o', 'c', 'a', 'l', 'F', 'o', 'c', 'u', 's', 0,
    'I', 'S', 'O', 'S', 'p', 'e', 'e', 'd', 'R', 'a', 't', 'i', 'n', 'g', 's', 0,
    'I', 'n', 't', 'e', 'r', 'l', 'a', 'c', 'e', 'd', 'F', 'r', 'a', 'm', 'e', 0,
    'M', 'e', 't', 'e', 'r', 'i', 'n', 'g', 'A', 'v', 'e', 'r', 'a', 'g', 'e', 0,
    'O', 'u', 't', 'O', 'f', 'R', 'a', 'n', 'g', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'O', 'u', 't', 'O', 'f', 'S', 'p', 'a', 'c', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', ':', ':', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'T', 'i', 'm', 'e', 'R', 'a', 'n', 'g', 'e', 0,
    'R', 'e', 'c', 'o', 'r', 'd', 'i', 'n', 'g', 'S', 't', 'a', 't', 'u', 's', 0,
    'S', 'u', 'b', 'j', 'e', 'c', 't', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    'T', 'w', 'o', 'P', 'a', 's', 's', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 0,
    'U', 'n', 'l', 'o', 'a', 'd', 'i', 'n', 'g', 'S', 't', 'a', 't', 'u', 's', 0,
    'V', 'e', 'r', 'y', 'H', 'i', 'g', 'h', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    'Y', 'C', 'b', 'C', 'r', '_', 'U', 'n', 'd', 'e', 'f', 'i', 'n', 'e', 'd', 0,
    'a', 'p', 'e', 'r', 't', 'u', 'r', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 'M', 'o', 'd', 'e', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 'I', 'n', 'p', 'u', 't', 's', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'c', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'c', 'o', 'n', 't', 'r', 'a', 's', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 's', 't', 'o', 'm', 'A', 'u', 'd', 'i', 'o', 'R', 'o', 'l', 'e', 0,
    'd', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'i', 'm', 'a', 'g', 'e', 'P', 'r', 'o', 'c', 'e', 's', 's', 'i', 'n', 'g', 0,
    'i', 's', 'B', 'a', 'n', 'd', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'm', 'e', 't', 'a', 'D', 'a', 't', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'e', 'f', 'e', 'r', 'r', 'e', 'd', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'p', 'r', 'o', 'g', 'r', 'a', 'm', 'T', 'y', 'p', 'e', 'N', 'a', 'm', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'T', 'i', 'm', 'e', 'R', 'a', 'n', 'g', 'e', 0,
    's', 'e', 'e', 'k', 'a', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 'O', 'u', 't', 'p', 'u', 't', 0,
    's', 'e', 't', 'A', 'u', 'd', 'i', 'o', 'B', 'i', 't', 'R', 'a', 't', 'e', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'A', 'p', 'e', 'r', 't', 'u', 'r', 'e', 0,
    's', 'e', 't', 'B', 'u', 'f', 'f', 'e', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'E', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'M', 'e', 't', 'e', 'r', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'P', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'P', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'R', 'a', 't', 'e', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    's', 'e', 't', 'V', 'i', 'd', 'e', 'o', 'B', 'i', 't', 'R', 'a', 't', 'e', 0,
    's', 'h', 'a', 'r', 'p', 'e', 'n', 'i', 'n', 'g', 'L', 'e', 'v', 'e', 'l', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'C', 'o', 'd', 'e', 'c', 's', 0,
    'w', 'r', 'i', 't', 'a', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'y', 'C', 'b', 'C', 'r', 'C', 'o', 'l', 'o', 'r', 'S', 'p', 'a', 'c', 'e', 0,
    'B', 'u', 'f', 'f', 'e', 'r', 'i', 'n', 'g', 'M', 'e', 'd', 'i', 'a', 0,
    'C', 'u', 'r', 'r', 'e', 'n', 't', 'A', 'f', 'f', 'a', 'i', 'r', 's', 0,
    'E', 'G', 'L', 'I', 'm', 'a', 'g', 'e', 'H', 'a', 'n', 'd', 'l', 'e', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'M', 'a', 'n', 'u', 'a', 'l', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'S', 'p', 'o', 'r', 't', 's', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'S', 'u', 'n', 's', 'e', 't', 0,
    'F', 'o', 'c', 'u', 's', 'P', 'o', 'i', 'n', 't', 'A', 'u', 't', 'o', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'Y', 'U', 'V', '4', '4', '4', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'I', 'n', 'v', 'a', 'l', 'i', 'd', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'Y', 'U', 'V', '4', '2', '0', 'P', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'Y', 'U', 'V', '4', '2', '2', 'P', 0,
    'L', 'i', 'g', 'h', 't', 'C', 'l', 'a', 's', 's', 'i', 'c', 'a', 'l', 0,
    'M', 'a', 'y', 'b', 'e', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'M', 'e', 't', 'e', 'r', 'i', 'n', 'g', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'P', 'a', 'r', 'e', 'n', 't', 'a', 'l', 'R', 'a', 't', 'i', 'n', 'g', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'R', 'e', 'c', 'o', 'r', 'd', 'e', 'r', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', ':', ':', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'S', 't', 'r', 'i', 'n', 'g', '>', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'M', 'e', 't', 'a', 'D', 'a', 't', 'a', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'l', 'i', 's', 't', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'R', 'e', 'c', 'o', 'r', 'd', 'e', 'r', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'R', 'e', 'c', 'o', 'r', 'd', 'i', 'n', 'g', 'S', 't', 'a', 't', 'e', 0,
    'R', 'e', 'l', 'i', 'g', 'i', 'o', 'u', 's', 'M', 'u', 's', 'i', 'c', 0,
    'S', 'e', 'r', 'v', 'i', 'c', 'e', 'M', 'i', 's', 's', 'i', 'n', 'g', 0,
    'S', 't', 'a', 'r', 't', 'i', 'n', 'g', 'S', 't', 'a', 't', 'u', 's', 0,
    'S', 't', 'o', 'p', 'p', 'i', 'n', 'g', 'S', 't', 'a', 't', 'u', 's', 0,
    'S', 't', 'r', 'e', 'a', 'm', 'P', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 0,
    'S', 'u', 's', 'p', 'e', 'n', 'd', 'e', 'd', 'S', 't', 'a', 't', 'e', 0,
    'T', 'h', 'u', 'm', 'b', 'n', 'a', 'i', 'l', 'I', 'm', 'a', 'g', 'e', 0,
    'U', 'n', 'l', 'o', 'a', 'd', 'e', 'd', 'S', 't', 'a', 't', 'u', 's', 0,
    'V', 'e', 'r', 'y', 'L', 'o', 'w', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    'V', 'i', 'd', 'e', 'o', 'F', 'r', 'a', 'm', 'e', 'R', 'a', 't', 'e', 0,
    'Y', 'C', 'b', 'C', 'r', '_', 'x', 'v', 'Y', 'C', 'C', '6', '0', '1', 0,
    'Y', 'C', 'b', 'C', 'r', '_', 'x', 'v', 'Y', 'C', 'C', '7', '0', '9', 0,
    'a', 'c', 't', 'u', 'a', 'l', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'b', 'y', 't', 'e', 's', 'F', 'o', 'r', 'F', 'r', 'a', 'm', 'e', 's', 0,
    'c', 'a', 'm', 'e', 'r', 'a', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'd', 'e', 'n', 'o', 'i', 's', 'i', 'n', 'g', 'L', 'e', 'v', 'e', 'l', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'f', 'o', 'c', 'u', 's', 'P', 'o', 'i', 'n', 't', 'M', 'o', 'd', 'e', 0,
    'f', 'r', 'a', 'm', 'e', 's', 'F', 'o', 'r', 'B', 'y', 't', 'e', 's', 0,
    'f', 'r', 'e', 'q', 'u', 'e', 'n', 'c', 'y', 'R', 'a', 'n', 'g', 'e', 0,
    'i', 'm', 'a', 'g', 'e', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'o', 'S', 'e', 'n', 's', 'i', 't', 'i', 'v', 'i', 't', 'y', 0,
    'l', 'o', 'o', 'p', 's', 'R', 'e', 'm', 'a', 'i', 'n', 'i', 'n', 'g', 0,
    'n', 'o', 't', 'i', 'f', 'y', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    'o', 'u', 't', 'p', 'u', 't', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'p', 'l', 'a', 'y', 'i', 'n', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'o', 'c', 'e', 's', 's', 'e', 'd', 'U', 'S', 'e', 'c', 's', 0,
    'r', 'e', 'l', 'e', 'a', 's', 'e', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 'L', 'o', 'c', 'k', 's', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'B', 'a', 'c', 'k', 'w', 'a', 'r', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 'I', 'n', 'p', 'u', 't', 0,
    's', 'e', 't', 'A', 'u', 'd', 'i', 'o', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 0,
    's', 'e', 't', 'D', 'i', 's', 'p', 'l', 'a', 'y', 'R', 'e', 'c', 't', 0,
    's', 'e', 't', 'M', 'e', 'd', 'i', 'a', 'O', 'b', 'j', 'e', 'c', 't', 0,
    's', 'e', 't', 'P', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'V', 'i', 'd', 'e', 'o', 'O', 'u', 't', 'p', 'u', 't', 0,
    's', 'i', 'g', 'n', 'a', 'l', 'S', 't', 'r', 'e', 'n', 'g', 't', 'h', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'F', 'i', 'l', 'e', 'n', 'a', 'm', 'e', 0,
    's', 't', 'r', 'e', 'a', 'm', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'L', 'o', 'c', 'k', 's', 0,
    'B', 'u', 'f', 'f', 'e', 'r', 'e', 'd', 'M', 'e', 'd', 'i', 'a', 0,
    'C', 'a', 'p', 't', 'u', 'r', 'e', 'T', 'o', 'F', 'i', 'l', 'e', 0,
    'C', 'h', 'a', 'p', 't', 'e', 'r', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'C', 'o', 'v', 'e', 'r', 'A', 'r', 't', 'I', 'm', 'a', 'g', 'e', 0,
    'D', 'e', 'c', 'o', 'd', 'i', 'n', 'g', 'S', 't', 'a', 't', 'e', 0,
    'E', 'a', 's', 'y', 'L', 'i', 's', 't', 'e', 'n', 'i', 'n', 'g', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'B', 'e', 'a', 'c', 'h', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'N', 'i', 'g', 'h', 't', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'P', 'a', 'r', 't', 'y', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'B', 'G', 'R', '3', '2', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'A', 'R', 'G', 'B', '3', '2', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'B', 'G', 'R', '5', '5', '5', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'B', 'G', 'R', '5', '6', '5', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'B', 'G', 'R', 'A', '3', '2', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '5', '5', '5', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '5', '6', '5', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'Y', 'U', 'V', '4', '4', '4', 0,
    'G', 'P', 'S', 'S', 'a', 't', 'e', 'l', 'l', 'i', 't', 'e', 's', 0,
    'I', 'm', 'a', 'g', 'e', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'd', 0,
    'I', 'n', 'f', 'i', 'n', 'i', 't', 'y', 'F', 'o', 'c', 'u', 's', 0,
    'L', 'e', 'a', 'd', 'P', 'e', 'r', 'f', 'o', 'r', 'm', 'e', 'r', 0,
    'L', 'o', 'a', 'd', 'i', 'n', 'g', 'S', 't', 'a', 't', 'u', 's', 0,
    'N', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'M', 'u', 's', 'i', 'c', 0,
    'N', 'o', 'r', 'm', 'a', 'l', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    'N', 'o', 't', 'R', 'e', 'a', 'd', 'y', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', ':', ':', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'D', 'e', 'c', 'o', 'd', 'e', 'r', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'C', 'o', 'n', 't', 'e', 'n', 't', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'S', 'e', 'r', 'v', 'i', 'c', 'e', 0,
    'Q', 'P', 'i', 'x', 'm', 'a', 'p', 'H', 'a', 'n', 'd', 'l', 'e', 0,
    'R', 'e', 'l', 'i', 'g', 'i', 'o', 'u', 's', 'T', 'a', 'l', 'k', 0,
    'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'S', 'o', 'c', 'i', 'a', 'l', 'A', 'f', 'f', 'a', 'i', 'r', 's', 0,
    'S', 't', 'a', 'n', 'd', 'b', 'y', 'S', 't', 'a', 't', 'u', 's', 0,
    'U', 'n', 'd', 'e', 'r', 'r', 'u', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'S', 't', 'r', 'e', 'a', 'm', 0,
    'U', 'n', 'l', 'o', 'a', 'd', 'e', 'd', 'S', 't', 'a', 't', 'e', 0,
    'U', 's', 'e', 'r', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'p', 'p', 'l', 'y', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'a', 'u', 'd', 'i', 'o', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'b', 'y', 't', 'e', 's', 'P', 'e', 'r', 'F', 'r', 'a', 'm', 'e', 0,
    'c', 'a', 'n', 'c', 'e', 'l', 'C', 'a', 'p', 't', 'u', 'r', 'e', 0,
    'c', 'o', 'n', 'v', 'e', 'r', 't', 'V', 'o', 'l', 'u', 'm', 'e', 0,
    'c', 'r', 'o', 's', 's', 'f', 'a', 'd', 'e', 'T', 'i', 'm', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'C', 'a', 'm', 'e', 'r', 'a', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'O', 'u', 't', 'p', 'u', 't', 0,
    'e', 'r', 'r', 'o', 'r', 'O', 'c', 'c', 'u', 'r', 'r', 'e', 'd', 0,
    'f', 'o', 'r', 'm', 'a', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'r', 'e', 'q', 'u', 'e', 'n', 'c', 'y', 'S', 't', 'e', 'p', 0,
    'i', 'm', 'a', 'g', 'e', 'C', 'a', 'p', 't', 'u', 'r', 'e', 'd', 0,
    'i', 'm', 'a', 'g', 'e', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'l', 'o', 'a', 'd', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'e', 'd', 'i', 'a', 'I', 'n', 's', 'e', 'r', 't', 'e', 'd', 0,
    'n', 'e', 'a', 'r', 'e', 's', 't', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'I', 'n', 'd', 'e', 'x', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'N', 'a', 'm', 'e', 's', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'A', 'n', 'd', 'L', 'o', 'c', 'k', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'F', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    's', 'e', 't', 'A', 'u', 'd', 'i', 'o', 'C', 'o', 'd', 'e', 'c', 0,
    's', 'e', 't', 'A', 'u', 'd', 'i', 'o', 'I', 'n', 'p', 'u', 't', 0,
    's', 'e', 't', 'B', 'r', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', 0,
    's', 'e', 't', 'B', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'F', 'u', 'l', 'l', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    's', 'e', 't', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'a', 'm', 'p', 'l', 'e', 'R', 'a', 't', 'e', 0,
    's', 'e', 't', 'S', 'a', 'm', 'p', 'l', 'e', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'S', 'a', 'm', 'p', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'S', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 't', 'e', 'r', 'e', 'o', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'V', 'i', 'd', 'e', 'o', 'C', 'o', 'd', 'e', 'c', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 't', 'a', 't', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'v', 'i', 'd', 'e', 'o', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    'v', 'o', 'l', 'u', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'A', 'c', 't', 'i', 'v', 'e', 'S', 't', 'a', 't', 'u', 's', 0,
    'A', 'v', 'e', 'r', 'a', 'g', 'e', 'L', 'e', 'v', 'e', 'l', 0,
    'C', 'a', 'p', 't', 'u', 'r', 'e', 'V', 'i', 'd', 'e', 'o', 0,
    'C', 'o', 'u', 'n', 't', 'r', 'y', 'M', 'u', 's', 'i', 'c', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'A', 'u', 't', 'o', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'S', 'n', 'o', 'w', 0,
    'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'T', 'i', 'm', 'e', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'B', 'G', 'R', '2', '4', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'B', 'G', 'R', '3', '2', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '2', '4', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'R', 'G', 'B', '3', '2', 0,
    'G', 'P', 'S', 'L', 'o', 'n', 'g', 'i', 't', 'u', 'd', 'e', 0,
    'G', 'P', 'S', 'T', 'i', 'm', 'e', 'S', 't', 'a', 'm', 'p', 0,
    'I', 'n', 'v', 'a', 'l', 'i', 'd', 'M', 'e', 'd', 'i', 'a', 0,
    'L', 'i', 't', 't', 'l', 'e', 'E', 'n', 'd', 'i', 'a', 'n', 0,
    'L', 'o', 'a', 'd', 'e', 'd', 'S', 't', 'a', 't', 'u', 's', 0,
    'L', 'o', 'a', 'd', 'i', 'n', 'g', 'M', 'e', 'd', 'i', 'a', 0,
    'L', 'o', 'c', 'k', 'A', 'c', 'q', 'u', 'i', 'r', 'e', 'd', 0,
    'L', 'o', 'c', 'k', 'E', 'x', 'p', 'o', 's', 'u', 'r', 'e', 0,
    'M', 'e', 't', 'e', 'r', 'i', 'n', 'g', 'S', 'p', 'o', 't', 0,
    'N', 'e', 't', 'w', 'o', 'r', 'k', 'E', 'r', 'r', 'o', 'r', 0,
    'N', 'o', 't', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'P', 'a', 'u', 's', 'e', 'd', 'S', 't', 'a', 't', 'u', 's', 0,
    'P', 'l', 'a', 'y', 'i', 'n', 'g', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', ':', ':', 'M', 'o', 'd', 'e', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', ':', ':', 'R', 'o', 'l', 'e', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'O', 'u', 't', 'p', 'u', 't', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'F', 'o', 'c', 'u', 's', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'Q', 'M', 'e', 'd', 'i', 'a', 'P', 'l', 'a', 'y', 'e', 'r', 0,
    'Q', 'S', 'o', 'u', 'n', 'd', ':', ':', 'L', 'o', 'o', 'p', 0,
    'Q', 'S', 'o', 'u', 'n', 'd', 'E', 'f', 'f', 'e', 'c', 't', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'R', 'i', 'n', 'g', 't', 'o', 'n', 'e', 'R', 'o', 'l', 'e', 0,
    'S', 't', 'a', 'l', 'l', 'e', 'd', 'M', 'e', 'd', 'i', 'a', 0,
    'S', 't', 'o', 'p', 'p', 'e', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'S', 't', 'o', 'p', 'p', 'e', 'd', 'S', 't', 'a', 't', 'e', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'O', 'u', 't', 'p', 'u', 't', 0,
    'a', 'd', 'd', 'T', 'i', 'm', 'e', 'R', 'a', 'n', 'g', 'e', 0,
    'a', 'u', 'd', 'i', 'o', 'B', 'i', 't', 'R', 'a', 't', 'e', 0,
    'a', 'v', 'a', 'i', 'l', 'a', 'b', 'i', 'l', 'i', 't', 'y', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 'S', 't', 'a', 't', 'u', 's', 0,
    'b', 'y', 't', 'e', 's', 'P', 'e', 'r', 'L', 'i', 'n', 'e', 0,
    'c', 'a', 'n', 'c', 'e', 'l', 'S', 'e', 'a', 'r', 'c', 'h', 0,
    'c', 'a', 'n', 'o', 'n', 'i', 'c', 'a', 'l', 'U', 'r', 'l', 0,
    'c', 'h', 'a', 'n', 'n', 'e', 'l', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'M', 'e', 'd', 'i', 'a', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'I', 'n', 'p', 'u', 't', 0,
    'e', 'a', 'r', 'l', 'i', 'e', 's', 't', 'T', 'i', 'm', 'e', 0,
    'e', 'l', 'a', 'p', 's', 'e', 'd', 'U', 'S', 'e', 'c', 's', 0,
    'e', 'n', 'c', 'o', 'd', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'e', 'x', 'p', 'o', 's', 'u', 'r', 'e', 'M', 'o', 'd', 'e', 0,
    'i', 'm', 'a', 'g', 'e', 'E', 'x', 'p', 'o', 's', 'e', 'd', 0,
    'i', 's', 'C', 'o', 'n', 't', 'i', 'n', 'u', 'o', 'u', 's', 0,
    'i', 's', 'F', 'l', 'a', 's', 'h', 'R', 'e', 'a', 'd', 'y', 0,
    'i', 's', 'F', 'u', 'l', 'l', 'S', 'c', 'r', 'e', 'e', 'n', 0,
    'm', 'e', 'd', 'i', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'e', 'd', 'i', 'a', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'm', 'e', 't', 'e', 'r', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'm', 'u', 't', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'M', 'o', 'd', 'e', 0,
    'p', 'l', 'a', 'y', 'b', 'a', 'c', 'k', 'R', 'a', 't', 'e', 0,
    's', 'e', 't', 'A', 'u', 'd', 'i', 'o', 'R', 'o', 'l', 'e', 0,
    's', 'e', 't', 'B', 'y', 't', 'e', 'O', 'r', 'd', 'e', 'r', 0,
    's', 'e', 't', 'D', 'r', 'i', 'v', 'e', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'F', 'i', 'e', 'l', 'd', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'F', 'l', 'a', 's', 'h', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'F', 'o', 'c', 'u', 's', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'F', 'r', 'a', 'm', 'e', 'R', 'a', 't', 'e', 0,
    's', 'e', 't', 'F', 'r', 'a', 'm', 'e', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'F', 'r', 'e', 'q', 'u', 'e', 'n', 'c', 'y', 0,
    's', 'e', 't', 'L', 'o', 'o', 'p', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'N', 'e', 'x', 't', 'M', 'e', 'd', 'i', 'a', 0,
    's', 'e', 't', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 0,
    's', 'e', 't', 'S', 't', 'a', 'r', 't', 'T', 'i', 'm', 'e', 0,
    's', 'h', 'u', 't', 't', 'e', 'r', 'S', 'p', 'e', 'e', 'd', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    's', 't', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 't', 'a', 't', 'i', 'o', 'n', 'F', 'o', 'u', 'n', 'd', 0,
    'v', 'i', 'd', 'e', 'o', 'B', 'i', 't', 'R', 'a', 't', 'e', 0,
    'A', 'c', 't', 'i', 'v', 'e', 'S', 't', 'a', 't', 'e', 0,
    'A', 'l', 'b', 'u', 'm', 'A', 'r', 't', 'i', 's', 't', 0,
    'A', 'u', 'd', 'i', 'o', 'S', 't', 'r', 'e', 'a', 'm', 0,
    'B', 'o', 't', 't', 'o', 'm', 'F', 'i', 'e', 'l', 'd', 0,
    'B', 'o', 't', 't', 'o', 'm', 'T', 'o', 'T', 'o', 'p', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'E', 'r', 'r', 'o', 'r', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'M', 'o', 'd', 'e', 'l', 0,
    'C', 'l', 'a', 's', 's', 'i', 'c', 'R', 'o', 'c', 'k', 0,
    'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'a', 'r', 'y', 0,
    'F', 'l', 'a', 's', 'h', 'M', 'a', 'n', 'u', 'a', 'l', 0,
    'F', 'o', 'c', 'a', 'l', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'F', 'o', 'r', 'c', 'e', 'S', 't', 'e', 'r', 'e', 'o', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'I', 'M', 'C', '1', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'I', 'M', 'C', '2', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'I', 'M', 'C', '3', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'I', 'M', 'C', '4', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'J', 'p', 'e', 'g', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'N', 'V', '1', '2', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'N', 'V', '2', '1', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'U', 'Y', 'V', 'Y', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'U', 's', 'e', 'r', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'Y', 'U', 'Y', 'V', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'Y', 'V', '1', '2', 0,
    'G', 'P', 'S', 'A', 'l', 't', 'i', 't', 'u', 'd', 'e', 0,
    'G', 'P', 'S', 'L', 'a', 't', 'i', 't', 'u', 'd', 'e', 0,
    'G', 'P', 'S', 'M', 'a', 'p', 'D', 'a', 't', 'u', 'm', 0,
    'G', 'P', 'S', 'T', 'r', 'a', 'c', 'k', 'R', 'e', 'f', 0,
    'G', 'a', 'i', 'n', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'L', 'a', 's', 't', 'I', 'n', 'C', 'h', 'a', 'i', 'n', 0,
    'L', 'i', 'g', 'h', 't', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'L', 'o', 'a', 'd', 'e', 'd', 'M', 'e', 'd', 'i', 'a', 0,
    'L', 'o', 'a', 'd', 'e', 'd', 'S', 't', 'a', 't', 'e', 0,
    'M', 'a', 'n', 'u', 'a', 'l', 'F', 'o', 'c', 'u', 's', 0,
    'O', 'l', 'd', 'i', 'e', 's', 'M', 'u', 's', 'i', 'c', 0,
    'P', 'a', 'u', 's', 'e', 'd', 'S', 't', 'a', 't', 'e', 0,
    'P', 'e', 'r', 's', 'o', 'n', 'a', 'l', 'i', 't', 'y', 0,
    'P', 'o', 's', 't', 'e', 'r', 'I', 'm', 'a', 'g', 'e', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'I', 'n', 'p', 'u', 't', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 'P', 'r', 'o', 'b', 'e', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 'I', 'n', 'f', 'o', 0,
    'Q', 'M', 'u', 'l', 't', 'i', 'm', 'e', 'd', 'i', 'a', 0,
    'Q', 'R', 'a', 'd', 'i', 'o', 'T', 'u', 'n', 'e', 'r', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'F', 'r', 'a', 'm', 'e', 0,
    'Q', 'V', 'i', 'd', 'e', 'o', 'P', 'r', 'o', 'b', 'e', 0,
    'T', 'o', 'p', 'T', 'o', 'B', 'o', 't', 't', 'o', 'm', 0,
    'T', 'r', 'a', 'c', 'k', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'U', 'n', 'S', 'i', 'g', 'n', 'e', 'd', 'I', 'n', 't', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'R', 'o', 'l', 'e', 0,
    'U', 's', 'e', 'r', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    'V', 'i', 'd', 'e', 'o', 'S', 't', 'r', 'e', 'a', 'm', 0,
    'Y', 'C', 'b', 'C', 'r', '_', 'B', 'T', '6', '0', '1', 0,
    'Y', 'C', 'b', 'C', 'r', '_', 'B', 'T', '7', '0', '9', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'I', 'n', 'p', 'u', 't', 0,
    'a', 'c', 't', 'u', 'a', 'l', 'V', 'a', 'l', 'u', 'e', 0,
    'a', 'd', 'd', 'I', 'n', 't', 'e', 'r', 'v', 'a', 'l', 0,
    'a', 'u', 'd', 'i', 'o', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'a', 'u', 'd', 'i', 'o', 'I', 'n', 'p', 'u', 't', 's', 0,
    'b', 'a', 'n', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 'R', 'e', 'a', 'd', 'y', 0,
    'c', 'a', 'p', 't', 'u', 'r', 'e', 'M', 'o', 'd', 'e', 0,
    'c', 'o', 'l', 'o', 'r', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'd', 'i', 'g', 'i', 't', 'a', 'l', 'Z', 'o', 'o', 'm', 0,
    'd', 'i', 's', 'p', 'l', 'a', 'y', 'R', 'e', 'c', 't', 0,
    'e', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'f', 'r', 'a', 'm', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'i', 'n', 's', 'e', 'r', 't', 'M', 'e', 'd', 'i', 'a', 0,
    'i', 's', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'S', 'e', 'a', 'r', 'c', 'h', 'i', 'n', 'g', 0,
    'm', 'a', 'p', 'p', 'e', 'd', 'B', 'y', 't', 'e', 's', 0,
    'm', 'e', 'd', 'i', 'a', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'm', 'e', 'd', 'i', 'a', 'S', 't', 'a', 't', 'u', 's', 0,
    'm', 'e', 'd', 'i', 'a', 'S', 't', 'r', 'e', 'a', 'm', 0,
    'o', 'p', 't', 'i', 'c', 'a', 'l', 'Z', 'o', 'o', 'm', 0,
    'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'p', 'i', 'x', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'p', 'r', 'o', 'g', 'r', 'a', 'm', 'T', 'y', 'p', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'M', 'e', 'd', 'i', 'a', 0,
    's', 'a', 'm', 'p', 'l', 'e', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'r', 'a', 's', 't', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 0,
    's', 'e', 't', 'M', 'e', 't', 'a', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'M', 'i', 'r', 'r', 'o', 'r', 'e', 'd', 0,
    's', 'e', 't', 'P', 'l', 'a', 'y', 'l', 'i', 's', 't', 0,
    's', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    's', 't', 'a', 't', 'i', 'o', 'n', 'N', 'a', 'm', 'e', 0,
    's', 't', 'r', 'e', 'a', 'm', 'C', 'o', 'u', 'n', 't', 0,
    'A', 'l', 'b', 'u', 'm', 'T', 'i', 't', 'l', 'e', 0,
    'C', 'u', 's', 't', 'o', 'm', 'R', 'o', 'l', 'e', 0,
    'D', 'a', 't', 'a', 'S', 't', 'r', 'e', 'a', 'm', 0,
    'E', 'n', 'd', 'O', 'f', 'M', 'e', 'd', 'i', 'a', 0,
    'F', 'a', 't', 'a', 'l', 'E', 'r', 'r', 'o', 'r', 0,
    'F', 'l', 'a', 's', 'h', 'P', 'o', 'w', 'e', 'r', 0,
    'F', 'l', 'a', 's', 'h', 'T', 'o', 'r', 'c', 'h', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'Y', '1', '6', 0,
    'I', 'm', 'a', 'g', 'e', 'E', 'r', 'r', 'o', 'r', 0,
    'I', 'm', 'a', 'g', 'e', 'S', 'a', 'v', 'e', 'd', 0,
    'L', 'o', 'c', 'k', 'F', 'a', 'i', 'l', 'e', 'd', 0,
    'L', 'o', 'w', 'L', 'a', 't', 'e', 'n', 'c', 'y', 0,
    'M', 'a', 'c', 'r', 'o', 'F', 'o', 'c', 'u', 's', 0,
    'O', 't', 'h', 'e', 'r', 'M', 'u', 's', 'i', 'c', 0,
    'Q', 'R', 'a', 'd', 'i', 'o', 'D', 'a', 't', 'a', 0,
    'S', 'e', 'a', 'r', 'c', 'h', 'F', 'a', 's', 't', 0,
    'S', 'e', 'q', 'u', 'e', 'n', 't', 'i', 'a', 'l', 0,
    'S', 'h', 'a', 'r', 'p', 'e', 'n', 'i', 'n', 'g', 0,
    'T', 'o', 'r', 'c', 'h', 'P', 'o', 'w', 'e', 'r', 0,
    'T', 'r', 'a', 'c', 'k', 'C', 'o', 'u', 'n', 't', 0,
    'U', 's', 'e', 'r', 'H', 'a', 'n', 'd', 'l', 'e', 0,
    'U', 's', 'e', 'r', 'R', 'a', 't', 'i', 'n', 'g', 0,
    'Y', 'C', 'b', 'C', 'r', '_', 'J', 'P', 'E', 'G', 0,
    '_', '_', 'i', 'n', 'v', 'e', 'r', 't', '_', '_', 0,
    'a', 'u', 'd', 'i', 'o', 'C', 'o', 'd', 'e', 'c', 0,
    'a', 'u', 'd', 'i', 'o', 'I', 'n', 'p', 'u', 't', 0,
    'b', 'r', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 'S', 'i', 'z', 'e', 0,
    'b', 'y', 't', 'e', 's', 'R', 'e', 'a', 'd', 'y', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'U', 'r', 'l', 0,
    'c', 'o', 'n', 't', 'i', 'n', 'u', 'o', 'u', 's', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'N', 'a', 'm', 'e', 0,
    'f', 'l', 'a', 's', 'h', 'R', 'e', 'a', 'd', 'y', 0,
    'f', 'o', 'c', 'u', 's', 'Z', 'o', 'n', 'e', 's', 0,
    'f', 'r', 'a', 'm', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'f', 'r', 'a', 'm', 'e', 'W', 'i', 'd', 't', 'h', 0,
    'h', 'a', 'n', 'd', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'h', 'a', 's', 'S', 'u', 'p', 'p', 'o', 'r', 't', 0,
    'h', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'm', 'a', 'g', 'e', 'S', 'a', 'v', 'e', 'd', 0,
    'i', 's', 'F', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    'i', 's', 'M', 'i', 'r', 'r', 'o', 'r', 'e', 'd', 0,
    'i', 's', 'R', 'e', 'a', 'd', 'O', 'n', 'l', 'y', 0,
    'i', 's', 'R', 'e', 'a', 'd', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'S', 'e', 'e', 'k', 'a', 'b', 'l', 'e', 0,
    'i', 's', 'W', 'r', 'i', 't', 'a', 'b', 'l', 'e', 0,
    'l', 'a', 't', 'e', 's', 't', 'T', 'i', 'm', 'e', 0,
    'l', 'o', 'a', 'd', 'F', 'a', 'i', 'l', 'e', 'd', 0,
    'l', 'o', 'c', 'k', 'F', 'a', 'i', 'l', 'e', 'd', 0,
    'l', 'o', 'c', 'k', 'S', 't', 'a', 't', 'u', 's', 0,
    'm', 'e', 'd', 'i', 'a', 'C', 'o', 'u', 'n', 't', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'S', 'i', 'z', 'e', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 0,
    'p', 'e', 'r', 'i', 'o', 'd', 'S', 'i', 'z', 'e', 0,
    'p', 'l', 'a', 'n', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'r', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    's', 'a', 'm', 'p', 'l', 'e', 'R', 'a', 't', 'e', 0,
    's', 'a', 'm', 'p', 'l', 'e', 'S', 'i', 'z', 'e', 0,
    's', 'a', 'm', 'p', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 'a', 'r', 'c', 'h', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'B', 'i', 't', 'R', 'a', 't', 'e', 0,
    's', 'e', 't', 'E', 'n', 'd', 'T', 'i', 'm', 'e', 0,
    's', 'e', 't', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    's', 'e', 't', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    's', 't', 'e', 'r', 'e', 'o', 'M', 'o', 'd', 'e', 0,
    's', 't', 'r', 'e', 'a', 'm', 'T', 'y', 'p', 'e', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 'd', 0,
    'v', 'i', 'd', 'e', 'o', 'C', 'o', 'd', 'e', 'c', 0,
    'A', 'd', 'u', 'l', 't', 'H', 'i', 't', 's', 0,
    'A', 'l', 'a', 'r', 'm', 'R', 'o', 'l', 'e', 0,
    'A', 'l', 'a', 'r', 'm', 'T', 'e', 's', 't', 0,
    'A', 'u', 't', 'o', 'F', 'o', 'c', 'u', 's', 0,
    'B', 'i', 'g', 'E', 'n', 'd', 'i', 'a', 'n', 0,
    'C', 'o', 'n', 'd', 'u', 'c', 't', 'o', 'r', 0,
    'C', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 't', 0,
    'D', 'e', 'n', 'o', 'i', 's', 'i', 'n', 'g', 0,
    'E', 'd', 'u', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'F', 'l', 'a', 's', 'h', 'A', 'u', 't', 'o', 0,
    'F', 'l', 'a', 's', 'h', 'F', 'i', 'l', 'l', 0,
    'F', 'o', 'l', 'k', 'M', 'u', 's', 'i', 'c', 0,
    'F', 'o', 'r', 'c', 'e', 'M', 'o', 'n', 'o', 0,
    'F', 'o', 'r', 'm', 'a', 't', '_', 'Y', '8', 0,
    'F', 'r', 'o', 'n', 't', 'F', 'a', 'c', 'e', 0,
    'G', 'P', 'S', 'S', 't', 'a', 't', 'u', 's', 0,
    'I', 'd', 'l', 'e', 'S', 't', 'a', 't', 'e', 0,
    'J', 'a', 'z', 'z', 'M', 'u', 's', 'i', 'c', 0,
    'L', 'o', 'c', 'k', 'F', 'o', 'c', 'u', 's', 0,
    'M', 'e', 'd', 'i', 'a', 'T', 'y', 'p', 'e', 0,
    'M', 'u', 's', 'i', 'c', 'R', 'o', 'l', 'e', 0,
    'N', 'o', 's', 't', 'a', 'l', 'g', 'i', 'a', 0,
    'N', 'o', 't', 'M', 'a', 'p', 'p', 'e', 'd', 0,
    'O', 'p', 'e', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'P', 'e', 'a', 'k', 'V', 'a', 'l', 'u', 'e', 0,
    'P', 'o', 's', 't', 'e', 'r', 'U', 'r', 'l', 0,
    'P', 'u', 'b', 'l', 'i', 's', 'h', 'e', 'r', 0,
    'R', 'e', 'a', 'd', 'W', 'r', 'i', 't', 'e', 0,
    'R', 'o', 'c', 'k', 'M', 'u', 's', 'i', 'c', 0,
    'S', 'h', 'a', 'r', 'p', 'n', 'e', 's', 's', 0,
    'V', 'i', 'd', 'e', 'o', 'R', 'o', 'l', 'e', 0,
    'W', 'r', 'i', 't', 'e', 'O', 'n', 'l', 'y', 0,
    '_', '_', 'i', 'n', 'd', 'e', 'x', '_', '_', 0,
    'a', 'u', 'd', 'i', 'o', 'R', 'o', 'l', 'e', 0,
    'b', 'y', 't', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'b', 'y', 't', 'e', 'O', 'r', 'd', 'e', 'r', 0,
    'b', 'y', 't', 'e', 's', 'F', 'r', 'e', 'e', 0,
    'c', 'o', 'n', 's', 't', 'D', 'a', 't', 'a', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'r', 0,
    'd', 'r', 'i', 'v', 'e', 'M', 'o', 'd', 'e', 0,
    'f', 'i', 'e', 'l', 'd', 'T', 'y', 'p', 'e', 0,
    'f', 'l', 'a', 's', 'h', 'M', 'o', 'd', 'e', 0,
    'f', 'o', 'c', 'u', 's', 'M', 'o', 'd', 'e', 0,
    'f', 'r', 'a', 'm', 'e', 'R', 'a', 't', 'e', 0,
    'f', 'r', 'a', 'm', 'e', 'S', 'i', 'z', 'e', 0,
    'f', 'r', 'e', 'q', 'u', 'e', 'n', 'c', 'y', 0,
    'i', 'n', 't', 'e', 'r', 'v', 'a', 'l', 's', 0,
    'i', 's', 'P', 'l', 'a', 'y', 'i', 'n', 'g', 0,
    'l', 'o', 'o', 'p', 'C', 'o', 'u', 'n', 't', 0,
    'n', 'e', 'x', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'n', 'e', 'x', 't', 'M', 'e', 'd', 'i', 'a', 0,
    'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 0,
    'r', 'a', 'd', 'i', 'o', 'D', 'a', 't', 'a', 0,
    'r', 'a', 'd', 'i', 'o', 'T', 'e', 'x', 't', 0,
    'r', 'e', 's', 'o', 'u', 'r', 'c', 'e', 's', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    's', 'e', 't', 'V', 'o', 'l', 'u', 'm', 'e', 0,
    's', 't', 'a', 'r', 't', 'T', 'i', 'm', 'e', 0,
    's', 't', 'a', 't', 'i', 'o', 'n', 'I', 'd', 0,
    'B', 'a', 'c', 'k', 'F', 'a', 'c', 'e', 0,
    'C', 'o', 'm', 'p', 'o', 's', 'e', 'r', 0,
    'D', 'i', 'r', 'e', 'c', 't', 'o', 'r', 0,
    'F', 'l', 'a', 's', 'h', 'O', 'f', 'f', 0,
    'G', 'P', 'S', 'S', 'p', 'e', 'e', 'd', 0,
    'G', 'P', 'S', 'T', 'r', 'a', 'c', 'k', 0,
    'G', 'a', 'm', 'e', 'R', 'o', 'l', 'e', 0,
    'I', 'n', 'f', 'i', 'n', 'i', 't', 'e', 0,
    'K', 'e', 'y', 'w', 'o', 'r', 'd', 's', 0,
    'L', 'o', 'c', 'k', 'L', 'o', 's', 't', 0,
    'N', 'o', 'H', 'a', 'n', 'd', 'l', 'e', 0,
    'P', 'o', 'p', 'M', 'u', 's', 'i', 'c', 0,
    'R', 'e', 'l', 'i', 'g', 'i', 'o', 'n', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'e', 'd', 0,
    'S', 'o', 'f', 't', 'R', 'o', 'c', 'k', 0,
    'S', 'u', 'b', 'T', 'i', 't', 'l', 'e', 0,
    'T', 'o', 'p', 'F', 'i', 'e', 'l', 'd', 0,
    'U', 'n', 'l', 'o', 'c', 'k', 'e', 'd', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'i', 'a', 'd', 'd', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 's', 'u', 'b', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    'a', 'd', 'd', 'M', 'e', 'd', 'i', 'a', 0,
    'a', 'p', 'e', 'r', 't', 'u', 'r', 'e', 0,
    'c', 'a', 't', 'e', 'g', 'o', 'r', 'y', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 's', 0,
    'c', 'o', 'n', 't', 'r', 'a', 's', 't', 0,
    'd', 'a', 't', 'a', 'S', 'i', 'z', 'e', 0,
    'd', 'u', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'e', 'x', 'p', 'o', 's', 'u', 'r', 'e', 0,
    'f', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'f', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    'i', 's', 'A', 'c', 't', 'i', 'v', 'e', 0,
    'i', 's', 'L', 'o', 'a', 'd', 'e', 'd', 0,
    'i', 's', 'M', 'a', 'p', 'p', 'e', 'd', 0,
    'i', 's', 'N', 'o', 'r', 'm', 'a', 'l', 0,
    'i', 's', 'S', 't', 'e', 'r', 'e', 'o', 0,
    'l', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 0,
    'm', 'e', 't', 'a', 'D', 'a', 't', 'a', 0,
    'm', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 0,
    'p', 'l', 'a', 'y', 'l', 'i', 's', 't', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'e', 't', 'C', 'o', 'd', 'e', 'c', 0,
    's', 'e', 't', 'E', 'r', 'r', 'o', 'r', 0,
    's', 'e', 't', 'L', 'o', 'o', 'p', 's', 0,
    's', 'e', 't', 'M', 'e', 'd', 'i', 'a', 0,
    's', 'e', 't', 'M', 'u', 't', 'e', 'd', 0,
    's', 'e', 't', 'S', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'W', 'i', 'n', 'I', 'd', 0,
    's', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    's', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    'C', 'o', 'l', 'l', 'e', 'g', 'e', 0,
    'C', 'o', 'm', 'm', 'e', 'n', 't', 0,
    'C', 'u', 'l', 't', 'u', 'r', 'e', 0,
    'F', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    'F', 'i', 'n', 'a', 'n', 'c', 'e', 0,
    'F', 'l', 'a', 's', 'h', 'O', 'n', 0,
    'F', 'o', 'c', 'u', 's', 'e', 'd', 0,
    'I', 'O', 'E', 'r', 'r', 'o', 'r', 0,
    'L', 'e', 'i', 's', 'u', 'r', 'e', 0,
    'L', 'o', 'a', 'd', 'i', 'n', 'g', 0,
    'N', 'o', 'E', 'r', 'r', 'o', 'r', 0,
    'N', 'o', 'M', 'e', 'd', 'i', 'a', 0,
    'P', 'h', 'o', 'n', 'e', 'I', 'n', 0,
    'Q', 'C', 'a', 'm', 'e', 'r', 'a', 0,
    'S', 'c', 'i', 'e', 'n', 'c', 'e', 0,
    'S', 'u', 'b', 'j', 'e', 'c', 't', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 0,
    'W', 'e', 'a', 't', 'h', 'e', 'r', 0,
    '_', '_', 'a', 'd', 'd', '_', '_', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 's', 'u', 'b', '_', '_', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    'b', 'i', 't', 'R', 'a', 't', 'e', 0,
    'c', 'a', 'p', 't', 'u', 'r', 'e', 0,
    'e', 'n', 'd', 'T', 'i', 'm', 'e', 0,
    'i', 's', 'E', 'm', 'p', 't', 'y', 0,
    'i', 's', 'M', 'u', 't', 'e', 'd', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    'm', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'p', 'r', 'e', 's', 'e', 'n', 't', 0,
    'q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    'r', 'e', 'l', 'e', 'a', 's', 'e', 0,
    'r', 'e', 'p', 'a', 'i', 'n', 't', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 0,
    's', 'e', 'r', 'v', 'i', 'c', 'e', 0,
    's', 'e', 't', 'B', 'a', 'n', 'd', 0,
    's', 'h', 'u', 'f', 'f', 'l', 'e', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    's', 'u', 's', 'p', 'e', 'n', 'd', 0,
    'A', 'u', 't', 'h', 'o', 'r', 0,
    'G', 'P', 'S', 'D', 'O', 'P', 0,
    'L', 'y', 'r', 'i', 'c', 's', 0,
    'N', 'o', 'L', 'o', 'c', 'k', 0,
    'P', 'u', 'b', 'l', 'i', 'c', 0,
    'Q', 'A', 'u', 'd', 'i', 'o', 0,
    'Q', 'S', 'o', 'u', 'n', 'd', 0,
    'R', 'a', 'n', 'd', 'o', 'm', 0,
    'T', 'r', 'a', 'v', 'e', 'l', 0,
    'U', 'n', 'u', 's', 'e', 'd', 0,
    'V', 'a', 'r', 'i', 'e', 'd', 0,
    'W', 'r', 'i', 't', 'e', 'r', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 0,
    'c', 'o', 'd', 'e', 'c', 's', 0,
    'f', 'o', 'r', 'm', 'a', 't', 0,
    'h', 'a', 'n', 'd', 'l', 'e', 0,
    'h', 'e', 'i', 'g', 'h', 't', 0,
    'i', 's', 'N', 'u', 'l', 'l', 0,
    'l', 'o', 'a', 'd', 'e', 'd', 0,
    'n', 'o', 't', 'i', 'f', 'y', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'r', 'e', 'c', 'o', 'r', 'd', 0,
    'r', 'e', 's', 'u', 'm', 'e', 0,
    's', 'e', 't', 'H', 'u', 'e', 0,
    's', 't', 'a', 't', 'u', 's', 0,
    's', 't', 'r', 'e', 'a', 'm', 0,
    'u', 'n', 'b', 'i', 'n', 'd', 0,
    'u', 'n', 'l', 'o', 'a', 'd', 0,
    'u', 'n', 'l', 'o', 'c', 'k', 0,
    'v', 'o', 'l', 'u', 'm', 'e', 0,
    'z', 'o', 'o', 'm', 'T', 'o', 0,
    'A', 'l', 'a', 'r', 'm', 0,
    'D', 'r', 'a', 'm', 'a', 0,
    'F', 'l', 'o', 'a', 't', 0,
    'G', 'e', 'n', 'r', 'e', 0,
    'S', 'p', 'o', 'r', 't', 0,
    'T', 'o', 'p', '4', '0', 0,
    'c', 'l', 'e', 'a', 'r', 0,
    'c', 'o', 'd', 'e', 'c', 0,
    'e', 'r', 'r', 'o', 'r', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'f', 'l', 'a', 'g', 's', 0,
    'f', 'l', 'u', 's', 'h', 0,
    'f', 'o', 'c', 'u', 's', 0,
    'i', 'm', 'a', 'g', 'e', 0,
    'l', 'o', 'o', 'p', 's', 0,
    'p', 'a', 'u', 's', 'e', 0,
    'r', 'e', 'a', 'l', 'm', 0,
    's', 't', 'a', 'r', 't', 0,
    's', 't', 'a', 't', 'e', 0,
    's', 't', 'e', 'p', 's', 0,
    'u', 'n', 'm', 'a', 'p', 0,
    'v', 'i', 'd', 'e', 'o', 0,
    'w', 'i', 'd', 't', 'h', 0,
    'w', 'i', 'n', 'I', 'd', 0,
    'B', 'u', 's', 'y', 0,
    'D', 'a', 't', 'e', 0,
    'M', 'o', 'o', 'd', 0,
    'N', 'e', 'w', 's', 0,
    'S', 'o', 'f', 't', 0,
    'Y', 'e', 'a', 'r', 0,
    'a', 'r', 'e', 'a', 0,
    'b', 'a', 'n', 'd', 0,
    'b', 'i', 't', 's', 0,
    'd', 'a', 't', 'a', 0,
    'f', 'i', 'l', 'e', 0,
    'n', 'e', 'x', 't', 0,
    'p', 'l', 'a', 'y', 0,
    'r', 'e', 'a', 'd', 0,
    's', 'a', 'v', 'e', 0,
    's', 'i', 'z', 'e', 0,
    's', 't', 'o', 'p', 0,
    's', 'w', 'a', 'p', 0,
    't', 'y', 'p', 'e', 0,
    'F', 'M', '2', 0,
    'I', 'S', 'O', 0,
    'h', 'u', 'e', 0,
    'r', 'u', 'n', 0,
    'u', 'r', 'l', 0,
    'A', 'M', 0,
    'F', 'M', 0,
    'L', 'W', 0,
    'S', 'W', 0,
};

void sipVH_QtMultimedia_148(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::Qt::AspectRatioMode a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_Qt_AspectRatioMode);
}

::Qt::AspectRatioMode sipVH_QtMultimedia_147(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::Qt::AspectRatioMode sipRes = ::Qt::IgnoreAspectRatio;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_Qt_AspectRatioMode, &sipRes);

    return sipRes;
}

::QSize sipVH_QtMultimedia_146(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_145(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QRect& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QRect(a0), sipType_QRect, SIP_NULLPTR);
}

::QRect sipVH_QtMultimedia_144(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QRect sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QRect, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_143(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::WId a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::WId(a0), sipType_quintptr, SIP_NULLPTR);
}

::WId sipVH_QtMultimedia_142(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::WId sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_quintptr, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_141(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QAbstractVideoSurface*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QAbstractVideoSurface, SIP_NULLPTR);
}

::QAbstractVideoSurface* sipVH_QtMultimedia_140(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QAbstractVideoSurface* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QAbstractVideoSurface, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_139(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QVideoEncoderSettings& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QVideoEncoderSettings(a0), sipType_QVideoEncoderSettings, SIP_NULLPTR);
}

::QVideoEncoderSettings sipVH_QtMultimedia_138(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QVideoEncoderSettings sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVideoEncoderSettings, &sipRes);

    return sipRes;
}

::QList< ::qreal> sipVH_QtMultimedia_137(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QVideoEncoderSettings& a0, bool*a1)
{
    ::QList< ::qreal> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QVideoEncoderSettings(a0), sipType_QVideoEncoderSettings, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(H5b)", sipType_QList_2400, &sipRes, a1);

    return sipRes;
}

QList< ::QSize> sipVH_QtMultimedia_136(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QVideoEncoderSettings& a0, bool*a1)
{
    QList< ::QSize> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QVideoEncoderSettings(a0), sipType_QVideoEncoderSettings, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(H5b)", sipType_QList_0100QSize, &sipRes, a1);

    return sipRes;
}

::QString sipVH_QtMultimedia_135(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

::QRadioTuner::Error sipVH_QtMultimedia_134(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QRadioTuner::Error sipRes = ::QRadioTuner::NoError;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QRadioTuner_Error, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_133(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QRadioTuner::SearchMode a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_QRadioTuner_SearchMode);
}

void sipVH_QtMultimedia_132(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QRadioTuner::StereoMode a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_QRadioTuner_StereoMode);
}

::QRadioTuner::StereoMode sipVH_QtMultimedia_131(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QRadioTuner::StereoMode sipRes = ::QRadioTuner::ForceStereo;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QRadioTuner_StereoMode, &sipRes);

    return sipRes;
}

::QPair<int, int> sipVH_QtMultimedia_130(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QRadioTuner::Band a0)
{
    ::QPair<int, int> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QRadioTuner_Band);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QPair_1800_1800, &sipRes);

    return sipRes;
}

int sipVH_QtMultimedia_129(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QRadioTuner::Band a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QRadioTuner_Band);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_128(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QRadioTuner::Band a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QRadioTuner_Band);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_127(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QRadioTuner::Band a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_QRadioTuner_Band);
}

::QRadioTuner::Band sipVH_QtMultimedia_126(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QRadioTuner::Band sipRes = ::QRadioTuner::AM;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QRadioTuner_Band, &sipRes);

    return sipRes;
}

::QRadioTuner::State sipVH_QtMultimedia_125(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QRadioTuner::State sipRes = ::QRadioTuner::ActiveState;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QRadioTuner_State, &sipRes);

    return sipRes;
}

::QRadioData::Error sipVH_QtMultimedia_124(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QRadioData::Error sipRes = ::QRadioData::NoError;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QRadioData_Error, &sipRes);

    return sipRes;
}

::QRadioData::ProgramType sipVH_QtMultimedia_123(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QRadioData::ProgramType sipRes = ::QRadioData::Undefined;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QRadioData_ProgramType, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_122(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0, const ::QVariant& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NN", new ::QString(a0), sipType_QString, SIP_NULLPTR, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR);
}

::QVariant sipVH_QtMultimedia_121(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_120(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, bool a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "ib", a0, a1);
}

bool sipVH_QtMultimedia_119(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QVariant sipVH_QtMultimedia_118(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, const ::QString& a1)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iN", a0, new ::QString(a1), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

::QMediaStreamsControl::StreamType sipVH_QtMultimedia_117(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    ::QMediaStreamsControl::StreamType sipRes = ::QMediaStreamsControl::UnknownStream;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QMediaStreamsControl_StreamType, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_116(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMediaControl*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMediaControl, SIP_NULLPTR);
}

::QMediaControl* sipVH_QtMultimedia_115(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const char*a0)
{
    ::QMediaControl* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "A", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QMediaControl, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_114(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMediaRecorder::State a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_QMediaRecorder_State);
}

::QMediaRecorder::Status sipVH_QtMultimedia_113(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QMediaRecorder::Status sipRes = ::QMediaRecorder::UnavailableStatus;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QMediaRecorder_Status, &sipRes);

    return sipRes;
}

::QMediaRecorder::State sipVH_QtMultimedia_112(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QMediaRecorder::State sipRes = ::QMediaRecorder::StoppedState;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QMediaRecorder_State, &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_111(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QUrl& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QUrl(a0), sipType_QUrl, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QUrl sipVH_QtMultimedia_110(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QUrl sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QUrl, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_109(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMediaContent& a0, ::QIODevice*a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "ND", new ::QMediaContent(a0), sipType_QMediaContent, SIP_NULLPTR, a1, sipType_QIODevice, SIP_NULLPTR);
}

const ::QIODevice* sipVH_QtMultimedia_108(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QIODevice* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QIODevice, &sipRes);

    return sipRes;
}

::QMediaTimeRange sipVH_QtMultimedia_107(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QMediaTimeRange sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QMediaTimeRange, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_106(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "b", a0);
}

void sipVH_QtMultimedia_105(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "i", a0);
}

int sipVH_QtMultimedia_104(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_103(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::qint64 a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "n", a0);
}

::QMediaPlayer::MediaStatus sipVH_QtMultimedia_102(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QMediaPlayer::MediaStatus sipRes = ::QMediaPlayer::UnknownMediaStatus;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QMediaPlayer_MediaStatus, &sipRes);

    return sipRes;
}

::QMediaPlayer::State sipVH_QtMultimedia_101(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QMediaPlayer::State sipRes = ::QMediaPlayer::StoppedState;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QMediaPlayer_State, &sipRes);

    return sipRes;
}

::QNetworkConfiguration sipVH_QtMultimedia_100(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QNetworkConfiguration sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QNetworkConfiguration, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_99(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const QList< ::QNetworkConfiguration>& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new QList< ::QNetworkConfiguration>(a0), sipType_QList_0100QNetworkConfiguration, SIP_NULLPTR);
}

void sipVH_QtMultimedia_98(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::qreal a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "d", a0);
}

void sipVH_QtMultimedia_97(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMediaContent& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMediaContent(a0), sipType_QMediaContent, SIP_NULLPTR);
}

::QMediaContent sipVH_QtMultimedia_96(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QMediaContent sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QMediaContent, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_95(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QImageEncoderSettings& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QImageEncoderSettings(a0), sipType_QImageEncoderSettings, SIP_NULLPTR);
}

::QImageEncoderSettings sipVH_QtMultimedia_94(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QImageEncoderSettings sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QImageEncoderSettings, &sipRes);

    return sipRes;
}

QList< ::QSize> sipVH_QtMultimedia_93(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QImageEncoderSettings& a0, bool*a1)
{
    QList< ::QSize> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QImageEncoderSettings(a0), sipType_QImageEncoderSettings, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(H5b)", sipType_QList_0100QSize, &sipRes, a1);

    return sipRes;
}

void sipVH_QtMultimedia_92(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::qreal a0, ::qreal a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "dd", a0, a1);
}

::qreal sipVH_QtMultimedia_91(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::qreal sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "d", &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_90(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QCameraViewfinderSettings& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QCameraViewfinderSettings(a0), sipType_QCameraViewfinderSettings, SIP_NULLPTR);
}

::QCameraViewfinderSettings sipVH_QtMultimedia_89(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QCameraViewfinderSettings sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QCameraViewfinderSettings, &sipRes);

    return sipRes;
}

QList< ::QCameraViewfinderSettings> sipVH_QtMultimedia_88(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    QList< ::QCameraViewfinderSettings> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QCameraViewfinderSettings, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_87(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraViewfinderSettingsControl::ViewfinderParameter a0, const ::QVariant& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "FN", a0, sipType_QCameraViewfinderSettingsControl_ViewfinderParameter, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR);
}

::QVariant sipVH_QtMultimedia_86(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraViewfinderSettingsControl::ViewfinderParameter a0)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QCameraViewfinderSettingsControl_ViewfinderParameter);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_85(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraViewfinderSettingsControl::ViewfinderParameter a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QCameraViewfinderSettingsControl_ViewfinderParameter);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_84(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCamera::LockTypes a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QCamera::LockTypes(a0), sipType_QCamera_LockTypes, SIP_NULLPTR);
}

::QCamera::LockStatus sipVH_QtMultimedia_83(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCamera::LockType a0)
{
    ::QCamera::LockStatus sipRes = ::QCamera::Unlocked;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QCamera_LockType);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QCamera_LockStatus, &sipRes);

    return sipRes;
}

::QCamera::LockTypes sipVH_QtMultimedia_82(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QCamera::LockTypes sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QCamera_LockTypes, &sipRes);

    return sipRes;
}

::QCamera::Position sipVH_QtMultimedia_81(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    ::QCamera::Position sipRes = ::QCamera::UnspecifiedPosition;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QCamera_Position, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_80(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraImageProcessingControl::ProcessingParameter a0, const ::QVariant& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "FN", a0, sipType_QCameraImageProcessingControl_ProcessingParameter, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR);
}

::QVariant sipVH_QtMultimedia_79(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraImageProcessingControl::ProcessingParameter a0)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QCameraImageProcessingControl_ProcessingParameter);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_78(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraImageProcessingControl::ProcessingParameter a0, const ::QVariant& a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "FN", a0, sipType_QCameraImageProcessingControl_ProcessingParameter, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_77(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraImageProcessingControl::ProcessingParameter a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QCameraImageProcessingControl_ProcessingParameter);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

int sipVH_QtMultimedia_76(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_75(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraImageCapture::DriveMode a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_QCameraImageCapture_DriveMode);
}

::QCameraImageCapture::DriveMode sipVH_QtMultimedia_74(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QCameraImageCapture::DriveMode sipRes = ::QCameraImageCapture::SingleImageCapture;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QCameraImageCapture_DriveMode, &sipRes);

    return sipRes;
}

::QCameraFocusZoneList sipVH_QtMultimedia_73(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QCameraFocusZoneList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QCameraFocusZone, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_72(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPointF& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QPointF(a0), sipType_QPointF, SIP_NULLPTR);
}

::QPointF sipVH_QtMultimedia_71(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPointF sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QPointF, &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_70(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraFocus::FocusPointMode a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QCameraFocus_FocusPointMode);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_69(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraFocus::FocusPointMode a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_QCameraFocus_FocusPointMode);
}

::QCameraFocus::FocusPointMode sipVH_QtMultimedia_68(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QCameraFocus::FocusPointMode sipRes = ::QCameraFocus::FocusPointAuto;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QCameraFocus_FocusPointMode, &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_67(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraFocus::FocusModes a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QCameraFocus::FocusModes(a0), sipType_QCameraFocus_FocusModes, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_66(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraFocus::FocusModes a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QCameraFocus::FocusModes(a0), sipType_QCameraFocus_FocusModes, SIP_NULLPTR);
}

::QCameraFocus::FocusModes sipVH_QtMultimedia_65(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QCameraFocus::FocusModes sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QCameraFocus_FocusModes, &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_64(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraExposure::FlashModes a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QCameraExposure::FlashModes(a0), sipType_QCameraExposure_FlashModes, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_63(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraExposure::FlashModes a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QCameraExposure::FlashModes(a0), sipType_QCameraExposure_FlashModes, SIP_NULLPTR);
}

::QCameraExposure::FlashModes sipVH_QtMultimedia_62(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QCameraExposure::FlashModes sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QCameraExposure_FlashModes, &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_61(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraFeedbackControl::EventType a0, const ::QString& a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "FN", a0, sipType_QCameraFeedbackControl_EventType, new ::QString(a1), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_60(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraFeedbackControl::EventType a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_QCameraFeedbackControl_EventType);
}

bool sipVH_QtMultimedia_59(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraFeedbackControl::EventType a0, bool a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "Fb", a0, sipType_QCameraFeedbackControl_EventType, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_58(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraFeedbackControl::EventType a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QCameraFeedbackControl_EventType);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_57(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraExposureControl::ExposureParameter a0, const ::QVariant& a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "FN", a0, sipType_QCameraExposureControl_ExposureParameter, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QVariant sipVH_QtMultimedia_56(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraExposureControl::ExposureParameter a0)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QCameraExposureControl_ExposureParameter);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

::QVariantList sipVH_QtMultimedia_55(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraExposureControl::ExposureParameter a0, bool*a1)
{
    ::QVariantList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QCameraExposureControl_ExposureParameter);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(H5b)", sipType_QList_0100QVariant, &sipRes, a1);

    return sipRes;
}

bool sipVH_QtMultimedia_54(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraExposureControl::ExposureParameter a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QCameraExposureControl_ExposureParameter);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_53(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraControl::PropertyChangeType a0, ::QCamera::Status a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "FF", a0, sipType_QCameraControl_PropertyChangeType, a1, sipType_QCamera_Status);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_52(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCamera::CaptureModes a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QCamera::CaptureModes(a0), sipType_QCamera_CaptureModes, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_51(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCamera::CaptureModes a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QCamera::CaptureModes(a0), sipType_QCamera_CaptureModes, SIP_NULLPTR);
}

::QCamera::CaptureModes sipVH_QtMultimedia_50(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QCamera::CaptureModes sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QCamera_CaptureModes, &sipRes);

    return sipRes;
}

::QCamera::Status sipVH_QtMultimedia_49(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QCamera::Status sipRes = ::QCamera::UnavailableStatus;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QCamera_Status, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_48(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCamera::State a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_QCamera_State);
}

::QCamera::State sipVH_QtMultimedia_47(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QCamera::State sipRes = ::QCamera::UnloadedState;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QCamera_State, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_46(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraImageCapture::CaptureDestinations a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QCameraImageCapture::CaptureDestinations(a0), sipType_QCameraImageCapture_CaptureDestinations, SIP_NULLPTR);
}

::QCameraImageCapture::CaptureDestinations sipVH_QtMultimedia_45(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QCameraImageCapture::CaptureDestinations sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QCameraImageCapture_CaptureDestinations, &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_44(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCameraImageCapture::CaptureDestinations a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QCameraImageCapture::CaptureDestinations(a0), sipType_QCameraImageCapture_CaptureDestinations, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_43(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QVideoFrame::PixelFormat a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_QVideoFrame_PixelFormat);
}

::QVideoFrame::PixelFormat sipVH_QtMultimedia_42(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QVideoFrame::PixelFormat sipRes = ::QVideoFrame::Format_Invalid;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QVideoFrame_PixelFormat, &sipRes);

    return sipRes;
}

::QList< ::QVideoFrame::PixelFormat> sipVH_QtMultimedia_41(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QList< ::QVideoFrame::PixelFormat> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QVideoFrame_PixelFormat, &sipRes);

    return sipRes;
}

::QList< ::QAudio::Role> sipVH_QtMultimedia_40(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QList< ::QAudio::Role> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QAudio_Role, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_39(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QAudio::Role a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_QAudio_Role);
}

::QAudio::Role sipVH_QtMultimedia_38(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QAudio::Role sipRes = ::QAudio::UnknownRole;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QAudio_Role, &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_37(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMediaObject*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QMediaObject, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QMediaObject* sipVH_QtMultimedia_36(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QMediaObject* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QMediaObject, &sipRes);

    return sipRes;
}

QList< ::QString> sipVH_QtMultimedia_35(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    QList< ::QString> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QString, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_34(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QAudioEncoderSettings& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QAudioEncoderSettings(a0), sipType_QAudioEncoderSettings, SIP_NULLPTR);
}

::QAudioEncoderSettings sipVH_QtMultimedia_33(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QAudioEncoderSettings sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QAudioEncoderSettings, &sipRes);

    return sipRes;
}

::QList<int> sipVH_QtMultimedia_32(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QAudioEncoderSettings& a0, bool*a1)
{
    ::QList<int> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QAudioEncoderSettings(a0), sipType_QAudioEncoderSettings, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(H5b)", sipType_QList_1800, &sipRes, a1);

    return sipRes;
}

::QString sipVH_QtMultimedia_31(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

::QStringList sipVH_QtMultimedia_30(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QStringList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QStringList, &sipRes);

    return sipRes;
}

::qint64 sipVH_QtMultimedia_29(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::qint64 sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "n", &sipRes);

    return sipRes;
}

::QAudioBuffer sipVH_QtMultimedia_28(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QAudioBuffer sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QAudioBuffer, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_27(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QAudioFormat& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QAudioFormat(a0), sipType_QAudioFormat, SIP_NULLPTR);
}

::QAudioFormat sipVH_QtMultimedia_26(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QAudioFormat sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QAudioFormat, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_25(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QIODevice*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QIODevice, SIP_NULLPTR);
}

::QIODevice* sipVH_QtMultimedia_24(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QIODevice* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QIODevice, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_23(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);
}

::QString sipVH_QtMultimedia_22(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

::QAudioDecoder::State sipVH_QtMultimedia_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QAudioDecoder::State sipRes = ::QAudioDecoder::StoppedState;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QAudioDecoder_State, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QObject, SIP_NULLPTR);
}

bool sipVH_QtMultimedia_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QObject, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QMediaService* sipVH_QtMultimedia_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QMediaService* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QMediaService, &sipRes);

    return sipRes;
}

::QMultimedia::AvailabilityStatus sipVH_QtMultimedia_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QMultimedia::AvailabilityStatus sipRes = ::QMultimedia::Available;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QMultimedia_AvailabilityStatus, &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QVideoFrame& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QVideoFrame(a0), sipType_QVideoFrame, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QVideoSurfaceFormat sipVH_QtMultimedia_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QVideoSurfaceFormat& a0)
{
    ::QVideoSurfaceFormat sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QVideoSurfaceFormat(a0), sipType_QVideoSurfaceFormat, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVideoSurfaceFormat, &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QVideoSurfaceFormat& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QVideoSurfaceFormat(a0), sipType_QVideoSurfaceFormat, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QList< ::QVideoFrame::PixelFormat> sipVH_QtMultimedia_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QAbstractVideoBuffer::HandleType a0)
{
    ::QList< ::QVideoFrame::PixelFormat> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QAbstractVideoBuffer_HandleType);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QVideoFrame_PixelFormat, &sipRes);

    return sipRes;
}

::QVideoFilterRunnable* sipVH_QtMultimedia_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QVideoFilterRunnable* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QVideoFilterRunnable, &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtMultimedia_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtMultimedia_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtMultimedia_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtMultimedia_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}

::QVideoFrame sipVH_QtMultimedia_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QVideoFrame*a0, const ::QVideoSurfaceFormat& a1, ::QVideoFilterRunnable::RunFlags a2)
{
    ::QVideoFrame sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DNN", a0, sipType_QVideoFrame, SIP_NULLPTR, new ::QVideoSurfaceFormat(a1), sipType_QVideoSurfaceFormat, SIP_NULLPTR, new ::QVideoFilterRunnable::RunFlags(a2), sipType_QVideoFilterRunnable_RunFlags, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVideoFrame, &sipRes);

    return sipRes;
}

::QVariant sipVH_QtMultimedia_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

void sipVH_QtMultimedia_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

::uchar* sipVH_QtMultimedia_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QAbstractVideoBuffer::MapMode a0, int*a1, int*a2, int sipResKey)
{
    ::uchar* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QAbstractVideoBuffer_MapMode);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(Bii)", sipResKey, &sipRes, a1, a2);

    return sipRes;
}

::QAbstractVideoBuffer::MapMode sipVH_QtMultimedia_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QAbstractVideoBuffer::MapMode sipRes = ::QAbstractVideoBuffer::NotMapped;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QAbstractVideoBuffer_MapMode, &sipRes);

    return sipRes;
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QAbstractVideoSurface(void **);}
static const sipTypeDef *sipSubClass_QAbstractVideoSurface(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtMultimedia/qabstractvideosurface.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
    #if QT_VERSION >= 0x050500
        {sipName_QAbstractVideoFilter, &sipType_QAbstractVideoFilter, -1, 1},
    #else
        {0, 0, -1, 1},
    #endif
        {sipName_QAbstractVideoSurface, &sipType_QAbstractVideoSurface, -1, 2},
        {sipName_QMediaObject, &sipType_QMediaObject, 18, 3},
        {sipName_QMediaControl, &sipType_QMediaControl, 22, 4},
        {sipName_QAudioInput, &sipType_QAudioInput, -1, 5},
        {sipName_QAudioOutput, &sipType_QAudioOutput, -1, 6},
        {sipName_QAudioProbe, &sipType_QAudioProbe, -1, 7},
        {sipName_QMediaRecorder, &sipType_QMediaRecorder, 60, 8},
        {sipName_QCameraExposure, &sipType_QCameraExposure, -1, 9},
        {sipName_QCameraFocus, &sipType_QCameraFocus, -1, 10},
        {sipName_QCameraImageCapture, &sipType_QCameraImageCapture, -1, 11},
        {sipName_QCameraImageProcessing, &sipType_QCameraImageProcessing, -1, 12},
        {sipName_QMediaPlaylist, &sipType_QMediaPlaylist, -1, 13},
        {sipName_QMediaService, &sipType_QMediaService, -1, 14},
        {sipName_QRadioData, &sipType_QRadioData, -1, 15},
        {sipName_QSound, &sipType_QSound, -1, 16},
        {sipName_QSoundEffect, &sipType_QSoundEffect, -1, 17},
        {sipName_QVideoProbe, &sipType_QVideoProbe, -1, -1},
        {sipName_QAudioDecoder, &sipType_QAudioDecoder, -1, 19},
        {sipName_QCamera, &sipType_QCamera, -1, 20},
        {sipName_QMediaPlayer, &sipType_QMediaPlayer, -1, 21},
        {sipName_QRadioTuner, &sipType_QRadioTuner, -1, -1},
        {sipName_QAudioDecoderControl, &sipType_QAudioDecoderControl, -1, 23},
        {sipName_QAudioEncoderSettingsControl, &sipType_QAudioEncoderSettingsControl, -1, 24},
        {sipName_QAudioInputSelectorControl, &sipType_QAudioInputSelectorControl, -1, 25},
        {sipName_QAudioOutputSelectorControl, &sipType_QAudioOutputSelectorControl, -1, 26},
    #if QT_VERSION >= 0x050600
        {sipName_QAudioRoleControl, &sipType_QAudioRoleControl, -1, 27},
    #else
        {0, 0, -1, 27},
    #endif
        {sipName_QCameraCaptureBufferFormatControl, &sipType_QCameraCaptureBufferFormatControl, -1, 28},
        {sipName_QCameraCaptureDestinationControl, &sipType_QCameraCaptureDestinationControl, -1, 29},
        {sipName_QCameraControl, &sipType_QCameraControl, -1, 30},
        {sipName_QCameraExposureControl, &sipType_QCameraExposureControl, -1, 31},
        {sipName_QCameraFeedbackControl, &sipType_QCameraFeedbackControl, -1, 32},
        {sipName_QCameraFlashControl, &sipType_QCameraFlashControl, -1, 33},
        {sipName_QCameraFocusControl, &sipType_QCameraFocusControl, -1, 34},
        {sipName_QCameraImageCaptureControl, &sipType_QCameraImageCaptureControl, -1, 35},
        {sipName_QCameraImageProcessingControl, &sipType_QCameraImageProcessingControl, -1, 36},
        {sipName_QCameraInfoControl, &sipType_QCameraInfoControl, -1, 37},
        {sipName_QCameraLocksControl, &sipType_QCameraLocksControl, -1, 38},
        {sipName_QCameraViewfinderSettingsControl, &sipType_QCameraViewfinderSettingsControl, -1, 39},
        {sipName_QCameraViewfinderSettingsControl2, &sipType_QCameraViewfinderSettingsControl2, -1, 40},
        {sipName_QCameraZoomControl, &sipType_QCameraZoomControl, -1, 41},
    #if QT_VERSION >= 0x050b00
        {sipName_QCustomAudioRoleControl, &sipType_QCustomAudioRoleControl, -1, 42},
    #else
        {0, 0, -1, 42},
    #endif
        {sipName_QImageEncoderControl, &sipType_QImageEncoderControl, -1, 43},
        {sipName_QMediaAudioProbeControl, &sipType_QMediaAudioProbeControl, -1, 44},
        {sipName_QMediaAvailabilityControl, &sipType_QMediaAvailabilityControl, -1, 45},
        {sipName_QMediaContainerControl, &sipType_QMediaContainerControl, -1, 46},
        {sipName_QMediaGaplessPlaybackControl, &sipType_QMediaGaplessPlaybackControl, -1, 47},
        {sipName_QMediaNetworkAccessControl, &sipType_QMediaNetworkAccessControl, -1, 48},
        {sipName_QMediaPlayerControl, &sipType_QMediaPlayerControl, -1, 49},
        {sipName_QMediaRecorderControl, &sipType_QMediaRecorderControl, -1, 50},
        {sipName_QMediaStreamsControl, &sipType_QMediaStreamsControl, -1, 51},
        {sipName_QMediaVideoProbeControl, &sipType_QMediaVideoProbeControl, -1, 52},
        {sipName_QMetaDataReaderControl, &sipType_QMetaDataReaderControl, -1, 53},
        {sipName_QMetaDataWriterControl, &sipType_QMetaDataWriterControl, -1, 54},
        {sipName_QRadioDataControl, &sipType_QRadioDataControl, -1, 55},
        {sipName_QRadioTunerControl, &sipType_QRadioTunerControl, -1, 56},
        {sipName_QVideoDeviceSelectorControl, &sipType_QVideoDeviceSelectorControl, -1, 57},
        {sipName_QVideoEncoderSettingsControl, &sipType_QVideoEncoderSettingsControl, -1, 58},
        {sipName_QVideoRendererControl, &sipType_QVideoRendererControl, -1, 59},
        {sipName_QVideoWindowControl, &sipType_QVideoWindowControl, -1, -1},
        {sipName_QAudioRecorder, &sipType_QAudioRecorder, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 2829 "/build/pyqt5/src/PyQt5-5.15.11/build/QtMultimedia/sipQtMultimediacmodule.cpp"

    return sipType;
}


/* This defines each external type declared in this module, */
static sipExternalTypeDef externalTypesTable[] = {
    {83, "QGraphicsVideoItem"},
    {169, "QVideoWidget"},
    {-1, SIP_NULLPTR}
};


extern "C" {static PyObject *slot_QCameraImageCapture_CaptureDestination___or__(PyObject *, PyObject *);}
static PyObject *slot_QCameraImageCapture_CaptureDestination___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCameraImageCapture::CaptureDestination a0;
        ::QCameraImageCapture::CaptureDestinations* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QCameraImageCapture_CaptureDestination, &a0, sipType_QCameraImageCapture_CaptureDestinations, &a1, &a1State))
        {
            ::QCameraImageCapture::CaptureDestinations*sipRes;

            sipRes = new ::QCameraImageCapture::CaptureDestinations((a0 | *a1));
            sipReleaseType(a1, sipType_QCameraImageCapture_CaptureDestinations, a1State);

            return sipConvertFromNewType(sipRes, sipType_QCameraImageCapture_CaptureDestinations, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QCameraImageCapture_CaptureDestination[] = {
    {(void *)slot_QCameraImageCapture_CaptureDestination___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QCameraFocus_FocusMode___or__(PyObject *, PyObject *);}
static PyObject *slot_QCameraFocus_FocusMode___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCameraFocus::FocusMode a0;
        ::QCameraFocus::FocusModes* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QCameraFocus_FocusMode, &a0, sipType_QCameraFocus_FocusModes, &a1, &a1State))
        {
            ::QCameraFocus::FocusModes*sipRes;

            sipRes = new ::QCameraFocus::FocusModes((a0 | *a1));
            sipReleaseType(a1, sipType_QCameraFocus_FocusModes, a1State);

            return sipConvertFromNewType(sipRes, sipType_QCameraFocus_FocusModes, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QCameraFocus_FocusMode[] = {
    {(void *)slot_QCameraFocus_FocusMode___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QCameraExposure_FlashMode___or__(PyObject *, PyObject *);}
static PyObject *slot_QCameraExposure_FlashMode___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCameraExposure::FlashMode a0;
        ::QCameraExposure::FlashModes* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QCameraExposure_FlashMode, &a0, sipType_QCameraExposure_FlashModes, &a1, &a1State))
        {
            ::QCameraExposure::FlashModes*sipRes;

            sipRes = new ::QCameraExposure::FlashModes((a0 | *a1));
            sipReleaseType(a1, sipType_QCameraExposure_FlashModes, a1State);

            return sipConvertFromNewType(sipRes, sipType_QCameraExposure_FlashModes, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QCameraExposure_FlashMode[] = {
    {(void *)slot_QCameraExposure_FlashMode___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QCamera_LockType___or__(PyObject *, PyObject *);}
static PyObject *slot_QCamera_LockType___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCamera::LockType a0;
        ::QCamera::LockTypes* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QCamera_LockType, &a0, sipType_QCamera_LockTypes, &a1, &a1State))
        {
            ::QCamera::LockTypes*sipRes;

            sipRes = new ::QCamera::LockTypes((a0 | *a1));
            sipReleaseType(a1, sipType_QCamera_LockTypes, a1State);

            return sipConvertFromNewType(sipRes, sipType_QCamera_LockTypes, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QCamera_LockType[] = {
    {(void *)slot_QCamera_LockType___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QVideoFilterRunnable_RunFlag___or__(PyObject *, PyObject *);}
static PyObject *slot_QVideoFilterRunnable_RunFlag___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVideoFilterRunnable::RunFlag a0;
        ::QVideoFilterRunnable::RunFlags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QVideoFilterRunnable_RunFlag, &a0, sipType_QVideoFilterRunnable_RunFlags, &a1, &a1State))
        {
            ::QVideoFilterRunnable::RunFlags*sipRes;

            sipRes = new ::QVideoFilterRunnable::RunFlags((a0 | *a1));
            sipReleaseType(a1, sipType_QVideoFilterRunnable_RunFlags, a1State);

            return sipConvertFromNewType(sipRes, sipType_QVideoFilterRunnable_RunFlags, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QVideoFilterRunnable_RunFlag[] = {
    {(void *)slot_QVideoFilterRunnable_RunFlag___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};

static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAbstractVideoBuffer__HandleType, SIP_NULLPTR, 0}, sipNameNr_HandleType, 0, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAbstractVideoBuffer__MapMode, SIP_NULLPTR, 0}, sipNameNr_MapMode, 0, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAbstractVideoSurface__Error, SIP_NULLPTR, 0}, sipNameNr_Error, 4, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAudio__Error, SIP_NULLPTR, 0}, sipNameNr_Error, 6, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAudio__Mode, SIP_NULLPTR, 0}, sipNameNr_Mode, 6, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAudio__Role, SIP_NULLPTR, 0}, sipNameNr_Role, 6, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAudio__State, SIP_NULLPTR, 0}, sipNameNr_State, 6, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAudio__VolumeScale, SIP_NULLPTR, 0}, sipNameNr_VolumeScale, 6, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAudioDecoder__Error, SIP_NULLPTR, 0}, sipNameNr_Error, 13, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAudioDecoder__State, SIP_NULLPTR, 0}, sipNameNr_State, 13, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAudioFormat__Endian, SIP_NULLPTR, 0}, sipNameNr_Endian, 20, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QAudioFormat__SampleType, SIP_NULLPTR, 0}, sipNameNr_SampleType, 20, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCamera__CaptureMode, SIP_NULLPTR, 0}, sipNameNr_CaptureMode, 30, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCamera__Error, SIP_NULLPTR, 0}, sipNameNr_Error, 30, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCamera__LockChangeReason, SIP_NULLPTR, 0}, sipNameNr_LockChangeReason, 30, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCamera__LockStatus, SIP_NULLPTR, 0}, sipNameNr_LockStatus, 30, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCamera__LockType, SIP_NULLPTR, 0}, sipNameNr_LockType, 30, slots_QCamera_LockType},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCamera__Position, SIP_NULLPTR, 0}, sipNameNr_Position, 30, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCamera__State, SIP_NULLPTR, 0}, sipNameNr_State, 30, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCamera__Status, SIP_NULLPTR, 0}, sipNameNr_Status, 30, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraControl__PropertyChangeType, SIP_NULLPTR, 0}, sipNameNr_PropertyChangeType, 44, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraExposure__ExposureMode, SIP_NULLPTR, 0}, sipNameNr_ExposureMode, 46, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraExposure__FlashMode, SIP_NULLPTR, 0}, sipNameNr_FlashMode, 46, slots_QCameraExposure_FlashMode},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraExposure__MeteringMode, SIP_NULLPTR, 0}, sipNameNr_MeteringMode, 46, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraExposureControl__ExposureParameter, SIP_NULLPTR, 0}, sipNameNr_ExposureParameter, 51, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraFeedbackControl__EventType, SIP_NULLPTR, 0}, sipNameNr_EventType, 53, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraFocus__FocusMode, SIP_NULLPTR, 0}, sipNameNr_FocusMode, 56, slots_QCameraFocus_FocusMode},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraFocus__FocusPointMode, SIP_NULLPTR, 0}, sipNameNr_FocusPointMode, 56, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraFocusZone__FocusZoneStatus, SIP_NULLPTR, 0}, sipNameNr_FocusZoneStatus, 61, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraImageCapture__CaptureDestination, SIP_NULLPTR, 0}, sipNameNr_CaptureDestination, 63, slots_QCameraImageCapture_CaptureDestination},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraImageCapture__DriveMode, SIP_NULLPTR, 0}, sipNameNr_DriveMode, 63, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraImageCapture__Error, SIP_NULLPTR, 0}, sipNameNr_Error, 63, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraImageProcessing__ColorFilter, SIP_NULLPTR, 0}, sipNameNr_ColorFilter, 69, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraImageProcessing__WhiteBalanceMode, SIP_NULLPTR, 0}, sipNameNr_WhiteBalanceMode, 69, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraImageProcessingControl__ProcessingParameter, SIP_NULLPTR, 0}, sipNameNr_ProcessingParameter, 72, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QCameraViewfinderSettingsControl__ViewfinderParameter, SIP_NULLPTR, 0}, sipNameNr_ViewfinderParameter, 78, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMediaPlayer__Error, SIP_NULLPTR, 0}, sipNameNr_Error, 109, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMediaPlayer__Flag, SIP_NULLPTR, 0}, sipNameNr_Flag, 109, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMediaPlayer__MediaStatus, SIP_NULLPTR, 0}, sipNameNr_MediaStatus, 109, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMediaPlayer__State, SIP_NULLPTR, 0}, sipNameNr_State, 109, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMediaPlaylist__Error, SIP_NULLPTR, 0}, sipNameNr_Error, 116, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMediaPlaylist__PlaybackMode, SIP_NULLPTR, 0}, sipNameNr_PlaybackMode, 116, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMediaRecorder__Error, SIP_NULLPTR, 0}, sipNameNr_Error, 119, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMediaRecorder__State, SIP_NULLPTR, 0}, sipNameNr_State, 119, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMediaRecorder__Status, SIP_NULLPTR, 0}, sipNameNr_Status, 119, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMediaStreamsControl__StreamType, SIP_NULLPTR, 0}, sipNameNr_StreamType, 126, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMultimedia__AvailabilityStatus, SIP_NULLPTR, 0}, sipNameNr_AvailabilityStatus, 133, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMultimedia__EncodingMode, SIP_NULLPTR, 0}, sipNameNr_EncodingMode, 133, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMultimedia__EncodingQuality, SIP_NULLPTR, 0}, sipNameNr_EncodingQuality, 133, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QMultimedia__SupportEstimate, SIP_NULLPTR, 0}, sipNameNr_SupportEstimate, 133, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QRadioData__Error, SIP_NULLPTR, 0}, sipNameNr_Error, 138, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QRadioData__ProgramType, SIP_NULLPTR, 0}, sipNameNr_ProgramType, 138, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QRadioTuner__Band, SIP_NULLPTR, 0}, sipNameNr_Band, 142, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QRadioTuner__Error, SIP_NULLPTR, 0}, sipNameNr_Error, 142, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QRadioTuner__SearchMode, SIP_NULLPTR, 0}, sipNameNr_SearchMode, 142, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QRadioTuner__State, SIP_NULLPTR, 0}, sipNameNr_State, 142, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QRadioTuner__StereoMode, SIP_NULLPTR, 0}, sipNameNr_StereoMode, 142, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSound__Loop, SIP_NULLPTR, 0}, sipNameNr_Loop, 149, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSoundEffect__Loop, SIP_NULLPTR, 0}, sipNameNr_Loop, 151, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSoundEffect__Status, SIP_NULLPTR, 0}, sipNameNr_Status, 151, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QVideoFilterRunnable__RunFlag, SIP_NULLPTR, 0}, sipNameNr_RunFlag, 158, slots_QVideoFilterRunnable_RunFlag},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QVideoFrame__FieldType, SIP_NULLPTR, 0}, sipNameNr_FieldType, 161, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QVideoFrame__PixelFormat, SIP_NULLPTR, 0}, sipNameNr_PixelFormat, 161, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QVideoSurfaceFormat__Direction, SIP_NULLPTR, 0}, sipNameNr_Direction, 166, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QVideoSurfaceFormat__YCbCrColorSpace, SIP_NULLPTR, 0}, sipNameNr_YCbCrColorSpace, 166, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtMultimedia[] = {
    &sipTypeDef_QtMultimedia_QAbstractVideoBuffer.ctd_base,
    &enumTypes[0].etd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_QtMultimedia_QAbstractVideoFilter.ctd_base,
    &sipTypeDef_QtMultimedia_QAbstractVideoSurface.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_QtMultimedia_QAudio.ctd_base,
    &enumTypes[3].etd_base,
    &enumTypes[4].etd_base,
    &enumTypes[5].etd_base,
    &enumTypes[6].etd_base,
    &enumTypes[7].etd_base,
    &sipTypeDef_QtMultimedia_QAudioBuffer.ctd_base,
    &sipTypeDef_QtMultimedia_QAudioDecoder.ctd_base,
    &enumTypes[8].etd_base,
    &enumTypes[9].etd_base,
    &sipTypeDef_QtMultimedia_QAudioDecoderControl.ctd_base,
    &sipTypeDef_QtMultimedia_QAudioDeviceInfo.ctd_base,
    &sipTypeDef_QtMultimedia_QAudioEncoderSettings.ctd_base,
    &sipTypeDef_QtMultimedia_QAudioEncoderSettingsControl.ctd_base,
    &sipTypeDef_QtMultimedia_QAudioFormat.ctd_base,
    &enumTypes[10].etd_base,
    &enumTypes[11].etd_base,
    &sipTypeDef_QtMultimedia_QAudioInput.ctd_base,
    &sipTypeDef_QtMultimedia_QAudioInputSelectorControl.ctd_base,
    &sipTypeDef_QtMultimedia_QAudioOutput.ctd_base,
    &sipTypeDef_QtMultimedia_QAudioOutputSelectorControl.ctd_base,
    &sipTypeDef_QtMultimedia_QAudioProbe.ctd_base,
    &sipTypeDef_QtMultimedia_QAudioRecorder.ctd_base,
    &sipTypeDef_QtMultimedia_QAudioRoleControl.ctd_base,
    &sipTypeDef_QtMultimedia_QCamera.ctd_base,
    &enumTypes[12].etd_base,
    &sipTypeDef_QtMultimedia_QCamera_CaptureModes.ctd_base,
    &enumTypes[13].etd_base,
    &sipTypeDef_QtMultimedia_QCamera_FrameRateRange.ctd_base,
    &enumTypes[14].etd_base,
    &enumTypes[15].etd_base,
    &enumTypes[16].etd_base,
    &sipTypeDef_QtMultimedia_QCamera_LockTypes.ctd_base,
    &enumTypes[17].etd_base,
    &enumTypes[18].etd_base,
    &enumTypes[19].etd_base,
    &sipTypeDef_QtMultimedia_QCameraCaptureBufferFormatControl.ctd_base,
    &sipTypeDef_QtMultimedia_QCameraCaptureDestinationControl.ctd_base,
    &sipTypeDef_QtMultimedia_QCameraControl.ctd_base,
    &enumTypes[20].etd_base,
    &sipTypeDef_QtMultimedia_QCameraExposure.ctd_base,
    &enumTypes[21].etd_base,
    &enumTypes[22].etd_base,
    &sipTypeDef_QtMultimedia_QCameraExposure_FlashModes.ctd_base,
    &enumTypes[23].etd_base,
    &sipTypeDef_QtMultimedia_QCameraExposureControl.ctd_base,
    &enumTypes[24].etd_base,
    &sipTypeDef_QtMultimedia_QCameraFeedbackControl.ctd_base,
    &enumTypes[25].etd_base,
    &sipTypeDef_QtMultimedia_QCameraFlashControl.ctd_base,
    &sipTypeDef_QtMultimedia_QCameraFocus.ctd_base,
    &enumTypes[26].etd_base,
    &sipTypeDef_QtMultimedia_QCameraFocus_FocusModes.ctd_base,
    &enumTypes[27].etd_base,
    &sipTypeDef_QtMultimedia_QCameraFocusControl.ctd_base,
    &sipTypeDef_QtMultimedia_QCameraFocusZone.ctd_base,
    &enumTypes[28].etd_base,
    &sipTypeDef_QtMultimedia_QCameraImageCapture.ctd_base,
    &enumTypes[29].etd_base,
    &sipTypeDef_QtMultimedia_QCameraImageCapture_CaptureDestinations.ctd_base,
    &enumTypes[30].etd_base,
    &enumTypes[31].etd_base,
    &sipTypeDef_QtMultimedia_QCameraImageCaptureControl.ctd_base,
    &sipTypeDef_QtMultimedia_QCameraImageProcessing.ctd_base,
    &enumTypes[32].etd_base,
    &enumTypes[33].etd_base,
    &sipTypeDef_QtMultimedia_QCameraImageProcessingControl.ctd_base,
    &enumTypes[34].etd_base,
    &sipTypeDef_QtMultimedia_QCameraInfo.ctd_base,
    &sipTypeDef_QtMultimedia_QCameraInfoControl.ctd_base,
    &sipTypeDef_QtMultimedia_QCameraLocksControl.ctd_base,
    &sipTypeDef_QtMultimedia_QCameraViewfinderSettings.ctd_base,
    &sipTypeDef_QtMultimedia_QCameraViewfinderSettingsControl.ctd_base,
    &sipTypeDef_QtMultimedia_QCameraViewfinderSettingsControl2.ctd_base,
    &enumTypes[35].etd_base,
    &sipTypeDef_QtMultimedia_QCameraZoomControl.ctd_base,
    &sipTypeDef_QtMultimedia_QCustomAudioRoleControl.ctd_base,
    0,
    &sipTypeDef_QtMultimedia_QImageEncoderControl.ctd_base,
    &sipTypeDef_QtMultimedia_QImageEncoderSettings.ctd_base,
    &sipTypeDef_QtMultimedia_QList_0100QAudio_Role.mtd_base,
    &sipTypeDef_QtMultimedia_QList_0100QAudioDeviceInfo.mtd_base,
    &sipTypeDef_QtMultimedia_QList_0100QAudioFormat_Endian.mtd_base,
    &sipTypeDef_QtMultimedia_QList_0100QAudioFormat_SampleType.mtd_base,
    &sipTypeDef_QtMultimedia_QList_0100QCamera_FrameRateRange.mtd_base,
    &sipTypeDef_QtMultimedia_QList_0100QCameraFocusZone.mtd_base,
    &sipTypeDef_QtMultimedia_QList_0100QCameraInfo.mtd_base,
    &sipTypeDef_QtMultimedia_QList_0100QCameraViewfinderSettings.mtd_base,
    &sipTypeDef_QtMultimedia_QList_0100QMediaContent.mtd_base,
    &sipTypeDef_QtMultimedia_QList_0100QMediaResource.mtd_base,
    &sipTypeDef_QtMultimedia_QList_0100QMediaTimeInterval.mtd_base,
    &sipTypeDef_QtMultimedia_QList_0100QString.mtd_base,
    &sipTypeDef_QtMultimedia_QList_0100QVideoFrame_PixelFormat.mtd_base,
    &sipTypeDef_QtMultimedia_QMediaAudioProbeControl.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaAvailabilityControl.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaBindableInterface.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaContainerControl.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaContent.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaControl.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaGaplessPlaybackControl.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaMetaData.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaNetworkAccessControl.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaObject.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaPlayer.ctd_base,
    &enumTypes[36].etd_base,
    &enumTypes[37].etd_base,
    &sipTypeDef_QtMultimedia_QMediaPlayer_Flags.ctd_base,
    &enumTypes[38].etd_base,
    &enumTypes[39].etd_base,
    &sipTypeDef_QtMultimedia_QMediaPlayerControl.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaPlaylist.ctd_base,
    &enumTypes[40].etd_base,
    &enumTypes[41].etd_base,
    &sipTypeDef_QtMultimedia_QMediaRecorder.ctd_base,
    &enumTypes[42].etd_base,
    &enumTypes[43].etd_base,
    &enumTypes[44].etd_base,
    &sipTypeDef_QtMultimedia_QMediaRecorderControl.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaResource.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaService.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaStreamsControl.ctd_base,
    &enumTypes[45].etd_base,
    &sipTypeDef_QtMultimedia_QMediaTimeInterval.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaTimeRange.ctd_base,
    &sipTypeDef_QtMultimedia_QMediaVideoProbeControl.ctd_base,
    &sipTypeDef_QtMultimedia_QMetaDataReaderControl.ctd_base,
    &sipTypeDef_QtMultimedia_QMetaDataWriterControl.ctd_base,
    &sipTypeDef_QtMultimedia_QMultimedia.ctd_base,
    &enumTypes[46].etd_base,
    &enumTypes[47].etd_base,
    &enumTypes[48].etd_base,
    &enumTypes[49].etd_base,
    &sipTypeDef_QtMultimedia_QRadioData.ctd_base,
    &enumTypes[50].etd_base,
    &enumTypes[51].etd_base,
    &sipTypeDef_QtMultimedia_QRadioDataControl.ctd_base,
    &sipTypeDef_QtMultimedia_QRadioTuner.ctd_base,
    &enumTypes[52].etd_base,
    &enumTypes[53].etd_base,
    &enumTypes[54].etd_base,
    &enumTypes[55].etd_base,
    &enumTypes[56].etd_base,
    &sipTypeDef_QtMultimedia_QRadioTunerControl.ctd_base,
    &sipTypeDef_QtMultimedia_QSound.ctd_base,
    &enumTypes[57].etd_base,
    &sipTypeDef_QtMultimedia_QSoundEffect.ctd_base,
    &enumTypes[58].etd_base,
    &enumTypes[59].etd_base,
    &sipTypeDef_QtMultimedia_QVector_0101QAbstractVideoSurface.mtd_base,
    &sipTypeDef_QtMultimedia_QVideoDeviceSelectorControl.ctd_base,
    &sipTypeDef_QtMultimedia_QVideoEncoderSettings.ctd_base,
    &sipTypeDef_QtMultimedia_QVideoEncoderSettingsControl.ctd_base,
    &sipTypeDef_QtMultimedia_QVideoFilterRunnable.ctd_base,
    &enumTypes[60].etd_base,
    &sipTypeDef_QtMultimedia_QVideoFilterRunnable_RunFlags.ctd_base,
    &sipTypeDef_QtMultimedia_QVideoFrame.ctd_base,
    &enumTypes[61].etd_base,
    &enumTypes[62].etd_base,
    &sipTypeDef_QtMultimedia_QVideoProbe.ctd_base,
    &sipTypeDef_QtMultimedia_QVideoRendererControl.ctd_base,
    &sipTypeDef_QtMultimedia_QVideoSurfaceFormat.ctd_base,
    &enumTypes[63].etd_base,
    &enumTypes[64].etd_base,
    0,
    &sipTypeDef_QtMultimedia_QVideoWindowControl.ctd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"QCameraFocusZoneList", "QList<QCameraFocusZone>"},
    {"QMediaResourceList", "QList<QMediaResource>"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtMultimedia_QtCore[] = {
    {"QByteArray"},
    {"QChildEvent"},
    {"QEvent"},
    {"QIODevice"},
    {"QList<QByteArray>"},
    {"QList<QVariant>"},
    {"QList<int>"},
    {"QList<qreal>"},
    {"QMetaMethod"},
    {"QObject"},
    {"QPair<int,int>"},
    {"QPointF"},
    {"QRect"},
    {"QRectF"},
    {"QSize"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QVariant"},
    {"QVariantMap"},
    {"Qt::AspectRatioMode"},
    {"quintptr"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtMultimedia_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_QtMultimedia_QtGui[] = {
    {"QImage"},
    {"QImage::Format"},
    {"QList<QSize>"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtNetwork. */
sipImportedTypeDef sipImportedTypes_QtMultimedia_QtNetwork[] = {
    {"QList<QNetworkConfiguration>"},
    {"QNetworkConfiguration"},
    {"QNetworkRequest"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_QtMultimedia_QtCore, sipImportedVirtErrorHandlers_QtMultimedia_QtCore, SIP_NULLPTR},
    {"PyQt5.QtGui", sipImportedTypes_QtMultimedia_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.QtNetwork", sipImportedTypes_QtMultimedia_QtNetwork, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QAbstractVideoSurface, {9, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtMultimedia = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_QtMultimedia,
    0,
    sipStrings_QtMultimedia,
    importsTable,
    SIP_NULLPTR,
    171,
    sipExportedTypes_QtMultimedia,
    externalTypesTable,
    0,
    SIP_NULLPTR,
    2,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtMultimedia;

sip_qt_metaobject_func sip_QtMultimedia_qt_metaobject;
sip_qt_metacall_func sip_QtMultimedia_qt_metacall;
sip_qt_metacast_func sip_QtMultimedia_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtMultimedia()
#else
PyMODINIT_FUNC PyInit_QtMultimedia()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.QtMultimedia",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtMultimedia = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_QtMultimedia == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtMultimedia, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtMultimedia_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtMultimedia_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtMultimedia_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtMultimedia_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtMultimedia, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    return sipModule;
}
