/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtWidgetsAPI_H
#define _QtWidgetsAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_SH_ItemView_PaintAlternatingRowColorsForEmptyArea 0
#define sipName_SH_ItemView_PaintAlternatingRowColorsForEmptyArea &sipStrings_QtWidgets[0]
#define sipNameNr_QStyleOptionTabWidgetFrame__StyleOptionVersion 50
#define sipName_QStyleOptionTabWidgetFrame__StyleOptionVersion &sipStrings_QtWidgets[50]
#define sipNameNr_QStyleOptionGraphicsItem__StyleOptionVersion 97
#define sipName_QStyleOptionGraphicsItem__StyleOptionVersion &sipStrings_QtWidgets[97]
#define sipNameNr_SH_ItemView_MovementWithoutUpdatingSelection 142
#define sipName_SH_ItemView_MovementWithoutUpdatingSelection &sipStrings_QtWidgets[142]
#define sipNameNr_QStyleHintReturnVariant__StyleOptionVersion 187
#define sipName_QStyleHintReturnVariant__StyleOptionVersion &sipStrings_QtWidgets[187]
#define sipNameNr_QStyleOptionProgressBar__StyleOptionVersion 231
#define sipName_QStyleOptionProgressBar__StyleOptionVersion &sipStrings_QtWidgets[231]
#define sipNameNr_QStyleOptionTabWidgetFrame__StyleOptionType 275
#define sipName_QStyleOptionTabWidgetFrame__StyleOptionType &sipStrings_QtWidgets[275]
#define sipNameNr_SH_ScrollBar_ScrollWhenPointerLeavesControl 319
#define sipName_SH_ScrollBar_ScrollWhenPointerLeavesControl &sipStrings_QtWidgets[319]
#define sipNameNr_SH_TextControl_FocusIndicatorTextCharFormat 363
#define sipName_SH_TextControl_FocusIndicatorTextCharFormat &sipStrings_QtWidgets[363]
#define sipNameNr_QStyleOptionDockWidget__StyleOptionVersion 407
#define sipName_QStyleOptionDockWidget__StyleOptionVersion &sipStrings_QtWidgets[407]
#define sipNameNr_QStyleOptionRubberBand__StyleOptionVersion 450
#define sipName_QStyleOptionRubberBand__StyleOptionVersion &sipStrings_QtWidgets[450]
#define sipNameNr_QStyleOptionTabBarBase__StyleOptionVersion 493
#define sipName_QStyleOptionTabBarBase__StyleOptionVersion &sipStrings_QtWidgets[493]
#define sipNameNr_QStyleOptionToolButton__StyleOptionVersion 536
#define sipName_QStyleOptionToolButton__StyleOptionVersion &sipStrings_QtWidgets[536]
#define sipNameNr_QStyleOptionToolButton__ToolButtonFeatures 579
#define sipName_QStyleOptionToolButton__ToolButtonFeatures &sipStrings_QtWidgets[579]
#define sipNameNr_QStyleOptionFocusRect__StyleOptionVersion 622
#define sipName_QStyleOptionFocusRect__StyleOptionVersion &sipStrings_QtWidgets[622]
#define sipNameNr_QStyleOptionGraphicsItem__StyleOptionType 664
#define sipName_QStyleOptionGraphicsItem__StyleOptionType &sipStrings_QtWidgets[664]
#define sipNameNr_QStyleOptionToolButton__ToolButtonFeature 706
#define sipName_QStyleOptionToolButton__ToolButtonFeature &sipStrings_QtWidgets[706]
#define sipNameNr_SH_ItemView_ArrowKeysNavigateIntoChildren 748
#define sipName_SH_ItemView_ArrowKeysNavigateIntoChildren &sipStrings_QtWidgets[748]
#define sipNameNr_QAbstractItemView__DropIndicatorPosition 790
#define sipName_QAbstractItemView__DropIndicatorPosition &sipStrings_QtWidgets[790]
#define sipNameNr_QStyleHintReturnMask__StyleOptionVersion 831
#define sipName_QStyleHintReturnMask__StyleOptionVersion &sipStrings_QtWidgets[831]
#define sipNameNr_QStyleHintReturnVariant__StyleOptionType 872
#define sipName_QStyleHintReturnVariant__StyleOptionType &sipStrings_QtWidgets[872]
#define sipNameNr_QStyleOptionComboBox__StyleOptionVersion 913
#define sipName_QStyleOptionComboBox__StyleOptionVersion &sipStrings_QtWidgets[913]
#define sipNameNr_QStyleOptionGroupBox__StyleOptionVersion 954
#define sipName_QStyleOptionGroupBox__StyleOptionVersion &sipStrings_QtWidgets[954]
#define sipNameNr_QStyleOptionMenuItem__StyleOptionVersion 995
#define sipName_QStyleOptionMenuItem__StyleOptionVersion &sipStrings_QtWidgets[995]
#define sipNameNr_QStyleOptionProgressBar__StyleOptionType 1036
#define sipName_QStyleOptionProgressBar__StyleOptionType &sipStrings_QtWidgets[1036]
#define sipNameNr_QStyleOptionSizeGrip__StyleOptionVersion 1077
#define sipName_QStyleOptionSizeGrip__StyleOptionVersion &sipStrings_QtWidgets[1077]
#define sipNameNr_QStyleOptionTitleBar__StyleOptionVersion 1118
#define sipName_QStyleOptionTitleBar__StyleOptionVersion &sipStrings_QtWidgets[1118]
#define sipNameNr_QStyleOptionViewItem__StyleOptionVersion 1159
#define sipName_QStyleOptionViewItem__StyleOptionVersion &sipStrings_QtWidgets[1159]
#define sipNameNr_SH_Menu_SubMenuResetWhenReenteringParent 1200
#define sipName_SH_Menu_SubMenuResetWhenReenteringParent &sipStrings_QtWidgets[1200]
#define sipNameNr_SH_ScrollBar_MiddleClickAbsolutePosition 1241
#define sipName_SH_ScrollBar_MiddleClickAbsolutePosition &sipStrings_QtWidgets[1241]
#define sipNameNr_QCalendarWidget__HorizontalHeaderFormat 1282
#define sipName_QCalendarWidget__HorizontalHeaderFormat &sipStrings_QtWidgets[1282]
#define sipNameNr_QStyleOptionComplex__StyleOptionVersion 1322
#define sipName_QStyleOptionComplex__StyleOptionVersion &sipStrings_QtWidgets[1322]
#define sipNameNr_QStyleOptionDockWidget__StyleOptionType 1362
#define sipName_QStyleOptionDockWidget__StyleOptionType &sipStrings_QtWidgets[1362]
#define sipNameNr_QStyleOptionRubberBand__StyleOptionType 1402
#define sipName_QStyleOptionRubberBand__StyleOptionType &sipStrings_QtWidgets[1402]
#define sipNameNr_QStyleOptionSpinBox__StyleOptionVersion 1442
#define sipName_QStyleOptionSpinBox__StyleOptionVersion &sipStrings_QtWidgets[1442]
#define sipNameNr_QStyleOptionTabBarBase__StyleOptionType 1482
#define sipName_QStyleOptionTabBarBase__StyleOptionType &sipStrings_QtWidgets[1482]
#define sipNameNr_QStyleOptionToolBar__StyleOptionVersion 1522
#define sipName_QStyleOptionToolBar__StyleOptionVersion &sipStrings_QtWidgets[1522]
#define sipNameNr_QStyleOptionToolBox__StyleOptionVersion 1562
#define sipName_QStyleOptionToolBox__StyleOptionVersion &sipStrings_QtWidgets[1562]
#define sipNameNr_QStyleOptionToolButton__StyleOptionType 1602
#define sipName_QStyleOptionToolButton__StyleOptionType &sipStrings_QtWidgets[1602]
#define sipNameNr_SH_Menu_SubMenuSloppySelectOtherActions 1642
#define sipName_SH_Menu_SubMenuSloppySelectOtherActions &sipStrings_QtWidgets[1642]
#define sipNameNr_SH_MessageBox_UseBorderForButtonSpacing 1682
#define sipName_SH_MessageBox_UseBorderForButtonSpacing &sipStrings_QtWidgets[1682]
#define sipNameNr_QGraphicsSceneContextMenuEvent__Reason 1722
#define sipName_QGraphicsSceneContextMenuEvent__Reason &sipStrings_QtWidgets[1722]
#define sipNameNr_QStyleOptionButton__StyleOptionVersion 1761
#define sipName_QStyleOptionButton__StyleOptionVersion &sipStrings_QtWidgets[1761]
#define sipNameNr_QStyleOptionFocusRect__StyleOptionType 1800
#define sipName_QStyleOptionFocusRect__StyleOptionType &sipStrings_QtWidgets[1800]
#define sipNameNr_QStyleOptionHeader__StyleOptionVersion 1839
#define sipName_QStyleOptionHeader__StyleOptionVersion &sipStrings_QtWidgets[1839]
#define sipNameNr_QStyleOptionSlider__StyleOptionVersion 1878
#define sipName_QStyleOptionSlider__StyleOptionVersion &sipStrings_QtWidgets[1878]
#define sipNameNr_QStyleOptionViewItem__ViewItemFeatures 1917
#define sipName_QStyleOptionViewItem__ViewItemFeatures &sipStrings_QtWidgets[1917]
#define sipNameNr_QStyleOptionViewItem__ViewItemPosition 1956
#define sipName_QStyleOptionViewItem__ViewItemPosition &sipStrings_QtWidgets[1956]
#define sipNameNr_QTreeWidgetItemIterator__IteratorFlags 1995
#define sipName_QTreeWidgetItemIterator__IteratorFlags &sipStrings_QtWidgets[1995]
#define sipNameNr_SH_GroupBox_TextLabelVerticalAlignment 2034
#define sipName_SH_GroupBox_TextLabelVerticalAlignment &sipStrings_QtWidgets[2034]
#define sipNameNr_SH_ScrollBar_LeftClickAbsolutePosition 2073
#define sipName_SH_ScrollBar_LeftClickAbsolutePosition &sipStrings_QtWidgets[2073]
#define sipNameNr_AdjustToMinimumContentsLengthWithIcon 2112
#define sipName_AdjustToMinimumContentsLengthWithIcon &sipStrings_QtWidgets[2112]
#define sipNameNr_PM_HeaderDefaultSectionSizeHorizontal 2150
#define sipName_PM_HeaderDefaultSectionSizeHorizontal &sipStrings_QtWidgets[2150]
#define sipNameNr_QAbstractScrollArea__SizeAdjustPolicy 2188
#define sipName_QAbstractScrollArea__SizeAdjustPolicy &sipStrings_QtWidgets[2188]
#define sipNameNr_QCalendarWidget__VerticalHeaderFormat 2226
#define sipName_QCalendarWidget__VerticalHeaderFormat &sipStrings_QtWidgets[2226]
#define sipNameNr_QStyleHintReturnMask__StyleOptionType 2264
#define sipName_QStyleHintReturnMask__StyleOptionType &sipStrings_QtWidgets[2264]
#define sipNameNr_QStyleOptionComboBox__StyleOptionType 2302
#define sipName_QStyleOptionComboBox__StyleOptionType &sipStrings_QtWidgets[2302]
#define sipNameNr_QStyleOptionFrame__StyleOptionVersion 2340
#define sipName_QStyleOptionFrame__StyleOptionVersion &sipStrings_QtWidgets[2340]
#define sipNameNr_QStyleOptionGroupBox__StyleOptionType 2378
#define sipName_QStyleOptionGroupBox__StyleOptionType &sipStrings_QtWidgets[2378]
#define sipNameNr_QStyleOptionMenuItem__StyleOptionType 2416
#define sipName_QStyleOptionMenuItem__StyleOptionType &sipStrings_QtWidgets[2416]
#define sipNameNr_QStyleOptionSizeGrip__StyleOptionType 2454
#define sipName_QStyleOptionSizeGrip__StyleOptionType &sipStrings_QtWidgets[2454]
#define sipNameNr_QStyleOptionTabV4__StyleOptionVersion 2492
#define sipName_QStyleOptionTabV4__StyleOptionVersion &sipStrings_QtWidgets[2492]
#define sipNameNr_QStyleOptionTitleBar__StyleOptionType 2530
#define sipName_QStyleOptionTitleBar__StyleOptionType &sipStrings_QtWidgets[2530]
#define sipNameNr_QStyleOptionToolBox__SelectedPosition 2568
#define sipName_QStyleOptionToolBox__SelectedPosition &sipStrings_QtWidgets[2568]
#define sipNameNr_QStyleOptionViewItem__StyleOptionType 2606
#define sipName_QStyleOptionViewItem__StyleOptionType &sipStrings_QtWidgets[2606]
#define sipNameNr_QStyleOptionViewItem__ViewItemFeature 2644
#define sipName_QStyleOptionViewItem__ViewItemFeature &sipStrings_QtWidgets[2644]
#define sipNameNr_QTreeWidgetItem__ChildIndicatorPolicy 2682
#define sipName_QTreeWidgetItem__ChildIndicatorPolicy &sipStrings_QtWidgets[2682]
#define sipNameNr_QTreeWidgetItemIterator__IteratorFlag 2720
#define sipName_QTreeWidgetItemIterator__IteratorFlag &sipStrings_QtWidgets[2720]
#define sipNameNr_SH_ItemView_ActivateItemOnSingleClick 2758
#define sipName_SH_ItemView_ActivateItemOnSingleClick &sipStrings_QtWidgets[2758]
#define sipNameNr_SH_Menu_SubMenuDontStartSloppyOnLeave 2796
#define sipName_SH_Menu_SubMenuDontStartSloppyOnLeave &sipStrings_QtWidgets[2796]
#define sipNameNr_SH_ScrollView_FrameOnlyAroundContents 2834
#define sipName_SH_ScrollView_FrameOnlyAroundContents &sipStrings_QtWidgets[2834]
#define sipNameNr_ItemDoesntPropagateOpacityToChildren 2872
#define sipName_ItemDoesntPropagateOpacityToChildren &sipStrings_QtWidgets[2872]
#define sipNameNr_QAbstractItemView__SelectionBehavior 2909
#define sipName_QAbstractItemView__SelectionBehavior &sipStrings_QtWidgets[2909]
#define sipNameNr_QScrollerProperties__OvershootPolicy 2946
#define sipName_QScrollerProperties__OvershootPolicy &sipStrings_QtWidgets[2946]
#define sipNameNr_QStyleHintReturn__StyleOptionVersion 2983
#define sipName_QStyleHintReturn__StyleOptionVersion &sipStrings_QtWidgets[2983]
#define sipNameNr_QStyleOptionComplex__StyleOptionType 3020
#define sipName_QStyleOptionComplex__StyleOptionType &sipStrings_QtWidgets[3020]
#define sipNameNr_QStyleOptionHeader__SelectedPosition 3057
#define sipName_QStyleOptionHeader__SelectedPosition &sipStrings_QtWidgets[3057]
#define sipNameNr_QStyleOptionSpinBox__StyleOptionType 3094
#define sipName_QStyleOptionSpinBox__StyleOptionType &sipStrings_QtWidgets[3094]
#define sipNameNr_QStyleOptionToolBar__StyleOptionType 3131
#define sipName_QStyleOptionToolBar__StyleOptionType &sipStrings_QtWidgets[3131]
#define sipNameNr_QStyleOptionToolBar__ToolBarFeatures 3168
#define sipName_QStyleOptionToolBar__ToolBarFeatures &sipStrings_QtWidgets[3168]
#define sipNameNr_QStyleOptionToolBar__ToolBarPosition 3205
#define sipName_QStyleOptionToolBar__ToolBarPosition &sipStrings_QtWidgets[3205]
#define sipNameNr_QStyleOptionToolBox__StyleOptionType 3242
#define sipName_QStyleOptionToolBox__StyleOptionType &sipStrings_QtWidgets[3242]
#define sipNameNr_SH_Menu_SubMenuUniDirectionFailCount 3279
#define sipName_SH_Menu_SubMenuUniDirectionFailCount &sipStrings_QtWidgets[3279]
#define sipNameNr_SH_ProgressDialog_CenterCancelButton 3316
#define sipName_SH_ProgressDialog_CenterCancelButton &sipStrings_QtWidgets[3316]
#define sipNameNr_SH_ProgressDialog_TextLabelAlignment 3353
#define sipName_SH_ProgressDialog_TextLabelAlignment &sipStrings_QtWidgets[3353]
#define sipNameNr_PM_HeaderDefaultSectionSizeVertical 3390
#define sipName_PM_HeaderDefaultSectionSizeVertical &sipStrings_QtWidgets[3390]
#define sipNameNr_QStyleOptionButton__StyleOptionType 3426
#define sipName_QStyleOptionButton__StyleOptionType &sipStrings_QtWidgets[3426]
#define sipNameNr_QStyleOptionHeader__SectionPosition 3462
#define sipName_QStyleOptionHeader__SectionPosition &sipStrings_QtWidgets[3462]
#define sipNameNr_QStyleOptionHeader__StyleOptionType 3498
#define sipName_QStyleOptionHeader__StyleOptionType &sipStrings_QtWidgets[3498]
#define sipNameNr_QStyleOptionSlider__StyleOptionType 3534
#define sipName_QStyleOptionSlider__StyleOptionType &sipStrings_QtWidgets[3534]
#define sipNameNr_QStyleOptionTab__StyleOptionVersion 3570
#define sipName_QStyleOptionTab__StyleOptionVersion &sipStrings_QtWidgets[3570]
#define sipNameNr_QStyleOptionToolBar__ToolBarFeature 3606
#define sipName_QStyleOptionToolBar__ToolBarFeature &sipStrings_QtWidgets[3606]
#define sipNameNr_SH_DialogButtonBox_ButtonsHaveIcons 3642
#define sipName_SH_DialogButtonBox_ButtonsHaveIcons &sipStrings_QtWidgets[3642]
#define sipNameNr_SH_SpinBox_ClickAutoRepeatThreshold 3678
#define sipName_SH_SpinBox_ClickAutoRepeatThreshold &sipStrings_QtWidgets[3678]
#define sipNameNr_SP_ToolBarHorizontalExtensionButton 3714
#define sipName_SP_ToolBarHorizontalExtensionButton &sipStrings_QtWidgets[3714]
#define sipNameNr_ItemTransformOriginPointHasChanged 3750
#define sipName_ItemTransformOriginPointHasChanged &sipStrings_QtWidgets[3750]
#define sipNameNr_PE_IndicatorDockWidgetResizeHandle 3785
#define sipName_PE_IndicatorDockWidgetResizeHandle &sipStrings_QtWidgets[3785]
#define sipNameNr_QAbstractItemDelegate__EndEditHint 3820
#define sipName_QAbstractItemDelegate__EndEditHint &sipStrings_QtWidgets[3820]
#define sipNameNr_QStyleOptionButton__ButtonFeatures 3855
#define sipName_QStyleOptionButton__ButtonFeatures &sipStrings_QtWidgets[3855]
#define sipNameNr_QStyleOptionFrame__StyleOptionType 3890
#define sipName_QStyleOptionFrame__StyleOptionType &sipStrings_QtWidgets[3890]
#define sipNameNr_QStyleOptionMenuItem__MenuItemType 3925
#define sipName_QStyleOptionMenuItem__MenuItemType &sipStrings_QtWidgets[3925]
#define sipNameNr_RSIP_OnMouseClickAndAlreadyFocused 3960
#define sipName_RSIP_OnMouseClickAndAlreadyFocused &sipStrings_QtWidgets[3960]
#define sipNameNr_SH_FontDialog_SelectAssociatedText 3995
#define sipName_SH_FontDialog_SelectAssociatedText &sipStrings_QtWidgets[3995]
#define sipNameNr_SH_ItemView_ChangeHighlightOnFocus 4030
#define sipName_SH_ItemView_ChangeHighlightOnFocus &sipStrings_QtWidgets[4030]
#define sipNameNr_SH_ItemView_ShowDecorationSelected 4065
#define sipName_SH_ItemView_ShowDecorationSelected &sipStrings_QtWidgets[4065]
#define sipNameNr_SH_MessageBox_TextInteractionFlags 4100
#define sipName_SH_MessageBox_TextInteractionFlags &sipStrings_QtWidgets[4100]
#define sipNameNr_DontMaximizeSubWindowOnActivation 4135
#define sipName_DontMaximizeSubWindowOnActivation &sipStrings_QtWidgets[4135]
#define sipNameNr_PM_DockWidgetTitleBarButtonMargin 4169
#define sipName_PM_DockWidgetTitleBarButtonMargin &sipStrings_QtWidgets[4169]
#define sipNameNr_QAbstractSpinBox__StepEnabledFlag 4203
#define sipName_QAbstractSpinBox__StepEnabledFlag &sipStrings_QtWidgets[4203]
#define sipNameNr_QDialogButtonBox__StandardButtons 4237
#define sipName_QDialogButtonBox__StandardButtons &sipStrings_QtWidgets[4237]
#define sipNameNr_QGraphicsItem__GraphicsItemChange 4271
#define sipName_QGraphicsItem__GraphicsItemChange &sipStrings_QtWidgets[4271]
#define sipNameNr_QGraphicsView__ViewportUpdateMode 4305
#define sipName_QGraphicsView__ViewportUpdateMode &sipStrings_QtWidgets[4305]
#define sipNameNr_4339 4339
#define sipName_4339 &sipStrings_QtWidgets[4339]
#define sipNameNr_QScrollerProperties__ScrollMetric 4373
#define sipName_QScrollerProperties__ScrollMetric &sipStrings_QtWidgets[4373]
#define sipNameNr_QStyle__RequestSoftwareInputPanel 4407
#define sipName_QStyle__RequestSoftwareInputPanel &sipStrings_QtWidgets[4407]
#define sipNameNr_QStyleHintReturn__StyleOptionType 4441
#define sipName_QStyleHintReturn__StyleOptionType &sipStrings_QtWidgets[4441]
#define sipNameNr_QStyleOptionButton__ButtonFeature 4475
#define sipName_QStyleOptionButton__ButtonFeature &sipStrings_QtWidgets[4475]
#define sipNameNr_QStyleOptionHeader__SortIndicator 4509
#define sipName_QStyleOptionHeader__SortIndicator &sipStrings_QtWidgets[4509]
#define sipNameNr_QStyleOptionTab__SelectedPosition 4543
#define sipName_QStyleOptionTab__SelectedPosition &sipStrings_QtWidgets[4543]
#define sipNameNr_QSystemTrayIcon__ActivationReason 4577
#define sipName_QSystemTrayIcon__ActivationReason &sipStrings_QtWidgets[4577]
#define sipNameNr_SH_ListViewExpand_SelectMouseType 4611
#define sipName_SH_ListViewExpand_SelectMouseType &sipStrings_QtWidgets[4611]
#define sipNameNr_SH_Menu_SubMenuSloppyCloseTimeout 4645
#define sipName_SH_Menu_SubMenuSloppyCloseTimeout &sipStrings_QtWidgets[4645]
#define sipNameNr_SH_SpinBox_KeyPressAutoRepeatRate 4679
#define sipName_SH_SpinBox_KeyPressAutoRepeatRate &sipStrings_QtWidgets[4679]
#define sipNameNr_SH_TitleBar_ShowToolTipsOnButtons 4713
#define sipName_SH_TitleBar_ShowToolTipsOnButtons &sipStrings_QtWidgets[4713]
#define sipNameNr_SP_ToolBarVerticalExtensionButton 4747
#define sipName_SP_ToolBarVerticalExtensionButton &sipStrings_QtWidgets[4747]
#define sipNameNr_QAbstractItemView__SelectionMode 4781
#define sipName_QAbstractItemView__SelectionMode &sipStrings_QtWidgets[4781]
#define sipNameNr_QAbstractSpinBox__CorrectionMode 4814
#define sipName_QAbstractSpinBox__CorrectionMode &sipStrings_QtWidgets[4814]
#define sipNameNr_QColorDialog__ColorDialogOptions 4847
#define sipName_QColorDialog__ColorDialogOptions &sipStrings_QtWidgets[4847]
#define sipNameNr_QDialogButtonBox__StandardButton 4880
#define sipName_QDialogButtonBox__StandardButton &sipStrings_QtWidgets[4880]
#define sipNameNr_QGraphicsItem__GraphicsItemFlags 4913
#define sipName_QGraphicsItem__GraphicsItemFlags &sipStrings_QtWidgets[4913]
#define sipNameNr_QGraphicsView__OptimizationFlags 4946
#define sipName_QGraphicsView__OptimizationFlags &sipStrings_QtWidgets[4946]
#define sipNameNr_QInputDialog__InputDialogOptions 4979
#define sipName_QInputDialog__InputDialogOptions &sipStrings_QtWidgets[4979]
#define sipNameNr_5012 5012
#define sipName_5012 &sipStrings_QtWidgets[5012]
#define sipNameNr_QStyleHintReturn__HintReturnType 5045
#define sipName_QStyleHintReturn__HintReturnType &sipStrings_QtWidgets[5045]
#define sipNameNr_QStyleOption__StyleOptionVersion 5078
#define sipName_QStyleOption__StyleOptionVersion &sipStrings_QtWidgets[5078]
#define sipNameNr_QStyleOptionFrame__FrameFeatures 5111
#define sipName_QStyleOptionFrame__FrameFeatures &sipStrings_QtWidgets[5111]
#define sipNameNr_QStyleOptionTab__StyleOptionType 5144
#define sipName_QStyleOptionTab__StyleOptionType &sipStrings_QtWidgets[5144]
#define sipNameNr_QStyleOptionToolBox__TabPosition 5177
#define sipName_QStyleOptionToolBox__TabPosition &sipStrings_QtWidgets[5177]
#define sipNameNr_QToolButton__ToolButtonPopupMode 5210
#define sipName_QToolButton__ToolButtonPopupMode &sipStrings_QtWidgets[5210]
#define sipNameNr_SH_PrintDialog_RightAlignButtons 5243
#define sipName_SH_PrintDialog_RightAlignButtons &sipStrings_QtWidgets[5243]
#define sipNameNr_SH_ScrollBar_StopMouseOverSlider 5276
#define sipName_SH_ScrollBar_StopMouseOverSlider &sipStrings_QtWidgets[5276]
#define sipNameNr_SH_ToolBox_SelectedPageTitleBold 5309
#define sipName_SH_ToolBox_SelectedPageTitleBold &sipStrings_QtWidgets[5309]
#define sipNameNr_SH_Workspace_FillSpaceOnMaximize 5342
#define sipName_SH_Workspace_FillSpaceOnMaximize &sipStrings_QtWidgets[5342]
#define sipNameNr_ItemNegativeZStacksBehindParent 5375
#define sipName_ItemNegativeZStacksBehindParent &sipStrings_QtWidgets[5375]
#define sipNameNr_QAbstractItemView__CursorAction 5407
#define sipName_QAbstractItemView__CursorAction &sipStrings_QtWidgets[5407]
#define sipNameNr_QAbstractItemView__DragDropMode 5439
#define sipName_QAbstractItemView__DragDropMode &sipStrings_QtWidgets[5439]
#define sipNameNr_QAbstractItemView__EditTriggers 5471
#define sipName_QAbstractItemView__EditTriggers &sipStrings_QtWidgets[5471]
#define sipNameNr_QAbstractSpinBox__ButtonSymbols 5503
#define sipName_QAbstractSpinBox__ButtonSymbols &sipStrings_QtWidgets[5503]
#define sipNameNr_QColorDialog__ColorDialogOption 5535
#define sipName_QColorDialog__ColorDialogOption &sipStrings_QtWidgets[5535]
#define sipNameNr_QDataWidgetMapper__SubmitPolicy 5567
#define sipName_QDataWidgetMapper__SubmitPolicy &sipStrings_QtWidgets[5567]
#define sipNameNr_QDockWidget__DockWidgetFeatures 5599
#define sipName_QDockWidget__DockWidgetFeatures &sipStrings_QtWidgets[5599]
#define sipNameNr_QGraphicsItem__GraphicsItemFlag 5631
#define sipName_QGraphicsItem__GraphicsItemFlag &sipStrings_QtWidgets[5631]
#define sipNameNr_QGraphicsScene__ItemIndexMethod 5663
#define sipName_QGraphicsScene__ItemIndexMethod &sipStrings_QtWidgets[5663]
#define sipNameNr_QGraphicsView__OptimizationFlag 5695
#define sipName_QGraphicsView__OptimizationFlag &sipStrings_QtWidgets[5695]
#define sipNameNr_QInputDialog__InputDialogOption 5727
#define sipName_QInputDialog__InputDialogOption &sipStrings_QtWidgets[5727]
#define sipNameNr_QMdiSubWindow__SubWindowOptions 5759
#define sipName_QMdiSubWindow__SubWindowOptions &sipStrings_QtWidgets[5759]
#define sipNameNr_QScrollerProperties__FrameRates 5791
#define sipName_QScrollerProperties__FrameRates &sipStrings_QtWidgets[5791]
#define sipNameNr_QStyleOptionFrame__FrameFeature 5823
#define sipName_QStyleOptionFrame__FrameFeature &sipStrings_QtWidgets[5823]
#define sipNameNr_QStyleOptionMenuItem__CheckType 5855
#define sipName_QStyleOptionMenuItem__CheckType &sipStrings_QtWidgets[5855]
#define sipNameNr_SH_ComboBox_AllowWheelScrolling 5887
#define sipName_SH_ComboBox_AllowWheelScrolling &sipStrings_QtWidgets[5887]
#define sipNameNr_SH_MainWindow_SpaceBelowMenuBar 5919
#define sipName_SH_MainWindow_SpaceBelowMenuBar &sipStrings_QtWidgets[5919]
#define sipNameNr_SH_ScrollBar_RollBetweenButtons 5951
#define sipName_SH_ScrollBar_RollBetweenButtons &sipStrings_QtWidgets[5951]
#define sipNameNr_SH_SpinControls_DisableOnBounds 5983
#define sipName_SH_SpinControls_DisableOnBounds &sipStrings_QtWidgets[5983]
#define sipNameNr_SH_TabWidget_DefaultTabPosition 6015
#define sipName_SH_TabWidget_DefaultTabPosition &sipStrings_QtWidgets[6015]
#define sipNameNr_horizontalScrollbarValueChanged 6047
#define sipName_horizontalScrollbarValueChanged &sipStrings_QtWidgets[6047]
#define sipNameNr_setShortcutVisibleInContextMenu 6079
#define sipName_setShortcutVisibleInContextMenu &sipStrings_QtWidgets[6079]
#define sipNameNr_AcceleratingFlickSpeedupFactor 6111
#define sipName_AcceleratingFlickSpeedupFactor &sipStrings_QtWidgets[6111]
#define sipNameNr_DontShowIndicatorWhenChildless 6142
#define sipName_DontShowIndicatorWhenChildless &sipStrings_QtWidgets[6142]
#define sipNameNr_ItemTransformOriginPointChange 6173
#define sipName_ItemTransformOriginPointChange &sipStrings_QtWidgets[6173]
#define sipNameNr_PM_ScrollView_ScrollBarOverlap 6204
#define sipName_PM_ScrollView_ScrollBarOverlap &sipStrings_QtWidgets[6204]
#define sipNameNr_PM_ScrollView_ScrollBarSpacing 6235
#define sipName_PM_ScrollView_ScrollBarSpacing &sipStrings_QtWidgets[6235]
#define sipNameNr_QAbstractItemView__EditTrigger 6266
#define sipName_QAbstractItemView__EditTrigger &sipStrings_QtWidgets[6266]
#define sipNameNr_QCalendarWidget__SelectionMode 6297
#define sipName_QCalendarWidget__SelectionMode &sipStrings_QtWidgets[6297]
#define sipNameNr_QDialogButtonBox__ButtonLayout 6328
#define sipName_QDialogButtonBox__ButtonLayout &sipStrings_QtWidgets[6328]
#define sipNameNr_QDockWidget__DockWidgetFeature 6359
#define sipName_QDockWidget__DockWidgetFeature &sipStrings_QtWidgets[6359]
#define sipNameNr_QFontDialog__FontDialogOptions 6390
#define sipName_QFontDialog__FontDialogOptions &sipStrings_QtWidgets[6390]
#define sipNameNr_QFormLayout__FieldGrowthPolicy 6421
#define sipName_QFormLayout__FieldGrowthPolicy &sipStrings_QtWidgets[6421]
#define sipNameNr_QGestureRecognizer__ResultFlag 6452
#define sipName_QGestureRecognizer__ResultFlag &sipStrings_QtWidgets[6452]
#define sipNameNr_QGraphicsBlurEffect__BlurHints 6483
#define sipName_QGraphicsBlurEffect__BlurHints &sipStrings_QtWidgets[6483]
#define sipNameNr_QGraphicsEffect__PixmapPadMode 6514
#define sipName_QGraphicsEffect__PixmapPadMode &sipStrings_QtWidgets[6514]
#define sipNameNr_QGraphicsPixmapItem__ShapeMode 6545
#define sipName_QGraphicsPixmapItem__ShapeMode &sipStrings_QtWidgets[6545]
#define sipNameNr_QGraphicsSceneContextMenuEvent 6576
#define sipName_QGraphicsSceneContextMenuEvent &sipStrings_QtWidgets[6576]
#define sipNameNr_QMdiSubWindow__SubWindowOption 6607
#define sipName_QMdiSubWindow__SubWindowOption &sipStrings_QtWidgets[6607]
#define sipNameNr_QScroller__ScrollerGestureType 6638
#define sipName_QScroller__ScrollerGestureType &sipStrings_QtWidgets[6638]
#define sipNameNr_QStyleOptionTab__CornerWidgets 6669
#define sipName_QStyleOptionTab__CornerWidgets &sipStrings_QtWidgets[6669]
#define sipNameNr_QStyleOptionViewItem__Position 6700
#define sipName_QStyleOptionViewItem__Position &sipStrings_QtWidgets[6700]
#define sipNameNr_SH_BlinkCursorWhenTextSelected 6731
#define sipName_SH_BlinkCursorWhenTextSelected &sipStrings_QtWidgets[6731]
#define sipNameNr_SH_DialogButtons_DefaultButton 6762
#define sipName_SH_DialogButtons_DefaultButton &sipStrings_QtWidgets[6762]
#define sipNameNr_SH_DockWidget_ButtonsHaveFrame 6793
#define sipName_SH_DockWidget_ButtonsHaveFrame &sipStrings_QtWidgets[6793]
#define sipNameNr_SH_FormLayoutFieldGrowthPolicy 6824
#define sipName_SH_FormLayoutFieldGrowthPolicy &sipStrings_QtWidgets[6824]
#define sipNameNr_SH_Menu_AllowActiveAndDisabled 6855
#define sipName_SH_Menu_AllowActiveAndDisabled &sipStrings_QtWidgets[6855]
#define sipNameNr_SH_RichText_FullWidthSelection 6886
#define sipName_SH_RichText_FullWidthSelection &sipStrings_QtWidgets[6886]
#define sipNameNr_SH_SpinBox_ClickAutoRepeatRate 6917
#define sipName_SH_SpinBox_ClickAutoRepeatRate &sipStrings_QtWidgets[6917]
#define sipNameNr_SH_TitleBar_ModifyNotification 6948
#define sipName_SH_TitleBar_ModifyNotification &sipStrings_QtWidgets[6948]
#define sipNameNr_isShortcutVisibleInContextMenu 6979
#define sipName_isShortcutVisibleInContextMenu &sipStrings_QtWidgets[6979]
#define sipNameNr_setUnifiedTitleAndToolBarOnMac 7010
#define sipName_setUnifiedTitleAndToolBarOnMac &sipStrings_QtWidgets[7010]
#define sipNameNr_unsetDefaultScrollerProperties 7041
#define sipName_unsetDefaultScrollerProperties &sipStrings_QtWidgets[7041]
#define sipNameNr_AdjustToMinimumContentsLength 7072
#define sipName_AdjustToMinimumContentsLength &sipStrings_QtWidgets[7072]
#define sipNameNr_ItemSendsScenePositionChanges 7102
#define sipName_ItemSendsScenePositionChanges &sipStrings_QtWidgets[7102]
#define sipNameNr_OvershootDragResistanceFactor 7132
#define sipName_OvershootDragResistanceFactor &sipStrings_QtWidgets[7132]
#define sipNameNr_OvershootScrollDistanceFactor 7162
#define sipName_OvershootScrollDistanceFactor &sipStrings_QtWidgets[7162]
#define sipNameNr_PE_IndicatorItemViewItemCheck 7192
#define sipName_PE_IndicatorItemViewItemCheck &sipStrings_QtWidgets[7192]
#define sipNameNr_PM_MdiSubWindowMinimizedWidth 7222
#define sipName_PM_MdiSubWindowMinimizedWidth &sipStrings_QtWidgets[7222]
#define sipNameNr_PM_TabBar_ScrollButtonOverlap 7252
#define sipName_PM_TabBar_ScrollButtonOverlap &sipStrings_QtWidgets[7252]
#define sipNameNr_QAbstractItemView__ScrollHint 7282
#define sipName_QAbstractItemView__ScrollHint &sipStrings_QtWidgets[7282]
#define sipNameNr_QAbstractItemView__ScrollMode 7312
#define sipName_QAbstractItemView__ScrollMode &sipStrings_QtWidgets[7312]
#define sipNameNr_QAbstractSlider__SliderAction 7342
#define sipName_QAbstractSlider__SliderAction &sipStrings_QtWidgets[7342]
#define sipNameNr_QAbstractSlider__SliderChange 7372
#define sipName_QAbstractSlider__SliderChange &sipStrings_QtWidgets[7372]
#define sipNameNr_QAbstractSpinBox__StepEnabled 7402
#define sipName_QAbstractSpinBox__StepEnabled &sipStrings_QtWidgets[7402]
#define sipNameNr_QActionGroup__ExclusionPolicy 7432
#define sipName_QActionGroup__ExclusionPolicy &sipStrings_QtWidgets[7432]
#define sipNameNr_QFontDialog__FontDialogOption 7462
#define sipName_QFontDialog__FontDialogOption &sipStrings_QtWidgets[7462]
#define sipNameNr_QGesture__GestureCancelPolicy 7492
#define sipName_QGesture__GestureCancelPolicy &sipStrings_QtWidgets[7492]
#define sipNameNr_QGraphicsBlurEffect__BlurHint 7522
#define sipName_QGraphicsBlurEffect__BlurHint &sipStrings_QtWidgets[7522]
#define sipNameNr_QGraphicsView__ViewportAnchor 7552
#define sipName_QGraphicsView__ViewportAnchor &sipStrings_QtWidgets[7552]
#define sipNameNr_QOpenGLWidget__UpdateBehavior 7582
#define sipName_QOpenGLWidget__UpdateBehavior &sipStrings_QtWidgets[7582]
#define sipNameNr_QStyleOption__StyleOptionType 7612
#define sipName_QStyleOption__StyleOptionType &sipStrings_QtWidgets[7612]
#define sipNameNr_QStyleOptionTab__CornerWidget 7642
#define sipName_QStyleOptionTab__CornerWidget &sipStrings_QtWidgets[7642]
#define sipNameNr_QSwipeGesture__SwipeDirection 7672
#define sipName_QSwipeGesture__SwipeDirection &sipStrings_QtWidgets[7672]
#define sipNameNr_QTextEdit__AutoFormattingFlag 7702
#define sipName_QTextEdit__AutoFormattingFlag &sipStrings_QtWidgets[7702]
#define sipNameNr_SE_ItemViewItemCheckIndicator 7732
#define sipName_SE_ItemViewItemCheckIndicator &sipStrings_QtWidgets[7732]
#define sipNameNr_SH_ComboBox_ListMouseTracking 7762
#define sipName_SH_ComboBox_ListMouseTracking &sipStrings_QtWidgets[7762]
#define sipNameNr_SH_ItemView_DrawDelegateFrame 7792
#define sipName_SH_ItemView_DrawDelegateFrame &sipStrings_QtWidgets[7792]
#define sipNameNr_SH_LineEdit_PasswordCharacter 7822
#define sipName_SH_LineEdit_PasswordCharacter &sipStrings_QtWidgets[7822]
#define sipNameNr_SH_LineEdit_PasswordMaskDelay 7852
#define sipName_SH_LineEdit_PasswordMaskDelay &sipStrings_QtWidgets[7852]
#define sipNameNr_SH_Slider_StopMouseOverSlider 7882
#define sipName_SH_Slider_StopMouseOverSlider &sipStrings_QtWidgets[7882]
#define sipNameNr_SH_SpinBox_ButtonsInsideFrame 7912
#define sipName_SH_SpinBox_ButtonsInsideFrame &sipStrings_QtWidgets[7912]
#define sipNameNr_SH_TabBar_CloseButtonPosition 7942
#define sipName_SH_TabBar_CloseButtonPosition &sipStrings_QtWidgets[7942]
#define sipNameNr_verticalScrollbarValueChanged 7972
#define sipName_verticalScrollbarValueChanged &sipStrings_QtWidgets[7972]
#define sipNameNr_AcceleratingFlickMaximumTime 8002
#define sipName_AcceleratingFlickMaximumTime &sipStrings_QtWidgets[8002]
#define sipNameNr_CaseInsensitivelySortedModel 8031
#define sipName_CaseInsensitivelySortedModel &sipStrings_QtWidgets[8031]
#define sipNameNr_DisabledBackButtonOnLastPage 8060
#define sipName_DisabledBackButtonOnLastPage &sipStrings_QtWidgets[8060]
#define sipNameNr_HaveFinishButtonOnEarlyPages 8089
#define sipName_HaveFinishButtonOnEarlyPages &sipStrings_QtWidgets[8089]
#define sipNameNr_PE_IndicatorItemViewItemDrop 8118
#define sipName_PE_IndicatorItemViewItemDrop &sipStrings_QtWidgets[8118]
#define sipNameNr_PE_IndicatorToolBarSeparator 8147
#define sipName_PE_IndicatorToolBarSeparator &sipStrings_QtWidgets[8147]
#define sipNameNr_PM_DialogButtonsButtonHeight 8176
#define sipName_PM_DialogButtonsButtonHeight &sipStrings_QtWidgets[8176]
#define sipNameNr_PM_DockWidgetSeparatorExtent 8205
#define sipName_PM_DockWidgetSeparatorExtent &sipStrings_QtWidgets[8205]
#define sipNameNr_QDialogButtonBox__ButtonRole 8234
#define sipName_QDialogButtonBox__ButtonRole &sipStrings_QtWidgets[8234]
#define sipNameNr_QGraphicsEffect__ChangeFlags 8263
#define sipName_QGraphicsEffect__ChangeFlags &sipStrings_QtWidgets[8263]
#define sipNameNr_QGraphicsItem__PanelModality 8292
#define sipName_QGraphicsItem__PanelModality &sipStrings_QtWidgets[8292]
#define sipNameNr_QGraphicsView__CacheModeFlag 8321
#define sipName_QGraphicsView__CacheModeFlag &sipStrings_QtWidgets[8321]
#define sipNameNr_8350 8350
#define sipName_8350 &sipStrings_QtWidgets[8350]
#define sipNameNr_QMessageBox__StandardButtons 8379
#define sipName_QMessageBox__StandardButtons &sipStrings_QtWidgets[8379]
#define sipNameNr_QPlainTextEdit__LineWrapMode 8408
#define sipName_QPlainTextEdit__LineWrapMode &sipStrings_QtWidgets[8408]
#define sipNameNr_QStackedLayout__StackingMode 8437
#define sipName_QStackedLayout__StackingMode &sipStrings_QtWidgets[8437]
#define sipNameNr_QStyleOptionTab__TabFeatures 8466
#define sipName_QStyleOptionTab__TabFeatures &sipStrings_QtWidgets[8466]
#define sipNameNr_QStyleOptionTab__TabPosition 8495
#define sipName_QStyleOptionTab__TabPosition &sipStrings_QtWidgets[8495]
#define sipNameNr_QSystemTrayIcon__MessageIcon 8524
#define sipName_QSystemTrayIcon__MessageIcon &sipStrings_QtWidgets[8524]
#define sipNameNr_SC_TitleBarContextHelpButton 8553
#define sipName_SC_TitleBarContextHelpButton &sipStrings_QtWidgets[8553]
#define sipNameNr_SE_DialogButtonBoxLayoutItem 8582
#define sipName_SE_DialogButtonBoxLayoutItem &sipStrings_QtWidgets[8582]
#define sipNameNr_SH_ItemView_EllipsisLocation 8611
#define sipName_SH_ItemView_EllipsisLocation &sipStrings_QtWidgets[8611]
#define sipNameNr_SH_Menu_FillScreenWithScroll 8640
#define sipName_SH_Menu_FillScreenWithScroll &sipStrings_QtWidgets[8640]
#define sipNameNr_SH_RequestSoftwareInputPanel 8669
#define sipName_SH_RequestSoftwareInputPanel &sipStrings_QtWidgets[8669]
#define sipNameNr_SH_Slider_AbsoluteSetButtons 8698
#define sipName_SH_Slider_AbsoluteSetButtons &sipStrings_QtWidgets[8698]
#define sipNameNr_SH_TabBar_ChangeCurrentDelay 8727
#define sipName_SH_TabBar_ChangeCurrentDelay &sipStrings_QtWidgets[8727]
#define sipNameNr_SH_Widget_Animation_Duration 8756
#define sipName_SH_Widget_Animation_Duration &sipStrings_QtWidgets[8756]
#define sipNameNr_SP_TitleBarContextHelpButton 8785
#define sipName_SP_TitleBarContextHelpButton &sipStrings_QtWidgets[8785]
#define sipNameNr_UsePlainTextEditForTextInput 8814
#define sipName_UsePlainTextEditForTextInput &sipStrings_QtWidgets[8814]
#define sipNameNr_setBoundingRegionGranularity 8843
#define sipName_setBoundingRegionGranularity &sipStrings_QtWidgets[8843]
#define sipNameNr_setDefaultScrollerProperties 7043
#define sipName_setDefaultScrollerProperties &sipStrings_QtWidgets[7043]
#define sipNameNr_setHorizontalScrollBarPolicy 8872
#define sipName_setHorizontalScrollBarPolicy &sipStrings_QtWidgets[8872]
#define sipNameNr_setSelectionBehaviorOnRemove 8901
#define sipName_setSelectionBehaviorOnRemove &sipStrings_QtWidgets[8901]
#define sipNameNr_AdjustToContentsOnFirstShow 8930
#define sipName_AdjustToContentsOnFirstShow &sipStrings_QtWidgets[8930]
#define sipNameNr_DontUseCustomDirectoryIcons 8958
#define sipName_DontUseCustomDirectoryIcons &sipStrings_QtWidgets[8958]
#define sipNameNr_DragVelocitySmoothingFactor 8986
#define sipName_DragVelocitySmoothingFactor &sipStrings_QtWidgets[8986]
#define sipNameNr_ItemContainsChildrenInShape 9014
#define sipName_ItemContainsChildrenInShape &sipStrings_QtWidgets[9014]
#define sipNameNr_ItemScenePositionHasChanged 9042
#define sipName_ItemScenePositionHasChanged &sipStrings_QtWidgets[9042]
#define sipNameNr_ItemUsesExtendedStyleOption 9070
#define sipName_ItemUsesExtendedStyleOption &sipStrings_QtWidgets[9070]
#define sipNameNr_MaximumClickThroughVelocity 9098
#define sipName_MaximumClickThroughVelocity &sipStrings_QtWidgets[9098]
#define sipNameNr_OvershootDragDistanceFactor 9126
#define sipName_OvershootDragDistanceFactor &sipStrings_QtWidgets[9126]
#define sipNameNr_PE_IndicatorColumnViewArrow 9154
#define sipName_PE_IndicatorColumnViewArrow &sipStrings_QtWidgets[9154]
#define sipNameNr_PM_DialogButtonsButtonWidth 9182
#define sipName_PM_DialogButtonsButtonWidth &sipStrings_QtWidgets[9182]
#define sipNameNr_PM_ExclusiveIndicatorHeight 9210
#define sipName_PM_ExclusiveIndicatorHeight &sipStrings_QtWidgets[9210]
#define sipNameNr_PM_TabBarTabShiftHorizontal 9238
#define sipName_PM_TabBarTabShiftHorizontal &sipStrings_QtWidgets[9238]
#define sipNameNr_QComboBox__SizeAdjustPolicy 9266
#define sipName_QComboBox__SizeAdjustPolicy &sipStrings_QtWidgets[9266]
#define sipNameNr_QFileIconProvider__IconType 9294
#define sipName_QFileIconProvider__IconType &sipStrings_QtWidgets[9294]
#define sipNameNr_QGraphicsEffect__ChangeFlag 9322
#define sipName_QGraphicsEffect__ChangeFlag &sipStrings_QtWidgets[9322]
#define sipNameNr_QGraphicsScene__SceneLayers 9350
#define sipName_QGraphicsScene__SceneLayers &sipStrings_QtWidgets[9350]
#define sipNameNr_QGraphicsSceneDragDropEvent 9378
#define sipName_QGraphicsSceneDragDropEvent &sipStrings_QtWidgets[9378]
#define sipNameNr_9406 9406
#define sipName_9406 &sipStrings_QtWidgets[9406]
#define sipNameNr_QMessageBox__StandardButton 9434
#define sipName_QMessageBox__StandardButton &sipStrings_QtWidgets[9434]
#define sipNameNr_QStyleOptionTab__TabFeature 9462
#define sipName_QStyleOptionTab__TabFeature &sipStrings_QtWidgets[9462]
#define sipNameNr_SE_TabBarTearIndicatorRight 9490
#define sipName_SE_TabBarTearIndicatorRight &sipStrings_QtWidgets[9490]
#define sipNameNr_SH_ComboBox_LayoutDirection 9518
#define sipName_SH_ComboBox_LayoutDirection &sipStrings_QtWidgets[9518]
#define sipNameNr_SH_ComboBox_PopupFrameStyle 9546
#define sipName_SH_ComboBox_PopupFrameStyle &sipStrings_QtWidgets[9546]
#define sipNameNr_SH_FormLayoutLabelAlignment 9574
#define sipName_SH_FormLayoutLabelAlignment &sipStrings_QtWidgets[9574]
#define sipNameNr_SH_MenuBar_AltKeyNavigation 9602
#define sipName_SH_MenuBar_AltKeyNavigation &sipStrings_QtWidgets[9602]
#define sipNameNr_SH_Menu_SubMenuUniDirection 9630
#define sipName_SH_Menu_SubMenuUniDirection &sipStrings_QtWidgets[9630]
#define sipNameNr_SH_MessageBox_CenterButtons 9658
#define sipName_SH_MessageBox_CenterButtons &sipStrings_QtWidgets[9658]
#define sipNameNr_SH_SpellCheckUnderlineStyle 9686
#define sipName_SH_SpellCheckUnderlineStyle &sipStrings_QtWidgets[9686]
#define sipNameNr_UseListViewForComboBoxItems 9714
#define sipName_UseListViewForComboBoxItems &sipStrings_QtWidgets[9714]
#define sipNameNr_createMimeDataFromSelection 9742
#define sipName_createMimeDataFromSelection &sipStrings_QtWidgets[9742]
#define sipNameNr_tabifiedDockWidgetActivated 9770
#define sipName_tabifiedDockWidgetActivated &sipStrings_QtWidgets[9770]
#define sipNameNr_unifiedTitleAndToolBarOnMac 9798
#define sipName_unifiedTitleAndToolBarOnMac &sipStrings_QtWidgets[9798]
#define sipNameNr_BoundingRectViewportUpdate 9826
#define sipName_BoundingRectViewportUpdate &sipStrings_QtWidgets[9826]
#define sipNameNr_CaseSensitivelySortedModel 9853
#define sipName_CaseSensitivelySortedModel &sipStrings_QtWidgets[9853]
#define sipNameNr_DockWidgetVerticalTitleBar 9880
#define sipName_DockWidgetVerticalTitleBar &sipStrings_QtWidgets[9880]
#define sipNameNr_ItemIgnoresTransformations 9907
#define sipName_ItemIgnoresTransformations &sipStrings_QtWidgets[9907]
#define sipNameNr_NextAndPreviousAreSelected 9934
#define sipName_NextAndPreviousAreSelected &sipStrings_QtWidgets[9934]
#define sipNameNr_PE_IndicatorButtonDropDown 9961
#define sipName_PE_IndicatorButtonDropDown &sipStrings_QtWidgets[9961]
#define sipNameNr_PM_ExclusiveIndicatorWidth 9988
#define sipName_PM_ExclusiveIndicatorWidth &sipStrings_QtWidgets[9988]
#define sipNameNr_PM_LayoutHorizontalSpacing 10015
#define sipName_PM_LayoutHorizontalSpacing &sipStrings_QtWidgets[10015]
#define sipNameNr_PM_RadioButtonLabelSpacing 10042
#define sipName_PM_RadioButtonLabelSpacing &sipStrings_QtWidgets[10042]
#define sipNameNr_PM_TabBarScrollButtonWidth 10069
#define sipName_PM_TabBarScrollButtonWidth &sipStrings_QtWidgets[10069]
#define sipNameNr_PM_TabCloseIndicatorHeight 10096
#define sipName_PM_TabCloseIndicatorHeight &sipStrings_QtWidgets[10096]
#define sipNameNr_PadToEffectiveBoundingRect 10123
#define sipName_PadToEffectiveBoundingRect &sipStrings_QtWidgets[10123]
#define sipNameNr_QAbstractGraphicsShapeItem 10150
#define sipName_QAbstractGraphicsShapeItem &sipStrings_QtWidgets[10150]
#define sipNameNr_QAbstractSpinBox__StepType 10177
#define sipName_QAbstractSpinBox__StepType &sipStrings_QtWidgets[10177]
#define sipNameNr_QCompleter__CompletionMode 10204
#define sipName_QCompleter__CompletionMode &sipStrings_QtWidgets[10204]
#define sipNameNr_QFileIconProvider__Options 10231
#define sipName_QFileIconProvider__Options &sipStrings_QtWidgets[10231]
#define sipNameNr_QFontComboBox__FontFilters 10258
#define sipName_QFontComboBox__FontFilters &sipStrings_QtWidgets[10258]
#define sipNameNr_QFormLayout__RowWrapPolicy 10285
#define sipName_QFormLayout__RowWrapPolicy &sipStrings_QtWidgets[10285]
#define sipNameNr_QFormLayout__TakeRowResult 10312
#define sipName_QFormLayout__TakeRowResult &sipStrings_QtWidgets[10312]
#define sipNameNr_QGestureRecognizer__Result 10339
#define sipName_QGestureRecognizer__Result &sipStrings_QtWidgets[10339]
#define sipNameNr_QGraphicsScene__SceneLayer 10366
#define sipName_QGraphicsScene__SceneLayer &sipStrings_QtWidgets[10366]
#define sipNameNr_10393 10393
#define sipName_10393 &sipStrings_QtWidgets[10393]
#define sipNameNr_QPinchGesture__ChangeFlags 10420
#define sipName_QPinchGesture__ChangeFlags &sipStrings_QtWidgets[10420]
#define sipNameNr_QStyleOptionTabWidgetFrame 10447
#define sipName_QStyleOptionTabWidgetFrame &sipStrings_QtWidgets[10447]
#define sipNameNr_QTabBar__SelectionBehavior 10474
#define sipName_QTabBar__SelectionBehavior &sipStrings_QtWidgets[10474]
#define sipNameNr_QTableWidgetItem__ItemType 10501
#define sipName_QTableWidgetItem__ItemType &sipStrings_QtWidgets[10501]
#define sipNameNr_QTableWidgetSelectionRange 10528
#define sipName_QTableWidgetSelectionRange &sipStrings_QtWidgets[10528]
#define sipNameNr_SE_TabBarScrollRightButton 10555
#define sipName_SE_TabBarScrollRightButton &sipStrings_QtWidgets[10555]
#define sipNameNr_SE_TabBarTearIndicatorLeft 10582
#define sipName_SE_TabBarTearIndicatorLeft &sipStrings_QtWidgets[10582]
#define sipNameNr_SH_FormLayoutFormAlignment 10609
#define sipName_SH_FormLayoutFormAlignment &sipStrings_QtWidgets[10609]
#define sipNameNr_SH_GroupBox_TextLabelColor 10636
#define sipName_SH_GroupBox_TextLabelColor &sipStrings_QtWidgets[10636]
#define sipNameNr_SH_Menu_FlashTriggeredItem 10663
#define sipName_SH_Menu_FlashTriggeredItem &sipStrings_QtWidgets[10663]
#define sipNameNr_SH_Menu_SpaceActivatesItem 10690
#define sipName_SH_Menu_SpaceActivatesItem &sipStrings_QtWidgets[10690]
#define sipNameNr_SH_ToolTip_FallAsleepDelay 10717
#define sipName_SH_ToolTip_FallAsleepDelay &sipStrings_QtWidgets[10717]
#define sipNameNr_customContextMenuRequested 10744
#define sipName_customContextMenuRequested &sipStrings_QtWidgets[10744]
#define sipNameNr_levelOfDetailFromTransform 10771
#define sipName_levelOfDetailFromTransform &sipStrings_QtWidgets[10771]
#define sipNameNr_scheduleDelayedItemsLayout 10798
#define sipName_scheduleDelayedItemsLayout &sipStrings_QtWidgets[10798]
#define sipNameNr_sectionHandleDoubleClicked 10825
#define sipName_sectionHandleDoubleClicked &sipStrings_QtWidgets[10825]
#define sipNameNr_setCascadingSectionResizes 10852
#define sipName_setCascadingSectionResizes &sipStrings_QtWidgets[10852]
#define sipNameNr_setOffsetToSectionPosition 10879
#define sipName_setOffsetToSectionPosition &sipStrings_QtWidgets[10879]
#define sipNameNr_setResizeContentsPrecision 10906
#define sipName_setResizeContentsPrecision &sipStrings_QtWidgets[10906]
#define sipNameNr_setRubberBandSelectionMode 10933
#define sipName_setRubberBandSelectionMode &sipStrings_QtWidgets[10933]
#define sipNameNr_setVerticalScrollBarPolicy 10960
#define sipName_setVerticalScrollBarPolicy &sipStrings_QtWidgets[10960]
#define sipNameNr_DontAdjustForAntialiasing 10987
#define sipName_DontAdjustForAntialiasing &sipStrings_QtWidgets[10987]
#define sipNameNr_HorizontalOvershootPolicy 11013
#define sipName_HorizontalOvershootPolicy &sipStrings_QtWidgets[11013]
#define sipNameNr_PE_IndicatorMenuCheckMark 11039
#define sipName_PE_IndicatorMenuCheckMark &sipStrings_QtWidgets[11039]
#define sipNameNr_PE_IndicatorProgressChunk 11065
#define sipName_PE_IndicatorProgressChunk &sipStrings_QtWidgets[11065]
#define sipNameNr_PE_IndicatorToolBarHandle 11091
#define sipName_PE_IndicatorToolBarHandle &sipStrings_QtWidgets[11091]
#define sipNameNr_PE_IndicatorViewItemCheck 11117
#define sipName_PE_IndicatorViewItemCheck &sipStrings_QtWidgets[11117]
#define sipNameNr_PM_ButtonDefaultIndicator 11143
#define sipName_PM_ButtonDefaultIndicator &sipStrings_QtWidgets[11143]
#define sipNameNr_PM_DialogButtonsSeparator 11169
#define sipName_PM_DialogButtonsSeparator &sipStrings_QtWidgets[11169]
#define sipNameNr_PM_DockWidgetHandleExtent 11195
#define sipName_PM_DockWidgetHandleExtent &sipStrings_QtWidgets[11195]
#define sipNameNr_PM_MdiSubWindowFrameWidth 11221
#define sipName_PM_MdiSubWindowFrameWidth &sipStrings_QtWidgets[11221]
#define sipNameNr_PM_SliderControlThickness 11247
#define sipName_PM_SliderControlThickness &sipStrings_QtWidgets[11247]
#define sipNameNr_PM_TabBarTabShiftVertical 11273
#define sipName_PM_TabBarTabShiftVertical &sipStrings_QtWidgets[11273]
#define sipNameNr_PM_TabCloseIndicatorWidth 11299
#define sipName_PM_TabCloseIndicatorWidth &sipStrings_QtWidgets[11299]
#define sipNameNr_PM_TitleBarButtonIconSize 11325
#define sipName_PM_TitleBarButtonIconSize &sipStrings_QtWidgets[11325]
#define sipNameNr_PM_ToolBarExtensionExtent 11351
#define sipName_PM_ToolBarExtensionExtent &sipStrings_QtWidgets[11351]
#define sipNameNr_PM_ToolBarSeparatorExtent 11377
#define sipName_PM_ToolBarSeparatorExtent &sipStrings_QtWidgets[11377]
#define sipNameNr_PM_ToolTipLabelFrameWidth 11403
#define sipName_PM_ToolTipLabelFrameWidth &sipStrings_QtWidgets[11403]
#define sipNameNr_QFileIconProvider__Option 11429
#define sipName_QFileIconProvider__Option &sipStrings_QtWidgets[11429]
#define sipNameNr_QFileSystemModel__Options 11455
#define sipName_QFileSystemModel__Options &sipStrings_QtWidgets[11455]
#define sipNameNr_QFontComboBox__FontFilter 11481
#define sipName_QFontComboBox__FontFilter &sipStrings_QtWidgets[11481]
#define sipNameNr_QGraphicsDropShadowEffect 11507
#define sipName_QGraphicsDropShadowEffect &sipStrings_QtWidgets[11507]
#define sipNameNr_QGraphicsSceneResizeEvent 11533
#define sipName_QGraphicsSceneResizeEvent &sipStrings_QtWidgets[11533]
#define sipNameNr_QLineEdit__ActionPosition 11559
#define sipName_QLineEdit__ActionPosition &sipStrings_QtWidgets[11559]
#define sipNameNr_QListWidgetItem__ItemType 11585
#define sipName_QListWidgetItem__ItemType &sipStrings_QtWidgets[11585]
#define sipNameNr_QPinchGesture__ChangeFlag 11611
#define sipName_QPinchGesture__ChangeFlag &sipStrings_QtWidgets[11611]
#define sipNameNr_QSizePolicy__ControlTypes 11637
#define sipName_QSizePolicy__ControlTypes &sipStrings_QtWidgets[11637]
#define sipNameNr_QTextEdit__AutoFormatting 11663
#define sipName_QTextEdit__AutoFormatting &sipStrings_QtWidgets[11663]
#define sipNameNr_QTextEdit__ExtraSelection 11689
#define sipName_QTextEdit__ExtraSelection &sipStrings_QtWidgets[11689]
#define sipNameNr_QTreeWidgetItem__ItemType 11715
#define sipName_QTreeWidgetItem__ItemType &sipStrings_QtWidgets[11715]
#define sipNameNr_RequestSoftwareInputPanel 4415
#define sipName_RequestSoftwareInputPanel &sipStrings_QtWidgets[4415]
#define sipNameNr_SE_DateTimeEditLayoutItem 11741
#define sipName_SE_DateTimeEditLayoutItem &sipStrings_QtWidgets[11741]
#define sipNameNr_SE_DockWidgetTitleBarText 11767
#define sipName_SE_DockWidgetTitleBarText &sipStrings_QtWidgets[11767]
#define sipNameNr_SE_ItemViewItemDecoration 11793
#define sipName_SE_ItemViewItemDecoration &sipStrings_QtWidgets[11793]
#define sipNameNr_SE_TabBarScrollLeftButton 11819
#define sipName_SE_TabBarScrollLeftButton &sipStrings_QtWidgets[11819]
#define sipNameNr_SE_TreeViewDisclosureItem 11845
#define sipName_SE_TreeViewDisclosureItem &sipStrings_QtWidgets[11845]
#define sipNameNr_SE_ViewItemCheckIndicator 11871
#define sipName_SE_ViewItemCheckIndicator &sipStrings_QtWidgets[11871]
#define sipNameNr_SH_FocusFrame_AboveWidget 11897
#define sipName_SH_FocusFrame_AboveWidget &sipStrings_QtWidgets[11897]
#define sipNameNr_SH_Menu_SubMenuPopupDelay 11923
#define sipName_SH_Menu_SubMenuPopupDelay &sipStrings_QtWidgets[11923]
#define sipNameNr_SH_Slider_SloppyKeyEvents 11949
#define sipName_SH_Slider_SloppyKeyEvents &sipStrings_QtWidgets[11949]
#define sipNameNr_SH_TabBar_SelectMouseType 11975
#define sipName_SH_TabBar_SelectMouseType &sipStrings_QtWidgets[11975]
#define sipNameNr_SH_Widget_ShareActivation 12001
#define sipName_SH_Widget_ShareActivation &sipStrings_QtWidgets[12001]
#define sipNameNr_SP_FileDialogContentsView 12027
#define sipName_SP_FileDialogContentsView &sipStrings_QtWidgets[12027]
#define sipNameNr_SP_FileDialogDetailedView 12053
#define sipName_SP_FileDialogDetailedView &sipStrings_QtWidgets[12053]
#define sipNameNr_SourceBoundingRectChanged 12079
#define sipName_SourceBoundingRectChanged &sipStrings_QtWidgets[12079]
#define sipNameNr_State_KeyboardFocusChange 12105
#define sipName_State_KeyboardFocusChange &sipStrings_QtWidgets[12105]
#define sipNameNr_UnfilteredPopupCompletion 12131
#define sipName_UnfilteredPopupCompletion &sipStrings_QtWidgets[12131]
#define sipNameNr_activatePreviousSubWindow 12157
#define sipName_activatePreviousSubWindow &sipStrings_QtWidgets[12157]
#define sipNameNr_associatedGraphicsWidgets 12183
#define sipName_associatedGraphicsWidgets &sipStrings_QtWidgets[12183]
#define sipNameNr_boundingRegionGranularity 12209
#define sipName_boundingRegionGranularity &sipStrings_QtWidgets[12209]
#define sipNameNr_createProxyForChildWidget 12235
#define sipName_createProxyForChildWidget &sipStrings_QtWidgets[12235]
#define sipNameNr_createStandardContextMenu 12261
#define sipName_createStandardContextMenu &sipStrings_QtWidgets[12261]
#define sipNameNr_executeDelayedItemsLayout 12287
#define sipName_executeDelayedItemsLayout &sipStrings_QtWidgets[12287]
#define sipNameNr_horizontalScrollBarPolicy 12313
#define sipName_horizontalScrollBarPolicy &sipStrings_QtWidgets[12313]
#define sipNameNr_horizontalScrollbarAction 12339
#define sipName_horizontalScrollbarAction &sipStrings_QtWidgets[12339]
#define sipNameNr_resetHorizontalScrollMode 12365
#define sipName_resetHorizontalScrollMode &sipStrings_QtWidgets[12365]
#define sipNameNr_scrollerPropertiesChanged 12391
#define sipName_scrollerPropertiesChanged &sipStrings_QtWidgets[12391]
#define sipNameNr_selectionBehaviorOnRemove 12417
#define sipName_selectionBehaviorOnRemove &sipStrings_QtWidgets[12417]
#define sipNameNr_setFirstItemColumnSpanned 12443
#define sipName_setFirstItemColumnSpanned &sipStrings_QtWidgets[12443]
#define sipNameNr_setHorizontalHeaderFormat 12469
#define sipName_setHorizontalHeaderFormat &sipStrings_QtWidgets[12469]
#define sipNameNr_setHorizontalHeaderLabels 12495
#define sipName_setHorizontalHeaderLabels &sipStrings_QtWidgets[12495]
#define sipNameNr_HaveNextButtonOnLastPage 12521
#define sipName_HaveNextButtonOnLastPage &sipStrings_QtWidgets[12521]
#define sipNameNr_ItemClipsChildrenToShape 12546
#define sipName_ItemClipsChildrenToShape &sipStrings_QtWidgets[12546]
#define sipNameNr_ItemIgnoresParentOpacity 12571
#define sipName_ItemIgnoresParentOpacity &sipStrings_QtWidgets[12571]
#define sipNameNr_ItemSendsGeometryChanges 12596
#define sipName_ItemSendsGeometryChanges &sipStrings_QtWidgets[12596]
#define sipNameNr_MiddleMouseButtonGesture 12621
#define sipName_MiddleMouseButtonGesture &sipStrings_QtWidgets[12621]
#define sipNameNr_NoCancelButtonOnLastPage 12646
#define sipName_NoCancelButtonOnLastPage &sipStrings_QtWidgets[12646]
#define sipNameNr_PE_IndicatorTabTearRight 12671
#define sipName_PE_IndicatorTabTearRight &sipStrings_QtWidgets[12671]
#define sipNameNr_PE_PanelScrollAreaCorner 12696
#define sipName_PE_PanelScrollAreaCorner &sipStrings_QtWidgets[12696]
#define sipNameNr_PM_ButtonShiftHorizontal 12721
#define sipName_PM_ButtonShiftHorizontal &sipStrings_QtWidgets[12721]
#define sipNameNr_PM_DefaultTopLevelMargin 12746
#define sipName_PM_DefaultTopLevelMargin &sipStrings_QtWidgets[12746]
#define sipNameNr_PM_DockWidgetTitleMargin 12771
#define sipName_PM_DockWidgetTitleMargin &sipStrings_QtWidgets[12771]
#define sipNameNr_PM_LayoutVerticalSpacing 12796
#define sipName_PM_LayoutVerticalSpacing &sipStrings_QtWidgets[12796]
#define sipNameNr_PM_MenuDesktopFrameWidth 12821
#define sipName_PM_MenuDesktopFrameWidth &sipStrings_QtWidgets[12821]
#define sipNameNr_PM_ProgressBarChunkWidth 12846
#define sipName_PM_ProgressBarChunkWidth &sipStrings_QtWidgets[12846]
#define sipNameNr_QAbstractItemView__State 12871
#define sipName_QAbstractItemView__State &sipStrings_QtWidgets[12871]
#define sipNameNr_QCompleter__ModelSorting 12896
#define sipName_QCompleter__ModelSorting &sipStrings_QtWidgets[12896]
#define sipNameNr_QFileDialog__DialogLabel 12921
#define sipName_QFileDialog__DialogLabel &sipStrings_QtWidgets[12921]
#define sipNameNr_QFileSystemModel__Option 12946
#define sipName_QFileSystemModel__Option &sipStrings_QtWidgets[12946]
#define sipNameNr_QGraphicsItem__CacheMode 12971
#define sipName_QGraphicsItem__CacheMode &sipStrings_QtWidgets[12971]
#define sipNameNr_QGraphicsSceneHoverEvent 12996
#define sipName_QGraphicsSceneHoverEvent &sipStrings_QtWidgets[12996]
#define sipNameNr_QGraphicsSceneMouseEvent 13021
#define sipName_QGraphicsSceneMouseEvent &sipStrings_QtWidgets[13021]
#define sipNameNr_QGraphicsSceneWheelEvent 13046
#define sipName_QGraphicsSceneWheelEvent &sipStrings_QtWidgets[13046]
#define sipNameNr_QGraphicsView__CacheMode 13071
#define sipName_QGraphicsView__CacheMode &sipStrings_QtWidgets[13071]
#define sipNameNr_QLCDNumber__SegmentStyle 13096
#define sipName_QLCDNumber__SegmentStyle &sipStrings_QtWidgets[13096]
#define sipNameNr_13121 13121
#define sipName_13121 &sipStrings_QtWidgets[13121]
#define sipNameNr_QMainWindow__DockOptions 13146
#define sipName_QMainWindow__DockOptions &sipStrings_QtWidgets[13146]
#define sipNameNr_QPlainTextDocumentLayout 13171
#define sipName_QPlainTextDocumentLayout &sipStrings_QtWidgets[13171]
#define sipNameNr_QSizePolicy__ControlType 13196
#define sipName_QSizePolicy__ControlType &sipStrings_QtWidgets[13196]
#define sipNameNr_QStyle__PrimitiveElement 13221
#define sipName_QStyle__PrimitiveElement &sipStrings_QtWidgets[13221]
#define sipNameNr_QStyleOption__OptionType 13246
#define sipName_QStyleOption__OptionType &sipStrings_QtWidgets[13246]
#define sipNameNr_QStyleOptionGraphicsItem 13271
#define sipName_QStyleOptionGraphicsItem &sipStrings_QtWidgets[13271]
#define sipNameNr_SC_TitleBarUnshadeButton 13296
#define sipName_SC_TitleBarUnshadeButton &sipStrings_QtWidgets[13296]
#define sipNameNr_SE_DockWidgetCloseButton 13321
#define sipName_SE_DockWidgetCloseButton &sipStrings_QtWidgets[13321]
#define sipNameNr_SE_DockWidgetFloatButton 13346
#define sipName_SE_DockWidgetFloatButton &sipStrings_QtWidgets[13346]
#define sipNameNr_SE_ItemViewItemFocusRect 13371
#define sipName_SE_ItemViewItemFocusRect &sipStrings_QtWidgets[13371]
#define sipNameNr_SE_ProgressBarLayoutItem 13396
#define sipName_SE_ProgressBarLayoutItem &sipStrings_QtWidgets[13396]
#define sipNameNr_SE_RadioButtonLayoutItem 13421
#define sipName_SE_RadioButtonLayoutItem &sipStrings_QtWidgets[13421]
#define sipNameNr_SH_Header_ArrowAlignment 13446
#define sipName_SH_Header_ArrowAlignment &sipStrings_QtWidgets[13446]
#define sipNameNr_SH_MenuBar_MouseTracking 13471
#define sipName_SH_MenuBar_MouseTracking &sipStrings_QtWidgets[13471]
#define sipNameNr_SH_Menu_SupportsSections 13496
#define sipName_SH_Menu_SupportsSections &sipStrings_QtWidgets[13496]
#define sipNameNr_SH_ScrollBar_ContextMenu 13521
#define sipName_SH_ScrollBar_ContextMenu &sipStrings_QtWidgets[13521]
#define sipNameNr_SH_Slider_PageSetButtons 13546
#define sipName_SH_Slider_PageSetButtons &sipStrings_QtWidgets[13546]
#define sipNameNr_SH_SpinBox_AnimateButton 13571
#define sipName_SH_SpinBox_AnimateButton &sipStrings_QtWidgets[13571]
#define sipNameNr_SH_Splitter_OpaqueResize 13596
#define sipName_SH_Splitter_OpaqueResize &sipStrings_QtWidgets[13596]
#define sipNameNr_SH_TabBar_PreferNoArrows 13621
#define sipName_SH_TabBar_PreferNoArrows &sipStrings_QtWidgets[13621]
#define sipNameNr_SH_ToolButton_PopupDelay 13646
#define sipName_SH_ToolButton_PopupDelay &sipStrings_QtWidgets[13646]
#define sipNameNr_SP_DockWidgetCloseButton 13671
#define sipName_SP_DockWidgetCloseButton &sipStrings_QtWidgets[13671]
#define sipNameNr_SP_MessageBoxInformation 13696
#define sipName_SP_MessageBoxInformation &sipStrings_QtWidgets[13696]
#define sipNameNr_SP_RestoreDefaultsButton 13721
#define sipName_SP_RestoreDefaultsButton &sipStrings_QtWidgets[13721]
#define sipNameNr_SP_TitleBarUnshadeButton 13746
#define sipName_SP_TitleBarUnshadeButton &sipStrings_QtWidgets[13746]
#define sipNameNr_currentCharFormatChanged 13771
#define sipName_currentCharFormatChanged &sipStrings_QtWidgets[13771]
#define sipNameNr_defaultFramebufferObject 13796
#define sipName_defaultFramebufferObject &sipStrings_QtWidgets[13796]
#define sipNameNr_isFirstItemColumnSpanned 13821
#define sipName_isFirstItemColumnSpanned &sipStrings_QtWidgets[13821]
#define sipNameNr_sectionsAboutToBeRemoved 13846
#define sipName_sectionsAboutToBeRemoved &sipStrings_QtWidgets[13846]
#define sipNameNr_setAccessibleDescription 13871
#define sipName_setAccessibleDescription &sipStrings_QtWidgets[13871]
#define sipNameNr_setDragDropOverwriteMode 13896
#define sipName_setDragDropOverwriteMode &sipStrings_QtWidgets[13896]
#define sipNameNr_setItemDelegateForColumn 13921
#define sipName_setItemDelegateForColumn &sipStrings_QtWidgets[13921]
#define sipNameNr_setKeyboardInputInterval 13946
#define sipName_setKeyboardInputInterval &sipStrings_QtWidgets[13946]
#define sipNameNr_setLineWrapColumnOrWidth 13971
#define sipName_setLineWrapColumnOrWidth &sipStrings_QtWidgets[13971]
#define sipNameNr_setMinimumContentsLength 13996
#define sipName_setMinimumContentsLength &sipStrings_QtWidgets[13996]
#define sipNameNr_setSeparatorsCollapsible 14021
#define sipName_setSeparatorsCollapsible &sipStrings_QtWidgets[14021]
#define sipNameNr_takeHorizontalHeaderItem 14046
#define sipName_takeHorizontalHeaderItem &sipStrings_QtWidgets[14046]
#define sipNameNr_visualRegionForSelection 14071
#define sipName_visualRegionForSelection &sipStrings_QtWidgets[14071]
#define sipNameNr_AdaptiveDecimalStepType 14096
#define sipName_AdaptiveDecimalStepType &sipStrings_QtWidgets[14096]
#define sipNameNr_ApplicationSpecificRole 14120
#define sipName_ApplicationSpecificRole &sipStrings_QtWidgets[14120]
#define sipNameNr_ExtendedWatermarkPixmap 14144
#define sipName_ExtendedWatermarkPixmap &sipStrings_QtWidgets[14144]
#define sipNameNr_ItemTransformHasChanged 14168
#define sipName_ItemTransformHasChanged &sipStrings_QtWidgets[14168]
#define sipNameNr_NoBackButtonOnStartPage 14192
#define sipName_NoBackButtonOnStartPage &sipStrings_QtWidgets[14192]
#define sipNameNr_OvershootWhenScrollable 14216
#define sipName_OvershootWhenScrollable &sipStrings_QtWidgets[14216]
#define sipNameNr_PE_IndicatorHeaderArrow 14240
#define sipName_PE_IndicatorHeaderArrow &sipStrings_QtWidgets[14240]
#define sipNameNr_PE_IndicatorRadioButton 14264
#define sipName_PE_IndicatorRadioButton &sipStrings_QtWidgets[14264]
#define sipNameNr_PE_IndicatorTabTearLeft 14288
#define sipName_PE_IndicatorTabTearLeft &sipStrings_QtWidgets[14288]
#define sipNameNr_PM_CheckBoxLabelSpacing 14312
#define sipName_PM_CheckBoxLabelSpacing &sipStrings_QtWidgets[14312]
#define sipNameNr_PM_DefaultLayoutSpacing 14336
#define sipName_PM_DefaultLayoutSpacing &sipStrings_QtWidgets[14336]
#define sipNameNr_PM_DockWidgetFrameWidth 14360
#define sipName_PM_DockWidgetFrameWidth &sipStrings_QtWidgets[14360]
#define sipNameNr_PM_SliderSpaceAvailable 14384
#define sipName_PM_SliderSpaceAvailable &sipStrings_QtWidgets[14384]
#define sipNameNr_PM_SliderTickmarkOffset 14408
#define sipName_PM_SliderTickmarkOffset &sipStrings_QtWidgets[14408]
#define sipNameNr_QApplication__ColorSpec 14432
#define sipName_QApplication__ColorSpec &sipStrings_QtWidgets[14432]
#define sipNameNr_QComboBox__InsertPolicy 14456
#define sipName_QComboBox__InsertPolicy &sipStrings_QtWidgets[14456]
#define sipNameNr_QDateTimeEdit__Sections 14480
#define sipName_QDateTimeEdit__Sections &sipStrings_QtWidgets[14480]
#define sipNameNr_QFileDialog__AcceptMode 14504
#define sipName_QFileDialog__AcceptMode &sipStrings_QtWidgets[14504]
#define sipNameNr_QFileSystemModel__Roles 14528
#define sipName_QFileSystemModel__Roles &sipStrings_QtWidgets[14528]
#define sipNameNr_QGraphicsColorizeEffect 14552
#define sipName_QGraphicsColorizeEffect &sipStrings_QtWidgets[14552]
#define sipNameNr_QGraphicsSceneHelpEvent 14576
#define sipName_QGraphicsSceneHelpEvent &sipStrings_QtWidgets[14576]
#define sipNameNr_QGraphicsSceneMoveEvent 14600
#define sipName_QGraphicsSceneMoveEvent &sipStrings_QtWidgets[14600]
#define sipNameNr_QGraphicsSimpleTextItem 14624
#define sipName_QGraphicsSimpleTextItem &sipStrings_QtWidgets[14624]
#define sipNameNr_QGraphicsView__DragMode 14648
#define sipName_QGraphicsView__DragMode &sipStrings_QtWidgets[14648]
#define sipNameNr_QHeaderView__ResizeMode 14672
#define sipName_QHeaderView__ResizeMode &sipStrings_QtWidgets[14672]
#define sipNameNr_QInputDialog__InputMode 14696
#define sipName_QInputDialog__InputMode &sipStrings_QtWidgets[14696]
#define sipNameNr_QLayout__SizeConstraint 14720
#define sipName_QLayout__SizeConstraint &sipStrings_QtWidgets[14720]
#define sipNameNr_14744 14744
#define sipName_14744 &sipStrings_QtWidgets[14744]
#define sipNameNr_14768 14768
#define sipName_14768 &sipStrings_QtWidgets[14768]
#define sipNameNr_14792 14792
#define sipName_14792 &sipStrings_QtWidgets[14792]
#define sipNameNr_14816 14816
#define sipName_14816 &sipStrings_QtWidgets[14816]
#define sipNameNr_QMainWindow__DockOption 14840
#define sipName_QMainWindow__DockOption &sipStrings_QtWidgets[14840]
#define sipNameNr_QMessageBox__ButtonRole 14864
#define sipName_QMessageBox__ButtonRole &sipStrings_QtWidgets[14864]
#define sipNameNr_QProgressBar__Direction 14888
#define sipName_QProgressBar__Direction &sipStrings_QtWidgets[14888]
#define sipNameNr_QSizePolicy__PolicyFlag 14912
#define sipName_QSizePolicy__PolicyFlag &sipStrings_QtWidgets[14912]
#define sipNameNr_QStyleHintReturnVariant 14936
#define sipName_QStyleHintReturnVariant &sipStrings_QtWidgets[14936]
#define sipNameNr_QStyleOptionProgressBar 14960
#define sipName_QStyleOptionProgressBar &sipStrings_QtWidgets[14960]
#define sipNameNr_QTabBar__ButtonPosition 14984
#define sipName_QTabBar__ButtonPosition &sipStrings_QtWidgets[14984]
#define sipNameNr_QTabWidget__TabPosition 15008
#define sipName_QTabWidget__TabPosition &sipStrings_QtWidgets[15008]
#define sipNameNr_QTextEdit__LineWrapMode 15032
#define sipName_QTextEdit__LineWrapMode &sipStrings_QtWidgets[15032]
#define sipNameNr_QTreeWidgetItemIterator 15056
#define sipName_QTreeWidgetItemIterator &sipStrings_QtWidgets[15056]
#define sipNameNr_RightMouseButtonGesture 15080
#define sipName_RightMouseButtonGesture &sipStrings_QtWidgets[15080]
#define sipNameNr_SC_ComboBoxListBoxPopup 15104
#define sipName_SC_ComboBoxListBoxPopup &sipStrings_QtWidgets[15104]
#define sipNameNr_SC_TitleBarNormalButton 15128
#define sipName_SC_TitleBarNormalButton &sipStrings_QtWidgets[15128]
#define sipNameNr_SE_PushButtonLayoutItem 15152
#define sipName_SE_PushButtonLayoutItem &sipStrings_QtWidgets[15152]
#define sipNameNr_SE_RadioButtonClickRect 15176
#define sipName_SE_RadioButtonClickRect &sipStrings_QtWidgets[15176]
#define sipNameNr_SE_RadioButtonFocusRect 15200
#define sipName_SE_RadioButtonFocusRect &sipStrings_QtWidgets[15200]
#define sipNameNr_SE_RadioButtonIndicator 15224
#define sipName_SE_RadioButtonIndicator &sipStrings_QtWidgets[15224]
#define sipNameNr_SE_TabBarTabRightButton 15248
#define sipName_SE_TabBarTabRightButton &sipStrings_QtWidgets[15248]
#define sipNameNr_SE_TabWidgetRightCorner 15272
#define sipName_SE_TabWidgetRightCorner &sipStrings_QtWidgets[15272]
#define sipNameNr_SE_TabWidgetTabContents 15296
#define sipName_SE_TabWidgetTabContents &sipStrings_QtWidgets[15296]
#define sipNameNr_SE_ToolButtonLayoutItem 15320
#define sipName_SE_ToolButtonLayoutItem &sipStrings_QtWidgets[15320]
#define sipNameNr_SH_DrawMenuBarSeparator 15344
#define sipName_SH_DrawMenuBarSeparator &sipStrings_QtWidgets[15344]
#define sipNameNr_SH_FormLayoutWrapPolicy 15368
#define sipName_SH_FormLayoutWrapPolicy &sipStrings_QtWidgets[15368]
#define sipNameNr_SH_SpinBox_StepModifier 15392
#define sipName_SH_SpinBox_StepModifier &sipStrings_QtWidgets[15392]
#define sipNameNr_SH_ToolTipLabel_Opacity 15416
#define sipName_SH_ToolTipLabel_Opacity &sipStrings_QtWidgets[15416]
#define sipNameNr_SP_DialogYesToAllButton 15440
#define sipName_SP_DialogYesToAllButton &sipStrings_QtWidgets[15440]
#define sipNameNr_SP_TitleBarNormalButton 15464
#define sipName_SP_TitleBarNormalButton &sipStrings_QtWidgets[15464]
#define sipNameNr_SliderOrientationChange 15488
#define sipName_SliderOrientationChange &sipStrings_QtWidgets[15488]
#define sipNameNr_VerticalOvershootPolicy 15512
#define sipName_VerticalOvershootPolicy &sipStrings_QtWidgets[15512]
#define sipNameNr_cascadingSectionResizes 15536
#define sipName_cascadingSectionResizes &sipStrings_QtWidgets[15536]
#define sipNameNr_getExistingDirectoryUrl 15560
#define sipName_getExistingDirectoryUrl &sipStrings_QtWidgets[15560]
#define sipNameNr_installSceneEventFilter 15584
#define sipName_installSceneEventFilter &sipStrings_QtWidgets[15584]
#define sipNameNr_resetDefaultSectionSize 15608
#define sipName_resetDefaultSectionSize &sipStrings_QtWidgets[15608]
#define sipNameNr_resetVerticalScrollMode 15632
#define sipName_resetVerticalScrollMode &sipStrings_QtWidgets[15632]
#define sipNameNr_resizeColumnsToContents 15656
#define sipName_resizeColumnsToContents &sipStrings_QtWidgets[15656]
#define sipNameNr_resizeContentsPrecision 15680
#define sipName_resizeContentsPrecision &sipStrings_QtWidgets[15680]
#define sipNameNr_rubberBandSelectionMode 15704
#define sipName_rubberBandSelectionMode &sipStrings_QtWidgets[15704]
#define sipNameNr_sectionSizeFromContents 15728
#define sipName_sectionSizeFromContents &sipStrings_QtWidgets[15728]
#define sipNameNr_sectionViewportPosition 15752
#define sipName_sectionViewportPosition &sipStrings_QtWidgets[15752]
#define sipNameNr_setAcceptedMouseButtons 15776
#define sipName_setAcceptedMouseButtons &sipStrings_QtWidgets[15776]
#define sipNameNr_setAlternatingRowColors 15800
#define sipName_setAlternatingRowColors &sipStrings_QtWidgets[15800]
#define sipNameNr_setChildIndicatorPolicy 15824
#define sipName_setChildIndicatorPolicy &sipStrings_QtWidgets[15824]
#define sipNameNr_setColumnPreferredWidth 15848
#define sipName_setColumnPreferredWidth &sipStrings_QtWidgets[15848]
#define sipNameNr_setExpandsOnDoubleClick 15872
#define sipName_setExpandsOnDoubleClick &sipStrings_QtWidgets[15872]
#define sipNameNr_setHorizontalHeaderItem 15896
#define sipName_setHorizontalHeaderItem &sipStrings_QtWidgets[15896]
#define sipNameNr_setHorizontalScrollMode 12367
#define sipName_setHorizontalScrollMode &sipStrings_QtWidgets[12367]
#define sipNameNr_setNavigationBarVisible 15920
#define sipName_setNavigationBarVisible &sipStrings_QtWidgets[15920]
#define sipNameNr_setRetainSizeWhenHidden 15944
#define sipName_setRetainSizeWhenHidden &sipStrings_QtWidgets[15944]
#define sipNameNr_setSelectionRectVisible 15968
#define sipName_setSelectionRectVisible &sipStrings_QtWidgets[15968]
#define sipNameNr_setTextInteractionFlags 15992
#define sipName_setTextInteractionFlags &sipStrings_QtWidgets[15992]
#define sipNameNr_setTransformOriginPoint 16016
#define sipName_setTransformOriginPoint &sipStrings_QtWidgets[16016]
#define sipNameNr_setTransformationAnchor 16040
#define sipName_setTransformationAnchor &sipStrings_QtWidgets[16040]
#define sipNameNr_setVerticalHeaderFormat 16064
#define sipName_setVerticalHeaderFormat &sipStrings_QtWidgets[16064]
#define sipNameNr_setVerticalHeaderLabels 16088
#define sipName_setVerticalHeaderLabels &sipStrings_QtWidgets[16088]
#define sipNameNr_sliderPositionFromValue 16112
#define sipName_sliderPositionFromValue &sipStrings_QtWidgets[16112]
#define sipNameNr_sliderValueFromPosition 16136
#define sipName_sliderValueFromPosition &sipStrings_QtWidgets[16136]
#define sipNameNr_unsetWindowFrameMargins 16160
#define sipName_unsetWindowFrameMargins &sipStrings_QtWidgets[16160]
#define sipNameNr_verticalScrollBarPolicy 16184
#define sipName_verticalScrollBarPolicy &sipStrings_QtWidgets[16184]
#define sipNameNr_verticalScrollbarAction 16208
#define sipName_verticalScrollbarAction &sipStrings_QtWidgets[16208]
#define sipNameNr_ActivationHistoryOrder 16232
#define sipName_ActivationHistoryOrder &sipStrings_QtWidgets[16232]
#define sipNameNr_CE_ProgressBarContents 16255
#define sipName_CE_ProgressBarContents &sipStrings_QtWidgets[16255]
#define sipNameNr_CorrectToPreviousValue 16278
#define sipName_CorrectToPreviousValue &sipStrings_QtWidgets[16278]
#define sipNameNr_HorizontalHeaderFormat 1299
#define sipName_HorizontalHeaderFormat &sipStrings_QtWidgets[1299]
#define sipNameNr_ItemAcceptsInputMethod 16301
#define sipName_ItemAcceptsInputMethod &sipStrings_QtWidgets[16301]
#define sipNameNr_ItemChildRemovedChange 16324
#define sipName_ItemChildRemovedChange &sipStrings_QtWidgets[16324]
#define sipNameNr_ItemPositionHasChanged 16347
#define sipName_ItemPositionHasChanged &sipStrings_QtWidgets[16347]
#define sipNameNr_ItemRotationHasChanged 16370
#define sipName_ItemRotationHasChanged &sipStrings_QtWidgets[16370]
#define sipNameNr_ItemSelectedHasChanged 16393
#define sipName_ItemSelectedHasChanged &sipStrings_QtWidgets[16393]
#define sipNameNr_ItemStacksBehindParent 16416
#define sipName_ItemStacksBehindParent &sipStrings_QtWidgets[16416]
#define sipNameNr_LeftMouseButtonGesture 16439
#define sipName_LeftMouseButtonGesture &sipStrings_QtWidgets[16439]
#define sipNameNr_NoBackButtonOnLastPage 16462
#define sipName_NoBackButtonOnLastPage &sipStrings_QtWidgets[16462]
#define sipNameNr_PE_IndicatorArrowRight 16485
#define sipName_PE_IndicatorArrowRight &sipStrings_QtWidgets[16485]
#define sipNameNr_PM_ButtonShiftVertical 16508
#define sipName_PM_ButtonShiftVertical &sipStrings_QtWidgets[16508]
#define sipNameNr_PM_MaximumDragDistance 16531
#define sipName_PM_MaximumDragDistance &sipStrings_QtWidgets[16531]
#define sipNameNr_PM_MenuButtonIndicator 16554
#define sipName_PM_MenuButtonIndicator &sipStrings_QtWidgets[16554]
#define sipNameNr_PM_SpinBoxSliderHeight 16577
#define sipName_PM_SpinBoxSliderHeight &sipStrings_QtWidgets[16577]
#define sipNameNr_PM_ToolBarHandleExtent 16600
#define sipName_PM_ToolBarHandleExtent &sipStrings_QtWidgets[16600]
#define sipNameNr_PM_TreeViewIndentation 16623
#define sipName_PM_TreeViewIndentation &sipStrings_QtWidgets[16623]
#define sipNameNr_PadToTransparentBorder 16646
#define sipName_PadToTransparentBorder &sipStrings_QtWidgets[16646]
#define sipNameNr_QDateTimeEdit__Section 16669
#define sipName_QDateTimeEdit__Section &sipStrings_QtWidgets[16669]
#define sipNameNr_QGraphicsOpacityEffect 16692
#define sipName_QGraphicsOpacityEffect &sipStrings_QtWidgets[16692]
#define sipNameNr_QItemEditorCreatorBase 16715
#define sipName_QItemEditorCreatorBase &sipStrings_QtWidgets[16715]
#define sipNameNr_QStyle__ComplexControl 16738
#define sipName_QStyle__ComplexControl &sipStrings_QtWidgets[16738]
#define sipNameNr_QStyle__ControlElement 16761
#define sipName_QStyle__ControlElement &sipStrings_QtWidgets[16761]
#define sipNameNr_QStyle__StandardPixmap 16784
#define sipName_QStyle__StandardPixmap &sipStrings_QtWidgets[16784]
#define sipNameNr_QStyleOptionDockWidget 16807
#define sipName_QStyleOptionDockWidget &sipStrings_QtWidgets[16807]
#define sipNameNr_QStyleOptionRubberBand 16830
#define sipName_QStyleOptionRubberBand &sipStrings_QtWidgets[16830]
#define sipNameNr_QStyleOptionTabBarBase 16853
#define sipName_QStyleOptionTabBarBase &sipStrings_QtWidgets[16853]
#define sipNameNr_QStyleOptionToolButton 16876
#define sipName_QStyleOptionToolButton &sipStrings_QtWidgets[16876]
#define sipNameNr_QWizard__WizardOptions 16899
#define sipName_QWizard__WizardOptions &sipStrings_QtWidgets[16899]
#define sipNameNr_SC_TitleBarCloseButton 16922
#define sipName_SC_TitleBarCloseButton &sipStrings_QtWidgets[16922]
#define sipNameNr_SC_TitleBarShadeButton 16945
#define sipName_SC_TitleBarShadeButton &sipStrings_QtWidgets[16945]
#define sipNameNr_SE_ProgressBarContents 16968
#define sipName_SE_ProgressBarContents &sipStrings_QtWidgets[16968]
#define sipNameNr_SE_PushButtonFocusRect 16991
#define sipName_SE_PushButtonFocusRect &sipStrings_QtWidgets[16991]
#define sipNameNr_SE_RadioButtonContents 17014
#define sipName_SE_RadioButtonContents &sipStrings_QtWidgets[17014]
#define sipNameNr_SE_ShapedFrameContents 17037
#define sipName_SE_ShapedFrameContents &sipStrings_QtWidgets[17037]
#define sipNameNr_SE_TabBarTabLeftButton 17060
#define sipName_SE_TabBarTabLeftButton &sipStrings_QtWidgets[17060]
#define sipNameNr_SE_TabBarTearIndicator 17083
#define sipName_SE_TabBarTearIndicator &sipStrings_QtWidgets[17083]
#define sipNameNr_SE_TabWidgetLayoutItem 17106
#define sipName_SE_TabWidgetLayoutItem &sipStrings_QtWidgets[17106]
#define sipNameNr_SE_TabWidgetLeftCorner 17129
#define sipName_SE_TabWidgetLeftCorner &sipStrings_QtWidgets[17129]
#define sipNameNr_SH_Dial_BackgroundRole 17152
#define sipName_SH_Dial_BackgroundRole &sipStrings_QtWidgets[17152]
#define sipNameNr_SH_ItemView_ScrollMode 17175
#define sipName_SH_ItemView_ScrollMode &sipStrings_QtWidgets[17175]
#define sipNameNr_SH_Menu_KeyboardSearch 17198
#define sipName_SH_Menu_KeyboardSearch &sipStrings_QtWidgets[17198]
#define sipNameNr_SH_Menu_SloppySubMenus 17221
#define sipName_SH_Menu_SloppySubMenus &sipStrings_QtWidgets[17221]
#define sipNameNr_SH_ScrollBar_Transient 17244
#define sipName_SH_ScrollBar_Transient &sipStrings_QtWidgets[17244]
#define sipNameNr_SH_Table_GridLineColor 17267
#define sipName_SH_Table_GridLineColor &sipStrings_QtWidgets[17267]
#define sipNameNr_SH_ToolTip_WakeUpDelay 17290
#define sipName_SH_ToolTip_WakeUpDelay &sipStrings_QtWidgets[17290]
#define sipNameNr_SP_DialogDiscardButton 17313
#define sipName_SP_DialogDiscardButton &sipStrings_QtWidgets[17313]
#define sipNameNr_SP_DialogNoToAllButton 17336
#define sipName_SP_DialogNoToAllButton &sipStrings_QtWidgets[17336]
#define sipNameNr_SP_DialogSaveAllButton 17359
#define sipName_SP_DialogSaveAllButton &sipStrings_QtWidgets[17359]
#define sipNameNr_SP_FileDialogNewFolder 17382
#define sipName_SP_FileDialogNewFolder &sipStrings_QtWidgets[17382]
#define sipNameNr_SP_LineEditClearButton 17405
#define sipName_SP_LineEditClearButton &sipStrings_QtWidgets[17405]
#define sipNameNr_SP_TitleBarCloseButton 17428
#define sipName_SP_TitleBarCloseButton &sipStrings_QtWidgets[17428]
#define sipNameNr_SP_TitleBarShadeButton 17451
#define sipName_SP_TitleBarShadeButton &sipStrings_QtWidgets[17451]
#define sipNameNr_columnViewportPosition 17474
#define sipName_columnViewportPosition &sipStrings_QtWidgets[17474]
#define sipNameNr_horizontalHeaderFormat 17497
#define sipName_horizontalHeaderFormat &sipStrings_QtWidgets[17497]
#define sipNameNr_isNavigationBarVisible 17520
#define sipName_isNavigationBarVisible &sipStrings_QtWidgets[17520]
#define sipNameNr_isPersistentEditorOpen 17543
#define sipName_isPersistentEditorOpen &sipStrings_QtWidgets[17543]
#define sipNameNr_isSelectionRectVisible 17566
#define sipName_isSelectionRectVisible &sipStrings_QtWidgets[17566]
#define sipNameNr_mergeCurrentCharFormat 17589
#define sipName_mergeCurrentCharFormat &sipStrings_QtWidgets[17589]
#define sipNameNr_removeSceneEventFilter 17612
#define sipName_removeSceneEventFilter &sipStrings_QtWidgets[17612]
#define sipNameNr_resizeColumnToContents 17635
#define sipName_resizeColumnToContents &sipStrings_QtWidgets[17635]
#define sipNameNr_selectedMimeTypeFilter 17658
#define sipName_selectedMimeTypeFilter &sipStrings_QtWidgets[17658]
#define sipNameNr_setAllColumnsShowFocus 17681
#define sipName_setAllColumnsShowFocus &sipStrings_QtWidgets[17681]
#define sipNameNr_setChangeCurrentOnDrag 17704
#define sipName_setChangeCurrentOnDrag &sipStrings_QtWidgets[17704]
#define sipNameNr_setChildrenCollapsible 17727
#define sipName_setChildrenCollapsible &sipStrings_QtWidgets[17727]
#define sipNameNr_setColumnStretchFactor 17750
#define sipName_setColumnStretchFactor &sipStrings_QtWidgets[17750]
#define sipNameNr_setCornerButtonEnabled 17773
#define sipName_setCornerButtonEnabled &sipStrings_QtWidgets[17773]
#define sipNameNr_setCurrentSectionIndex 17796
#define sipName_setCurrentSectionIndex &sipStrings_QtWidgets[17796]
#define sipNameNr_setDateEditAcceptDelay 17819
#define sipName_setDateEditAcceptDelay &sipStrings_QtWidgets[17819]
#define sipNameNr_setDoubleClickInterval 17842
#define sipName_setDoubleClickInterval &sipStrings_QtWidgets[17842]
#define sipNameNr_setFirstSectionMovable 17865
#define sipName_setFirstSectionMovable &sipStrings_QtWidgets[17865]
#define sipNameNr_setGestureCancelPolicy 17888
#define sipName_setGestureCancelPolicy &sipStrings_QtWidgets[17888]
#define sipNameNr_setGroupSeparatorShown 17911
#define sipName_setGroupSeparatorShown &sipStrings_QtWidgets[17911]
#define sipNameNr_setHorizontalScrollBar 17934
#define sipName_setHorizontalScrollBar &sipStrings_QtWidgets[17934]
#define sipNameNr_setOffsetToLastSection 17957
#define sipName_setOffsetToLastSection &sipStrings_QtWidgets[17957]
#define sipNameNr_setTextBackgroundColor 17980
#define sipName_setTextBackgroundColor &sipStrings_QtWidgets[17980]
#define sipNameNr_showDecorationSelected 18003
#define sipName_showDecorationSelected &sipStrings_QtWidgets[18003]
#define sipNameNr_takeVerticalHeaderItem 18026
#define sipName_takeVerticalHeaderItem &sipStrings_QtWidgets[18026]
#define sipNameNr_toolButtonStyleChanged 18049
#define sipName_toolButtonStyleChanged &sipStrings_QtWidgets[18049]
#define sipNameNr_updateEditorGeometries 18072
#define sipName_updateEditorGeometries &sipStrings_QtWidgets[18072]
#define sipNameNr_AllDockWidgetFeatures 18095
#define sipName_AllDockWidgetFeatures &sipStrings_QtWidgets[18095]
#define sipNameNr_AllNonFixedFieldsGrow 18117
#define sipName_AllNonFixedFieldsGrow &sipStrings_QtWidgets[18117]
#define sipNameNr_CorrectToNearestValue 18139
#define sipName_CorrectToNearestValue &sipStrings_QtWidgets[18139]
#define sipNameNr_DeviceCoordinateCache 18161
#define sipName_DeviceCoordinateCache &sipStrings_QtWidgets[18161]
#define sipNameNr_DropIndicatorPosition 809
#define sipName_DropIndicatorPosition &sipStrings_QtWidgets[809]
#define sipNameNr_HideNameFilterDetails 18183
#define sipName_HideNameFilterDetails &sipStrings_QtWidgets[18183]
#define sipNameNr_ItemEnabledHasChanged 18205
#define sipName_ItemEnabledHasChanged &sipStrings_QtWidgets[18205]
#define sipNameNr_ItemOpacityHasChanged 18227
#define sipName_ItemOpacityHasChanged &sipStrings_QtWidgets[18227]
#define sipNameNr_ItemToolTipHasChanged 18249
#define sipName_ItemToolTipHasChanged &sipStrings_QtWidgets[18249]
#define sipNameNr_ItemVisibleHasChanged 18271
#define sipName_ItemVisibleHasChanged &sipStrings_QtWidgets[18271]
#define sipNameNr_MinimalViewportUpdate 18293
#define sipName_MinimalViewportUpdate &sipStrings_QtWidgets[18293]
#define sipNameNr_PE_FrameDefaultButton 18315
#define sipName_PE_FrameDefaultButton &sipStrings_QtWidgets[18315]
#define sipNameNr_PE_FrameStatusBarItem 18337
#define sipName_PE_FrameStatusBarItem &sipStrings_QtWidgets[18337]
#define sipNameNr_PE_IndicatorArrowDown 18359
#define sipName_PE_IndicatorArrowDown &sipStrings_QtWidgets[18359]
#define sipNameNr_PE_IndicatorArrowLeft 18381
#define sipName_PE_IndicatorArrowLeft &sipStrings_QtWidgets[18381]
#define sipNameNr_PE_IndicatorSpinMinus 18403
#define sipName_PE_IndicatorSpinMinus &sipStrings_QtWidgets[18403]
#define sipNameNr_PE_PanelButtonCommand 18425
#define sipName_PE_PanelButtonCommand &sipStrings_QtWidgets[18425]
#define sipNameNr_PM_ComboBoxFrameWidth 18447
#define sipName_PM_ComboBoxFrameWidth &sipStrings_QtWidgets[18447]
#define sipNameNr_PM_DefaultChildMargin 18469
#define sipName_PM_DefaultChildMargin &sipStrings_QtWidgets[18469]
#define sipNameNr_PM_LayoutBottomMargin 18491
#define sipName_PM_LayoutBottomMargin &sipStrings_QtWidgets[18491]
#define sipNameNr_PM_MenuBarItemSpacing 18513
#define sipName_PM_MenuBarItemSpacing &sipStrings_QtWidgets[18513]
#define sipNameNr_PM_MenuScrollerHeight 18535
#define sipName_PM_MenuScrollerHeight &sipStrings_QtWidgets[18535]
#define sipNameNr_PM_MessageBoxIconSize 18557
#define sipName_PM_MessageBoxIconSize &sipStrings_QtWidgets[18557]
#define sipNameNr_PM_ScrollBarSliderMin 18579
#define sipName_PM_ScrollBarSliderMin &sipStrings_QtWidgets[18579]
#define sipNameNr_PM_TitleBarButtonSize 18601
#define sipName_PM_TitleBarButtonSize &sipStrings_QtWidgets[18601]
#define sipNameNr_PM_ToolBarItemSpacing 18623
#define sipName_PM_ToolBarItemSpacing &sipStrings_QtWidgets[18623]
#define sipNameNr_QAbstractItemDelegate 18645
#define sipName_QAbstractItemDelegate &sipStrings_QtWidgets[18645]
#define sipNameNr_QBoxLayout__Direction 18667
#define sipName_QBoxLayout__Direction &sipStrings_QtWidgets[18667]
#define sipNameNr_QFileDialog__FileMode 18689
#define sipName_QFileDialog__FileMode &sipStrings_QtWidgets[18689]
#define sipNameNr_QFileDialog__ViewMode 18711
#define sipName_QFileDialog__ViewMode &sipStrings_QtWidgets[18711]
#define sipNameNr_QFormLayout__ItemRole 18733
#define sipName_QFormLayout__ItemRole &sipStrings_QtWidgets[18733]
#define sipNameNr_QGraphicsAnchorLayout 18755
#define sipName_QGraphicsAnchorLayout &sipStrings_QtWidgets[18755]
#define sipNameNr_QGraphicsLinearLayout 18777
#define sipName_QGraphicsLinearLayout &sipStrings_QtWidgets[18777]
#define sipNameNr_18799 18799
#define sipName_18799 &sipStrings_QtWidgets[18799]
#define sipNameNr_18821 18821
#define sipName_18821 &sipStrings_QtWidgets[18821]
#define sipNameNr_18843 18843
#define sipName_18843 &sipStrings_QtWidgets[18843]
#define sipNameNr_QListView__LayoutMode 18865
#define sipName_QListView__LayoutMode &sipStrings_QtWidgets[18865]
#define sipNameNr_QListView__ResizeMode 18887
#define sipName_QListView__ResizeMode &sipStrings_QtWidgets[18887]
#define sipNameNr_QMdiArea__AreaOptions 18909
#define sipName_QMdiArea__AreaOptions &sipStrings_QtWidgets[18909]
#define sipNameNr_QMdiArea__WindowOrder 18931
#define sipName_QMdiArea__WindowOrder &sipStrings_QtWidgets[18931]
#define sipNameNr_QMouseEventTransition 18953
#define sipName_QMouseEventTransition &sipStrings_QtWidgets[18953]
#define sipNameNr_QSlider__TickPosition 18975
#define sipName_QSlider__TickPosition &sipStrings_QtWidgets[18975]
#define sipNameNr_QStyleOptionFocusRect 18997
#define sipName_QStyleOptionFocusRect &sipStrings_QtWidgets[18997]
#define sipNameNr_QWizard__WizardButton 19019
#define sipName_QWizard__WizardButton &sipStrings_QtWidgets[19019]
#define sipNameNr_QWizard__WizardOption 19041
#define sipName_QWizard__WizardOption &sipStrings_QtWidgets[19041]
#define sipNameNr_QWizard__WizardPixmap 19063
#define sipName_QWizard__WizardPixmap &sipStrings_QtWidgets[19063]
#define sipNameNr_SE_CheckBoxLayoutItem 19085
#define sipName_SE_CheckBoxLayoutItem &sipStrings_QtWidgets[19085]
#define sipNameNr_SE_ComboBoxLayoutItem 19107
#define sipName_SE_ComboBoxLayoutItem &sipStrings_QtWidgets[19107]
#define sipNameNr_SE_GroupBoxLayoutItem 19129
#define sipName_SE_GroupBoxLayoutItem &sipStrings_QtWidgets[19129]
#define sipNameNr_SE_PushButtonContents 19151
#define sipName_SE_PushButtonContents &sipStrings_QtWidgets[19151]
#define sipNameNr_SE_ToolBoxTabContents 19173
#define sipName_SE_ToolBoxTabContents &sipStrings_QtWidgets[19173]
#define sipNameNr_SH_Button_FocusPolicy 19195
#define sipName_SH_Button_FocusPolicy &sipStrings_QtWidgets[19195]
#define sipNameNr_SH_DialogButtonLayout 19217
#define sipName_SH_DialogButtonLayout &sipStrings_QtWidgets[19217]
#define sipNameNr_SH_DitherDisabledText 19239
#define sipName_SH_DitherDisabledText &sipStrings_QtWidgets[19239]
#define sipNameNr_SH_Menu_FadeOutOnHide 19261
#define sipName_SH_Menu_FadeOutOnHide &sipStrings_QtWidgets[19261]
#define sipNameNr_SH_Menu_MouseTracking 19283
#define sipName_SH_Menu_MouseTracking &sipStrings_QtWidgets[19283]
#define sipNameNr_SH_Menu_SelectionWrap 19305
#define sipName_SH_Menu_SelectionWrap &sipStrings_QtWidgets[19305]
#define sipNameNr_SH_Slider_SnapToValue 19327
#define sipName_SH_Slider_SnapToValue &sipStrings_QtWidgets[19327]
#define sipNameNr_SH_TitleBar_AutoRaise 19349
#define sipName_SH_TitleBar_AutoRaise &sipStrings_QtWidgets[19349]
#define sipNameNr_SP_DialogCancelButton 19371
#define sipName_SP_DialogCancelButton &sipStrings_QtWidgets[19371]
#define sipNameNr_SP_DialogIgnoreButton 19393
#define sipName_SP_DialogIgnoreButton &sipStrings_QtWidgets[19393]
#define sipNameNr_SP_FileDialogInfoView 19415
#define sipName_SP_FileDialogInfoView &sipStrings_QtWidgets[19415]
#define sipNameNr_SP_FileDialogListView 19437
#define sipName_SP_FileDialogListView &sipStrings_QtWidgets[19437]
#define sipNameNr_SP_FileDialogToParent 19459
#define sipName_SP_FileDialogToParent &sipStrings_QtWidgets[19459]
#define sipNameNr_SP_MessageBoxCritical 19481
#define sipName_SP_MessageBoxCritical &sipStrings_QtWidgets[19481]
#define sipNameNr_SP_MessageBoxQuestion 19503
#define sipName_SP_MessageBoxQuestion &sipStrings_QtWidgets[19503]
#define sipNameNr_SP_TitleBarMenuButton 19525
#define sipName_SP_TitleBarMenuButton &sipStrings_QtWidgets[19525]
#define sipNameNr_accessibleDescription 19547
#define sipName_accessibleDescription &sipStrings_QtWidgets[19547]
#define sipNameNr_activateNextSubWindow 19569
#define sipName_activateNextSubWindow &sipStrings_QtWidgets[19569]
#define sipNameNr_blockBoundingGeometry 19591
#define sipName_blockBoundingGeometry &sipStrings_QtWidgets[19591]
#define sipNameNr_canInsertFromMimeData 19613
#define sipName_canInsertFromMimeData &sipStrings_QtWidgets[19613]
#define sipNameNr_closePersistentEditor 19635
#define sipName_closePersistentEditor &sipStrings_QtWidgets[19635]
#define sipNameNr_closestAcceptableSize 19657
#define sipName_closestAcceptableSize &sipStrings_QtWidgets[19657]
#define sipNameNr_combinedLayoutSpacing 19679
#define sipName_combinedLayoutSpacing &sipStrings_QtWidgets[19679]
#define sipNameNr_createWindowContainer 19701
#define sipName_createWindowContainer &sipStrings_QtWidgets[19701]
#define sipNameNr_cursorPositionChanged 19723
#define sipName_cursorPositionChanged &sipStrings_QtWidgets[19723]
#define sipNameNr_dragDropOverwriteMode 19745
#define sipName_dragDropOverwriteMode &sipStrings_QtWidgets[19745]
#define sipNameNr_dropIndicatorPosition 19767
#define sipName_dropIndicatorPosition &sipStrings_QtWidgets[19767]
#define sipNameNr_getWindowFrameMargins 19789
#define sipName_getWindowFrameMargins &sipStrings_QtWidgets[19789]
#define sipNameNr_hitTestComplexControl 19811
#define sipName_hitTestComplexControl &sipStrings_QtWidgets[19811]
#define sipNameNr_insertPermanentWidget 19833
#define sipName_insertPermanentWidget &sipStrings_QtWidgets[19833]
#define sipNameNr_isBlockedByModalPanel 19855
#define sipName_isBlockedByModalPanel &sipStrings_QtWidgets[19855]
#define sipNameNr_isCornerButtonEnabled 19877
#define sipName_isCornerButtonEnabled &sipStrings_QtWidgets[19877]
#define sipNameNr_isFirstSectionMovable 19899
#define sipName_isFirstSectionMovable &sipStrings_QtWidgets[19899]
#define sipNameNr_isGroupSeparatorShown 19921
#define sipName_isGroupSeparatorShown &sipStrings_QtWidgets[19921]
#define sipNameNr_isSystemTrayAvailable 19943
#define sipName_isSystemTrayAvailable &sipStrings_QtWidgets[19943]
#define sipNameNr_itemDelegateForColumn 19965
#define sipName_itemDelegateForColumn &sipStrings_QtWidgets[19965]
#define sipNameNr_keyboardInputInterval 19987
#define sipName_keyboardInputInterval &sipStrings_QtWidgets[19987]
#define sipNameNr_lineWrapColumnOrWidth 20009
#define sipName_lineWrapColumnOrWidth &sipStrings_QtWidgets[20009]
#define sipNameNr_menuHasCheckableItems 20031
#define sipName_menuHasCheckableItems &sipStrings_QtWidgets[20031]
#define sipNameNr_minimumContentsLength 20053
#define sipName_minimumContentsLength &sipStrings_QtWidgets[20053]
#define sipNameNr_minimumHeightForWidth 20075
#define sipName_minimumHeightForWidth &sipStrings_QtWidgets[20075]
#define sipNameNr_mouseDoubleClickEvent 20097
#define sipName_mouseDoubleClickEvent &sipStrings_QtWidgets[20097]
#define sipNameNr_prepareGeometryChange 20119
#define sipName_prepareGeometryChange &sipStrings_QtWidgets[20119]
#define sipNameNr_rightCornerWidgetSize 20141
#define sipName_rightCornerWidgetSize &sipStrings_QtWidgets[20141]
#define sipNameNr_separatorsCollapsible 20163
#define sipName_separatorsCollapsible &sipStrings_QtWidgets[20163]
#define sipNameNr_setAutoFillBackground 20185
#define sipName_setAutoFillBackground &sipStrings_QtWidgets[20185]
#define sipNameNr_setAutoRepeatInterval 20207
#define sipName_setAutoRepeatInterval &sipStrings_QtWidgets[20207]
#define sipNameNr_setClearButtonEnabled 20229
#define sipName_setClearButtonEnabled &sipStrings_QtWidgets[20229]
#define sipNameNr_setColumnMaximumWidth 20251
#define sipName_setColumnMaximumWidth &sipStrings_QtWidgets[20251]
#define sipNameNr_setColumnMinimumWidth 20273
#define sipName_setColumnMinimumWidth &sipStrings_QtWidgets[20273]
#define sipNameNr_setDefaultPositioning 20295
#define sipName_setDefaultPositioning &sipStrings_QtWidgets[20295]
#define sipNameNr_setDefaultSectionSize 15610
#define sipName_setDefaultSectionSize &sipStrings_QtWidgets[15610]
#define sipNameNr_setDisplayIntegerBase 20317
#define sipName_setDisplayIntegerBase &sipStrings_QtWidgets[20317]
#define sipNameNr_setDockNestingEnabled 20339
#define sipName_setDockNestingEnabled &sipStrings_QtWidgets[20339]
#define sipNameNr_setDropIndicatorShown 20361
#define sipName_setDropIndicatorShown &sipStrings_QtWidgets[20361]
#define sipNameNr_setFiltersChildEvents 20383
#define sipName_setFiltersChildEvents &sipStrings_QtWidgets[20383]
#define sipNameNr_setFirstColumnSpanned 20405
#define sipName_setFirstColumnSpanned &sipStrings_QtWidgets[20405]
#define sipNameNr_setInvertedAppearance 20427
#define sipName_setInvertedAppearance &sipStrings_QtWidgets[20427]
#define sipNameNr_setItemDelegateForRow 20449
#define sipName_setItemDelegateForRow &sipStrings_QtWidgets[20449]
#define sipNameNr_setKeyboardSingleStep 20471
#define sipName_setKeyboardSingleStep &sipStrings_QtWidgets[20471]
#define sipNameNr_setMaximumSectionSize 20493
#define sipName_setMaximumSectionSize &sipStrings_QtWidgets[20493]
#define sipNameNr_setMinimumSectionSize 20515
#define sipName_setMinimumSectionSize &sipStrings_QtWidgets[20515]
#define sipNameNr_setNameFilterDisables 20537
#define sipName_setNameFilterDisables &sipStrings_QtWidgets[20537]
#define sipNameNr_setResizeGripsVisible 20559
#define sipName_setResizeGripsVisible &sipStrings_QtWidgets[20559]
#define sipNameNr_setRowPreferredHeight 20581
#define sipName_setRowPreferredHeight &sipStrings_QtWidgets[20581]
#define sipNameNr_setScrollerProperties 20603
#define sipName_setScrollerProperties &sipStrings_QtWidgets[20603]
#define sipNameNr_setShortcutAutoRepeat 20625
#define sipName_setShortcutAutoRepeat &sipStrings_QtWidgets[20625]
#define sipNameNr_setSortIndicatorShown 20647
#define sipName_setSortIndicatorShown &sipStrings_QtWidgets[20647]
#define sipNameNr_setStretchLastSection 20669
#define sipName_setStretchLastSection &sipStrings_QtWidgets[20669]
#define sipNameNr_setTotalRotationAngle 20691
#define sipName_setTotalRotationAngle &sipStrings_QtWidgets[20691]
#define sipNameNr_setTransformationMode 20713
#define sipName_setTransformationMode &sipStrings_QtWidgets[20713]
#define sipNameNr_setVerticalHeaderItem 20735
#define sipName_setVerticalHeaderItem &sipStrings_QtWidgets[20735]
#define sipNameNr_setVerticalScrollMode 15634
#define sipName_setVerticalScrollMode &sipStrings_QtWidgets[15634]
#define sipNameNr_setViewportUpdateMode 20757
#define sipName_setViewportUpdateMode &sipStrings_QtWidgets[20757]
#define sipNameNr_setWindowFrameMargins 16162
#define sipName_setWindowFrameMargins &sipStrings_QtWidgets[16162]
#define sipNameNr_windowIconTextChanged 20779
#define sipName_windowIconTextChanged &sipStrings_QtWidgets[20779]
#define sipNameNr_CE_ProgressBarGroove 20801
#define sipName_CE_ProgressBarGroove &sipStrings_QtWidgets[20801]
#define sipNameNr_ChildIndicatorPolicy 2699
#define sipName_ChildIndicatorPolicy &sipStrings_QtWidgets[2699]
#define sipNameNr_DontConfirmOverwrite 20822
#define sipName_DontConfirmOverwrite &sipStrings_QtWidgets[20822]
#define sipNameNr_DontSavePainterState 20843
#define sipName_DontSavePainterState &sipStrings_QtWidgets[20843]
#define sipNameNr_DrawWindowBackground 20864
#define sipName_DrawWindowBackground &sipStrings_QtWidgets[20864]
#define sipNameNr_FieldsStayAtSizeHint 20885
#define sipName_FieldsStayAtSizeHint &sipStrings_QtWidgets[20885]
#define sipNameNr_InsertAlphabetically 20906
#define sipName_InsertAlphabetically &sipStrings_QtWidgets[20906]
#define sipNameNr_ItemChildAddedChange 20927
#define sipName_ItemChildAddedChange &sipStrings_QtWidgets[20927]
#define sipNameNr_ItemCursorHasChanged 20948
#define sipName_ItemCursorHasChanged &sipStrings_QtWidgets[20948]
#define sipNameNr_ItemFlagsHaveChanged 20969
#define sipName_ItemFlagsHaveChanged &sipStrings_QtWidgets[20969]
#define sipNameNr_ItemParentHasChanged 20990
#define sipName_ItemParentHasChanged &sipStrings_QtWidgets[20990]
#define sipNameNr_ItemZValueHasChanged 21011
#define sipName_ItemZValueHasChanged &sipStrings_QtWidgets[21011]
#define sipNameNr_MousePressEventDelay 21032
#define sipName_MousePressEventDelay &sipStrings_QtWidgets[21032]
#define sipNameNr_NoDockWidgetFeatures 21053
#define sipName_NoDockWidgetFeatures &sipStrings_QtWidgets[21053]
#define sipNameNr_PE_IndicatorCheckBox 21074
#define sipName_PE_IndicatorCheckBox &sipStrings_QtWidgets[21074]
#define sipNameNr_PE_IndicatorSpinDown 21095
#define sipName_PE_IndicatorSpinDown &sipStrings_QtWidgets[21095]
#define sipNameNr_PE_IndicatorSpinPlus 21116
#define sipName_PE_IndicatorSpinPlus &sipStrings_QtWidgets[21116]
#define sipNameNr_PE_IndicatorTabClose 21137
#define sipName_PE_IndicatorTabClose &sipStrings_QtWidgets[21137]
#define sipNameNr_PE_PanelItemViewItem 21158
#define sipName_PE_PanelItemViewItem &sipStrings_QtWidgets[21158]
#define sipNameNr_PM_DefaultFrameWidth 21179
#define sipName_PM_DefaultFrameWidth &sipStrings_QtWidgets[21179]
#define sipNameNr_PM_FocusFrameHMargin 21200
#define sipName_PM_FocusFrameHMargin &sipStrings_QtWidgets[21200]
#define sipNameNr_PM_FocusFrameVMargin 21221
#define sipName_PM_FocusFrameVMargin &sipStrings_QtWidgets[21221]
#define sipNameNr_PM_LayoutRightMargin 21242
#define sipName_PM_LayoutRightMargin &sipStrings_QtWidgets[21242]
#define sipNameNr_PM_MDIMinimizedWidth 21263
#define sipName_PM_MDIMinimizedWidth &sipStrings_QtWidgets[21263]
#define sipNameNr_PM_MenuBarPanelWidth 21284
#define sipName_PM_MenuBarPanelWidth &sipStrings_QtWidgets[21284]
#define sipNameNr_PM_MenuTearoffHeight 21305
#define sipName_PM_MenuTearoffHeight &sipStrings_QtWidgets[21305]
#define sipNameNr_PM_SpinBoxFrameWidth 21326
#define sipName_PM_SpinBoxFrameWidth &sipStrings_QtWidgets[21326]
#define sipNameNr_PM_TabBarBaseOverlap 21347
#define sipName_PM_TabBarBaseOverlap &sipStrings_QtWidgets[21347]
#define sipNameNr_PM_ToolBarFrameWidth 21368
#define sipName_PM_ToolBarFrameWidth &sipStrings_QtWidgets[21368]
#define sipNameNr_PM_ToolBarItemMargin 21389
#define sipName_PM_ToolBarItemMargin &sipStrings_QtWidgets[21389]
#define sipNameNr_QAction__ActionEvent 21410
#define sipName_QAction__ActionEvent &sipStrings_QtWidgets[21410]
#define sipNameNr_QFileDialog__Options 21431
#define sipName_QFileDialog__Options &sipStrings_QtWidgets[21431]
#define sipNameNr_QGraphicsEllipseItem 21452
#define sipName_QGraphicsEllipseItem &sipStrings_QtWidgets[21452]
#define sipNameNr_QGraphicsPolygonItem 21473
#define sipName_QGraphicsPolygonItem &sipStrings_QtWidgets[21473]
#define sipNameNr_QGraphicsProxyWidget 21494
#define sipName_QGraphicsProxyWidget &sipStrings_QtWidgets[21494]
#define sipNameNr_QMdiArea__AreaOption 21515
#define sipName_QMdiArea__AreaOption &sipStrings_QtWidgets[21515]
#define sipNameNr_QStyle__ContentsType 21536
#define sipName_QStyle__ContentsType &sipStrings_QtWidgets[21536]
#define sipNameNr_QStyleHintReturnMask 21557
#define sipName_QStyleHintReturnMask &sipStrings_QtWidgets[21557]
#define sipNameNr_QStyleOptionComboBox 21578
#define sipName_QStyleOptionComboBox &sipStrings_QtWidgets[21578]
#define sipNameNr_QStyleOptionGroupBox 21599
#define sipName_QStyleOptionGroupBox &sipStrings_QtWidgets[21599]
#define sipNameNr_QStyleOptionMenuItem 21620
#define sipName_QStyleOptionMenuItem &sipStrings_QtWidgets[21620]
#define sipNameNr_QStyleOptionSizeGrip 21641
#define sipName_QStyleOptionSizeGrip &sipStrings_QtWidgets[21641]
#define sipNameNr_QStyleOptionTitleBar 21662
#define sipName_QStyleOptionTitleBar &sipStrings_QtWidgets[21662]
#define sipNameNr_QStyleOptionViewItem 21683
#define sipName_QStyleOptionViewItem &sipStrings_QtWidgets[21683]
#define sipNameNr_QTabWidget__TabShape 21704
#define sipName_QTabWidget__TabShape &sipStrings_QtWidgets[21704]
#define sipNameNr_QWidget__RenderFlags 21725
#define sipName_QWidget__RenderFlags &sipStrings_QtWidgets[21725]
#define sipNameNr_QWizard__WizardStyle 21746
#define sipName_QWizard__WizardStyle &sipStrings_QtWidgets[21746]
#define sipNameNr_RotationAngleChanged 21767
#define sipName_RotationAngleChanged &sipStrings_QtWidgets[21767]
#define sipNameNr_SC_ComboBoxEditField 21788
#define sipName_SC_ComboBoxEditField &sipStrings_QtWidgets[21788]
#define sipNameNr_SC_TitleBarMaxButton 21809
#define sipName_SC_TitleBarMaxButton &sipStrings_QtWidgets[21809]
#define sipNameNr_SC_TitleBarMinButton 21830
#define sipName_SC_TitleBarMinButton &sipStrings_QtWidgets[21830]
#define sipNameNr_SE_CheckBoxClickRect 21851
#define sipName_SE_CheckBoxClickRect &sipStrings_QtWidgets[21851]
#define sipNameNr_SE_CheckBoxFocusRect 21872
#define sipName_SE_CheckBoxFocusRect &sipStrings_QtWidgets[21872]
#define sipNameNr_SE_CheckBoxIndicator 21893
#define sipName_SE_CheckBoxIndicator &sipStrings_QtWidgets[21893]
#define sipNameNr_SE_ComboBoxFocusRect 21914
#define sipName_SE_ComboBoxFocusRect &sipStrings_QtWidgets[21914]
#define sipNameNr_SE_ProgressBarGroove 21935
#define sipName_SE_ProgressBarGroove &sipStrings_QtWidgets[21935]
#define sipNameNr_SE_SpinBoxLayoutItem 21956
#define sipName_SE_SpinBoxLayoutItem &sipStrings_QtWidgets[21956]
#define sipNameNr_SH_TitleBar_NoBorder 21977
#define sipName_SH_TitleBar_NoBorder &sipStrings_QtWidgets[21977]
#define sipNameNr_SH_UnderlineShortcut 21998
#define sipName_SH_UnderlineShortcut &sipStrings_QtWidgets[21998]
#define sipNameNr_SO_ComplexCustomBase 22019
#define sipName_SO_ComplexCustomBase &sipStrings_QtWidgets[22019]
#define sipNameNr_SP_DialogAbortButton 22040
#define sipName_SP_DialogAbortButton &sipStrings_QtWidgets[22040]
#define sipNameNr_SP_DialogApplyButton 22061
#define sipName_SP_DialogApplyButton &sipStrings_QtWidgets[22061]
#define sipNameNr_SP_DialogCloseButton 22082
#define sipName_SP_DialogCloseButton &sipStrings_QtWidgets[22082]
#define sipNameNr_SP_DialogResetButton 22103
#define sipName_SP_DialogResetButton &sipStrings_QtWidgets[22103]
#define sipNameNr_SP_DialogRetryButton 22124
#define sipName_SP_DialogRetryButton &sipStrings_QtWidgets[22124]
#define sipNameNr_SP_MediaSeekBackward 22145
#define sipName_SP_MediaSeekBackward &sipStrings_QtWidgets[22145]
#define sipNameNr_SP_MediaSkipBackward 22166
#define sipName_SP_MediaSkipBackward &sipStrings_QtWidgets[22166]
#define sipNameNr_SP_MessageBoxWarning 22187
#define sipName_SP_MessageBoxWarning &sipStrings_QtWidgets[22187]
#define sipNameNr_SP_TitleBarMaxButton 22208
#define sipName_SP_TitleBarMaxButton &sipStrings_QtWidgets[22208]
#define sipNameNr_SP_TitleBarMinButton 22229
#define sipName_SP_TitleBarMinButton &sipStrings_QtWidgets[22229]
#define sipNameNr_SetDefaultConstraint 22250
#define sipName_SetDefaultConstraint &sipStrings_QtWidgets[22250]
#define sipNameNr_SingleLetterDayNames 22271
#define sipName_SingleLetterDayNames &sipStrings_QtWidgets[22271]
#define sipNameNr_VerticalHeaderFormat 2243
#define sipName_VerticalHeaderFormat &sipStrings_QtWidgets[2243]
#define sipNameNr_acceptProposedAction 22292
#define sipName_acceptProposedAction &sipStrings_QtWidgets[22292]
#define sipNameNr_acceptedMouseButtons 22313
#define sipName_acceptedMouseButtons &sipStrings_QtWidgets[22313]
#define sipNameNr_activatedAmbiguously 22334
#define sipName_activatedAmbiguously &sipStrings_QtWidgets[22334]
#define sipNameNr_alternatingRowColors 22355
#define sipName_alternatingRowColors &sipStrings_QtWidgets[22355]
#define sipNameNr_backwardHistoryCount 22376
#define sipName_backwardHistoryCount &sipStrings_QtWidgets[22376]
#define sipNameNr_childIndicatorPolicy 22397
#define sipName_childIndicatorPolicy &sipStrings_QtWidgets[22397]
#define sipNameNr_childrenBoundingRect 22418
#define sipName_childrenBoundingRect &sipStrings_QtWidgets[22418]
#define sipNameNr_clearMaximumDateTime 22439
#define sipName_clearMaximumDateTime &sipStrings_QtWidgets[22439]
#define sipNameNr_clearMinimumDateTime 22460
#define sipName_clearMinimumDateTime &sipStrings_QtWidgets[22460]
#define sipNameNr_closeActiveSubWindow 22481
#define sipName_closeActiveSubWindow &sipStrings_QtWidgets[22481]
#define sipNameNr_closestLegalPosition 22502
#define sipName_closestLegalPosition &sipStrings_QtWidgets[22502]
#define sipNameNr_columnPreferredWidth 22523
#define sipName_columnPreferredWidth &sipStrings_QtWidgets[22523]
#define sipNameNr_expandsOnDoubleClick 22544
#define sipName_expandsOnDoubleClick &sipStrings_QtWidgets[22544]
#define sipNameNr_getExistingDirectory 22565
#define sipName_getExistingDirectory &sipStrings_QtWidgets[22565]
#define sipNameNr_horizontalHeaderItem 22586
#define sipName_horizontalHeaderItem &sipStrings_QtWidgets[22586]
#define sipNameNr_horizontalScrollMode 22607
#define sipName_horizontalScrollMode &sipStrings_QtWidgets[22607]
#define sipNameNr_isClearButtonEnabled 22628
#define sipName_isClearButtonEnabled &sipStrings_QtWidgets[22628]
#define sipNameNr_isDockNestingEnabled 22649
#define sipName_isDockNestingEnabled &sipStrings_QtWidgets[22649]
#define sipNameNr_isFirstColumnSpanned 22670
#define sipName_isFirstColumnSpanned &sipStrings_QtWidgets[22670]
#define sipNameNr_isSortIndicatorShown 22691
#define sipName_isSortIndicatorShown &sipStrings_QtWidgets[22691]
#define sipNameNr_isTearOffMenuVisible 22712
#define sipName_isTearOffMenuVisible &sipStrings_QtWidgets[22712]
#define sipNameNr_itemSelectionChanged 22733
#define sipName_itemSelectionChanged &sipStrings_QtWidgets[22733]
#define sipNameNr_leftCornerWidgetSize 22754
#define sipName_leftCornerWidgetSize &sipStrings_QtWidgets[22754]
#define sipNameNr_openPersistentEditor 22775
#define sipName_openPersistentEditor &sipStrings_QtWidgets[22775]
#define sipNameNr_positionInlineObject 22796
#define sipName_positionInlineObject &sipStrings_QtWidgets[22796]
#define sipNameNr_previousInFocusChain 22817
#define sipName_previousInFocusChain &sipStrings_QtWidgets[22817]
#define sipNameNr_primaryScreenChanged 22838
#define sipName_primaryScreenChanged &sipStrings_QtWidgets[22838]
#define sipNameNr_resizeRowsToContents 22859
#define sipName_resizeRowsToContents &sipStrings_QtWidgets[22859]
#define sipNameNr_retainSizeWhenHidden 22880
#define sipName_retainSizeWhenHidden &sipStrings_QtWidgets[22880]
#define sipNameNr_rowsAboutToBeRemoved 22901
#define sipName_rowsAboutToBeRemoved &sipStrings_QtWidgets[22901]
#define sipNameNr_sectionDoubleClicked 22922
#define sipName_sectionDoubleClicked &sipStrings_QtWidgets[22922]
#define sipNameNr_selectMimeTypeFilter 22943
#define sipName_selectMimeTypeFilter &sipStrings_QtWidgets[22943]
#define sipNameNr_setAcceptHoverEvents 22964
#define sipName_setAcceptHoverEvents &sipStrings_QtWidgets[22964]
#define sipNameNr_setAcceptTouchEvents 22985
#define sipName_setAcceptTouchEvents &sipStrings_QtWidgets[22985]
#define sipNameNr_setAccessibleTabName 23006
#define sipName_setAccessibleTabName &sipStrings_QtWidgets[23006]
#define sipNameNr_setBackgroundVisible 23027
#define sipName_setBackgroundVisible &sipStrings_QtWidgets[23027]
#define sipNameNr_setContextMenuPolicy 23048
#define sipName_setContextMenuPolicy &sipStrings_QtWidgets[23048]
#define sipNameNr_setCurrentCharFormat 23069
#define sipName_setCurrentCharFormat &sipStrings_QtWidgets[23069]
#define sipNameNr_setCurrentModelIndex 23090
#define sipName_setCurrentModelIndex &sipStrings_QtWidgets[23090]
#define sipNameNr_setDefaultDropAction 23111
#define sipName_setDefaultDropAction &sipStrings_QtWidgets[23111]
#define sipNameNr_setDuplicatesEnabled 23132
#define sipName_setDuplicatesEnabled &sipStrings_QtWidgets[23132]
#define sipNameNr_setFieldGrowthPolicy 23153
#define sipName_setFieldGrowthPolicy &sipStrings_QtWidgets[23153]
#define sipNameNr_setHighlightSections 23174
#define sipName_setHighlightSections &sipStrings_QtWidgets[23174]
#define sipNameNr_setHorizontalSpacing 23195
#define sipName_setHorizontalSpacing &sipStrings_QtWidgets[23195]
#define sipNameNr_setHorizontalStretch 23216
#define sipName_setHorizontalStretch &sipStrings_QtWidgets[23216]
#define sipNameNr_setIconVisibleInMenu 23237
#define sipName_setIconVisibleInMenu &sipStrings_QtWidgets[23237]
#define sipNameNr_setItemEditorFactory 23258
#define sipName_setItemEditorFactory &sipStrings_QtWidgets[23258]
#define sipNameNr_setLastRotationAngle 23279
#define sipName_setLastRotationAngle &sipStrings_QtWidgets[23279]
#define sipNameNr_setMaximumBlockCount 23300
#define sipName_setMaximumBlockCount &sipStrings_QtWidgets[23300]
#define sipNameNr_setMinimumRenderSize 23321
#define sipName_setMinimumRenderSize &sipStrings_QtWidgets[23321]
#define sipNameNr_setOpenExternalLinks 23342
#define sipName_setOpenExternalLinks &sipStrings_QtWidgets[23342]
#define sipNameNr_setOptimizationFlags 23363
#define sipName_setOptimizationFlags &sipStrings_QtWidgets[23363]
#define sipNameNr_setSectionResizeMode 23384
#define sipName_setSectionResizeMode &sipStrings_QtWidgets[23384]
#define sipNameNr_setSectionsClickable 23405
#define sipName_setSectionsClickable &sipStrings_QtWidgets[23405]
#define sipNameNr_setSelectionBehavior 23426
#define sipName_setSelectionBehavior &sipStrings_QtWidgets[23426]
#define sipNameNr_setSmallDecimalPoint 23447
#define sipName_setSmallDecimalPoint &sipStrings_QtWidgets[23447]
#define sipNameNr_setStartDragDistance 23468
#define sipName_setStartDragDistance &sipStrings_QtWidgets[23468]
#define sipNameNr_setUniformRowHeights 23489
#define sipName_setUniformRowHeights &sipStrings_QtWidgets[23489]
#define sipNameNr_setUsesScrollButtons 23510
#define sipName_setUsesScrollButtons &sipStrings_QtWidgets[23510]
#define sipNameNr_setVerticalScrollBar 23531
#define sipName_setVerticalScrollBar &sipStrings_QtWidgets[23531]
#define sipNameNr_setWeekdayTextFormat 23552
#define sipName_setWeekdayTextFormat &sipStrings_QtWidgets[23552]
#define sipNameNr_sortIndicatorChanged 23573
#define sipName_sortIndicatorChanged &sipStrings_QtWidgets[23573]
#define sipNameNr_sortIndicatorSection 23594
#define sipName_sortIndicatorSection &sipStrings_QtWidgets[23594]
#define sipNameNr_supportedDragActions 23615
#define sipName_supportedDragActions &sipStrings_QtWidgets[23615]
#define sipNameNr_supportedDropActions 23636
#define sipName_supportedDropActions &sipStrings_QtWidgets[23636]
#define sipNameNr_textInteractionFlags 23657
#define sipName_textInteractionFlags &sipStrings_QtWidgets[23657]
#define sipNameNr_transformOriginPoint 23678
#define sipName_transformOriginPoint &sipStrings_QtWidgets[23678]
#define sipNameNr_transformationAnchor 23699
#define sipName_transformationAnchor &sipStrings_QtWidgets[23699]
#define sipNameNr_unregisterRecognizer 23720
#define sipName_unregisterRecognizer &sipStrings_QtWidgets[23720]
#define sipNameNr_unsetLayoutDirection 23741
#define sipName_unsetLayoutDirection &sipStrings_QtWidgets[23741]
#define sipNameNr_updateEditorGeometry 23762
#define sipName_updateEditorGeometry &sipStrings_QtWidgets[23762]
#define sipNameNr_verticalHeaderFormat 23783
#define sipName_verticalHeaderFormat &sipStrings_QtWidgets[23783]
#define sipNameNr_windowFrameSectionAt 23804
#define sipName_windowFrameSectionAt &sipStrings_QtWidgets[23804]
#define sipNameNr_CE_MenuBarEmptyArea 23825
#define sipName_CE_MenuBarEmptyArea &sipStrings_QtWidgets[23825]
#define sipNameNr_CE_ProgressBarLabel 23845
#define sipName_CE_ProgressBarLabel &sipStrings_QtWidgets[23845]
#define sipNameNr_CE_RadioButtonLabel 23865
#define sipName_CE_RadioButtonLabel &sipStrings_QtWidgets[23865]
#define sipNameNr_CE_ScrollBarAddLine 23885
#define sipName_CE_ScrollBarAddLine &sipStrings_QtWidgets[23885]
#define sipNameNr_CE_ScrollBarAddPage 23905
#define sipName_CE_ScrollBarAddPage &sipStrings_QtWidgets[23905]
#define sipNameNr_CE_ScrollBarSubLine 23925
#define sipName_CE_ScrollBarSubLine &sipStrings_QtWidgets[23925]
#define sipNameNr_CE_ScrollBarSubPage 23945
#define sipName_CE_ScrollBarSubPage &sipStrings_QtWidgets[23945]
#define sipNameNr_ContiguousSelection 23965
#define sipName_ContiguousSelection &sipStrings_QtWidgets[23965]
#define sipNameNr_DockWidgetFloatable 23985
#define sipName_DockWidgetFloatable &sipStrings_QtWidgets[23985]
#define sipNameNr_DontResolveSymlinks 24005
#define sipName_DontResolveSymlinks &sipStrings_QtWidgets[24005]
#define sipNameNr_DontUseNativeDialog 24025
#define sipName_DontUseNativeDialog &sipStrings_QtWidgets[24025]
#define sipNameNr_DontWatchForChanges 24045
#define sipName_DontWatchForChanges &sipStrings_QtWidgets[24045]
#define sipNameNr_ExpandingFieldsGrow 24065
#define sipName_ExpandingFieldsGrow &sipStrings_QtWidgets[24065]
#define sipNameNr_GestureCancelPolicy 7502
#define sipName_GestureCancelPolicy &sipStrings_QtWidgets[7502]
#define sipNameNr_InsertBeforeCurrent 24085
#define sipName_InsertBeforeCurrent &sipStrings_QtWidgets[24085]
#define sipNameNr_ItemCoordinateCache 24105
#define sipName_ItemCoordinateCache &sipStrings_QtWidgets[24105]
#define sipNameNr_ItemScaleHasChanged 24125
#define sipName_ItemScaleHasChanged &sipStrings_QtWidgets[24125]
#define sipNameNr_ItemSceneHasChanged 24145
#define sipName_ItemSceneHasChanged &sipStrings_QtWidgets[24145]
#define sipNameNr_ItemTransformChange 24165
#define sipName_ItemTransformChange &sipStrings_QtWidgets[24165]
#define sipNameNr_OvershootScrollTime 24185
#define sipName_OvershootScrollTime &sipStrings_QtWidgets[24185]
#define sipNameNr_PE_FrameButtonBevel 24205
#define sipName_PE_FrameButtonBevel &sipStrings_QtWidgets[24205]
#define sipNameNr_PE_IndicatorArrowUp 24225
#define sipName_PE_IndicatorArrowUp &sipStrings_QtWidgets[24225]
#define sipNameNr_PE_IndicatorTabTear 24245
#define sipName_PE_IndicatorTabTear &sipStrings_QtWidgets[24245]
#define sipNameNr_PE_PanelButtonBevel 24265
#define sipName_PE_PanelButtonBevel &sipStrings_QtWidgets[24265]
#define sipNameNr_PE_PanelItemViewRow 24285
#define sipName_PE_PanelItemViewRow &sipStrings_QtWidgets[24285]
#define sipNameNr_PM_HeaderGripMargin 24305
#define sipName_PM_HeaderGripMargin &sipStrings_QtWidgets[24305]
#define sipNameNr_PM_IconViewIconSize 24325
#define sipName_PM_IconViewIconSize &sipStrings_QtWidgets[24325]
#define sipNameNr_PM_LayoutLeftMargin 24345
#define sipName_PM_LayoutLeftMargin &sipStrings_QtWidgets[24345]
#define sipNameNr_PM_ListViewIconSize 24365
#define sipName_PM_ListViewIconSize &sipStrings_QtWidgets[24365]
#define sipNameNr_PM_TabBarBaseHeight 24385
#define sipName_PM_TabBarBaseHeight &sipStrings_QtWidgets[24385]
#define sipNameNr_PM_TabBarTabOverlap 24405
#define sipName_PM_TabBarTabOverlap &sipStrings_QtWidgets[24405]
#define sipNameNr_QAbstractScrollArea 24425
#define sipName_QAbstractScrollArea &sipStrings_QtWidgets[24425]
#define sipNameNr_QDialog__DialogCode 24445
#define sipName_QDialog__DialogCode &sipStrings_QtWidgets[24445]
#define sipNameNr_QFileDialog__Option 24465
#define sipName_QFileDialog__Option &sipStrings_QtWidgets[24465]
#define sipNameNr_QGraphicsBlurEffect 24485
#define sipName_QGraphicsBlurEffect &sipStrings_QtWidgets[24485]
#define sipNameNr_QGraphicsGridLayout 24505
#define sipName_QGraphicsGridLayout &sipStrings_QtWidgets[24505]
#define sipNameNr_QGraphicsLayoutItem 24525
#define sipName_QGraphicsLayoutItem &sipStrings_QtWidgets[24525]
#define sipNameNr_QGraphicsPixmapItem 24545
#define sipName_QGraphicsPixmapItem &sipStrings_QtWidgets[24545]
#define sipNameNr_QGraphicsSceneEvent 24565
#define sipName_QGraphicsSceneEvent &sipStrings_QtWidgets[24565]
#define sipNameNr_QKeyEventTransition 24585
#define sipName_QKeyEventTransition &sipStrings_QtWidgets[24585]
#define sipNameNr_QLineEdit__EchoMode 24605
#define sipName_QLineEdit__EchoMode &sipStrings_QtWidgets[24605]
#define sipNameNr_24625 24625
#define sipName_24625 &sipStrings_QtWidgets[24625]
#define sipNameNr_QListView__Movement 24645
#define sipName_QListView__Movement &sipStrings_QtWidgets[24645]
#define sipNameNr_QListView__ViewMode 24665
#define sipName_QListView__ViewMode &sipStrings_QtWidgets[24665]
#define sipNameNr_QScrollerProperties 24685
#define sipName_QScrollerProperties &sipStrings_QtWidgets[24685]
#define sipNameNr_QSizePolicy__Policy 24705
#define sipName_QSizePolicy__Policy &sipStrings_QtWidgets[24705]
#define sipNameNr_QStyle__PixelMetric 24725
#define sipName_QStyle__PixelMetric &sipStrings_QtWidgets[24725]
#define sipNameNr_QStyle__SubControls 24745
#define sipName_QStyle__SubControls &sipStrings_QtWidgets[24745]
#define sipNameNr_QStyleOptionComplex 24765
#define sipName_QStyleOptionComplex &sipStrings_QtWidgets[24765]
#define sipNameNr_QStyleOptionSpinBox 24785
#define sipName_QStyleOptionSpinBox &sipStrings_QtWidgets[24785]
#define sipNameNr_QStyleOptionToolBar 24805
#define sipName_QStyleOptionToolBar &sipStrings_QtWidgets[24805]
#define sipNameNr_QStyleOptionToolBox 24825
#define sipName_QStyleOptionToolBox &sipStrings_QtWidgets[24825]
#define sipNameNr_QStyledItemDelegate 24845
#define sipName_QStyledItemDelegate &sipStrings_QtWidgets[24845]
#define sipNameNr_QWidget__RenderFlag 24865
#define sipName_QWidget__RenderFlag &sipStrings_QtWidgets[24865]
#define sipNameNr_SC_GroupBoxCheckBox 24885
#define sipName_SC_GroupBoxCheckBox &sipStrings_QtWidgets[24885]
#define sipNameNr_SC_GroupBoxContents 24905
#define sipName_SC_GroupBoxContents &sipStrings_QtWidgets[24905]
#define sipNameNr_SC_ScrollBarAddLine 24925
#define sipName_SC_ScrollBarAddLine &sipStrings_QtWidgets[24925]
#define sipNameNr_SC_ScrollBarAddPage 24945
#define sipName_SC_ScrollBarAddPage &sipStrings_QtWidgets[24945]
#define sipNameNr_SC_ScrollBarSubLine 24965
#define sipName_SC_ScrollBarSubLine &sipStrings_QtWidgets[24965]
#define sipNameNr_SC_ScrollBarSubPage 24985
#define sipName_SC_ScrollBarSubPage &sipStrings_QtWidgets[24985]
#define sipNameNr_SC_SpinBoxEditField 25005
#define sipName_SC_SpinBoxEditField &sipStrings_QtWidgets[25005]
#define sipNameNr_SE_CheckBoxContents 25025
#define sipName_SE_CheckBoxContents &sipStrings_QtWidgets[25025]
#define sipNameNr_SE_ItemViewItemText 25045
#define sipName_SE_ItemViewItemText &sipStrings_QtWidgets[25045]
#define sipNameNr_SE_LineEditContents 25065
#define sipName_SE_LineEditContents &sipStrings_QtWidgets[25065]
#define sipNameNr_SE_ProgressBarLabel 25085
#define sipName_SE_ProgressBarLabel &sipStrings_QtWidgets[25085]
#define sipNameNr_SE_SliderLayoutItem 25105
#define sipName_SE_SliderLayoutItem &sipStrings_QtWidgets[25105]
#define sipNameNr_SE_TabWidgetTabPane 25125
#define sipName_SE_TabWidgetTabPane &sipStrings_QtWidgets[25125]
#define sipNameNr_SH_EtchDisabledText 25145
#define sipName_SH_EtchDisabledText &sipStrings_QtWidgets[25145]
#define sipNameNr_SH_TabBar_Alignment 25165
#define sipName_SH_TabBar_Alignment &sipStrings_QtWidgets[25165]
#define sipNameNr_SH_TabBar_ElideMode 25185
#define sipName_SH_TabBar_ElideMode &sipStrings_QtWidgets[25185]
#define sipNameNr_SH_WindowFrame_Mask 25205
#define sipName_SH_WindowFrame_Mask &sipStrings_QtWidgets[25205]
#define sipNameNr_SP_DialogHelpButton 25225
#define sipName_SP_DialogHelpButton &sipStrings_QtWidgets[25225]
#define sipNameNr_SP_DialogOpenButton 25245
#define sipName_SP_DialogOpenButton &sipStrings_QtWidgets[25245]
#define sipNameNr_SP_DialogSaveButton 25265
#define sipName_SP_DialogSaveButton &sipStrings_QtWidgets[25265]
#define sipNameNr_SP_MediaSeekForward 25285
#define sipName_SP_MediaSeekForward &sipStrings_QtWidgets[25285]
#define sipNameNr_SP_MediaSkipForward 25305
#define sipName_SP_MediaSkipForward &sipStrings_QtWidgets[25305]
#define sipNameNr_SP_MediaVolumeMuted 25325
#define sipName_SP_MediaVolumeMuted &sipStrings_QtWidgets[25325]
#define sipNameNr_ScrollerGestureType 6649
#define sipName_ScrollerGestureType &sipStrings_QtWidgets[6649]
#define sipNameNr_SliderSingleStepAdd 25345
#define sipName_SliderSingleStepAdd &sipStrings_QtWidgets[25345]
#define sipNameNr_SliderSingleStepSub 25365
#define sipName_SliderSingleStepSub &sipStrings_QtWidgets[25365]
#define sipNameNr_SmartViewportUpdate 25385
#define sipName_SmartViewportUpdate &sipStrings_QtWidgets[25385]
#define sipNameNr_State_FocusAtBorder 25405
#define sipName_State_FocusAtBorder &sipStrings_QtWidgets[25405]
#define sipNameNr_ToolButtonPopupMode 5223
#define sipName_ToolButtonPopupMode &sipStrings_QtWidgets[5223]
#define sipNameNr_allColumnsShowFocus 25425
#define sipName_allColumnsShowFocus &sipStrings_QtWidgets[25425]
#define sipNameNr_allowedAreasChanged 25445
#define sipName_allowedAreasChanged &sipStrings_QtWidgets[25445]
#define sipNameNr_buttonDownScreenPos 25465
#define sipName_buttonDownScreenPos &sipStrings_QtWidgets[25465]
#define sipNameNr_changeCurrentOnDrag 25485
#define sipName_changeCurrentOnDrag &sipStrings_QtWidgets[25485]
#define sipNameNr_childrenCollapsible 25505
#define sipName_childrenCollapsible &sipStrings_QtWidgets[25505]
#define sipNameNr_columnStretchFactor 25525
#define sipName_columnStretchFactor &sipStrings_QtWidgets[25525]
#define sipNameNr_currentColorChanged 25545
#define sipName_currentColorChanged &sipStrings_QtWidgets[25545]
#define sipNameNr_currentIndexChanged 25565
#define sipName_currentIndexChanged &sipStrings_QtWidgets[25565]
#define sipNameNr_currentSectionIndex 25585
#define sipName_currentSectionIndex &sipStrings_QtWidgets[25585]
#define sipNameNr_customButtonClicked 25605
#define sipName_customButtonClicked &sipStrings_QtWidgets[25605]
#define sipNameNr_dateEditAcceptDelay 25625
#define sipName_dateEditAcceptDelay &sipStrings_QtWidgets[25625]
#define sipNameNr_decorationAlignment 25645
#define sipName_decorationAlignment &sipStrings_QtWidgets[25645]
#define sipNameNr_directoryUrlEntered 25665
#define sipName_directoryUrlEntered &sipStrings_QtWidgets[25665]
#define sipNameNr_dockLocationChanged 25685
#define sipName_dockLocationChanged &sipStrings_QtWidgets[25685]
#define sipNameNr_doubleClickInterval 25705
#define sipName_doubleClickInterval &sipStrings_QtWidgets[25705]
#define sipNameNr_doubleValueSelected 25725
#define sipName_doubleValueSelected &sipStrings_QtWidgets[25725]
#define sipNameNr_ensureCursorVisible 25745
#define sipName_ensureCursorVisible &sipStrings_QtWidgets[25745]
#define sipNameNr_ensureWidgetVisible 25765
#define sipName_ensureWidgetVisible &sipStrings_QtWidgets[25765]
#define sipNameNr_expandingDirections 25785
#define sipName_expandingDirections &sipStrings_QtWidgets[25785]
#define sipNameNr_forwardHistoryCount 25805
#define sipName_forwardHistoryCount &sipStrings_QtWidgets[25805]
#define sipNameNr_generatedIconPixmap 25825
#define sipName_generatedIconPixmap &sipStrings_QtWidgets[25825]
#define sipNameNr_gestureCancelPolicy 25845
#define sipName_gestureCancelPolicy &sipStrings_QtWidgets[25845]
#define sipNameNr_graphicsProxyWidget 25865
#define sipName_graphicsProxyWidget &sipStrings_QtWidgets[25865]
#define sipNameNr_horizontalDirection 25885
#define sipName_horizontalDirection &sipStrings_QtWidgets[25885]
#define sipNameNr_horizontalScrollBar 25905
#define sipName_horizontalScrollBar &sipStrings_QtWidgets[25905]
#define sipNameNr_indexOfTopLevelItem 25925
#define sipName_indexOfTopLevelItem &sipStrings_QtWidgets[25925]
#define sipNameNr_insertTopLevelItems 25945
#define sipName_insertTopLevelItems &sipStrings_QtWidgets[25945]
#define sipNameNr_isBackwardAvailable 25965
#define sipName_isBackwardAvailable &sipStrings_QtWidgets[25965]
#define sipNameNr_isIconVisibleInMenu 25985
#define sipName_isIconVisibleInMenu &sipStrings_QtWidgets[25985]
#define sipNameNr_maximumViewportSize 26005
#define sipName_maximumViewportSize &sipStrings_QtWidgets[26005]
#define sipNameNr_modificationChanged 26025
#define sipName_modificationChanged &sipStrings_QtWidgets[26025]
#define sipNameNr_overrideWindowFlags 26045
#define sipName_overrideWindowFlags &sipStrings_QtWidgets[26045]
#define sipNameNr_overrideWindowState 26065
#define sipName_overrideWindowState &sipStrings_QtWidgets[26065]
#define sipNameNr_resizeRowToContents 26085
#define sipName_resizeRowToContents &sipStrings_QtWidgets[26085]
#define sipNameNr_rowViewportPosition 26105
#define sipName_rowViewportPosition &sipStrings_QtWidgets[26105]
#define sipNameNr_sectionCountChanged 26125
#define sipName_sectionCountChanged &sipStrings_QtWidgets[26125]
#define sipNameNr_setAutoScrollMargin 26145
#define sipName_setAutoScrollMargin &sipStrings_QtWidgets[26145]
#define sipNameNr_setCancelButtonText 26165
#define sipName_setCancelButtonText &sipStrings_QtWidgets[26165]
#define sipNameNr_setColumnFixedWidth 26185
#define sipName_setColumnFixedWidth &sipStrings_QtWidgets[26185]
#define sipNameNr_setComboBoxEditable 26205
#define sipName_setComboBoxEditable &sipStrings_QtWidgets[26205]
#define sipNameNr_setCompletionColumn 26225
#define sipName_setCompletionColumn &sipStrings_QtWidgets[26225]
#define sipNameNr_setCompletionPrefix 26245
#define sipName_setCompletionPrefix &sipStrings_QtWidgets[26245]
#define sipNameNr_setDefaultAlignment 26265
#define sipName_setDefaultAlignment &sipStrings_QtWidgets[26265]
#define sipNameNr_setDefaultTextColor 26285
#define sipName_setDefaultTextColor &sipStrings_QtWidgets[26285]
#define sipNameNr_setHeaderTextFormat 26305
#define sipName_setHeaderTextFormat &sipStrings_QtWidgets[26305]
#define sipNameNr_setHorizontalHeader 26325
#define sipName_setHorizontalHeader &sipStrings_QtWidgets[26325]
#define sipNameNr_setHorizontalPolicy 26345
#define sipName_setHorizontalPolicy &sipStrings_QtWidgets[26345]
#define sipNameNr_setInputMethodHints 26365
#define sipName_setInputMethodHints &sipStrings_QtWidgets[26365]
#define sipNameNr_setInvertedControls 26385
#define sipName_setInvertedControls &sipStrings_QtWidgets[26385]
#define sipNameNr_setKeyboardPageStep 26405
#define sipName_setKeyboardPageStep &sipStrings_QtWidgets[26405]
#define sipNameNr_setKeyboardTracking 26425
#define sipName_setKeyboardTracking &sipStrings_QtWidgets[26425]
#define sipNameNr_setOptimizationFlag 26445
#define sipName_setOptimizationFlag &sipStrings_QtWidgets[26445]
#define sipNameNr_setParentLayoutItem 26465
#define sipName_setParentLayoutItem &sipStrings_QtWidgets[26465]
#define sipNameNr_setPositionForIndex 26485
#define sipName_setPositionForIndex &sipStrings_QtWidgets[26485]
#define sipNameNr_setRowMaximumHeight 26505
#define sipName_setRowMaximumHeight &sipStrings_QtWidgets[26505]
#define sipNameNr_setRowMinimumHeight 26525
#define sipName_setRowMinimumHeight &sipStrings_QtWidgets[26525]
#define sipNameNr_setRowStretchFactor 26545
#define sipName_setRowStretchFactor &sipStrings_QtWidgets[26545]
#define sipNameNr_setSizeAdjustPolicy 26565
#define sipName_setSizeAdjustPolicy &sipStrings_QtWidgets[26565]
#define sipNameNr_setSpecialValueText 26585
#define sipName_setSpecialValueText &sipStrings_QtWidgets[26585]
#define sipNameNr_setStartCenterPoint 26605
#define sipName_setStartCenterPoint &sipStrings_QtWidgets[26605]
#define sipNameNr_setSupportedSchemes 26625
#define sipName_setSupportedSchemes &sipStrings_QtWidgets[26625]
#define sipNameNr_setTabKeyNavigation 26645
#define sipName_setTabKeyNavigation &sipStrings_QtWidgets[26645]
#define sipNameNr_setTotalChangeFlags 26665
#define sipName_setTotalChangeFlags &sipStrings_QtWidgets[26665]
#define sipNameNr_setTotalScaleFactor 26685
#define sipName_setTotalScaleFactor &sipStrings_QtWidgets[26685]
#define sipNameNr_setUniformItemSizes 26705
#define sipName_setUniformItemSizes &sipStrings_QtWidgets[26705]
#define sipNameNr_setWheelScrollLines 26725
#define sipName_setWheelScrollLines &sipStrings_QtWidgets[26725]
#define sipNameNr_stretchSectionCount 26745
#define sipName_stretchSectionCount &sipStrings_QtWidgets[26745]
#define sipNameNr_tabBarDoubleClicked 26765
#define sipName_tabBarDoubleClicked &sipStrings_QtWidgets[26765]
#define sipNameNr_tabifiedDockWidgets 26785
#define sipName_tabifiedDockWidgets &sipStrings_QtWidgets[26785]
#define sipNameNr_textBackgroundColor 26805
#define sipName_textBackgroundColor &sipStrings_QtWidgets[26805]
#define sipNameNr_totalHeightForWidth 26825
#define sipName_totalHeightForWidth &sipStrings_QtWidgets[26825]
#define sipNameNr_ungrabKeyboardEvent 26845
#define sipName_ungrabKeyboardEvent &sipStrings_QtWidgets[26845]
#define sipNameNr_updatePreviewWidget 26865
#define sipName_updatePreviewWidget &sipStrings_QtWidgets[26865]
#define sipNameNr_validateCurrentPage 26885
#define sipName_validateCurrentPage &sipStrings_QtWidgets[26885]
#define sipNameNr_windowFrameGeometry 26905
#define sipName_windowFrameGeometry &sipStrings_QtWidgets[26905]
#define sipNameNr_AutoFormattingFlag 7713
#define sipName_AutoFormattingFlag &sipStrings_QtWidgets[7713]
#define sipNameNr_CE_DockWidgetTitle 26925
#define sipName_CE_DockWidgetTitle &sipStrings_QtWidgets[26925]
#define sipNameNr_CE_HeaderEmptyArea 26944
#define sipName_CE_HeaderEmptyArea &sipStrings_QtWidgets[26944]
#define sipNameNr_CE_PushButtonBevel 26963
#define sipName_CE_PushButtonBevel &sipStrings_QtWidgets[26963]
#define sipNameNr_CE_PushButtonLabel 26982
#define sipName_CE_PushButtonLabel &sipStrings_QtWidgets[26982]
#define sipNameNr_CE_ScrollBarSlider 27001
#define sipName_CE_ScrollBarSlider &sipStrings_QtWidgets[27001]
#define sipNameNr_CE_ToolBoxTabLabel 27020
#define sipName_CE_ToolBoxTabLabel &sipStrings_QtWidgets[27020]
#define sipNameNr_CE_ToolBoxTabShape 27039
#define sipName_CE_ToolBoxTabShape &sipStrings_QtWidgets[27039]
#define sipNameNr_CE_ToolButtonLabel 27058
#define sipName_CE_ToolButtonLabel &sipStrings_QtWidgets[27058]
#define sipNameNr_CancelAllInContext 27077
#define sipName_CancelAllInContext &sipStrings_QtWidgets[27077]
#define sipNameNr_CancelButtonOnLeft 27096
#define sipName_CancelButtonOnLeft &sipStrings_QtWidgets[27096]
#define sipNameNr_CenterPointChanged 27115
#define sipName_CenterPointChanged &sipStrings_QtWidgets[27115]
#define sipNameNr_ColorDialogOptions 4861
#define sipName_ColorDialogOptions &sipStrings_QtWidgets[4861]
#define sipNameNr_DecelerationFactor 27134
#define sipName_DecelerationFactor &sipStrings_QtWidgets[27134]
#define sipNameNr_DockWidgetClosable 27153
#define sipName_DockWidgetClosable &sipStrings_QtWidgets[27153]
#define sipNameNr_DockWidgetFeatures 5612
#define sipName_DockWidgetFeatures &sipStrings_QtWidgets[5612]
#define sipNameNr_DragSelectingState 27172
#define sipName_DragSelectingState &sipStrings_QtWidgets[27172]
#define sipNameNr_FullViewportUpdate 27191
#define sipName_FullViewportUpdate &sipStrings_QtWidgets[27191]
#define sipNameNr_GraphicsItemChange 4286
#define sipName_GraphicsItemChange &sipStrings_QtWidgets[4286]
#define sipNameNr_HeuristicMaskShape 27210
#define sipName_HeuristicMaskShape &sipStrings_QtWidgets[27210]
#define sipNameNr_InputDialogOptions 4993
#define sipName_InputDialogOptions &sipStrings_QtWidgets[4993]
#define sipNameNr_InsertAfterCurrent 27229
#define sipName_InsertAfterCurrent &sipStrings_QtWidgets[27229]
#define sipNameNr_ItemPositionChange 27248
#define sipName_ItemPositionChange &sipStrings_QtWidgets[27248]
#define sipNameNr_ItemRotationChange 27267
#define sipName_ItemRotationChange &sipStrings_QtWidgets[27267]
#define sipNameNr_ItemSelectedChange 27286
#define sipName_ItemSelectedChange &sipStrings_QtWidgets[27286]
#define sipNameNr_NoHorizontalHeader 27305
#define sipName_NoHorizontalHeader &sipStrings_QtWidgets[27305]
#define sipNameNr_OvershootAlwaysOff 27324
#define sipName_OvershootAlwaysOff &sipStrings_QtWidgets[27324]
#define sipNameNr_PE_FrameButtonTool 27343
#define sipName_PE_FrameButtonTool &sipStrings_QtWidgets[27343]
#define sipNameNr_PE_FrameDockWidget 27362
#define sipName_PE_FrameDockWidget &sipStrings_QtWidgets[27362]
#define sipNameNr_PE_FrameTabBarBase 27381
#define sipName_PE_FrameTabBarBase &sipStrings_QtWidgets[27381]
#define sipNameNr_PE_IndicatorBranch 27400
#define sipName_PE_IndicatorBranch &sipStrings_QtWidgets[27400]
#define sipNameNr_PE_IndicatorSpinUp 27419
#define sipName_PE_IndicatorSpinUp &sipStrings_QtWidgets[27419]
#define sipNameNr_PE_PanelButtonTool 27438
#define sipName_PE_PanelButtonTool &sipStrings_QtWidgets[27438]
#define sipNameNr_PM_IndicatorHeight 27457
#define sipName_PM_IndicatorHeight &sipStrings_QtWidgets[27457]
#define sipNameNr_PM_LayoutTopMargin 27476
#define sipName_PM_LayoutTopMargin &sipStrings_QtWidgets[27476]
#define sipNameNr_PM_ScrollBarExtent 27495
#define sipName_PM_ScrollBarExtent &sipStrings_QtWidgets[27495]
#define sipNameNr_PM_SliderThickness 27514
#define sipName_PM_SliderThickness &sipStrings_QtWidgets[27514]
#define sipNameNr_PM_TabBarTabHSpace 27533
#define sipName_PM_TabBarTabHSpace &sipStrings_QtWidgets[27533]
#define sipNameNr_PM_TabBarTabVSpace 27552
#define sipName_PM_TabBarTabVSpace &sipStrings_QtWidgets[27552]
#define sipNameNr_PM_TextCursorWidth 27571
#define sipName_PM_TextCursorWidth &sipStrings_QtWidgets[27571]
#define sipNameNr_PM_ToolBarIconSize 27590
#define sipName_PM_ToolBarIconSize &sipStrings_QtWidgets[27590]
#define sipNameNr_PasswordEchoOnEdit 27609
#define sipName_PasswordEchoOnEdit &sipStrings_QtWidgets[27609]
#define sipNameNr_PreviousIsSelected 27628
#define sipName_PreviousIsSelected &sipStrings_QtWidgets[27628]
#define sipNameNr_QCommandLinkButton 27647
#define sipName_QCommandLinkButton &sipStrings_QtWidgets[27647]
#define sipNameNr_QGestureRecognizer 27666
#define sipName_QGestureRecognizer &sipStrings_QtWidgets[27666]
#define sipNameNr_QGraphicsItemGroup 27685
#define sipName_QGraphicsItemGroup &sipStrings_QtWidgets[27685]
#define sipNameNr_QGraphicsTransform 27704
#define sipName_QGraphicsTransform &sipStrings_QtWidgets[27704]
#define sipNameNr_QItemEditorFactory 27723
#define sipName_QItemEditorFactory &sipStrings_QtWidgets[27723]
#define sipNameNr_27742 27742
#define sipName_27742 &sipStrings_QtWidgets[27742]
#define sipNameNr_QMdiArea__ViewMode 27761
#define sipName_QMdiArea__ViewMode &sipStrings_QtWidgets[27761]
#define sipNameNr_QRubberBand__Shape 27780
#define sipName_QRubberBand__Shape &sipStrings_QtWidgets[27780]
#define sipNameNr_QStyle__SubControl 27799
#define sipName_QStyle__SubControl &sipStrings_QtWidgets[27799]
#define sipNameNr_QStyle__SubElement 27818
#define sipName_QStyle__SubElement &sipStrings_QtWidgets[27818]
#define sipNameNr_QStyleOptionButton 27837
#define sipName_QStyleOptionButton &sipStrings_QtWidgets[27837]
#define sipNameNr_QStyleOptionHeader 27856
#define sipName_QStyleOptionHeader &sipStrings_QtWidgets[27856]
#define sipNameNr_QStyleOptionSlider 27875
#define sipName_QStyleOptionSlider &sipStrings_QtWidgets[27875]
#define sipNameNr_QTapAndHoldGesture 27894
#define sipName_QTapAndHoldGesture &sipStrings_QtWidgets[27894]
#define sipNameNr_SC_MdiNormalButton 27913
#define sipName_SC_MdiNormalButton &sipStrings_QtWidgets[27913]
#define sipNameNr_SC_ScrollBarGroove 27932
#define sipName_SC_ScrollBarGroove &sipStrings_QtWidgets[27932]
#define sipNameNr_SC_ScrollBarSlider 27951
#define sipName_SC_ScrollBarSlider &sipStrings_QtWidgets[27951]
#define sipNameNr_SC_SliderTickmarks 27970
#define sipName_SC_SliderTickmarks &sipStrings_QtWidgets[27970]
#define sipNameNr_SC_TitleBarSysMenu 27989
#define sipName_SC_TitleBarSysMenu &sipStrings_QtWidgets[27989]
#define sipNameNr_SE_FrameLayoutItem 28008
#define sipName_SE_FrameLayoutItem &sipStrings_QtWidgets[28008]
#define sipNameNr_SE_LabelLayoutItem 28027
#define sipName_SE_LabelLayoutItem &sipStrings_QtWidgets[28027]
#define sipNameNr_SE_PushButtonBevel 28046
#define sipName_SE_PushButtonBevel &sipStrings_QtWidgets[28046]
#define sipNameNr_SE_SliderFocusRect 28065
#define sipName_SE_SliderFocusRect &sipStrings_QtWidgets[28065]
#define sipNameNr_SE_TabWidgetTabBar 28084
#define sipName_SE_TabWidgetTabBar &sipStrings_QtWidgets[28084]
#define sipNameNr_SH_FocusFrame_Mask 28103
#define sipName_SH_FocusFrame_Mask &sipStrings_QtWidgets[28103]
#define sipNameNr_SH_Menu_Scrollable 28122
#define sipName_SH_Menu_Scrollable &sipStrings_QtWidgets[28122]
#define sipNameNr_SH_RubberBand_Mask 28141
#define sipName_SH_RubberBand_Mask &sipStrings_QtWidgets[28141]
#define sipNameNr_SH_ToolBar_Movable 28160
#define sipName_SH_ToolBar_Movable &sipStrings_QtWidgets[28160]
#define sipNameNr_SH_ToolButtonStyle 28179
#define sipName_SH_ToolButtonStyle &sipStrings_QtWidgets[28179]
#define sipNameNr_SP_DialogYesButton 28198
#define sipName_SP_DialogYesButton &sipStrings_QtWidgets[28198]
#define sipNameNr_SP_DirLinkOpenIcon 28217
#define sipName_SP_DirLinkOpenIcon &sipStrings_QtWidgets[28217]
#define sipNameNr_SP_FileDialogStart 28236
#define sipName_SP_FileDialogStart &sipStrings_QtWidgets[28236]
#define sipNameNr_ScaleFactorChanged 28255
#define sipName_ScaleFactorChanged &sipStrings_QtWidgets[28255]
#define sipNameNr_StyleOptionVersion 78
#define sipName_StyleOptionVersion &sipStrings_QtWidgets[78]
#define sipNameNr_ToolButtonFeatures 603
#define sipName_ToolButtonFeatures &sipStrings_QtWidgets[603]
#define sipNameNr_ViewportUpdateMode 4320
#define sipName_ViewportUpdateMode &sipStrings_QtWidgets[4320]
#define sipNameNr_activeStackChanged 28274
#define sipName_activeStackChanged &sipStrings_QtWidgets[28274]
#define sipNameNr_addChildLayoutItem 28293
#define sipName_addChildLayoutItem &sipStrings_QtWidgets[28293]
#define sipNameNr_addPermanentWidget 28312
#define sipName_addPermanentWidget &sipStrings_QtWidgets[28312]
#define sipNameNr_addScrollBarWidget 28331
#define sipName_addScrollBarWidget &sipStrings_QtWidgets[28331]
#define sipNameNr_autoFillBackground 28350
#define sipName_autoFillBackground &sipStrings_QtWidgets[28350]
#define sipNameNr_autoRepeatInterval 28369
#define sipName_autoRepeatInterval &sipStrings_QtWidgets[28369]
#define sipNameNr_buttonDownScenePos 28388
#define sipName_buttonDownScenePos &sipStrings_QtWidgets[28388]
#define sipNameNr_clearPropertyFlags 28407
#define sipName_clearPropertyFlags &sipStrings_QtWidgets[28407]
#define sipNameNr_closeAllSubWindows 28426
#define sipName_closeAllSubWindows &sipStrings_QtWidgets[28426]
#define sipNameNr_columnCountChanged 28445
#define sipName_columnCountChanged &sipStrings_QtWidgets[28445]
#define sipNameNr_columnMaximumWidth 28464
#define sipName_columnMaximumWidth &sipStrings_QtWidgets[28464]
#define sipNameNr_columnMinimumWidth 28483
#define sipName_columnMinimumWidth &sipStrings_QtWidgets[28483]
#define sipNameNr_commonAncestorItem 28502
#define sipName_commonAncestorItem &sipStrings_QtWidgets[28502]
#define sipNameNr_currentCellChanged 28521
#define sipName_currentCellChanged &sipStrings_QtWidgets[28521]
#define sipNameNr_currentFontChanged 28540
#define sipName_currentFontChanged &sipStrings_QtWidgets[28540]
#define sipNameNr_currentItemChanged 28559
#define sipName_currentItemChanged &sipStrings_QtWidgets[28559]
#define sipNameNr_currentPageChanged 28578
#define sipName_currentPageChanged &sipStrings_QtWidgets[28578]
#define sipNameNr_currentTextChanged 28597
#define sipName_currentTextChanged &sipStrings_QtWidgets[28597]
#define sipNameNr_cursorWordBackward 28616
#define sipName_cursorWordBackward &sipStrings_QtWidgets[28616]
#define sipNameNr_decorationPosition 28635
#define sipName_decorationPosition &sipStrings_QtWidgets[28635]
#define sipNameNr_defaultSectionSize 28654
#define sipName_defaultSectionSize &sipStrings_QtWidgets[28654]
#define sipNameNr_displayIntegerBase 28673
#define sipName_displayIntegerBase &sipStrings_QtWidgets[28673]
#define sipNameNr_doubleValueChanged 28692
#define sipName_doubleValueChanged &sipStrings_QtWidgets[28692]
#define sipNameNr_drawComplexControl 28711
#define sipName_drawComplexControl &sipStrings_QtWidgets[28711]
#define sipNameNr_enterWhatsThisMode 28730
#define sipName_enterWhatsThisMode &sipStrings_QtWidgets[28730]
#define sipNameNr_filtersChildEvents 28749
#define sipName_filtersChildEvents &sipStrings_QtWidgets[28749]
#define sipNameNr_focusNextPrevChild 28768
#define sipName_focusNextPrevChild &sipStrings_QtWidgets[28768]
#define sipNameNr_focusPreviousChild 28787
#define sipName_focusPreviousChild &sipStrings_QtWidgets[28787]
#define sipNameNr_getContentsMargins 28806
#define sipName_getContentsMargins &sipStrings_QtWidgets[28806]
#define sipNameNr_hasAcceptableInput 28825
#define sipName_hasAcceptableInput &sipStrings_QtWidgets[28825]
#define sipNameNr_hiddenSectionCount 28844
#define sipName_hiddenSectionCount &sipStrings_QtWidgets[28844]
#define sipNameNr_initializeSections 28863
#define sipName_initializeSections &sipStrings_QtWidgets[28863]
#define sipNameNr_insertFromMimeData 28882
#define sipName_insertFromMimeData &sipStrings_QtWidgets[28882]
#define sipNameNr_insertToolBarBreak 28901
#define sipName_insertToolBarBreak &sipStrings_QtWidgets[28901]
#define sipNameNr_insertTopLevelItem 28920
#define sipName_insertTopLevelItem &sipStrings_QtWidgets[28920]
#define sipNameNr_invertedAppearance 28939
#define sipName_invertedAppearance &sipStrings_QtWidgets[28939]
#define sipNameNr_isComboBoxEditable 28958
#define sipName_isComboBoxEditable &sipStrings_QtWidgets[28958]
#define sipNameNr_isForwardAvailable 28977
#define sipName_isForwardAvailable &sipStrings_QtWidgets[28977]
#define sipNameNr_itemDelegateForRow 28996
#define sipName_itemDelegateForRow &sipStrings_QtWidgets[28996]
#define sipNameNr_keySequenceChanged 29015
#define sipName_keySequenceChanged &sipStrings_QtWidgets[29015]
#define sipNameNr_keyboardSingleStep 29034
#define sipName_keyboardSingleStep &sipStrings_QtWidgets[29034]
#define sipNameNr_leaveWhatsThisMode 29053
#define sipName_leaveWhatsThisMode &sipStrings_QtWidgets[29053]
#define sipNameNr_mapToGraphicsScene 29072
#define sipName_mapToGraphicsScene &sipStrings_QtWidgets[29072]
#define sipNameNr_mappedPropertyName 29091
#define sipName_mappedPropertyName &sipStrings_QtWidgets[29091]
#define sipNameNr_maximumSectionSize 29110
#define sipName_maximumSectionSize &sipStrings_QtWidgets[29110]
#define sipNameNr_minimumSectionSize 29129
#define sipName_minimumSectionSize &sipStrings_QtWidgets[29129]
#define sipNameNr_minimumTabSizeHint 29148
#define sipName_minimumTabSizeHint &sipStrings_QtWidgets[29148]
#define sipNameNr_nameFilterDisables 29167
#define sipName_nameFilterDisables &sipStrings_QtWidgets[29167]
#define sipNameNr_nativeParentWidget 29186
#define sipName_nativeParentWidget &sipStrings_QtWidgets[29186]
#define sipNameNr_opacityMaskChanged 29205
#define sipName_opacityMaskChanged &sipStrings_QtWidgets[29205]
#define sipNameNr_orientationChanged 29224
#define sipName_orientationChanged &sipStrings_QtWidgets[29224]
#define sipNameNr_positionWithinLine 29243
#define sipName_positionWithinLine &sipStrings_QtWidgets[29243]
#define sipNameNr_registerRecognizer 23722
#define sipName_registerRecognizer &sipStrings_QtWidgets[23722]
#define sipNameNr_removeToolBarBreak 29262
#define sipName_removeToolBarBreak &sipStrings_QtWidgets[29262]
#define sipNameNr_resendPrepareEvent 29281
#define sipName_resendPrepareEvent &sipStrings_QtWidgets[29281]
#define sipNameNr_resetCachedContent 29300
#define sipName_resetCachedContent &sipStrings_QtWidgets[29300]
#define sipNameNr_resizeGripsVisible 29319
#define sipName_resizeGripsVisible &sipStrings_QtWidgets[29319]
#define sipNameNr_resizeInlineObject 29338
#define sipName_resizeInlineObject &sipStrings_QtWidgets[29338]
#define sipNameNr_rowPreferredHeight 29357
#define sipName_rowPreferredHeight &sipStrings_QtWidgets[29357]
#define sipNameNr_screenCountChanged 29376
#define sipName_screenCountChanged &sipStrings_QtWidgets[29376]
#define sipNameNr_scrollerProperties 29395
#define sipName_scrollerProperties &sipStrings_QtWidgets[29395]
#define sipNameNr_selectedNameFilter 29414
#define sipName_selectedNameFilter &sipStrings_QtWidgets[29414]
#define sipNameNr_setActivationOrder 29433
#define sipName_setActivationOrder &sipStrings_QtWidgets[29433]
#define sipNameNr_setActiveSubWindow 29452
#define sipName_setActiveSubWindow &sipStrings_QtWidgets[29452]
#define sipNameNr_setAutoExpandDelay 29471
#define sipName_setAutoExpandDelay &sipStrings_QtWidgets[29471]
#define sipNameNr_setAutoRepeatDelay 29490
#define sipName_setAutoRepeatDelay &sipStrings_QtWidgets[29490]
#define sipNameNr_setBackgroundBrush 29509
#define sipName_setBackgroundBrush &sipStrings_QtWidgets[29509]
#define sipNameNr_setCaseSensitivity 29528
#define sipName_setCaseSensitivity &sipStrings_QtWidgets[29528]
#define sipNameNr_setColumnAlignment 29547
#define sipName_setColumnAlignment &sipStrings_QtWidgets[29547]
#define sipNameNr_setContentsMargins 29566
#define sipName_setContentsMargins &sipStrings_QtWidgets[29566]
#define sipNameNr_setCursorFlashTime 29585
#define sipName_setCursorFlashTime &sipStrings_QtWidgets[29585]
#define sipNameNr_setCursorMoveStyle 29604
#define sipName_setCursorMoveStyle &sipStrings_QtWidgets[29604]
#define sipNameNr_setDateEditEnabled 29623
#define sipName_setDateEditEnabled &sipStrings_QtWidgets[29623]
#define sipNameNr_setDefaultProperty 29642
#define sipName_setDefaultProperty &sipStrings_QtWidgets[29642]
#define sipNameNr_setExclusionPolicy 29661
#define sipName_setExclusionPolicy &sipStrings_QtWidgets[29661]
#define sipNameNr_setExtraSelections 29680
#define sipName_setExtraSelections &sipStrings_QtWidgets[29680]
#define sipNameNr_setForegroundBrush 29699
#define sipName_setForegroundBrush &sipStrings_QtWidgets[29699]
#define sipNameNr_setInformativeText 29718
#define sipName_setInformativeText &sipStrings_QtWidgets[29718]
#define sipNameNr_setItemIndexMethod 29737
#define sipName_setItemIndexMethod &sipStrings_QtWidgets[29737]
#define sipNameNr_setItemsExpandable 29756
#define sipName_setItemsExpandable &sipStrings_QtWidgets[29756]
#define sipNameNr_setLastCenterPoint 29775
#define sipName_setLastCenterPoint &sipStrings_QtWidgets[29775]
#define sipNameNr_setLastScaleFactor 29794
#define sipName_setLastScaleFactor &sipStrings_QtWidgets[29794]
#define sipNameNr_setLayoutDirection 23743
#define sipName_setLayoutDirection &sipStrings_QtWidgets[23743]
#define sipNameNr_setMaxVisibleItems 29813
#define sipName_setMaxVisibleItems &sipStrings_QtWidgets[29813]
#define sipNameNr_setMaximumDateTime 29832
#define sipName_setMaximumDateTime &sipStrings_QtWidgets[29832]
#define sipNameNr_setMimeTypeFilters 29851
#define sipName_setMimeTypeFilters &sipStrings_QtWidgets[29851]
#define sipNameNr_setMinimumDateTime 29870
#define sipName_setMinimumDateTime &sipStrings_QtWidgets[29870]
#define sipNameNr_setMinimumDuration 29889
#define sipName_setMinimumDuration &sipStrings_QtWidgets[29889]
#define sipNameNr_setPlaceholderText 29908
#define sipName_setPlaceholderText &sipStrings_QtWidgets[29908]
#define sipNameNr_setPreferredHeight 29927
#define sipName_setPreferredHeight &sipStrings_QtWidgets[29927]
#define sipNameNr_setResolveSymlinks 29946
#define sipName_setResolveSymlinks &sipStrings_QtWidgets[29946]
#define sipNameNr_setRootIsDecorated 29965
#define sipName_setRootIsDecorated &sipStrings_QtWidgets[29965]
#define sipNameNr_setSectionsMovable 29984
#define sipName_setSectionsMovable &sipStrings_QtWidgets[29984]
#define sipNameNr_setSelectedSection 30003
#define sipName_setSelectedSection &sipStrings_QtWidgets[30003]
#define sipNameNr_setShortcutContext 30022
#define sipName_setShortcutContext &sipStrings_QtWidgets[30022]
#define sipNameNr_setShortcutEnabled 30041
#define sipName_setShortcutEnabled &sipStrings_QtWidgets[30041]
#define sipNameNr_setSizeGripEnabled 30060
#define sipName_setSizeGripEnabled &sipStrings_QtWidgets[30060]
#define sipNameNr_setStandardButtons 30079
#define sipName_setStandardButtons &sipStrings_QtWidgets[30079]
#define sipNameNr_setTabChangesFocus 30098
#define sipName_setTabChangesFocus &sipStrings_QtWidgets[30098]
#define sipNameNr_setTabStopDistance 30117
#define sipName_setTabStopDistance &sipStrings_QtWidgets[30117]
#define sipNameNr_setToolButtonStyle 30136
#define sipName_setToolButtonStyle &sipStrings_QtWidgets[30136]
#define sipNameNr_setToolTipDuration 30155
#define sipName_setToolTipDuration &sipStrings_QtWidgets[30155]
#define sipNameNr_setToolTipsVisible 30174
#define sipName_setToolTipsVisible &sipStrings_QtWidgets[30174]
#define sipNameNr_setTransformations 30193
#define sipName_setTransformations &sipStrings_QtWidgets[30193]
#define sipNameNr_setUndoRedoEnabled 30212
#define sipName_setUndoRedoEnabled &sipStrings_QtWidgets[30212]
#define sipNameNr_setVerticalSpacing 30231
#define sipName_setVerticalSpacing &sipStrings_QtWidgets[30231]
#define sipNameNr_setVerticalStretch 30250
#define sipName_setVerticalStretch &sipStrings_QtWidgets[30250]
#define sipNameNr_setViewportMargins 30269
#define sipName_setViewportMargins &sipStrings_QtWidgets[30269]
#define sipNameNr_setWidgetResizable 30288
#define sipName_setWidgetResizable &sipStrings_QtWidgets[30288]
#define sipNameNr_sortIndicatorOrder 30307
#define sipName_sortIndicatorOrder &sipStrings_QtWidgets[30307]
#define sipNameNr_sourceBoundingRect 30326
#define sipName_sourceBoundingRect &sipStrings_QtWidgets[30326]
#define sipNameNr_stretchLastSection 30345
#define sipName_stretchLastSection &sipStrings_QtWidgets[30345]
#define sipNameNr_subWindowActivated 30364
#define sipName_subWindowActivated &sipStrings_QtWidgets[30364]
#define sipNameNr_totalRotationAngle 30383
#define sipName_totalRotationAngle &sipStrings_QtWidgets[30383]
#define sipNameNr_transformationMode 30402
#define sipName_transformationMode &sipStrings_QtWidgets[30402]
#define sipNameNr_updateBoundingRect 30421
#define sipName_updateBoundingRect &sipStrings_QtWidgets[30421]
#define sipNameNr_verticalHeaderItem 30440
#define sipName_verticalHeaderItem &sipStrings_QtWidgets[30440]
#define sipNameNr_verticalScrollMode 30459
#define sipName_verticalScrollMode &sipStrings_QtWidgets[30459]
#define sipNameNr_viewportUpdateMode 30478
#define sipName_viewportUpdateMode &sipStrings_QtWidgets[30478]
#define sipNameNr_windowStateChanged 30497
#define sipName_windowStateChanged &sipStrings_QtWidgets[30497]
#define sipNameNr_windowTitleChanged 30516
#define sipName_windowTitleChanged &sipStrings_QtWidgets[30516]
#define sipNameNr_AutoDefaultButton 30535
#define sipName_AutoDefaultButton &sipStrings_QtWidgets[30535]
#define sipNameNr_AxisLockThreshold 30553
#define sipName_AxisLockThreshold &sipStrings_QtWidgets[30553]
#define sipNameNr_BoundingRectShape 30571
#define sipName_BoundingRectShape &sipStrings_QtWidgets[30571]
#define sipNameNr_CE_ColumnViewGrip 30589
#define sipName_CE_ColumnViewGrip &sipStrings_QtWidgets[30589]
#define sipNameNr_CE_ScrollBarFirst 30607
#define sipName_CE_ScrollBarFirst &sipStrings_QtWidgets[30607]
#define sipNameNr_CE_TabBarTabLabel 30625
#define sipName_CE_TabBarTabLabel &sipStrings_QtWidgets[30625]
#define sipNameNr_CE_TabBarTabShape 30643
#define sipName_CE_TabBarTabShape &sipStrings_QtWidgets[30643]
#define sipNameNr_ColorDialogOption 5549
#define sipName_ColorDialogOption &sipStrings_QtWidgets[5549]
#define sipNameNr_CommandLinkButton 27648
#define sipName_CommandLinkButton &sipStrings_QtWidgets[27648]
#define sipNameNr_DateSections_Mask 30661
#define sipName_DateSections_Mask &sipStrings_QtWidgets[30661]
#define sipNameNr_DockWidgetFeature 6372
#define sipName_DockWidgetFeature &sipStrings_QtWidgets[6372]
#define sipNameNr_DockWidgetMovable 30679
#define sipName_DockWidgetMovable &sipStrings_QtWidgets[30679]
#define sipNameNr_DontShowIndicator 30697
#define sipName_DontShowIndicator &sipStrings_QtWidgets[30697]
#define sipNameNr_DragStartDistance 30715
#define sipName_DragStartDistance &sipStrings_QtWidgets[30715]
#define sipNameNr_ExclusiveOptional 30733
#define sipName_ExclusiveOptional &sipStrings_QtWidgets[30733]
#define sipNameNr_ExtendedSelection 30751
#define sipName_ExtendedSelection &sipStrings_QtWidgets[30751]
#define sipNameNr_FieldGrowthPolicy 6434
#define sipName_FieldGrowthPolicy &sipStrings_QtWidgets[6434]
#define sipNameNr_FontDialogOptions 6403
#define sipName_FontDialogOptions &sipStrings_QtWidgets[6403]
#define sipNameNr_GraphicsItemFlags 4928
#define sipName_GraphicsItemFlags &sipStrings_QtWidgets[4928]
#define sipNameNr_HasCheckIndicator 30769
#define sipName_HasCheckIndicator &sipStrings_QtWidgets[30769]
#define sipNameNr_HaveCustomButton1 30787
#define sipName_HaveCustomButton1 &sipStrings_QtWidgets[30787]
#define sipNameNr_HaveCustomButton2 30805
#define sipName_HaveCustomButton2 &sipStrings_QtWidgets[30805]
#define sipNameNr_HaveCustomButton3 30823
#define sipName_HaveCustomButton3 &sipStrings_QtWidgets[30823]
#define sipNameNr_HelpButtonOnRight 30841
#define sipName_HelpButtonOnRight &sipStrings_QtWidgets[30841]
#define sipNameNr_InputDialogOption 5741
#define sipName_InputDialogOption &sipStrings_QtWidgets[5741]
#define sipNameNr_ItemEnabledChange 30859
#define sipName_ItemEnabledChange &sipStrings_QtWidgets[30859]
#define sipNameNr_ItemHasNoContents 30877
#define sipName_ItemHasNoContents &sipStrings_QtWidgets[30877]
#define sipNameNr_ItemOpacityChange 30895
#define sipName_ItemOpacityChange &sipStrings_QtWidgets[30895]
#define sipNameNr_ItemToolTipChange 30913
#define sipName_ItemToolTipChange &sipStrings_QtWidgets[30913]
#define sipNameNr_ItemVisibleChange 30931
#define sipName_ItemVisibleChange &sipStrings_QtWidgets[30931]
#define sipNameNr_OptimizationFlags 4961
#define sipName_OptimizationFlags &sipStrings_QtWidgets[4961]
#define sipNameNr_OvershootAlwaysOn 30949
#define sipName_OvershootAlwaysOn &sipStrings_QtWidgets[30949]
#define sipNameNr_PE_FrameFocusRect 30967
#define sipName_PE_FrameFocusRect &sipStrings_QtWidgets[30967]
#define sipNameNr_PE_FrameStatusBar 30985
#define sipName_PE_FrameStatusBar &sipStrings_QtWidgets[30985]
#define sipNameNr_PE_FrameTabWidget 31003
#define sipName_PE_FrameTabWidget &sipStrings_QtWidgets[31003]
#define sipNameNr_PE_PanelStatusBar 31021
#define sipName_PE_PanelStatusBar &sipStrings_QtWidgets[31021]
#define sipNameNr_PM_ButtonIconSize 31039
#define sipName_PM_ButtonIconSize &sipStrings_QtWidgets[31039]
#define sipNameNr_PM_HeaderMarkSize 31057
#define sipName_PM_HeaderMarkSize &sipStrings_QtWidgets[31057]
#define sipNameNr_PM_IndicatorWidth 31075
#define sipName_PM_IndicatorWidth &sipStrings_QtWidgets[31075]
#define sipNameNr_PM_MenuBarHMargin 31093
#define sipName_PM_MenuBarHMargin &sipStrings_QtWidgets[31093]
#define sipNameNr_PM_MenuBarVMargin 31111
#define sipName_PM_MenuBarVMargin &sipStrings_QtWidgets[31111]
#define sipNameNr_PM_MenuPanelWidth 31129
#define sipName_PM_MenuPanelWidth &sipStrings_QtWidgets[31129]
#define sipNameNr_PM_SubMenuOverlap 31147
#define sipName_PM_SubMenuOverlap &sipStrings_QtWidgets[31147]
#define sipNameNr_PM_TabBarIconSize 31165
#define sipName_PM_TabBarIconSize &sipStrings_QtWidgets[31165]
#define sipNameNr_PM_TitleBarHeight 31183
#define sipName_PM_TitleBarHeight &sipStrings_QtWidgets[31183]
#define sipNameNr_ProportionalFonts 31201
#define sipName_ProportionalFonts &sipStrings_QtWidgets[31201]
#define sipNameNr_QAbstractItemView 31219
#define sipName_QAbstractItemView &sipStrings_QtWidgets[31219]
#define sipNameNr_QAction__MenuRole 31237
#define sipName_QAction__MenuRole &sipStrings_QtWidgets[31237]
#define sipNameNr_QAction__Priority 31255
#define sipName_QAction__Priority &sipStrings_QtWidgets[31255]
#define sipNameNr_QDataWidgetMapper 31273
#define sipName_QDataWidgetMapper &sipStrings_QtWidgets[31273]
#define sipNameNr_QFileIconProvider 31291
#define sipName_QFileIconProvider &sipStrings_QtWidgets[31291]
#define sipNameNr_QFrame__StyleMask 31309
#define sipName_QFrame__StyleMask &sipStrings_QtWidgets[31309]
#define sipNameNr_QGraphicsLineItem 31327
#define sipName_QGraphicsLineItem &sipStrings_QtWidgets[31327]
#define sipNameNr_QGraphicsPathItem 31345
#define sipName_QGraphicsPathItem &sipStrings_QtWidgets[31345]
#define sipNameNr_QGraphicsRectItem 31363
#define sipName_QGraphicsRectItem &sipStrings_QtWidgets[31363]
#define sipNameNr_QGraphicsRotation 31381
#define sipName_QGraphicsRotation &sipStrings_QtWidgets[31381]
#define sipNameNr_QGraphicsTextItem 31399
#define sipName_QGraphicsTextItem &sipStrings_QtWidgets[31399]
#define sipNameNr_31417 31417
#define sipName_31417 &sipStrings_QtWidgets[31417]
#define sipNameNr_QMessageBox__Icon 31435
#define sipName_QMessageBox__Icon &sipStrings_QtWidgets[31435]
#define sipNameNr_QStyle__StateFlag 31453
#define sipName_QStyle__StateFlag &sipStrings_QtWidgets[31453]
#define sipNameNr_QStyle__StyleHint 31471
#define sipName_QStyle__StyleHint &sipStrings_QtWidgets[31471]
#define sipNameNr_QStyleOptionFrame 31489
#define sipName_QStyleOptionFrame &sipStrings_QtWidgets[31489]
#define sipNameNr_QStyleOptionTabV4 31507
#define sipName_QStyleOptionTabV4 &sipStrings_QtWidgets[31507]
#define sipNameNr_RSIP_OnMouseClick 31525
#define sipName_RSIP_OnMouseClick &sipStrings_QtWidgets[31525]
#define sipNameNr_RightCornerWidget 31543
#define sipName_RightCornerWidget &sipStrings_QtWidgets[31543]
#define sipNameNr_SC_MdiCloseButton 31561
#define sipName_SC_MdiCloseButton &sipStrings_QtWidgets[31561]
#define sipNameNr_SC_ScrollBarFirst 31579
#define sipName_SC_ScrollBarFirst &sipStrings_QtWidgets[31579]
#define sipNameNr_SC_ToolButtonMenu 31597
#define sipName_SC_ToolButtonMenu &sipStrings_QtWidgets[31597]
#define sipNameNr_SE_DockWidgetIcon 31615
#define sipName_SE_DockWidgetIcon &sipStrings_QtWidgets[31615]
#define sipNameNr_SH_ComboBox_Popup 31633
#define sipName_SH_ComboBox_Popup &sipStrings_QtWidgets[31633]
#define sipNameNr_SH_Widget_Animate 31651
#define sipName_SH_Widget_Animate &sipStrings_QtWidgets[31651]
#define sipNameNr_SO_TabWidgetFrame 31669
#define sipName_SO_TabWidgetFrame &sipStrings_QtWidgets[31669]
#define sipNameNr_SP_DialogNoButton 31687
#define sipName_SP_DialogNoButton &sipStrings_QtWidgets[31687]
#define sipNameNr_SP_DialogOkButton 31705
#define sipName_SP_DialogOkButton &sipStrings_QtWidgets[31705]
#define sipNameNr_SP_FileDialogBack 31723
#define sipName_SP_FileDialogBack &sipStrings_QtWidgets[31723]
#define sipNameNr_ScrollMetricCount 31741
#define sipName_ScrollMetricCount &sipStrings_QtWidgets[31741]
#define sipNameNr_SelectPreviousTab 31759
#define sipName_SelectPreviousTab &sipStrings_QtWidgets[31759]
#define sipNameNr_SelectionBehavior 2928
#define sipName_SelectionBehavior &sipStrings_QtWidgets[2928]
#define sipNameNr_SliderPageStepAdd 31777
#define sipName_SliderPageStepAdd &sipStrings_QtWidgets[31777]
#define sipNameNr_SliderPageStepSub 31795
#define sipName_SliderPageStepSub &sipStrings_QtWidgets[31795]
#define sipNameNr_SliderRangeChange 31813
#define sipName_SliderRangeChange &sipStrings_QtWidgets[31813]
#define sipNameNr_SliderStepsChange 31831
#define sipName_SliderStepsChange &sipStrings_QtWidgets[31831]
#define sipNameNr_SliderValueChange 31849
#define sipName_SliderValueChange &sipStrings_QtWidgets[31849]
#define sipNameNr_SnapPositionRatio 31867
#define sipName_SnapPositionRatio &sipStrings_QtWidgets[31867]
#define sipNameNr_SourceInvalidated 31885
#define sipName_SourceInvalidated &sipStrings_QtWidgets[31885]
#define sipNameNr_TextHeuristicRole 31903
#define sipName_TextHeuristicRole &sipStrings_QtWidgets[31903]
#define sipNameNr_TimeSections_Mask 31921
#define sipName_TimeSections_Mask &sipStrings_QtWidgets[31921]
#define sipNameNr_ToolButtonFeature 730
#define sipName_ToolButtonFeature &sipStrings_QtWidgets[730]
#define sipNameNr_acceptHoverEvents 31939
#define sipName_acceptHoverEvents &sipStrings_QtWidgets[31939]
#define sipNameNr_acceptTouchEvents 31957
#define sipName_acceptTouchEvents &sipStrings_QtWidgets[31957]
#define sipNameNr_accessibleTabName 31975
#define sipName_accessibleTabName &sipStrings_QtWidgets[31975]
#define sipNameNr_activeModalWidget 31993
#define sipName_activeModalWidget &sipStrings_QtWidgets[31993]
#define sipNameNr_activePopupWidget 32011
#define sipName_activePopupWidget &sipStrings_QtWidgets[32011]
#define sipNameNr_activeSubControls 32029
#define sipName_activeSubControls &sipStrings_QtWidgets[32029]
#define sipNameNr_associatedWidgets 32047
#define sipName_associatedWidgets &sipStrings_QtWidgets[32047]
#define sipNameNr_availableGeometry 32065
#define sipName_availableGeometry &sipStrings_QtWidgets[32065]
#define sipNameNr_backgroundVisible 32083
#define sipName_backgroundVisible &sipStrings_QtWidgets[32083]
#define sipNameNr_backwardAvailable 32101
#define sipName_backwardAvailable &sipStrings_QtWidgets[32101]
#define sipNameNr_blockBoundingRect 32119
#define sipName_blockBoundingRect &sipStrings_QtWidgets[32119]
#define sipNameNr_blockCountChanged 32137
#define sipName_blockCountChanged &sipStrings_QtWidgets[32137]
#define sipNameNr_blurRadiusChanged 32155
#define sipName_blurRadiusChanged &sipStrings_QtWidgets[32155]
#define sipNameNr_cascadeSubWindows 32173
#define sipName_cascadeSubWindows &sipStrings_QtWidgets[32173]
#define sipNameNr_cellDoubleClicked 32191
#define sipName_cellDoubleClicked &sipStrings_QtWidgets[32191]
#define sipNameNr_contextMenuPolicy 32209
#define sipName_contextMenuPolicy &sipStrings_QtWidgets[32209]
#define sipNameNr_currentCharFormat 32227
#define sipName_currentCharFormat &sipStrings_QtWidgets[32227]
#define sipNameNr_currentCompletion 32245
#define sipName_currentCompletion &sipStrings_QtWidgets[32245]
#define sipNameNr_currentRowChanged 32263
#define sipName_currentRowChanged &sipStrings_QtWidgets[32263]
#define sipNameNr_currentUrlChanged 32281
#define sipName_currentUrlChanged &sipStrings_QtWidgets[32281]
#define sipNameNr_cursorForPosition 32299
#define sipName_cursorForPosition &sipStrings_QtWidgets[32299]
#define sipNameNr_cursorWordForward 32317
#define sipName_cursorWordForward &sipStrings_QtWidgets[32317]
#define sipNameNr_defaultDropAction 32335
#define sipName_defaultDropAction &sipStrings_QtWidgets[32335]
#define sipNameNr_destroySubWindows 32353
#define sipName_destroySubWindows &sipStrings_QtWidgets[32353]
#define sipNameNr_dirtyRegionOffset 32371
#define sipName_dirtyRegionOffset &sipStrings_QtWidgets[32371]
#define sipNameNr_displayedSections 32389
#define sipName_displayedSections &sipStrings_QtWidgets[32389]
#define sipNameNr_duplicatesEnabled 32407
#define sipName_duplicatesEnabled &sipStrings_QtWidgets[32407]
#define sipNameNr_effectiveSizeHint 32425
#define sipName_effectiveSizeHint &sipStrings_QtWidgets[32425]
#define sipNameNr_ensureBlockLayout 32443
#define sipName_ensureBlockLayout &sipStrings_QtWidgets[32443]
#define sipNameNr_expandRecursively 32461
#define sipName_expandRecursively &sipStrings_QtWidgets[32461]
#define sipNameNr_fieldGrowthPolicy 32479
#define sipName_fieldGrowthPolicy &sipStrings_QtWidgets[32479]
#define sipNameNr_firstVisibleBlock 32497
#define sipName_firstVisibleBlock &sipStrings_QtWidgets[32497]
#define sipNameNr_frameBoundingRect 32515
#define sipName_frameBoundingRect &sipStrings_QtWidgets[32515]
#define sipNameNr_geometriesChanged 32533
#define sipName_geometriesChanged &sipStrings_QtWidgets[32533]
#define sipNameNr_getLayoutPosition 32551
#define sipName_getLayoutPosition &sipStrings_QtWidgets[32551]
#define sipNameNr_getWidgetPosition 32569
#define sipName_getWidgetPosition &sipStrings_QtWidgets[32569]
#define sipNameNr_grabKeyboardEvent 26847
#define sipName_grabKeyboardEvent &sipStrings_QtWidgets[26847]
#define sipNameNr_hasHeightForWidth 32587
#define sipName_hasHeightForWidth &sipStrings_QtWidgets[32587]
#define sipNameNr_hasScaledContents 32605
#define sipName_hasScaledContents &sipStrings_QtWidgets[32605]
#define sipNameNr_hasTabletTracking 32623
#define sipName_hasTabletTracking &sipStrings_QtWidgets[32623]
#define sipNameNr_hasWidthForHeight 32641
#define sipName_hasWidthForHeight &sipStrings_QtWidgets[32641]
#define sipNameNr_headerDataChanged 32659
#define sipName_headerDataChanged &sipStrings_QtWidgets[32659]
#define sipNameNr_highlightSections 32677
#define sipName_highlightSections &sipStrings_QtWidgets[32677]
#define sipNameNr_horizontalSpacing 32695
#define sipName_horizontalSpacing &sipStrings_QtWidgets[32695]
#define sipNameNr_horizontalStretch 32713
#define sipName_horizontalStretch &sipStrings_QtWidgets[32713]
#define sipNameNr_invisibleRootItem 32731
#define sipName_invisibleRootItem &sipStrings_QtWidgets[32731]
#define sipNameNr_isDateEditEnabled 32749
#define sipName_isDateEditEnabled &sipStrings_QtWidgets[32749]
#define sipNameNr_isSizeGripEnabled 32767
#define sipName_isSizeGripEnabled &sipStrings_QtWidgets[32767]
#define sipNameNr_isUndoRedoEnabled 32785
#define sipName_isUndoRedoEnabled &sipStrings_QtWidgets[32785]
#define sipNameNr_itemDoubleClicked 32803
#define sipName_itemDoubleClicked &sipStrings_QtWidgets[32803]
#define sipNameNr_itemEditorFactory 32821
#define sipName_itemEditorFactory &sipStrings_QtWidgets[32821]
#define sipNameNr_itemsBoundingRect 32839
#define sipName_itemsBoundingRect &sipStrings_QtWidgets[32839]
#define sipNameNr_lastRotationAngle 32857
#define sipName_lastRotationAngle &sipStrings_QtWidgets[32857]
#define sipNameNr_mapRectFromParent 32875
#define sipName_mapRectFromParent &sipStrings_QtWidgets[32875]
#define sipNameNr_maximumBlockCount 32893
#define sipName_maximumBlockCount &sipStrings_QtWidgets[32893]
#define sipNameNr_minimumRenderSize 32911
#define sipName_minimumRenderSize &sipStrings_QtWidgets[32911]
#define sipNameNr_mouseReleaseEvent 32929
#define sipName_mouseReleaseEvent &sipStrings_QtWidgets[32929]
#define sipNameNr_openExternalLinks 32947
#define sipName_openExternalLinks &sipStrings_QtWidgets[32947]
#define sipNameNr_optimizationFlags 32965
#define sipName_optimizationFlags &sipStrings_QtWidgets[32965]
#define sipNameNr_qDrawBorderPixmap 32983
#define sipName_qDrawBorderPixmap &sipStrings_QtWidgets[32983]
#define sipNameNr_restoreDockWidget 33001
#define sipName_restoreDockWidget &sipStrings_QtWidgets[33001]
#define sipNameNr_rubberBandChanged 33019
#define sipName_rubberBandChanged &sipStrings_QtWidgets[33019]
#define sipNameNr_sceneBoundingRect 33037
#define sipName_sceneBoundingRect &sipStrings_QtWidgets[33037]
#define sipNameNr_scrollDirtyRegion 33055
#define sipName_scrollDirtyRegion &sipStrings_QtWidgets[33055]
#define sipNameNr_scrollGestureType 33073
#define sipName_scrollGestureType &sipStrings_QtWidgets[33073]
#define sipNameNr_sectionResizeMode 33091
#define sipName_sectionResizeMode &sipStrings_QtWidgets[33091]
#define sipNameNr_sectionsClickable 33109
#define sipName_sectionsClickable &sipStrings_QtWidgets[33109]
#define sipNameNr_selectionBehavior 33127
#define sipName_selectionBehavior &sipStrings_QtWidgets[33127]
#define sipNameNr_setAcceptRichText 33145
#define sipName_setAcceptRichText &sipStrings_QtWidgets[33145]
#define sipNameNr_setAccessibleName 33163
#define sipName_setAccessibleName &sipStrings_QtWidgets[33163]
#define sipNameNr_setAutoFormatting 33181
#define sipName_setAutoFormatting &sipStrings_QtWidgets[33181]
#define sipNameNr_setAutoSipEnabled 33199
#define sipName_setAutoSipEnabled &sipStrings_QtWidgets[33199]
#define sipNameNr_setBackgroundRole 33217
#define sipName_setBackgroundRole &sipStrings_QtWidgets[33217]
#define sipNameNr_setCalendarWidget 33235
#define sipName_setCalendarWidget &sipStrings_QtWidgets[33235]
#define sipNameNr_setCenterOnScroll 33253
#define sipName_setCenterOnScroll &sipStrings_QtWidgets[33253]
#define sipNameNr_setCompletionMode 33271
#define sipName_setCompletionMode &sipStrings_QtWidgets[33271]
#define sipNameNr_setCompletionRole 33289
#define sipName_setCompletionRole &sipStrings_QtWidgets[33289]
#define sipNameNr_setCorrectionMode 33307
#define sipName_setCorrectionMode &sipStrings_QtWidgets[33307]
#define sipNameNr_setCurrentSection 33325
#define sipName_setCurrentSection &sipStrings_QtWidgets[33325]
#define sipNameNr_setCursorPosition 33343
#define sipName_setCursorPosition &sipStrings_QtWidgets[33343]
#define sipNameNr_setDateTextFormat 33361
#define sipName_setDateTextFormat &sipStrings_QtWidgets[33361]
#define sipNameNr_setDefaultFactory 33379
#define sipName_setDefaultFactory &sipStrings_QtWidgets[33379]
#define sipNameNr_setDoubleDecimals 33397
#define sipName_setDoubleDecimals &sipStrings_QtWidgets[33397]
#define sipNameNr_setFirstDayOfWeek 33415
#define sipName_setFirstDayOfWeek &sipStrings_QtWidgets[33415]
#define sipNameNr_setForegroundRole 33433
#define sipName_setForegroundRole &sipStrings_QtWidgets[33433]
#define sipNameNr_setGraphicsEffect 33451
#define sipName_setGraphicsEffect &sipStrings_QtWidgets[33451]
#define sipNameNr_setHeightForWidth 33469
#define sipName_setHeightForWidth &sipStrings_QtWidgets[33469]
#define sipNameNr_setLabelAlignment 33487
#define sipName_setLabelAlignment &sipStrings_QtWidgets[33487]
#define sipNameNr_setLazyChildCount 33505
#define sipName_setLazyChildCount &sipStrings_QtWidgets[33505]
#define sipNameNr_setNotchesVisible 33523
#define sipName_setNotchesVisible &sipStrings_QtWidgets[33523]
#define sipNameNr_setPreferredWidth 33541
#define sipName_setPreferredWidth &sipStrings_QtWidgets[33541]
#define sipNameNr_setRootModelIndex 33559
#define sipName_setRootModelIndex &sipStrings_QtWidgets[33559]
#define sipNameNr_setRowFixedHeight 33577
#define sipName_setRowFixedHeight &sipStrings_QtWidgets[33577]
#define sipNameNr_setScaledContents 33595
#define sipName_setScaledContents &sipStrings_QtWidgets[33595]
#define sipNameNr_setSelectionModel 33613
#define sipName_setSelectionModel &sipStrings_QtWidgets[33613]
#define sipNameNr_setSizeConstraint 33631
#define sipName_setSizeConstraint &sipStrings_QtWidgets[33631]
#define sipNameNr_setSliderPosition 33649
#define sipName_setSliderPosition &sipStrings_QtWidgets[33649]
#define sipNameNr_setSnapPositionsX 33667
#define sipName_setSnapPositionsX &sipStrings_QtWidgets[33667]
#define sipNameNr_setSnapPositionsY 33685
#define sipName_setSnapPositionsY &sipStrings_QtWidgets[33685]
#define sipNameNr_setSortingEnabled 33703
#define sipName_setSortingEnabled &sipStrings_QtWidgets[33703]
#define sipNameNr_setSubTitleFormat 33721
#define sipName_setSubTitleFormat &sipStrings_QtWidgets[33721]
#define sipNameNr_setTabBarAutoHide 33739
#define sipName_setTabBarAutoHide &sipStrings_QtWidgets[33739]
#define sipNameNr_setTabletTracking 33757
#define sipName_setTabletTracking &sipStrings_QtWidgets[33757]
#define sipNameNr_setTearOffEnabled 33775
#define sipName_setTearOffEnabled &sipStrings_QtWidgets[33775]
#define sipNameNr_setTitleBarWidget 33793
#define sipName_setTitleBarWidget &sipStrings_QtWidgets[33793]
#define sipNameNr_setUpdateBehavior 33811
#define sipName_setUpdateBehavior &sipStrings_QtWidgets[33811]
#define sipNameNr_setUpdatesEnabled 33829
#define sipName_setUpdatesEnabled &sipStrings_QtWidgets[33829]
#define sipNameNr_setVerticalHeader 33847
#define sipName_setVerticalHeader &sipStrings_QtWidgets[33847]
#define sipNameNr_setVerticalPolicy 33865
#define sipName_setVerticalPolicy &sipStrings_QtWidgets[33865]
#define sipNameNr_setWidthForHeight 33883
#define sipName_setWidthForHeight &sipStrings_QtWidgets[33883]
#define sipNameNr_setWindowFilePath 33901
#define sipName_setWindowFilePath &sipStrings_QtWidgets[33901]
#define sipNameNr_setWindowIconText 33919
#define sipName_setWindowIconText &sipStrings_QtWidgets[33919]
#define sipNameNr_setWindowModality 33937
#define sipName_setWindowModality &sipStrings_QtWidgets[33937]
#define sipNameNr_setWindowModified 33955
#define sipName_setWindowModified &sipStrings_QtWidgets[33955]
#define sipNameNr_showDropIndicator 33973
#define sipName_showDropIndicator &sipStrings_QtWidgets[33973]
#define sipNameNr_showPreviousMonth 33991
#define sipName_showPreviousMonth &sipStrings_QtWidgets[33991]
#define sipNameNr_sip_simplewrapper 34009
#define sipName_sip_simplewrapper &sipStrings_QtWidgets[34009]
#define sipNameNr_sizeHintForColumn 34027
#define sipName_sizeHintForColumn &sipStrings_QtWidgets[34027]
#define sipNameNr_smallDecimalPoint 34045
#define sipName_smallDecimalPoint &sipStrings_QtWidgets[34045]
#define sipNameNr_startDragDistance 34063
#define sipName_startDragDistance &sipStrings_QtWidgets[34063]
#define sipNameNr_tabCloseRequested 34081
#define sipName_tabCloseRequested &sipStrings_QtWidgets[34081]
#define sipNameNr_takeCentralWidget 34099
#define sipName_takeCentralWidget &sipStrings_QtWidgets[34099]
#define sipNameNr_textValueSelected 34117
#define sipName_textValueSelected &sipStrings_QtWidgets[34117]
#define sipNameNr_topLevelItemCount 34135
#define sipName_topLevelItemCount &sipStrings_QtWidgets[34135]
#define sipNameNr_uniformRowHeights 34153
#define sipName_uniformRowHeights &sipStrings_QtWidgets[34153]
#define sipNameNr_usesScrollButtons 34171
#define sipName_usesScrollButtons &sipStrings_QtWidgets[34171]
#define sipNameNr_valuePropertyName 34189
#define sipName_valuePropertyName &sipStrings_QtWidgets[34189]
#define sipNameNr_verticalDirection 34207
#define sipName_verticalDirection &sipStrings_QtWidgets[34207]
#define sipNameNr_verticalScrollBar 34225
#define sipName_verticalScrollBar &sipStrings_QtWidgets[34225]
#define sipNameNr_viewportTransform 34243
#define sipName_viewportTransform &sipStrings_QtWidgets[34243]
#define sipNameNr_visibilityChanged 34261
#define sipName_visibilityChanged &sipStrings_QtWidgets[34261]
#define sipNameNr_weekdayTextFormat 34279
#define sipName_weekdayTextFormat &sipStrings_QtWidgets[34279]
#define sipNameNr_windowIconChanged 34297
#define sipName_windowIconChanged &sipStrings_QtWidgets[34297]
#define sipNameNr_ActivationReason 4594
#define sipName_ActivationReason &sipStrings_QtWidgets[4594]
#define sipNameNr_AdjustToContents 34315
#define sipName_AdjustToContents &sipStrings_QtWidgets[34315]
#define sipNameNr_AllowNestedDocks 34332
#define sipName_AllowNestedDocks &sipStrings_QtWidgets[34332]
#define sipNameNr_AllowTabbedDocks 34349
#define sipName_AllowTabbedDocks &sipStrings_QtWidgets[34349]
#define sipNameNr_AnchorUnderMouse 34366
#define sipName_AnchorUnderMouse &sipStrings_QtWidgets[34366]
#define sipNameNr_AnchorViewCenter 34383
#define sipName_AnchorViewCenter &sipStrings_QtWidgets[34383]
#define sipNameNr_BackgroundPixmap 34400
#define sipName_BackgroundPixmap &sipStrings_QtWidgets[34400]
#define sipNameNr_CE_CheckBoxLabel 34417
#define sipName_CE_CheckBoxLabel &sipStrings_QtWidgets[34417]
#define sipNameNr_CE_ComboBoxLabel 34434
#define sipName_CE_ComboBoxLabel &sipStrings_QtWidgets[34434]
#define sipNameNr_CE_HeaderSection 34451
#define sipName_CE_HeaderSection &sipStrings_QtWidgets[34451]
#define sipNameNr_CE_MenuEmptyArea 34468
#define sipName_CE_MenuEmptyArea &sipStrings_QtWidgets[34468]
#define sipNameNr_CE_ScrollBarLast 34485
#define sipName_CE_ScrollBarLast &sipStrings_QtWidgets[34485]
#define sipNameNr_CT_DialogButtons 34502
#define sipName_CT_DialogButtons &sipStrings_QtWidgets[34502]
#define sipNameNr_CT_HeaderSection 34519
#define sipName_CT_HeaderSection &sipStrings_QtWidgets[34519]
#define sipNameNr_ConsumeEventHint 34536
#define sipName_ConsumeEventHint &sipStrings_QtWidgets[34536]
#define sipNameNr_EditPreviousItem 34553
#define sipName_EditPreviousItem &sipStrings_QtWidgets[34553]
#define sipNameNr_FixedColumnWidth 34570
#define sipName_FixedColumnWidth &sipStrings_QtWidgets[34570]
#define sipNameNr_FontDialogOption 7475
#define sipName_FontDialogOption &sipStrings_QtWidgets[7475]
#define sipNameNr_ForceTabbedDocks 34587
#define sipName_ForceTabbedDocks &sipStrings_QtWidgets[34587]
#define sipNameNr_GraphicsItemFlag 5646
#define sipName_GraphicsItemFlag &sipStrings_QtWidgets[5646]
#define sipNameNr_IndependentPages 34604
#define sipName_IndependentPages &sipStrings_QtWidgets[34604]
#define sipNameNr_InlineCompletion 34621
#define sipName_InlineCompletion &sipStrings_QtWidgets[34621]
#define sipNameNr_ItemClipsToShape 34638
#define sipName_ItemClipsToShape &sipStrings_QtWidgets[34638]
#define sipNameNr_ItemCursorChange 34655
#define sipName_ItemCursorChange &sipStrings_QtWidgets[34655]
#define sipNameNr_ItemIsSelectable 34672
#define sipName_ItemIsSelectable &sipStrings_QtWidgets[34672]
#define sipNameNr_ItemMatrixChange 34689
#define sipName_ItemMatrixChange &sipStrings_QtWidgets[34689]
#define sipNameNr_ItemParentChange 34706
#define sipName_ItemParentChange &sipStrings_QtWidgets[34706]
#define sipNameNr_ItemZValueChange 34723
#define sipName_ItemZValueChange &sipStrings_QtWidgets[34723]
#define sipNameNr_LeftCornerWidget 34740
#define sipName_LeftCornerWidget &sipStrings_QtWidgets[34740]
#define sipNameNr_MinimumExpanding 34757
#define sipName_MinimumExpanding &sipStrings_QtWidgets[34757]
#define sipNameNr_NoVerticalHeader 34774
#define sipName_NoVerticalHeader &sipStrings_QtWidgets[34774]
#define sipNameNr_NoViewportUpdate 34791
#define sipName_NoViewportUpdate &sipStrings_QtWidgets[34791]
#define sipNameNr_NonScalableFonts 34808
#define sipName_NonScalableFonts &sipStrings_QtWidgets[34808]
#define sipNameNr_OptimizationFlag 5710
#define sipName_OptimizationFlag &sipStrings_QtWidgets[5710]
#define sipNameNr_PE_FrameGroupBox 34825
#define sipName_PE_FrameGroupBox &sipStrings_QtWidgets[34825]
#define sipNameNr_PE_FrameLineEdit 34842
#define sipName_PE_FrameLineEdit &sipStrings_QtWidgets[34842]
#define sipNameNr_PE_PanelLineEdit 34859
#define sipName_PE_PanelLineEdit &sipStrings_QtWidgets[34859]
#define sipNameNr_PE_PanelTipLabel 34876
#define sipName_PE_PanelTipLabel &sipStrings_QtWidgets[34876]
#define sipNameNr_PM_LargeIconSize 34893
#define sipName_PM_LargeIconSize &sipStrings_QtWidgets[34893]
#define sipNameNr_PM_MDIFrameWidth 34910
#define sipName_PM_MDIFrameWidth &sipStrings_QtWidgets[34910]
#define sipNameNr_PM_SmallIconSize 34927
#define sipName_PM_SmallIconSize &sipStrings_QtWidgets[34927]
#define sipNameNr_PM_SplitterWidth 34944
#define sipName_PM_SplitterWidth &sipStrings_QtWidgets[34944]
#define sipNameNr_PositionAtBottom 34961
#define sipName_PositionAtBottom &sipStrings_QtWidgets[34961]
#define sipNameNr_PositionAtCenter 34978
#define sipName_PositionAtCenter &sipStrings_QtWidgets[34978]
#define sipNameNr_PrimitiveElement 13229
#define sipName_PrimitiveElement &sipStrings_QtWidgets[13229]
#define sipNameNr_QAbstractSpinBox 34995
#define sipName_QAbstractSpinBox &sipStrings_QtWidgets[34995]
#define sipNameNr_QDialogButtonBox 35012
#define sipName_QDialogButtonBox &sipStrings_QtWidgets[35012]
#define sipNameNr_QDirModel__Roles 35029
#define sipName_QDirModel__Roles &sipStrings_QtWidgets[35029]
#define sipNameNr_QFileSystemModel 35046
#define sipName_QFileSystemModel &sipStrings_QtWidgets[35046]
#define sipNameNr_QKeySequenceEdit 35063
#define sipName_QKeySequenceEdit &sipStrings_QtWidgets[35063]
#define sipNameNr_QLCDNumber__Mode 35080
#define sipName_QLCDNumber__Mode &sipStrings_QtWidgets[35080]
#define sipNameNr_35097 35097
#define sipName_35097 &sipStrings_QtWidgets[35097]
#define sipNameNr_QScroller__Input 35114
#define sipName_QScroller__Input &sipStrings_QtWidgets[35114]
#define sipNameNr_QScroller__State 35131
#define sipName_QScroller__State &sipStrings_QtWidgets[35131]
#define sipNameNr_QStyleHintReturn 35148
#define sipName_QStyleHintReturn &sipStrings_QtWidgets[35148]
#define sipNameNr_QTableWidgetItem 35165
#define sipName_QTableWidgetItem &sipStrings_QtWidgets[35165]
#define sipNameNr_ResizeToContents 35182
#define sipName_ResizeToContents &sipStrings_QtWidgets[35182]
#define sipNameNr_RevertModelCache 35199
#define sipName_RevertModelCache &sipStrings_QtWidgets[35199]
#define sipNameNr_RubberBandResize 35216
#define sipName_RubberBandResize &sipStrings_QtWidgets[35216]
#define sipNameNr_SC_ComboBoxArrow 35233
#define sipName_SC_ComboBoxArrow &sipStrings_QtWidgets[35233]
#define sipNameNr_SC_ComboBoxFrame 35250
#define sipName_SC_ComboBoxFrame &sipStrings_QtWidgets[35250]
#define sipNameNr_SC_DialTickmarks 35267
#define sipName_SC_DialTickmarks &sipStrings_QtWidgets[35267]
#define sipNameNr_SC_GroupBoxFrame 35284
#define sipName_SC_GroupBoxFrame &sipStrings_QtWidgets[35284]
#define sipNameNr_SC_GroupBoxLabel 35301
#define sipName_SC_GroupBoxLabel &sipStrings_QtWidgets[35301]
#define sipNameNr_SC_ScrollBarLast 35318
#define sipName_SC_ScrollBarLast &sipStrings_QtWidgets[35318]
#define sipNameNr_SC_TitleBarLabel 35335
#define sipName_SC_TitleBarLabel &sipStrings_QtWidgets[35335]
#define sipNameNr_SE_FrameContents 35352
#define sipName_SE_FrameContents &sipStrings_QtWidgets[35352]
#define sipNameNr_SE_TabBarTabText 35369
#define sipName_SE_TabBarTabText &sipStrings_QtWidgets[35369]
#define sipNameNr_SE_ToolBarHandle 35386
#define sipName_SE_ToolBarHandle &sipStrings_QtWidgets[35386]
#define sipNameNr_SP_BrowserReload 35403
#define sipName_SP_BrowserReload &sipStrings_QtWidgets[35403]
#define sipNameNr_SP_DirClosedIcon 35420
#define sipName_SP_DirClosedIcon &sipStrings_QtWidgets[35420]
#define sipNameNr_SP_FileDialogEnd 35437
#define sipName_SP_FileDialogEnd &sipStrings_QtWidgets[35437]
#define sipNameNr_SelectedPosition 2589
#define sipName_SelectedPosition &sipStrings_QtWidgets[2589]
#define sipNameNr_SetMinAndMaxSize 35454
#define sipName_SetMinAndMaxSize &sipStrings_QtWidgets[35454]
#define sipNameNr_ShowAlphaChannel 35471
#define sipName_ShowAlphaChannel &sipStrings_QtWidgets[35471]
#define sipNameNr_SizeAdjustPolicy 2209
#define sipName_SizeAdjustPolicy &sipStrings_QtWidgets[2209]
#define sipNameNr_State_Horizontal 35488
#define sipName_State_Horizontal &sipStrings_QtWidgets[35488]
#define sipNameNr_SubWindowOptions 5774
#define sipName_SubWindowOptions &sipStrings_QtWidgets[5774]
#define sipNameNr_SubmitModelCache 35505
#define sipName_SubmitModelCache &sipStrings_QtWidgets[35505]
#define sipNameNr_TrailingPosition 35522
#define sipName_TrailingPosition &sipStrings_QtWidgets[35522]
#define sipNameNr_ViewItemFeatures 1939
#define sipName_ViewItemFeatures &sipStrings_QtWidgets[1939]
#define sipNameNr_ViewItemPosition 1978
#define sipName_ViewItemPosition &sipStrings_QtWidgets[1978]
#define sipNameNr_addCornerAnchors 35539
#define sipName_addCornerAnchors &sipStrings_QtWidgets[35539]
#define sipNameNr_addTopLevelItems 35556
#define sipName_addTopLevelItems &sipStrings_QtWidgets[35556]
#define sipNameNr_autoScrollMargin 35573
#define sipName_autoScrollMargin &sipStrings_QtWidgets[35573]
#define sipNameNr_blurHintsChanged 35590
#define sipName_blurHintsChanged &sipStrings_QtWidgets[35590]
#define sipNameNr_cancelButtonText 35607
#define sipName_cancelButtonText &sipStrings_QtWidgets[35607]
#define sipNameNr_canceledGestures 35624
#define sipName_canceledGestures &sipStrings_QtWidgets[35624]
#define sipNameNr_clearMaximumDate 35641
#define sipName_clearMaximumDate &sipStrings_QtWidgets[35641]
#define sipNameNr_clearMaximumTime 35658
#define sipName_clearMaximumTime &sipStrings_QtWidgets[35658]
#define sipNameNr_clearMinimumDate 35675
#define sipName_clearMinimumDate &sipStrings_QtWidgets[35675]
#define sipNameNr_clearMinimumTime 35692
#define sipName_clearMinimumTime &sipStrings_QtWidgets[35692]
#define sipNameNr_collidesWithItem 35709
#define sipName_collidesWithItem &sipStrings_QtWidgets[35709]
#define sipNameNr_collidesWithPath 35726
#define sipName_collidesWithPath &sipStrings_QtWidgets[35726]
#define sipNameNr_completionColumn 35743
#define sipName_completionColumn &sipStrings_QtWidgets[35743]
#define sipNameNr_completionPrefix 35760
#define sipName_completionPrefix &sipStrings_QtWidgets[35760]
#define sipNameNr_contextMenuEvent 35777
#define sipName_contextMenuEvent &sipStrings_QtWidgets[35777]
#define sipNameNr_createRedoAction 35794
#define sipName_createRedoAction &sipStrings_QtWidgets[35794]
#define sipNameNr_createUndoAction 35811
#define sipName_createUndoAction &sipStrings_QtWidgets[35811]
#define sipNameNr_currentIdChanged 35828
#define sipName_currentIdChanged &sipStrings_QtWidgets[35828]
#define sipNameNr_currentSubWindow 35845
#define sipName_currentSubWindow &sipStrings_QtWidgets[35845]
#define sipNameNr_cursorPositionAt 35862
#define sipName_cursorPositionAt &sipStrings_QtWidgets[35862]
#define sipNameNr_dateTimeFromText 35879
#define sipName_dateTimeFromText &sipStrings_QtWidgets[35879]
#define sipNameNr_defaultAlignment 35896
#define sipName_defaultAlignment &sipStrings_QtWidgets[35896]
#define sipNameNr_defaultTextColor 35913
#define sipName_defaultTextColor &sipStrings_QtWidgets[35913]
#define sipNameNr_destroyItemGroup 35930
#define sipName_destroyItemGroup &sipStrings_QtWidgets[35930]
#define sipNameNr_destroyOldWindow 35947
#define sipName_destroyOldWindow &sipStrings_QtWidgets[35947]
#define sipNameNr_directoryEntered 35964
#define sipName_directoryEntered &sipStrings_QtWidgets[35964]
#define sipNameNr_disconnectNotify 35981
#define sipName_disconnectNotify &sipStrings_QtWidgets[35981]
#define sipNameNr_displayAlignment 35998
#define sipName_displayAlignment &sipStrings_QtWidgets[35998]
#define sipNameNr_drawInlineObject 36015
#define sipName_drawInlineObject &sipStrings_QtWidgets[36015]
#define sipNameNr_effectiveOpacity 36032
#define sipName_effectiveOpacity &sipStrings_QtWidgets[36032]
#define sipNameNr_focusItemChanged 36049
#define sipName_focusItemChanged &sipStrings_QtWidgets[36049]
#define sipNameNr_forwardAvailable 36066
#define sipName_forwardAvailable &sipStrings_QtWidgets[36066]
#define sipNameNr_getMultiLineText 36083
#define sipName_getMultiLineText &sipStrings_QtWidgets[36083]
#define sipNameNr_getOpenFileNames 36100
#define sipName_getOpenFileNames &sipStrings_QtWidgets[36100]
#define sipNameNr_hasMouseTracking 36117
#define sipName_hasMouseTracking &sipStrings_QtWidgets[36117]
#define sipNameNr_headerTextFormat 36134
#define sipName_headerTextFormat &sipStrings_QtWidgets[36134]
#define sipNameNr_horizontalHeader 36151
#define sipName_horizontalHeader &sipStrings_QtWidgets[36151]
#define sipNameNr_horizontalOffset 36168
#define sipName_horizontalOffset &sipStrings_QtWidgets[36168]
#define sipNameNr_horizontalPolicy 36185
#define sipName_horizontalPolicy &sipStrings_QtWidgets[36185]
#define sipNameNr_indexRowSizeHint 36202
#define sipName_indexRowSizeHint &sipStrings_QtWidgets[36202]
#define sipNameNr_initializeColumn 36219
#define sipName_initializeColumn &sipStrings_QtWidgets[36219]
#define sipNameNr_initializeWindow 36236
#define sipName_initializeWindow &sipStrings_QtWidgets[36236]
#define sipNameNr_inputMethodEvent 36253
#define sipName_inputMethodEvent &sipStrings_QtWidgets[36253]
#define sipNameNr_inputMethodHints 36270
#define sipName_inputMethodHints &sipStrings_QtWidgets[36270]
#define sipNameNr_inputMethodQuery 36287
#define sipName_inputMethodQuery &sipStrings_QtWidgets[36287]
#define sipNameNr_insertSpacerItem 36304
#define sipName_insertSpacerItem &sipStrings_QtWidgets[36304]
#define sipNameNr_intValueSelected 36321
#define sipName_intValueSelected &sipStrings_QtWidgets[36321]
#define sipNameNr_invertedControls 36338
#define sipName_invertedControls &sipStrings_QtWidgets[36338]
#define sipNameNr_isSortingEnabled 36355
#define sipName_isSortingEnabled &sipStrings_QtWidgets[36355]
#define sipNameNr_isTearOffEnabled 36372
#define sipName_isTearOffEnabled &sipStrings_QtWidgets[36372]
#define sipNameNr_isVirtualDesktop 36389
#define sipName_isVirtualDesktop &sipStrings_QtWidgets[36389]
#define sipNameNr_isWindowModified 36406
#define sipName_isWindowModified &sipStrings_QtWidgets[36406]
#define sipNameNr_keyboardPageStep 36423
#define sipName_keyboardPageStep &sipStrings_QtWidgets[36423]
#define sipNameNr_keyboardTracking 36440
#define sipName_keyboardTracking &sipStrings_QtWidgets[36440]
#define sipNameNr_logicalCacheSize 36457
#define sipName_logicalCacheSize &sipStrings_QtWidgets[36457]
#define sipNameNr_mapRectFromScene 36474
#define sipName_mapRectFromScene &sipStrings_QtWidgets[36474]
#define sipNameNr_mouseGrabberItem 36491
#define sipName_mouseGrabberItem &sipStrings_QtWidgets[36491]
#define sipNameNr_nextInFocusChain 36508
#define sipName_nextInFocusChain &sipStrings_QtWidgets[36508]
#define sipNameNr_paintWindowFrame 36525
#define sipName_paintWindowFrame &sipStrings_QtWidgets[36525]
#define sipNameNr_parentLayoutItem 36542
#define sipName_parentLayoutItem &sipStrings_QtWidgets[36542]
#define sipNameNr_removeCellWidget 36559
#define sipName_removeCellWidget &sipStrings_QtWidgets[36559]
#define sipNameNr_removeDockWidget 36576
#define sipName_removeDockWidget &sipStrings_QtWidgets[36576]
#define sipNameNr_removeItemWidget 36593
#define sipName_removeItemWidget &sipStrings_QtWidgets[36593]
#define sipNameNr_resetIndentation 36610
#define sipName_resetIndentation &sipStrings_QtWidgets[36610]
#define sipNameNr_rowMaximumHeight 36627
#define sipName_rowMaximumHeight &sipStrings_QtWidgets[36627]
#define sipNameNr_rowMinimumHeight 36644
#define sipName_rowMinimumHeight &sipStrings_QtWidgets[36644]
#define sipNameNr_rowStretchFactor 36661
#define sipName_rowStretchFactor &sipStrings_QtWidgets[36661]
#define sipNameNr_sceneEventFilter 36678
#define sipName_sceneEventFilter &sipStrings_QtWidgets[36678]
#define sipNameNr_sceneRectChanged 36695
#define sipName_sceneRectChanged &sipStrings_QtWidgets[36695]
#define sipNameNr_scrollBarWidgets 36712
#define sipName_scrollBarWidgets &sipStrings_QtWidgets[36712]
#define sipNameNr_scrollContentsBy 36729
#define sipName_scrollContentsBy &sipStrings_QtWidgets[36729]
#define sipNameNr_sectionsInserted 36746
#define sipName_sectionsInserted &sipStrings_QtWidgets[36746]
#define sipNameNr_selectNameFilter 36763
#define sipName_selectNameFilter &sipStrings_QtWidgets[36763]
#define sipNameNr_selectedPosition 36780
#define sipName_selectedPosition &sipStrings_QtWidgets[36780]
#define sipNameNr_selectionChanged 36797
#define sipName_selectionChanged &sipStrings_QtWidgets[36797]
#define sipNameNr_selectionCommand 36814
#define sipName_selectionCommand &sipStrings_QtWidgets[36814]
#define sipNameNr_setAutoExclusive 36831
#define sipName_setAutoExclusive &sipStrings_QtWidgets[36831]
#define sipNameNr_setButtonSymbols 36848
#define sipName_setButtonSymbols &sipStrings_QtWidgets[36848]
#define sipNameNr_setCalendarPopup 36865
#define sipName_setCalendarPopup &sipStrings_QtWidgets[36865]
#define sipNameNr_setCenterButtons 36882
#define sipName_setCenterButtons &sipStrings_QtWidgets[36882]
#define sipNameNr_setCentralWidget 36899
#define sipName_setCentralWidget &sipStrings_QtWidgets[36899]
#define sipNameNr_setColumnSpacing 36916
#define sipName_setColumnSpacing &sipStrings_QtWidgets[36916]
#define sipNameNr_setColumnStretch 36933
#define sipName_setColumnStretch &sipStrings_QtWidgets[36933]
#define sipNameNr_setComboBoxItems 36950
#define sipName_setComboBoxItems &sipStrings_QtWidgets[36950]
#define sipNameNr_setCurrentWidget 36967
#define sipName_setCurrentWidget &sipStrings_QtWidgets[36967]
#define sipNameNr_setDateTimeRange 36984
#define sipName_setDateTimeRange &sipStrings_QtWidgets[36984]
#define sipNameNr_setDefaultAction 37001
#define sipName_setDefaultAction &sipStrings_QtWidgets[37001]
#define sipNameNr_setDefaultButton 37018
#define sipName_setDefaultButton &sipStrings_QtWidgets[37018]
#define sipNameNr_setDefaultSuffix 37035
#define sipName_setDefaultSuffix &sipStrings_QtWidgets[37035]
#define sipNameNr_setDefaultWidget 37052
#define sipName_setDefaultWidget &sipStrings_QtWidgets[37052]
#define sipNameNr_setDisplayFormat 37069
#define sipName_setDisplayFormat &sipStrings_QtWidgets[37069]
#define sipNameNr_setDocumentTitle 37086
#define sipName_setDocumentTitle &sipStrings_QtWidgets[37086]
#define sipNameNr_setDoubleMaximum 37103
#define sipName_setDoubleMaximum &sipStrings_QtWidgets[37103]
#define sipNameNr_setDoubleMinimum 37120
#define sipName_setDoubleMinimum &sipStrings_QtWidgets[37120]
#define sipNameNr_setEffectEnabled 37137
#define sipName_setEffectEnabled &sipStrings_QtWidgets[37137]
#define sipNameNr_setFontPointSize 37154
#define sipName_setFontPointSize &sipStrings_QtWidgets[37154]
#define sipNameNr_setFontUnderline 37171
#define sipName_setFontUnderline &sipStrings_QtWidgets[37171]
#define sipNameNr_setFormAlignment 37188
#define sipName_setFormAlignment &sipStrings_QtWidgets[37188]
#define sipNameNr_setItemAlignment 37205
#define sipName_setItemAlignment &sipStrings_QtWidgets[37205]
#define sipNameNr_setItemPrototype 37222
#define sipName_setItemPrototype &sipStrings_QtWidgets[37222]
#define sipNameNr_setMaximumHeight 37239
#define sipName_setMaximumHeight &sipStrings_QtWidgets[37239]
#define sipNameNr_setMinimumHeight 37256
#define sipName_setMinimumHeight &sipStrings_QtWidgets[37256]
#define sipNameNr_setMouseTracking 37273
#define sipName_setMouseTracking &sipStrings_QtWidgets[37273]
#define sipNameNr_setNativeMenuBar 37290
#define sipName_setNativeMenuBar &sipStrings_QtWidgets[37290]
#define sipNameNr_setOverwriteMode 37307
#define sipName_setOverwriteMode &sipStrings_QtWidgets[37307]
#define sipNameNr_setOwnedByLayout 37324
#define sipName_setOwnedByLayout &sipStrings_QtWidgets[37324]
#define sipNameNr_setPanelModality 37341
#define sipName_setPanelModality &sipStrings_QtWidgets[37341]
#define sipNameNr_setPreferredSize 37358
#define sipName_setPreferredSize &sipStrings_QtWidgets[37358]
#define sipNameNr_setPreviewWidget 37375
#define sipName_setPreviewWidget &sipStrings_QtWidgets[37375]
#define sipNameNr_setRangeSelected 37392
#define sipName_setRangeSelected &sipStrings_QtWidgets[37392]
#define sipNameNr_setRotationAngle 37409
#define sipName_setRotationAngle &sipStrings_QtWidgets[37409]
#define sipNameNr_setRowWrapPolicy 37426
#define sipName_setRowWrapPolicy &sipStrings_QtWidgets[37426]
#define sipNameNr_setSectionHidden 37443
#define sipName_setSectionHidden &sipStrings_QtWidgets[37443]
#define sipNameNr_setSelectionArea 37460
#define sipName_setSelectionArea &sipStrings_QtWidgets[37460]
#define sipNameNr_setSelectionMode 37477
#define sipName_setSelectionMode &sipStrings_QtWidgets[37477]
#define sipNameNr_setSizeIncrement 37494
#define sipName_setSizeIncrement &sipStrings_QtWidgets[37494]
#define sipNameNr_setSortIndicator 37511
#define sipName_setSortIndicator &sipStrings_QtWidgets[37511]
#define sipNameNr_setStandardColor 37528
#define sipName_setStandardColor &sipStrings_QtWidgets[37528]
#define sipNameNr_setStartDragTime 37545
#define sipName_setStartDragTime &sipStrings_QtWidgets[37545]
#define sipNameNr_setStretchFactor 37562
#define sipName_setStretchFactor &sipStrings_QtWidgets[37562]
#define sipNameNr_setTextAlignment 37579
#define sipName_setTextAlignment &sipStrings_QtWidgets[37579]
#define sipNameNr_setTextDirection 37596
#define sipName_setTextDirection &sipStrings_QtWidgets[37596]
#define sipNameNr_setTextElideMode 37613
#define sipName_setTextElideMode &sipStrings_QtWidgets[37613]
#define sipNameNr_setTextureFormat 37630
#define sipName_setTextureFormat &sipStrings_QtWidgets[37630]
#define sipNameNr_setWindowOpacity 37647
#define sipName_setWindowOpacity &sipStrings_QtWidgets[37647]
#define sipNameNr_setWritingSystem 37664
#define sipName_setWritingSystem &sipStrings_QtWidgets[37664]
#define sipNameNr_showPreviousYear 37681
#define sipName_showPreviousYear &sipStrings_QtWidgets[37681]
#define sipNameNr_showSelectedDate 37698
#define sipName_showSelectedDate &sipStrings_QtWidgets[37698]
#define sipNameNr_sizeAdjustPolicy 37715
#define sipName_sizeAdjustPolicy &sipStrings_QtWidgets[37715]
#define sipNameNr_sizeFromContents 37732
#define sipName_sizeFromContents &sipStrings_QtWidgets[37732]
#define sipNameNr_sizeHintForIndex 37749
#define sipName_sizeHintForIndex &sipStrings_QtWidgets[37749]
#define sipNameNr_specialValueText 37766
#define sipName_specialValueText &sipStrings_QtWidgets[37766]
#define sipNameNr_startCenterPoint 37783
#define sipName_startCenterPoint &sipStrings_QtWidgets[37783]
#define sipNameNr_supportedSchemes 37800
#define sipName_supportedSchemes &sipStrings_QtWidgets[37800]
#define sipNameNr_supportsMessages 37817
#define sipName_supportsMessages &sipStrings_QtWidgets[37817]
#define sipNameNr_tabKeyNavigation 37834
#define sipName_tabKeyNavigation &sipStrings_QtWidgets[37834]
#define sipNameNr_tabifyDockWidget 37851
#define sipName_tabifyDockWidget &sipStrings_QtWidgets[37851]
#define sipNameNr_takeTopLevelItem 37868
#define sipName_takeTopLevelItem &sipStrings_QtWidgets[37868]
#define sipNameNr_textFromDateTime 37885
#define sipName_textFromDateTime &sipStrings_QtWidgets[37885]
#define sipNameNr_textValueChanged 37902
#define sipName_textValueChanged &sipStrings_QtWidgets[37902]
#define sipNameNr_toGraphicsObject 37919
#define sipName_toGraphicsObject &sipStrings_QtWidgets[37919]
#define sipNameNr_toggleViewAction 37936
#define sipName_toggleViewAction &sipStrings_QtWidgets[37936]
#define sipNameNr_totalChangeFlags 37953
#define sipName_totalChangeFlags &sipStrings_QtWidgets[37953]
#define sipNameNr_totalMaximumSize 37970
#define sipName_totalMaximumSize &sipStrings_QtWidgets[37970]
#define sipNameNr_totalMinimumSize 37987
#define sipName_totalMinimumSize &sipStrings_QtWidgets[37987]
#define sipNameNr_totalScaleFactor 38004
#define sipName_totalScaleFactor &sipStrings_QtWidgets[38004]
#define sipNameNr_ungrabMouseEvent 38021
#define sipName_ungrabMouseEvent &sipStrings_QtWidgets[38021]
#define sipNameNr_uniformItemSizes 38038
#define sipName_uniformItemSizes &sipStrings_QtWidgets[38038]
#define sipNameNr_updateEditorData 38055
#define sipName_updateEditorData &sipStrings_QtWidgets[38055]
#define sipNameNr_updateGeometries 38072
#define sipName_updateGeometries &sipStrings_QtWidgets[38072]
#define sipNameNr_updateMicroFocus 38089
#define sipName_updateMicroFocus &sipStrings_QtWidgets[38089]
#define sipNameNr_verticalTitleBar 38106
#define sipName_verticalTitleBar &sipStrings_QtWidgets[38106]
#define sipNameNr_viewItemPosition 38123
#define sipName_viewItemPosition &sipStrings_QtWidgets[38123]
#define sipNameNr_viewportSizeHint 38140
#define sipName_viewportSizeHint &sipStrings_QtWidgets[38140]
#define sipNameNr_wheelScrollLines 38157
#define sipName_wheelScrollLines &sipStrings_QtWidgets[38157]
#define sipNameNr_windowFrameEvent 38174
#define sipName_windowFrameEvent &sipStrings_QtWidgets[38174]
#define sipNameNr_AllEditTriggers 38191
#define sipName_AllEditTriggers &sipStrings_QtWidgets[38191]
#define sipNameNr_BackgroundLayer 38207
#define sipName_BackgroundLayer &sipStrings_QtWidgets[38207]
#define sipNameNr_CE_ItemViewItem 38223
#define sipName_CE_ItemViewItem &sipStrings_QtWidgets[38223]
#define sipNameNr_CE_MenuScroller 38239
#define sipName_CE_MenuScroller &sipStrings_QtWidgets[38239]
#define sipNameNr_CT_ItemViewItem 38255
#define sipName_CT_ItemViewItem &sipStrings_QtWidgets[38255]
#define sipNameNr_CacheBackground 38271
#define sipName_CacheBackground &sipStrings_QtWidgets[38271]
#define sipNameNr_CollapsingState 38287
#define sipName_CollapsingState &sipStrings_QtWidgets[38287]
#define sipNameNr_DefaultStepType 38303
#define sipName_DefaultStepType &sipStrings_QtWidgets[38303]
#define sipNameNr_DestructiveRole 38319
#define sipName_DestructiveRole &sipStrings_QtWidgets[38319]
#define sipNameNr_DontClipPainter 38335
#define sipName_DontClipPainter &sipStrings_QtWidgets[38335]
#define sipNameNr_ExclusionPolicy 7446
#define sipName_ExclusionPolicy &sipStrings_QtWidgets[7446]
#define sipNameNr_FilePermissions 38351
#define sipName_FilePermissions &sipStrings_QtWidgets[38351]
#define sipNameNr_FixedPixelWidth 38367
#define sipName_FixedPixelWidth &sipStrings_QtWidgets[38367]
#define sipNameNr_ForegroundLayer 38383
#define sipName_ForegroundLayer &sipStrings_QtWidgets[38383]
#define sipNameNr_GroupedDragging 38399
#define sipName_GroupedDragging &sipStrings_QtWidgets[38399]
#define sipNameNr_IgnoreSubTitles 38415
#define sipName_IgnoreSubTitles &sipStrings_QtWidgets[38415]
#define sipNameNr_InsertAtCurrent 38431
#define sipName_InsertAtCurrent &sipStrings_QtWidgets[38431]
#define sipNameNr_ItemFlagsChange 38447
#define sipName_ItemFlagsChange &sipStrings_QtWidgets[38447]
#define sipNameNr_ItemIndexMethod 5679
#define sipName_ItemIndexMethod &sipStrings_QtWidgets[5679]
#define sipNameNr_ItemIsFocusable 38463
#define sipName_ItemIsFocusable &sipStrings_QtWidgets[38463]
#define sipNameNr_ItemScaleChange 38479
#define sipName_ItemScaleChange &sipStrings_QtWidgets[38479]
#define sipNameNr_ItemSceneChange 38495
#define sipName_ItemSceneChange &sipStrings_QtWidgets[38495]
#define sipNameNr_LeadingPosition 38511
#define sipName_LeadingPosition &sipStrings_QtWidgets[38511]
#define sipNameNr_MaximumVelocity 38527
#define sipName_MaximumVelocity &sipStrings_QtWidgets[38527]
#define sipNameNr_MenuButtonPopup 38543
#define sipName_MenuButtonPopup &sipStrings_QtWidgets[38543]
#define sipNameNr_MinimumVelocity 38559
#define sipName_MinimumVelocity &sipStrings_QtWidgets[38559]
#define sipNameNr_MonospacedFonts 38575
#define sipName_MonospacedFonts &sipStrings_QtWidgets[38575]
#define sipNameNr_NoCornerWidgets 38591
#define sipName_NoCornerWidgets &sipStrings_QtWidgets[38591]
#define sipNameNr_NoDefaultButton 38607
#define sipName_NoDefaultButton &sipStrings_QtWidgets[38607]
#define sipNameNr_NoPartialUpdate 38623
#define sipName_NoPartialUpdate &sipStrings_QtWidgets[38623]
#define sipNameNr_OvershootPolicy 2967
#define sipName_OvershootPolicy &sipStrings_QtWidgets[2967]
#define sipNameNr_PE_PanelMenuBar 38639
#define sipName_PE_PanelMenuBar &sipStrings_QtWidgets[38639]
#define sipNameNr_PE_PanelToolBar 38655
#define sipName_PE_PanelToolBar &sipStrings_QtWidgets[38655]
#define sipNameNr_PM_ButtonMargin 38671
#define sipName_PM_ButtonMargin &sipStrings_QtWidgets[38671]
#define sipNameNr_PM_HeaderMargin 38687
#define sipName_PM_HeaderMargin &sipStrings_QtWidgets[38687]
#define sipNameNr_PM_SizeGripSize 38703
#define sipName_PM_SizeGripSize &sipStrings_QtWidgets[38703]
#define sipNameNr_PM_SliderLength 38719
#define sipName_PM_SliderLength &sipStrings_QtWidgets[38719]
#define sipNameNr_PerformanceHint 38735
#define sipName_PerformanceHint &sipStrings_QtWidgets[38735]
#define sipNameNr_PopupCompletion 12141
#define sipName_PopupCompletion &sipStrings_QtWidgets[12141]
#define sipNameNr_PreferencesRole 38751
#define sipName_PreferencesRole &sipStrings_QtWidgets[38751]
#define sipNameNr_PyQt5_QtWidgets 38767
#define sipName_PyQt5_QtWidgets &sipStrings_QtWidgets[38767]
#define sipNameNr_QAbstractButton 38783
#define sipName_QAbstractButton &sipStrings_QtWidgets[38783]
#define sipNameNr_QAbstractSlider 38799
#define sipName_QAbstractSlider &sipStrings_QtWidgets[38799]
#define sipNameNr_QCalendarWidget 38815
#define sipName_QCalendarWidget &sipStrings_QtWidgets[38815]
#define sipNameNr_QGraphicsAnchor 38831
#define sipName_QGraphicsAnchor &sipStrings_QtWidgets[38831]
#define sipNameNr_QGraphicsEffect 38847
#define sipName_QGraphicsEffect &sipStrings_QtWidgets[38847]
#define sipNameNr_QGraphicsLayout 38863
#define sipName_QGraphicsLayout &sipStrings_QtWidgets[38863]
#define sipNameNr_QGraphicsObject 38879
#define sipName_QGraphicsObject &sipStrings_QtWidgets[38879]
#define sipNameNr_QGraphicsWidget 38895
#define sipName_QGraphicsWidget &sipStrings_QtWidgets[38895]
#define sipNameNr_38911 38911
#define sipName_38911 &sipStrings_QtWidgets[38911]
#define sipNameNr_38927 38927
#define sipName_38927 &sipStrings_QtWidgets[38927]
#define sipNameNr_QListView__Flow 38943
#define sipName_QListView__Flow &sipStrings_QtWidgets[38943]
#define sipNameNr_QListWidgetItem 38959
#define sipName_QListWidgetItem &sipStrings_QtWidgets[38959]
#define sipNameNr_QProgressDialog 38975
#define sipName_QProgressDialog &sipStrings_QtWidgets[38975]
#define sipNameNr_QSplitterHandle 38991
#define sipName_QSplitterHandle &sipStrings_QtWidgets[38991]
#define sipNameNr_QStyleOptionTab 39007
#define sipName_QStyleOptionTab &sipStrings_QtWidgets[39007]
#define sipNameNr_QSystemTrayIcon 39023
#define sipName_QSystemTrayIcon &sipStrings_QtWidgets[39023]
#define sipNameNr_QTreeWidgetItem 39039
#define sipName_QTreeWidgetItem &sipStrings_QtWidgets[39039]
#define sipNameNr_QWIDGETSIZE_MAX 39055
#define sipName_QWIDGETSIZE_MAX &sipStrings_QtWidgets[39055]
#define sipNameNr_RestoreDefaults 39071
#define sipName_RestoreDefaults &sipStrings_QtWidgets[39071]
#define sipNameNr_SC_MdiMinButton 39087
#define sipName_SC_MdiMinButton &sipStrings_QtWidgets[39087]
#define sipNameNr_SC_SliderGroove 39103
#define sipName_SC_SliderGroove &sipStrings_QtWidgets[39103]
#define sipNameNr_SC_SliderHandle 39119
#define sipName_SC_SliderHandle &sipStrings_QtWidgets[39119]
#define sipNameNr_SC_SpinBoxFrame 39135
#define sipName_SC_SpinBoxFrame &sipStrings_QtWidgets[39135]
#define sipNameNr_SH_ToolTip_Mask 39151
#define sipName_SH_ToolTip_Mask &sipStrings_QtWidgets[39151]
#define sipNameNr_SO_GraphicsItem 39167
#define sipName_SO_GraphicsItem &sipStrings_QtWidgets[39167]
#define sipNameNr_SP_ArrowForward 39183
#define sipName_SP_ArrowForward &sipStrings_QtWidgets[39183]
#define sipNameNr_SP_ComputerIcon 39199
#define sipName_SP_ComputerIcon &sipStrings_QtWidgets[39199]
#define sipNameNr_SP_DriveDVDIcon 39215
#define sipName_SP_DriveDVDIcon &sipStrings_QtWidgets[39215]
#define sipNameNr_SP_DriveNetIcon 39231
#define sipName_SP_DriveNetIcon &sipStrings_QtWidgets[39231]
#define sipNameNr_SP_FileLinkIcon 39247
#define sipName_SP_FileLinkIcon &sipStrings_QtWidgets[39247]
#define sipNameNr_SectionPosition 3482
#define sipName_SectionPosition &sipStrings_QtWidgets[3482]
#define sipNameNr_SelectedClicked 39263
#define sipName_SelectedClicked &sipStrings_QtWidgets[39263]
#define sipNameNr_SetNoConstraint 39279
#define sipName_SetNoConstraint &sipStrings_QtWidgets[39279]
#define sipNameNr_SingleSelection 39295
#define sipName_SingleSelection &sipStrings_QtWidgets[39295]
#define sipNameNr_SliderToMaximum 39311
#define sipName_SliderToMaximum &sipStrings_QtWidgets[39311]
#define sipNameNr_SliderToMinimum 39327
#define sipName_SliderToMinimum &sipStrings_QtWidgets[39327]
#define sipNameNr_StandardButtons 4255
#define sipName_StandardButtons &sipStrings_QtWidgets[4255]
#define sipNameNr_State_AutoRaise 39343
#define sipName_State_AutoRaise &sipStrings_QtWidgets[39343]
#define sipNameNr_State_DownArrow 39359
#define sipName_State_DownArrow &sipStrings_QtWidgets[39359]
#define sipNameNr_State_MouseOver 39375
#define sipName_State_MouseOver &sipStrings_QtWidgets[39375]
#define sipNameNr_StepDownEnabled 39391
#define sipName_StepDownEnabled &sipStrings_QtWidgets[39391]
#define sipNameNr_StepEnabledFlag 4221
#define sipName_StepEnabledFlag &sipStrings_QtWidgets[4221]
#define sipNameNr_StyleOptionType 303
#define sipName_StyleOptionType &sipStrings_QtWidgets[303]
#define sipNameNr_SubWindowOption 6622
#define sipName_SubWindowOption &sipStrings_QtWidgets[6622]
#define sipNameNr_ToolBarFeatures 3189
#define sipName_ToolBarFeatures &sipStrings_QtWidgets[3189]
#define sipNameNr_ToolBarPosition 3226
#define sipName_ToolBarPosition &sipStrings_QtWidgets[3226]
#define sipNameNr_TriangularNorth 39407
#define sipName_TriangularNorth &sipStrings_QtWidgets[39407]
#define sipNameNr_TriangularSouth 39423
#define sipName_TriangularSouth &sipStrings_QtWidgets[39423]
#define sipNameNr_ViewItemFeature 2666
#define sipName_ViewItemFeature &sipStrings_QtWidgets[2666]
#define sipNameNr_WatermarkPixmap 14152
#define sipName_WatermarkPixmap &sipStrings_QtWidgets[14152]
#define sipNameNr_aboutToActivate 39439
#define sipName_aboutToActivate &sipStrings_QtWidgets[39439]
#define sipNameNr_actionTriggered 39455
#define sipName_actionTriggered &sipStrings_QtWidgets[39455]
#define sipNameNr_activationOrder 39471
#define sipName_activationOrder &sipStrings_QtWidgets[39471]
#define sipNameNr_activeScrollers 39487
#define sipName_activeScrollers &sipStrings_QtWidgets[39487]
#define sipNameNr_activeSubWindow 39503
#define sipName_activeSubWindow &sipStrings_QtWidgets[39503]
#define sipNameNr_addToolBarBreak 39519
#define sipName_addToolBarBreak &sipStrings_QtWidgets[39519]
#define sipNameNr_addTopLevelItem 39535
#define sipName_addTopLevelItem &sipStrings_QtWidgets[39535]
#define sipNameNr_ambiguousMember 39551
#define sipName_ambiguousMember &sipStrings_QtWidgets[39551]
#define sipNameNr_appendPlainText 39567
#define sipName_appendPlainText &sipStrings_QtWidgets[39567]
#define sipNameNr_autoExpandDelay 39583
#define sipName_autoExpandDelay &sipStrings_QtWidgets[39583]
#define sipNameNr_autoRepeatDelay 39599
#define sipName_autoRepeatDelay &sipStrings_QtWidgets[39599]
#define sipNameNr_backgroundBrush 39615
#define sipName_backgroundBrush &sipStrings_QtWidgets[39615]
#define sipNameNr_backgroundColor 39631
#define sipName_backgroundColor &sipStrings_QtWidgets[39631]
#define sipNameNr_boundingRectFor 39647
#define sipName_boundingRectFor &sipStrings_QtWidgets[39647]
#define sipNameNr_canDropMimeData 39663
#define sipName_canDropMimeData &sipStrings_QtWidgets[39663]
#define sipNameNr_caseSensitivity 39679
#define sipName_caseSensitivity &sipStrings_QtWidgets[39679]
#define sipNameNr_closeAllWindows 39695
#define sipName_closeAllWindows &sipStrings_QtWidgets[39695]
#define sipNameNr_columnAlignment 39711
#define sipName_columnAlignment &sipStrings_QtWidgets[39711]
#define sipNameNr_completeChanged 39727
#define sipName_completeChanged &sipStrings_QtWidgets[39727]
#define sipNameNr_completionCount 39743
#define sipName_completionCount &sipStrings_QtWidgets[39743]
#define sipNameNr_completionModel 39759
#define sipName_completionModel &sipStrings_QtWidgets[39759]
#define sipNameNr_contentsMargins 39775
#define sipName_contentsMargins &sipStrings_QtWidgets[39775]
#define sipNameNr_createItemGroup 39791
#define sipName_createItemGroup &sipStrings_QtWidgets[39791]
#define sipNameNr_createPopupMenu 39807
#define sipName_createPopupMenu &sipStrings_QtWidgets[39807]
#define sipNameNr_cursorFlashTime 39823
#define sipName_cursorFlashTime &sipStrings_QtWidgets[39823]
#define sipNameNr_cursorMoveStyle 39839
#define sipName_cursorMoveStyle &sipStrings_QtWidgets[39839]
#define sipNameNr_dateTimeChanged 39855
#define sipName_dateTimeChanged &sipStrings_QtWidgets[39855]
#define sipNameNr_deviceTransform 39871
#define sipName_deviceTransform &sipStrings_QtWidgets[39871]
#define sipNameNr_directoryLoaded 39887
#define sipName_directoryLoaded &sipStrings_QtWidgets[39887]
#define sipNameNr_documentChanged 39903
#define sipName_documentChanged &sipStrings_QtWidgets[39903]
#define sipNameNr_editTextChanged 39919
#define sipName_editTextChanged &sipStrings_QtWidgets[39919]
#define sipNameNr_editingFinished 39935
#define sipName_editingFinished &sipStrings_QtWidgets[39935]
#define sipNameNr_editorDestroyed 39951
#define sipName_editorDestroyed &sipStrings_QtWidgets[39951]
#define sipNameNr_emitDataChanged 39967
#define sipName_emitDataChanged &sipStrings_QtWidgets[39967]
#define sipNameNr_exclusionPolicy 39983
#define sipName_exclusionPolicy &sipStrings_QtWidgets[39983]
#define sipNameNr_extraSelections 39999
#define sipName_extraSelections &sipStrings_QtWidgets[39999]
#define sipNameNr_featuresChanged 40015
#define sipName_featuresChanged &sipStrings_QtWidgets[40015]
#define sipNameNr_foregroundBrush 40031
#define sipName_foregroundBrush &sipStrings_QtWidgets[40031]
#define sipNameNr_geometryChanged 40047
#define sipName_geometryChanged &sipStrings_QtWidgets[40047]
#define sipNameNr_getItemPosition 40063
#define sipName_getItemPosition &sipStrings_QtWidgets[40063]
#define sipNameNr_getOpenFileName 40079
#define sipName_getOpenFileName &sipStrings_QtWidgets[40079]
#define sipNameNr_getOpenFileUrls 40095
#define sipName_getOpenFileUrls &sipStrings_QtWidgets[40095]
#define sipNameNr_getPaintContext 40111
#define sipName_getPaintContext &sipStrings_QtWidgets[40111]
#define sipNameNr_getSaveFileName 40127
#define sipName_getSaveFileName &sipStrings_QtWidgets[40127]
#define sipNameNr_grabFramebuffer 40143
#define sipName_grabFramebuffer &sipStrings_QtWidgets[40143]
#define sipNameNr_hasSelectedText 40159
#define sipName_hasSelectedText &sipStrings_QtWidgets[40159]
#define sipNameNr_hideTearOffMenu 40175
#define sipName_hideTearOffMenu &sipStrings_QtWidgets[40175]
#define sipNameNr_hoverEnterEvent 40191
#define sipName_hoverEnterEvent &sipStrings_QtWidgets[40191]
#define sipNameNr_hoverLeaveEvent 40207
#define sipName_hoverLeaveEvent &sipStrings_QtWidgets[40207]
#define sipNameNr_iconSizeChanged 40223
#define sipName_iconSizeChanged &sipStrings_QtWidgets[40223]
#define sipNameNr_inWhatsThisMode 40239
#define sipName_inWhatsThisMode &sipStrings_QtWidgets[40239]
#define sipNameNr_informativeText 40255
#define sipName_informativeText &sipStrings_QtWidgets[40255]
#define sipNameNr_initStyleOption 40271
#define sipName_initStyleOption &sipStrings_QtWidgets[40271]
#define sipNameNr_insertPlainText 40287
#define sipName_insertPlainText &sipStrings_QtWidgets[40287]
#define sipNameNr_insertSeparator 40303
#define sipName_insertSeparator &sipStrings_QtWidgets[40303]
#define sipNameNr_intValueChanged 40319
#define sipName_intValueChanged &sipStrings_QtWidgets[40319]
#define sipNameNr_invalidateScene 40335
#define sipName_invalidateScene &sipStrings_QtWidgets[40335]
#define sipNameNr_isEffectEnabled 40351
#define sipName_isEffectEnabled &sipStrings_QtWidgets[40351]
#define sipNameNr_isNativeMenuBar 40367
#define sipName_isNativeMenuBar &sipStrings_QtWidgets[40367]
#define sipNameNr_isRedoAvailable 40383
#define sipName_isRedoAvailable &sipStrings_QtWidgets[40383]
#define sipNameNr_isSectionHidden 40399
#define sipName_isSectionHidden &sipStrings_QtWidgets[40399]
#define sipNameNr_isUndoAvailable 40415
#define sipName_isUndoAvailable &sipStrings_QtWidgets[40415]
#define sipNameNr_itemIndexMethod 40431
#define sipName_itemIndexMethod &sipStrings_QtWidgets[40431]
#define sipNameNr_itemsExpandable 40447
#define sipName_itemsExpandable &sipStrings_QtWidgets[40447]
#define sipNameNr_keyReleaseEvent 40463
#define sipName_keyReleaseEvent &sipStrings_QtWidgets[40463]
#define sipNameNr_keyboardGrabber 40479
#define sipName_keyboardGrabber &sipStrings_QtWidgets[40479]
#define sipNameNr_lastCenterPoint 40495
#define sipName_lastCenterPoint &sipStrings_QtWidgets[40495]
#define sipNameNr_lastScaleFactor 40511
#define sipName_lastScaleFactor &sipStrings_QtWidgets[40511]
#define sipNameNr_layoutDirection 40527
#define sipName_layoutDirection &sipStrings_QtWidgets[40527]
#define sipNameNr_mapRectFromItem 40543
#define sipName_mapRectFromItem &sipStrings_QtWidgets[40543]
#define sipNameNr_mapRectToParent 40559
#define sipName_mapRectToParent &sipStrings_QtWidgets[40559]
#define sipNameNr_maxVisibleItems 40575
#define sipName_maxVisibleItems &sipStrings_QtWidgets[40575]
#define sipNameNr_maximumDateTime 40591
#define sipName_maximumDateTime &sipStrings_QtWidgets[40591]
#define sipNameNr_mimeTypeFilters 40607
#define sipName_mimeTypeFilters &sipStrings_QtWidgets[40607]
#define sipNameNr_minimumDateTime 40623
#define sipName_minimumDateTime &sipStrings_QtWidgets[40623]
#define sipNameNr_minimumDuration 40639
#define sipName_minimumDuration &sipStrings_QtWidgets[40639]
#define sipNameNr_minimumSizeHint 40655
#define sipName_minimumSizeHint &sipStrings_QtWidgets[40655]
#define sipNameNr_mousePressEvent 40671
#define sipName_mousePressEvent &sipStrings_QtWidgets[40671]
#define sipNameNr_placeholderText 40687
#define sipName_placeholderText &sipStrings_QtWidgets[40687]
#define sipNameNr_possibleActions 40703
#define sipName_possibleActions &sipStrings_QtWidgets[40703]
#define sipNameNr_preferredHeight 40719
#define sipName_preferredHeight &sipStrings_QtWidgets[40719]
#define sipNameNr_qDrawShadePanel 40735
#define sipName_qDrawShadePanel &sipStrings_QtWidgets[40735]
#define sipNameNr_redoTextChanged 40751
#define sipName_redoTextChanged &sipStrings_QtWidgets[40751]
#define sipNameNr_releaseKeyboard 40767
#define sipName_releaseKeyboard &sipStrings_QtWidgets[40767]
#define sipNameNr_releaseShortcut 40783
#define sipName_releaseShortcut &sipStrings_QtWidgets[40783]
#define sipNameNr_removeFromGroup 40799
#define sipName_removeFromGroup &sipStrings_QtWidgets[40799]
#define sipNameNr_removeSubWindow 40815
#define sipName_removeSubWindow &sipStrings_QtWidgets[40815]
#define sipNameNr_resolveSymlinks 40831
#define sipName_resolveSymlinks &sipStrings_QtWidgets[40831]
#define sipNameNr_restoreGeometry 40847
#define sipName_restoreGeometry &sipStrings_QtWidgets[40847]
#define sipNameNr_rightButtonSize 40863
#define sipName_rightButtonSize &sipStrings_QtWidgets[40863]
#define sipNameNr_rootIsDecorated 40879
#define sipName_rootIsDecorated &sipStrings_QtWidgets[40879]
#define sipNameNr_rootPathChanged 40895
#define sipName_rootPathChanged &sipStrings_QtWidgets[40895]
#define sipNameNr_rotationChanged 40911
#define sipName_rotationChanged &sipStrings_QtWidgets[40911]
#define sipNameNr_rowCountChanged 40927
#define sipName_rowCountChanged &sipStrings_QtWidgets[40927]
#define sipNameNr_saveFileContent 40943
#define sipName_saveFileContent &sipStrings_QtWidgets[40943]
#define sipNameNr_sectionPosition 40959
#define sipName_sectionPosition &sipStrings_QtWidgets[40959]
#define sipNameNr_sectionSizeHint 40975
#define sipName_sectionSizeHint &sipStrings_QtWidgets[40975]
#define sipNameNr_sectionsMovable 40991
#define sipName_sectionsMovable &sipStrings_QtWidgets[40991]
#define sipNameNr_selectedIndexes 41007
#define sipName_selectedIndexes &sipStrings_QtWidgets[41007]
#define sipNameNr_selectedTabRect 41023
#define sipName_selectedTabRect &sipStrings_QtWidgets[41023]
#define sipNameNr_selectionLength 41039
#define sipName_selectionLength &sipStrings_QtWidgets[41039]
#define sipNameNr_setAcceleration 41055
#define sipName_setAcceleration &sipStrings_QtWidgets[41055]
#define sipNameNr_setActiveAction 41071
#define sipName_setActiveAction &sipStrings_QtWidgets[41071]
#define sipNameNr_setActiveWindow 41087
#define sipName_setActiveWindow &sipStrings_QtWidgets[41087]
#define sipNameNr_setAllowedAreas 41103
#define sipName_setAllowedAreas &sipStrings_QtWidgets[41103]
#define sipNameNr_setBspTreeDepth 41119
#define sipName_setBspTreeDepth &sipStrings_QtWidgets[41119]
#define sipNameNr_setButtonLayout 41135
#define sipName_setButtonLayout &sipStrings_QtWidgets[41135]
#define sipNameNr_setCancelButton 41151
#define sipName_setCancelButton &sipStrings_QtWidgets[41151]
#define sipNameNr_setColumnHidden 41167
#define sipName_setColumnHidden &sipStrings_QtWidgets[41167]
#define sipNameNr_setColumnWidths 41183
#define sipName_setColumnWidths &sipStrings_QtWidgets[41183]
#define sipNameNr_setCornerWidget 41199
#define sipName_setCornerWidget &sipStrings_QtWidgets[41199]
#define sipNameNr_setCurrentColor 41215
#define sipName_setCurrentColor &sipStrings_QtWidgets[41215]
#define sipNameNr_setCurrentIndex 41231
#define sipName_setCurrentIndex &sipStrings_QtWidgets[41231]
#define sipNameNr_setDetailedText 41247
#define sipName_setDetailedText &sipStrings_QtWidgets[41247]
#define sipNameNr_setDirectoryUrl 41263
#define sipName_setDirectoryUrl &sipStrings_QtWidgets[41263]
#define sipNameNr_setDocumentMode 41279
#define sipName_setDocumentMode &sipStrings_QtWidgets[41279]
#define sipNameNr_setDragDropMode 41295
#define sipName_setDragDropMode &sipStrings_QtWidgets[41295]
#define sipNameNr_setEditTriggers 41311
#define sipName_setEditTriggers &sipStrings_QtWidgets[41311]
#define sipNameNr_setEscapeButton 41327
#define sipName_setEscapeButton &sipStrings_QtWidgets[41327]
#define sipNameNr_setFocusOnTouch 41343
#define sipName_setFocusOnTouch &sipStrings_QtWidgets[41343]
#define sipNameNr_setGraphicsItem 41359
#define sipName_setGraphicsItem &sipStrings_QtWidgets[41359]
#define sipNameNr_setHeaderHidden 41375
#define sipName_setHeaderHidden &sipStrings_QtWidgets[41375]
#define sipNameNr_setHeaderLabels 41391
#define sipName_setHeaderLabels &sipStrings_QtWidgets[41391]
#define sipNameNr_setIconProvider 41407
#define sipName_setIconProvider &sipStrings_QtWidgets[41407]
#define sipNameNr_setInsertPolicy 41423
#define sipName_setInsertPolicy &sipStrings_QtWidgets[41423]
#define sipNameNr_setItemDelegate 41439
#define sipName_setItemDelegate &sipStrings_QtWidgets[41439]
#define sipNameNr_setLineWrapMode 41455
#define sipName_setLineWrapMode &sipStrings_QtWidgets[41455]
#define sipNameNr_setMaximumWidth 41471
#define sipName_setMaximumWidth &sipStrings_QtWidgets[41471]
#define sipNameNr_setMidLineWidth 41487
#define sipName_setMidLineWidth &sipStrings_QtWidgets[41487]
#define sipNameNr_setMinimumWidth 41503
#define sipName_setMinimumWidth &sipStrings_QtWidgets[41503]
#define sipNameNr_setModelSorting 41519
#define sipName_setModelSorting &sipStrings_QtWidgets[41519]
#define sipNameNr_setModifierMask 41535
#define sipName_setModifierMask &sipStrings_QtWidgets[41535]
#define sipNameNr_setOkButtonText 41551
#define sipName_setOkButtonText &sipStrings_QtWidgets[41551]
#define sipNameNr_setOpaqueResize 41567
#define sipName_setOpaqueResize &sipStrings_QtWidgets[41567]
#define sipNameNr_setOriginCorner 41583
#define sipName_setOriginCorner &sipStrings_QtWidgets[41583]
#define sipNameNr_setRepeatAction 41599
#define sipName_setRepeatAction &sipStrings_QtWidgets[41599]
#define sipNameNr_setResizeAnchor 41615
#define sipName_setResizeAnchor &sipStrings_QtWidgets[41615]
#define sipNameNr_setRowAlignment 41631
#define sipName_setRowAlignment &sipStrings_QtWidgets[41631]
#define sipNameNr_setScrollMetric 41647
#define sipName_setScrollMetric &sipStrings_QtWidgets[41647]
#define sipNameNr_setSegmentStyle 41663
#define sipName_setSegmentStyle &sipStrings_QtWidgets[41663]
#define sipNameNr_setSelectedDate 41679
#define sipName_setSelectedDate &sipStrings_QtWidgets[41679]
#define sipNameNr_setStackingMode 41695
#define sipName_setStackingMode &sipStrings_QtWidgets[41695]
#define sipNameNr_setSubmitPolicy 41711
#define sipName_setSubmitPolicy &sipStrings_QtWidgets[41711]
#define sipNameNr_setTabStopWidth 41727
#define sipName_setTabStopWidth &sipStrings_QtWidgets[41727]
#define sipNameNr_setTabTextColor 41743
#define sipName_setTabTextColor &sipStrings_QtWidgets[41743]
#define sipNameNr_setTabWhatsThis 41759
#define sipName_setTabWhatsThis &sipStrings_QtWidgets[41759]
#define sipNameNr_setTabsClosable 41775
#define sipName_setTabsClosable &sipStrings_QtWidgets[41775]
#define sipNameNr_setTextEchoMode 41791
#define sipName_setTextEchoMode &sipStrings_QtWidgets[41791]
#define sipNameNr_setTickInterval 41807
#define sipName_setTickInterval &sipStrings_QtWidgets[41807]
#define sipNameNr_setTickPosition 41823
#define sipName_setTickPosition &sipStrings_QtWidgets[41823]
#define sipNameNr_setTreePosition 41839
#define sipName_setTreePosition &sipStrings_QtWidgets[41839]
#define sipNameNr_setWordWrapMode 41855
#define sipName_setWordWrapMode &sipStrings_QtWidgets[41855]
#define sipNameNr_shortcutContext 41871
#define sipName_shortcutContext &sipStrings_QtWidgets[41871]
#define sipNameNr_showTearOffMenu 41887
#define sipName_showTearOffMenu &sipStrings_QtWidgets[41887]
#define sipNameNr_sizeHintChanged 41903
#define sipName_sizeHintChanged &sipStrings_QtWidgets[41903]
#define sipNameNr_splitDockWidget 41919
#define sipName_splitDockWidget &sipStrings_QtWidgets[41919]
#define sipNameNr_standardButtons 41935
#define sipName_standardButtons &sipStrings_QtWidgets[41935]
#define sipNameNr_standardPalette 41951
#define sipName_standardPalette &sipStrings_QtWidgets[41951]
#define sipNameNr_strengthChanged 41967
#define sipName_strengthChanged &sipStrings_QtWidgets[41967]
#define sipNameNr_tabChangesFocus 41983
#define sipName_tabChangesFocus &sipStrings_QtWidgets[41983]
#define sipNameNr_tabLayoutChange 41999
#define sipName_tabLayoutChange &sipStrings_QtWidgets[41999]
#define sipNameNr_tabStopDistance 42015
#define sipName_tabStopDistance &sipStrings_QtWidgets[42015]
#define sipNameNr_textHighlighted 42031
#define sipName_textHighlighted &sipStrings_QtWidgets[42031]
#define sipNameNr_toolButtonStyle 42047
#define sipName_toolButtonStyle &sipStrings_QtWidgets[42047]
#define sipNameNr_toolTipDuration 42063
#define sipName_toolTipDuration &sipStrings_QtWidgets[42063]
#define sipNameNr_toolTipsVisible 42079
#define sipName_toolTipsVisible &sipStrings_QtWidgets[42079]
#define sipNameNr_topLevelChanged 42095
#define sipName_topLevelChanged &sipStrings_QtWidgets[42095]
#define sipNameNr_topLevelWidgets 42111
#define sipName_topLevelWidgets &sipStrings_QtWidgets[42111]
#define sipNameNr_transformations 42127
#define sipName_transformations &sipStrings_QtWidgets[42127]
#define sipNameNr_undoTextChanged 42143
#define sipName_undoTextChanged &sipStrings_QtWidgets[42143]
#define sipNameNr_updateSceneRect 42159
#define sipName_updateSceneRect &sipStrings_QtWidgets[42159]
#define sipNameNr_verticalSpacing 42175
#define sipName_verticalSpacing &sipStrings_QtWidgets[42175]
#define sipNameNr_verticalStretch 42191
#define sipName_verticalStretch &sipStrings_QtWidgets[42191]
#define sipNameNr_viewportEntered 42207
#define sipName_viewportEntered &sipStrings_QtWidgets[42207]
#define sipNameNr_viewportMargins 42223
#define sipName_viewportMargins &sipStrings_QtWidgets[42223]
#define sipNameNr_visualAlignment 42239
#define sipName_visualAlignment &sipStrings_QtWidgets[42239]
#define sipNameNr_widgetForAction 42255
#define sipName_widgetForAction &sipStrings_QtWidgets[42255]
#define sipNameNr_widgetResizable 42271
#define sipName_widgetResizable &sipStrings_QtWidgets[42271]
#define sipNameNr_windowFrameRect 42287
#define sipName_windowFrameRect &sipStrings_QtWidgets[42287]
#define sipNameNr_workAreaResized 42303
#define sipName_workAreaResized &sipStrings_QtWidgets[42303]
#define sipNameNr_ActionPosition 11570
#define sipName_ActionPosition &sipStrings_QtWidgets[11570]
#define sipNameNr_AnimatingState 42319
#define sipName_AnimatingState &sipStrings_QtWidgets[42319]
#define sipNameNr_AutoBulletList 42334
#define sipName_AutoBulletList &sipStrings_QtWidgets[42334]
#define sipNameNr_AutoFormatting 11674
#define sipName_AutoFormatting &sipStrings_QtWidgets[11674]
#define sipNameNr_ButtonFeatures 607
#define sipName_ButtonFeatures &sipStrings_QtWidgets[607]
#define sipNameNr_ButtonPosition 7957
#define sipName_ButtonPosition &sipStrings_QtWidgets[7957]
#define sipNameNr_CC_MdiControls 42349
#define sipName_CC_MdiControls &sipStrings_QtWidgets[42349]
#define sipNameNr_CE_HeaderLabel 42364
#define sipName_CE_HeaderLabel &sipStrings_QtWidgets[42364]
#define sipNameNr_CE_MenuBarItem 42379
#define sipName_CE_MenuBarItem &sipStrings_QtWidgets[42379]
#define sipNameNr_CE_MenuHMargin 42394
#define sipName_CE_MenuHMargin &sipStrings_QtWidgets[42394]
#define sipNameNr_CE_MenuTearoff 42409
#define sipName_CE_MenuTearoff &sipStrings_QtWidgets[42409]
#define sipNameNr_CE_MenuVMargin 42424
#define sipName_CE_MenuVMargin &sipStrings_QtWidgets[42424]
#define sipNameNr_CE_ProgressBar 42439
#define sipName_CE_ProgressBar &sipStrings_QtWidgets[42439]
#define sipNameNr_CE_RadioButton 42454
#define sipName_CE_RadioButton &sipStrings_QtWidgets[42454]
#define sipNameNr_CE_ShapedFrame 42469
#define sipName_CE_ShapedFrame &sipStrings_QtWidgets[42469]
#define sipNameNr_CT_MdiControls 42484
#define sipName_CT_MdiControls &sipStrings_QtWidgets[42484]
#define sipNameNr_CT_MenuBarItem 42499
#define sipName_CT_MenuBarItem &sipStrings_QtWidgets[42499]
#define sipNameNr_CT_ProgressBar 42514
#define sipName_CT_ProgressBar &sipStrings_QtWidgets[42514]
#define sipNameNr_CT_RadioButton 42529
#define sipName_CT_RadioButton &sipStrings_QtWidgets[42529]
#define sipNameNr_CompletionMode 10216
#define sipName_CompletionMode &sipStrings_QtWidgets[10216]
#define sipNameNr_ComplexControl 16746
#define sipName_ComplexControl &sipStrings_QtWidgets[16746]
#define sipNameNr_ControlElement 16769
#define sipName_ControlElement &sipStrings_QtWidgets[16769]
#define sipNameNr_CorrectionMode 4832
#define sipName_CorrectionMode &sipStrings_QtWidgets[4832]
#define sipNameNr_CurrentChanged 42544
#define sipName_CurrentChanged &sipStrings_QtWidgets[42544]
#define sipNameNr_EditKeyPressed 42559
#define sipName_EditKeyPressed &sipStrings_QtWidgets[42559]
#define sipNameNr_ExpandingState 42574
#define sipName_ExpandingState &sipStrings_QtWidgets[42574]
#define sipNameNr_ExtraSelection 11700
#define sipName_ExtraSelection &sipStrings_QtWidgets[11700]
#define sipNameNr_HaveHelpButton 42589
#define sipName_HaveHelpButton &sipStrings_QtWidgets[42589]
#define sipNameNr_HintReturnType 5063
#define sipName_HintReturnType &sipStrings_QtWidgets[5063]
#define sipNameNr_ISOWeekNumbers 42604
#define sipName_ISOWeekNumbers &sipStrings_QtWidgets[42604]
#define sipNameNr_InsertAtBottom 42619
#define sipName_InsertAtBottom &sipStrings_QtWidgets[42619]
#define sipNameNr_MultiSelection 42634
#define sipName_MultiSelection &sipStrings_QtWidgets[42634]
#define sipNameNr_NextIsSelected 42649
#define sipName_NextIsSelected &sipStrings_QtWidgets[42649]
#define sipNameNr_NoCancelButton 42664
#define sipName_NoCancelButton &sipStrings_QtWidgets[42664]
#define sipNameNr_NoEditTriggers 42679
#define sipName_NoEditTriggers &sipStrings_QtWidgets[42679]
#define sipNameNr_NormalPriority 42694
#define sipName_NormalPriority &sipStrings_QtWidgets[42694]
#define sipNameNr_OnlyOneSection 42709
#define sipName_OnlyOneSection &sipStrings_QtWidgets[42709]
#define sipNameNr_PE_FrameWindow 42724
#define sipName_PE_FrameWindow &sipStrings_QtWidgets[42724]
#define sipNameNr_PM_MenuHMargin 42739
#define sipName_PM_MenuHMargin &sipStrings_QtWidgets[42739]
#define sipNameNr_PM_MenuVMargin 42754
#define sipName_PM_MenuVMargin &sipStrings_QtWidgets[42754]
#define sipNameNr_QDesktopWidget 42769
#define sipName_QDesktopWidget &sipStrings_QtWidgets[42769]
#define sipNameNr_QDoubleSpinBox 42784
#define sipName_QDoubleSpinBox &sipStrings_QtWidgets[42784]
#define sipNameNr_QFrame__Shadow 42799
#define sipName_QFrame__Shadow &sipStrings_QtWidgets[42799]
#define sipNameNr_QGraphicsScale 42814
#define sipName_QGraphicsScale &sipStrings_QtWidgets[42814]
#define sipNameNr_QGraphicsScene 42829
#define sipName_QGraphicsScene &sipStrings_QtWidgets[42829]
#define sipNameNr_QPlainTextEdit 42844
#define sipName_QPlainTextEdit &sipStrings_QtWidgets[42844]
#define sipNameNr_QStackedLayout 42859
#define sipName_QStackedLayout &sipStrings_QtWidgets[42859]
#define sipNameNr_QStackedWidget 42874
#define sipName_QStackedWidget &sipStrings_QtWidgets[42874]
#define sipNameNr_QTabBar__Shape 42889
#define sipName_QTabBar__Shape &sipStrings_QtWidgets[42889]
#define sipNameNr_RubberBandDrag 42904
#define sipName_RubberBandDrag &sipStrings_QtWidgets[42904]
#define sipNameNr_RubberBandMove 42919
#define sipName_RubberBandMove &sipStrings_QtWidgets[42919]
#define sipNameNr_SC_SpinBoxDown 42934
#define sipName_SC_SpinBoxDown &sipStrings_QtWidgets[42934]
#define sipNameNr_SE_HeaderArrow 42949
#define sipName_SE_HeaderArrow &sipStrings_QtWidgets[42949]
#define sipNameNr_SE_HeaderLabel 42964
#define sipName_SE_HeaderLabel &sipStrings_QtWidgets[42964]
#define sipNameNr_SH_WizardStyle 42979
#define sipName_SH_WizardStyle &sipStrings_QtWidgets[42979]
#define sipNameNr_SO_ProgressBar 42994
#define sipName_SO_ProgressBar &sipStrings_QtWidgets[42994]
#define sipNameNr_SP_BrowserStop 43009
#define sipName_SP_BrowserStop &sipStrings_QtWidgets[43009]
#define sipNameNr_SP_CommandLink 43024
#define sipName_SP_CommandLink &sipStrings_QtWidgets[43024]
#define sipNameNr_SP_DesktopIcon 43039
#define sipName_SP_DesktopIcon &sipStrings_QtWidgets[43039]
#define sipNameNr_SP_DirHomeIcon 43054
#define sipName_SP_DirHomeIcon &sipStrings_QtWidgets[43054]
#define sipNameNr_SP_DirLinkIcon 43069
#define sipName_SP_DirLinkIcon &sipStrings_QtWidgets[43069]
#define sipNameNr_SP_DirOpenIcon 43084
#define sipName_SP_DirOpenIcon &sipStrings_QtWidgets[43084]
#define sipNameNr_SP_DriveCDIcon 43099
#define sipName_SP_DriveCDIcon &sipStrings_QtWidgets[43099]
#define sipNameNr_SP_DriveFDIcon 43114
#define sipName_SP_DriveFDIcon &sipStrings_QtWidgets[43114]
#define sipNameNr_SP_DriveHDIcon 43129
#define sipName_SP_DriveHDIcon &sipStrings_QtWidgets[43129]
#define sipNameNr_SP_MediaVolume 43144
#define sipName_SP_MediaVolume &sipStrings_QtWidgets[43144]
#define sipNameNr_SP_VistaShield 43159
#define sipName_SP_VistaShield &sipStrings_QtWidgets[43159]
#define sipNameNr_ScrollHandDrag 43174
#define sipName_ScrollHandDrag &sipStrings_QtWidgets[43174]
#define sipNameNr_ScrollPerPixel 43189
#define sipName_ScrollPerPixel &sipStrings_QtWidgets[43189]
#define sipNameNr_ScrollingCurve 43204
#define sipName_ScrollingCurve &sipStrings_QtWidgets[43204]
#define sipNameNr_SelectRightTab 43219
#define sipName_SelectRightTab &sipStrings_QtWidgets[43219]
#define sipNameNr_SetMaximumSize 43234
#define sipName_SetMaximumSize &sipStrings_QtWidgets[43234]
#define sipNameNr_SetMinimumSize 43249
#define sipName_SetMinimumSize &sipStrings_QtWidgets[43249]
#define sipNameNr_SizeConstraint 14729
#define sipName_SizeConstraint &sipStrings_QtWidgets[14729]
#define sipNameNr_SliderNoAction 43264
#define sipName_SliderNoAction &sipStrings_QtWidgets[43264]
#define sipNameNr_SourceAttached 43279
#define sipName_SourceAttached &sipStrings_QtWidgets[43279]
#define sipNameNr_SourceDetached 43294
#define sipName_SourceDetached &sipStrings_QtWidgets[43294]
#define sipNameNr_StandardButton 4898
#define sipName_StandardButton &sipStrings_QtWidgets[4898]
#define sipNameNr_StandardPixmap 16792
#define sipName_StandardPixmap &sipStrings_QtWidgets[16792]
#define sipNameNr_State_Children 43309
#define sipName_State_Children &sipStrings_QtWidgets[43309]
#define sipNameNr_State_HasFocus 43324
#define sipName_State_HasFocus &sipStrings_QtWidgets[43324]
#define sipNameNr_State_NoChange 43339
#define sipName_State_NoChange &sipStrings_QtWidgets[43339]
#define sipNameNr_State_ReadOnly 43354
#define sipName_State_ReadOnly &sipStrings_QtWidgets[43354]
#define sipNameNr_State_Selected 43369
#define sipName_State_Selected &sipStrings_QtWidgets[43369]
#define sipNameNr_SwipeDirection 7687
#define sipName_SwipeDirection &sipStrings_QtWidgets[7687]
#define sipNameNr_TicksBothSides 43384
#define sipName_TicksBothSides &sipStrings_QtWidgets[43384]
#define sipNameNr_ToolBarFeature 3627
#define sipName_ToolBarFeature &sipStrings_QtWidgets[3627]
#define sipNameNr_TriangularEast 43399
#define sipName_TriangularEast &sipStrings_QtWidgets[43399]
#define sipNameNr_TriangularWest 43414
#define sipName_TriangularWest &sipStrings_QtWidgets[43414]
#define sipNameNr_TriggerGesture 43429
#define sipName_TriggerGesture &sipStrings_QtWidgets[43429]
#define sipNameNr_UpdateBehavior 7597
#define sipName_UpdateBehavior &sipStrings_QtWidgets[7597]
#define sipNameNr_ViewportAnchor 7567
#define sipName_ViewportAnchor &sipStrings_QtWidgets[7567]
#define sipNameNr_aboutToCompose 43444
#define sipName_aboutToCompose &sipStrings_QtWidgets[43444]
#define sipNameNr_acceptRichText 43459
#define sipName_acceptRichText &sipStrings_QtWidgets[43459]
#define sipNameNr_accessibleName 43474
#define sipName_accessibleName &sipStrings_QtWidgets[43474]
#define sipNameNr_actionGeometry 43489
#define sipName_actionGeometry &sipStrings_QtWidgets[43489]
#define sipNameNr_activateWindow 43504
#define sipName_activateWindow &sipStrings_QtWidgets[43504]
#define sipNameNr_activeGestures 43519
#define sipName_activeGestures &sipStrings_QtWidgets[43519]
#define sipNameNr_addChildLayout 43534
#define sipName_addChildLayout &sipStrings_QtWidgets[43534]
#define sipNameNr_addChildWidget 43549
#define sipName_addChildWidget &sipStrings_QtWidgets[43549]
#define sipNameNr_autoFormatting 43564
#define sipName_autoFormatting &sipStrings_QtWidgets[43564]
#define sipNameNr_autoSipEnabled 43579
#define sipName_autoSipEnabled &sipStrings_QtWidgets[43579]
#define sipNameNr_backgroundRole 43594
#define sipName_backgroundRole &sipStrings_QtWidgets[43594]
#define sipNameNr_boundingRegion 43609
#define sipName_boundingRegion &sipStrings_QtWidgets[43609]
#define sipNameNr_buttonReleased 43624
#define sipName_buttonReleased &sipStrings_QtWidgets[43624]
#define sipNameNr_calendarWidget 43639
#define sipName_calendarWidget &sipStrings_QtWidgets[43639]
#define sipNameNr_canRedoChanged 43654
#define sipName_canRedoChanged &sipStrings_QtWidgets[43654]
#define sipNameNr_canUndoChanged 43669
#define sipName_canUndoChanged &sipStrings_QtWidgets[43669]
#define sipNameNr_centerOnScroll 43684
#define sipName_centerOnScroll &sipStrings_QtWidgets[43684]
#define sipNameNr_childrenRegion 43699
#define sipName_childrenRegion &sipStrings_QtWidgets[43699]
#define sipNameNr_clearSelection 43714
#define sipName_clearSelection &sipStrings_QtWidgets[43714]
#define sipNameNr_collidingItems 43729
#define sipName_collidingItems &sipStrings_QtWidgets[43729]
#define sipNameNr_completionMode 43744
#define sipName_completionMode &sipStrings_QtWidgets[43744]
#define sipNameNr_completionRole 43759
#define sipName_completionRole &sipStrings_QtWidgets[43759]
#define sipNameNr_correctionMode 43774
#define sipName_correctionMode &sipStrings_QtWidgets[43774]
#define sipNameNr_createdWidgets 43789
#define sipName_createdWidgets &sipStrings_QtWidgets[43789]
#define sipNameNr_currentChanged 43804
#define sipName_currentChanged &sipStrings_QtWidgets[43804]
#define sipNameNr_currentMessage 43819
#define sipName_currentMessage &sipStrings_QtWidgets[43819]
#define sipNameNr_currentSection 43834
#define sipName_currentSection &sipStrings_QtWidgets[43834]
#define sipNameNr_cursorBackward 43849
#define sipName_cursorBackward &sipStrings_QtWidgets[43849]
#define sipNameNr_cursorPosition 43864
#define sipName_cursorPosition &sipStrings_QtWidgets[43864]
#define sipNameNr_dateTextFormat 43879
#define sipName_dateTextFormat &sipStrings_QtWidgets[43879]
#define sipNameNr_decorationSize 43894
#define sipName_decorationSize &sipStrings_QtWidgets[43894]
#define sipNameNr_defaultFactory 43909
#define sipName_defaultFactory &sipStrings_QtWidgets[43909]
#define sipNameNr_dockWidgetArea 43924
#define sipName_dockWidgetArea &sipStrings_QtWidgets[43924]
#define sipNameNr_doubleDecimals 43939
#define sipName_doubleDecimals &sipStrings_QtWidgets[43939]
#define sipNameNr_dragEnterEvent 43954
#define sipName_dragEnterEvent &sipStrings_QtWidgets[43954]
#define sipNameNr_dragLeaveEvent 43969
#define sipName_dragLeaveEvent &sipStrings_QtWidgets[43969]
#define sipNameNr_drawBackground 43984
#define sipName_drawBackground &sipStrings_QtWidgets[43984]
#define sipNameNr_drawDecoration 43999
#define sipName_drawDecoration &sipStrings_QtWidgets[43999]
#define sipNameNr_drawForeground 44014
#define sipName_drawForeground &sipStrings_QtWidgets[44014]
#define sipNameNr_drawItemPixmap 44029
#define sipName_drawItemPixmap &sipStrings_QtWidgets[44029]
#define sipNameNr_effectiveWinId 44044
#define sipName_effectiveWinId &sipStrings_QtWidgets[44044]
#define sipNameNr_enabledChanged 44059
#define sipName_enabledChanged &sipStrings_QtWidgets[44059]
#define sipNameNr_ensurePolished 44074
#define sipName_ensurePolished &sipStrings_QtWidgets[44074]
#define sipNameNr_filterSelected 44089
#define sipName_filterSelected &sipStrings_QtWidgets[44089]
#define sipNameNr_firstDayOfWeek 44104
#define sipName_firstDayOfWeek &sipStrings_QtWidgets[44104]
#define sipNameNr_focusNextChild 44119
#define sipName_focusNextChild &sipStrings_QtWidgets[44119]
#define sipNameNr_foregroundRole 44134
#define sipName_foregroundRole &sipStrings_QtWidgets[44134]
#define sipNameNr_getOpenFileUrl 44149
#define sipName_getOpenFileUrl &sipStrings_QtWidgets[44149]
#define sipNameNr_getSaveFileUrl 44164
#define sipName_getSaveFileUrl &sipStrings_QtWidgets[44164]
#define sipNameNr_getTextMargins 44179
#define sipName_getTextMargins &sipStrings_QtWidgets[44179]
#define sipNameNr_grabMouseEvent 38023
#define sipName_grabMouseEvent &sipStrings_QtWidgets[38023]
#define sipNameNr_grabbedGesture 44194
#define sipName_grabbedGesture &sipStrings_QtWidgets[44194]
#define sipNameNr_graphicsEffect 44209
#define sipName_graphicsEffect &sipStrings_QtWidgets[44209]
#define sipNameNr_hasVisitedPage 44224
#define sipName_hasVisitedPage &sipStrings_QtWidgets[44224]
#define sipNameNr_heightForWidth 44239
#define sipName_heightForWidth &sipStrings_QtWidgets[44239]
#define sipNameNr_historyChanged 44254
#define sipName_historyChanged &sipStrings_QtWidgets[44254]
#define sipNameNr_hoverMoveEvent 44269
#define sipName_hoverMoveEvent &sipStrings_QtWidgets[44269]
#define sipNameNr_initializePage 44284
#define sipName_initializePage &sipStrings_QtWidgets[44284]
#define sipNameNr_insertChildren 44299
#define sipName_insertChildren &sipStrings_QtWidgets[44299]
#define sipNameNr_isActiveWindow 44314
#define sipName_isActiveWindow &sipStrings_QtWidgets[44314]
#define sipNameNr_isColumnHidden 44329
#define sipName_isColumnHidden &sipStrings_QtWidgets[44329]
#define sipNameNr_isHeaderHidden 44344
#define sipName_isHeaderHidden &sipStrings_QtWidgets[44344]
#define sipNameNr_itemAtPosition 44359
#define sipName_itemAtPosition &sipStrings_QtWidgets[44359]
#define sipNameNr_itemPixmapRect 44374
#define sipName_itemPixmapRect &sipStrings_QtWidgets[44374]
#define sipNameNr_keyboardSearch 44389
#define sipName_keyboardSearch &sipStrings_QtWidgets[44389]
#define sipNameNr_labelAlignment 44404
#define sipName_labelAlignment &sipStrings_QtWidgets[44404]
#define sipNameNr_lazyChildCount 44419
#define sipName_lazyChildCount &sipStrings_QtWidgets[44419]
#define sipNameNr_leftButtonSize 44434
#define sipName_leftButtonSize &sipStrings_QtWidgets[44434]
#define sipNameNr_logicalIndexAt 44449
#define sipName_logicalIndexAt &sipStrings_QtWidgets[44449]
#define sipNameNr_mapRectToScene 44464
#define sipName_mapRectToScene &sipStrings_QtWidgets[44464]
#define sipNameNr_mappedWidgetAt 44479
#define sipName_mappedWidgetAt &sipStrings_QtWidgets[44479]
#define sipNameNr_messageChanged 44494
#define sipName_messageChanged &sipStrings_QtWidgets[44494]
#define sipNameNr_messageClicked 44509
#define sipName_messageClicked &sipStrings_QtWidgets[44509]
#define sipNameNr_mouseMoveEvent 44524
#define sipName_mouseMoveEvent &sipStrings_QtWidgets[44524]
#define sipNameNr_movableChanged 44539
#define sipName_movableChanged &sipStrings_QtWidgets[44539]
#define sipNameNr_newProxyWidget 44554
#define sipName_newProxyWidget &sipStrings_QtWidgets[44554]
#define sipNameNr_nextCheckState 44569
#define sipName_nextCheckState &sipStrings_QtWidgets[44569]
#define sipNameNr_normalGeometry 44584
#define sipName_normalGeometry &sipStrings_QtWidgets[44584]
#define sipNameNr_notchesVisible 44599
#define sipName_notchesVisible &sipStrings_QtWidgets[44599]
#define sipNameNr_opacityChanged 44614
#define sipName_opacityChanged &sipStrings_QtWidgets[44614]
#define sipNameNr_positionOfLine 44629
#define sipName_positionOfLine &sipStrings_QtWidgets[44629]
#define sipNameNr_preferredWidth 44644
#define sipName_preferredWidth &sipStrings_QtWidgets[44644]
#define sipNameNr_proposedAction 44659
#define sipName_proposedAction &sipStrings_QtWidgets[44659]
#define sipNameNr_qDrawPlainRect 44674
#define sipName_qDrawPlainRect &sipStrings_QtWidgets[44674]
#define sipNameNr_qDrawShadeLine 44689
#define sipName_qDrawShadeLine &sipStrings_QtWidgets[44689]
#define sipNameNr_qDrawShadeRect 44704
#define sipName_qDrawShadeRect &sipStrings_QtWidgets[44704]
#define sipNameNr_qDrawWinButton 44719
#define sipName_qDrawWinButton &sipStrings_QtWidgets[44719]
#define sipNameNr_registerEditor 44734
#define sipName_registerEditor &sipStrings_QtWidgets[44734]
#define sipNameNr_resetTransform 44749
#define sipName_resetTransform &sipStrings_QtWidgets[44749]
#define sipNameNr_resizeSections 44764
#define sipName_resizeSections &sipStrings_QtWidgets[44764]
#define sipNameNr_rootModelIndex 44779
#define sipName_rootModelIndex &sipStrings_QtWidgets[44779]
#define sipNameNr_rubberBandRect 44794
#define sipName_rubberBandRect &sipStrings_QtWidgets[44794]
#define sipNameNr_sceneTransform 44809
#define sipName_sceneTransform &sipStrings_QtWidgets[44809]
#define sipNameNr_screenGeometry 44824
#define sipName_screenGeometry &sipStrings_QtWidgets[44824]
#define sipNameNr_scrollToAnchor 44839
#define sipName_scrollToAnchor &sipStrings_QtWidgets[44839]
#define sipNameNr_scrollToBottom 44854
#define sipName_scrollToBottom &sipStrings_QtWidgets[44854]
#define sipNameNr_sectionClicked 44869
#define sipName_sectionClicked &sipStrings_QtWidgets[44869]
#define sipNameNr_sectionEntered 44884
#define sipName_sectionEntered &sipStrings_QtWidgets[44884]
#define sipNameNr_sectionPressed 44899
#define sipName_sectionPressed &sipStrings_QtWidgets[44899]
#define sipNameNr_sectionResized 44914
#define sipName_sectionResized &sipStrings_QtWidgets[44914]
#define sipNameNr_sectionsHidden 44929
#define sipName_sectionsHidden &sipStrings_QtWidgets[44929]
#define sipNameNr_selectedRanges 44944
#define sipName_selectedRanges &sipStrings_QtWidgets[44944]
#define sipNameNr_selectionModel 44959
#define sipName_selectionModel &sipStrings_QtWidgets[44959]
#define sipNameNr_selectionStart 44974
#define sipName_selectionStart &sipStrings_QtWidgets[44974]
#define sipNameNr_setAccelerated 44989
#define sipName_setAccelerated &sipStrings_QtWidgets[44989]
#define sipNameNr_setAcceptDrops 45004
#define sipName_setAcceptDrops &sipStrings_QtWidgets[45004]
#define sipNameNr_setActionGroup 45019
#define sipName_setActionGroup &sipStrings_QtWidgets[45019]
#define sipNameNr_setActivePanel 45034
#define sipName_setActivePanel &sipStrings_QtWidgets[45034]
#define sipNameNr_setActiveStack 45049
#define sipName_setActiveStack &sipStrings_QtWidgets[45049]
#define sipNameNr_setAutoDefault 45064
#define sipName_setAutoDefault &sipStrings_QtWidgets[45064]
#define sipNameNr_setCenterPoint 45079
#define sipName_setCenterPoint &sipStrings_QtWidgets[45079]
#define sipNameNr_setChangeFlags 45094
#define sipName_setChangeFlags &sipStrings_QtWidgets[45094]
#define sipNameNr_setCollapsible 45109
#define sipName_setCollapsible &sipStrings_QtWidgets[45109]
#define sipNameNr_setColumnCount 45124
#define sipName_setColumnCount &sipStrings_QtWidgets[45124]
#define sipNameNr_setColumnWidth 45139
#define sipName_setColumnWidth &sipStrings_QtWidgets[45139]
#define sipNameNr_setContextMenu 45154
#define sipName_setContextMenu &sipStrings_QtWidgets[45154]
#define sipNameNr_setControlType 45169
#define sipName_setControlType &sipStrings_QtWidgets[45169]
#define sipNameNr_setCurrentCell 45184
#define sipName_setCurrentCell &sipStrings_QtWidgets[45184]
#define sipNameNr_setCurrentFont 45199
#define sipName_setCurrentFont &sipStrings_QtWidgets[45199]
#define sipNameNr_setCurrentItem 45214
#define sipName_setCurrentItem &sipStrings_QtWidgets[45214]
#define sipNameNr_setCurrentPage 45229
#define sipName_setCurrentPage &sipStrings_QtWidgets[45229]
#define sipNameNr_setCurrentText 45244
#define sipName_setCurrentText &sipStrings_QtWidgets[45244]
#define sipNameNr_setCursorWidth 45259
#define sipName_setCursorWidth &sipStrings_QtWidgets[45259]
#define sipNameNr_setCustomColor 45274
#define sipName_setCustomColor &sipStrings_QtWidgets[45274]
#define sipNameNr_setDescription 45289
#define sipName_setDescription &sipStrings_QtWidgets[45289]
#define sipNameNr_setDirtyRegion 45304
#define sipName_setDirtyRegion &sipStrings_QtWidgets[45304]
#define sipNameNr_setDockOptions 45319
#define sipName_setDockOptions &sipStrings_QtWidgets[45319]
#define sipNameNr_setDoubleRange 45334
#define sipName_setDoubleRange &sipStrings_QtWidgets[45334]
#define sipNameNr_setDoubleValue 45349
#define sipName_setDoubleValue &sipStrings_QtWidgets[45349]
#define sipNameNr_setDragEnabled 45364
#define sipName_setDragEnabled &sipStrings_QtWidgets[45364]
#define sipNameNr_setFixedHeight 45379
#define sipName_setFixedHeight &sipStrings_QtWidgets[45379]
#define sipNameNr_setFocusPolicy 45394
#define sipName_setFocusPolicy &sipStrings_QtWidgets[45394]
#define sipNameNr_setFontFilters 45409
#define sipName_setFontFilters &sipStrings_QtWidgets[45409]
#define sipNameNr_setFrameShadow 45424
#define sipName_setFrameShadow &sipStrings_QtWidgets[45424]
#define sipNameNr_setGlobalStrut 45439
#define sipName_setGlobalStrut &sipStrings_QtWidgets[45439]
#define sipNameNr_setGridVisible 45454
#define sipName_setGridVisible &sipStrings_QtWidgets[45454]
#define sipNameNr_setHandleWidth 45469
#define sipName_setHandleWidth &sipStrings_QtWidgets[45469]
#define sipNameNr_setHeaderLabel 45484
#define sipName_setHeaderLabel &sipStrings_QtWidgets[45484]
#define sipNameNr_setHitTestPath 45499
#define sipName_setHitTestPath &sipStrings_QtWidgets[45499]
#define sipNameNr_setIndentation 36612
#define sipName_setIndentation &sipStrings_QtWidgets[36612]
#define sipNameNr_setIndexWidget 45514
#define sipName_setIndexWidget &sipStrings_QtWidgets[45514]
#define sipNameNr_setInteractive 45529
#define sipName_setInteractive &sipStrings_QtWidgets[45529]
#define sipNameNr_setItemEnabled 45544
#define sipName_setItemEnabled &sipStrings_QtWidgets[45544]
#define sipNameNr_setItemSpacing 45559
#define sipName_setItemSpacing &sipStrings_QtWidgets[45559]
#define sipNameNr_setItemToolTip 45574
#define sipName_setItemToolTip &sipStrings_QtWidgets[45574]
#define sipNameNr_setKeySequence 45589
#define sipName_setKeySequence &sipStrings_QtWidgets[45589]
#define sipNameNr_setMaximumDate 45604
#define sipName_setMaximumDate &sipStrings_QtWidgets[45604]
#define sipNameNr_setMaximumSize 45619
#define sipName_setMaximumSize &sipStrings_QtWidgets[45619]
#define sipNameNr_setMaximumTime 45634
#define sipName_setMaximumTime &sipStrings_QtWidgets[45634]
#define sipNameNr_setMinimumDate 45649
#define sipName_setMinimumDate &sipStrings_QtWidgets[45649]
#define sipNameNr_setMinimumSize 45664
#define sipName_setMinimumSize &sipStrings_QtWidgets[45664]
#define sipNameNr_setMinimumTime 45679
#define sipName_setMinimumTime &sipStrings_QtWidgets[45679]
#define sipNameNr_setModelColumn 45694
#define sipName_setModelColumn &sipStrings_QtWidgets[45694]
#define sipNameNr_setNameFilters 45709
#define sipName_setNameFilters &sipStrings_QtWidgets[45709]
#define sipNameNr_setNoReplayFor 45724
#define sipName_setNoReplayFor &sipStrings_QtWidgets[45724]
#define sipNameNr_setNotchTarget 45739
#define sipName_setNotchTarget &sipStrings_QtWidgets[45739]
#define sipNameNr_setOpacityMask 45754
#define sipName_setOpacityMask &sipStrings_QtWidgets[45754]
#define sipNameNr_setOrientation 45769
#define sipName_setOrientation &sipStrings_QtWidgets[45769]
#define sipNameNr_setRenderHints 45784
#define sipName_setRenderHints &sipStrings_QtWidgets[45784]
#define sipNameNr_setScaleFactor 45799
#define sipName_setScaleFactor &sipStrings_QtWidgets[45799]
#define sipNameNr_setSearchPaths 45814
#define sipName_setSearchPaths &sipStrings_QtWidgets[45814]
#define sipNameNr_setSidebarUrls 45829
#define sipName_setSidebarUrls &sipStrings_QtWidgets[45829]
#define sipNameNr_setStickyFocus 45844
#define sipName_setStickyFocus &sipStrings_QtWidgets[45844]
#define sipNameNr_setTabPosition 45859
#define sipName_setTabPosition &sipStrings_QtWidgets[45859]
#define sipNameNr_setTabsMovable 45874
#define sipName_setTabsMovable &sipStrings_QtWidgets[45874]
#define sipNameNr_setTextMargins 45889
#define sipName_setTextMargins &sipStrings_QtWidgets[45889]
#define sipNameNr_setTextVisible 45904
#define sipName_setTextVisible &sipStrings_QtWidgets[45904]
#define sipNameNr_setTitleFormat 45919
#define sipName_setTitleFormat &sipStrings_QtWidgets[45919]
#define sipNameNr_setWindowFlags 45934
#define sipName_setWindowFlags &sipStrings_QtWidgets[45934]
#define sipNameNr_setWindowState 45949
#define sipName_setWindowState &sipStrings_QtWidgets[45949]
#define sipNameNr_setWindowTitle 45964
#define sipName_setWindowTitle &sipStrings_QtWidgets[45964]
#define sipNameNr_setWizardStyle 45979
#define sipName_setWizardStyle &sipStrings_QtWidgets[45979]
#define sipNameNr_showFullScreen 45994
#define sipName_showFullScreen &sipStrings_QtWidgets[45994]
#define sipNameNr_showStatusText 46009
#define sipName_showStatusText &sipStrings_QtWidgets[46009]
#define sipNameNr_showSystemMenu 46024
#define sipName_showSystemMenu &sipStrings_QtWidgets[46024]
#define sipNameNr_sizeConstraint 46039
#define sipName_sizeConstraint &sipStrings_QtWidgets[46039]
#define sipNameNr_sizeHintForRow 46054
#define sipName_sizeHintForRow &sipStrings_QtWidgets[46054]
#define sipNameNr_sliderPosition 46069
#define sipName_sliderPosition &sipStrings_QtWidgets[46069]
#define sipNameNr_sliderReleased 46084
#define sipName_sliderReleased &sipStrings_QtWidgets[46084]
#define sipNameNr_sourceIsPixmap 46099
#define sipName_sourceIsPixmap &sipStrings_QtWidgets[46099]
#define sipNameNr_standardButton 46114
#define sipName_standardButton &sipStrings_QtWidgets[46114]
#define sipNameNr_standardPixmap 46129
#define sipName_standardPixmap &sipStrings_QtWidgets[46129]
#define sipNameNr_subControlRect 46144
#define sipName_subControlRect &sipStrings_QtWidgets[46144]
#define sipNameNr_subElementRect 46159
#define sipName_subElementRect &sipStrings_QtWidgets[46159]
#define sipNameNr_subTitleFormat 46174
#define sipName_subTitleFormat &sipStrings_QtWidgets[46174]
#define sipNameNr_tabBarAutoHide 46189
#define sipName_tabBarAutoHide &sipStrings_QtWidgets[46189]
#define sipNameNr_tileSubWindows 46204
#define sipName_tileSubWindows &sipStrings_QtWidgets[46204]
#define sipNameNr_titleBarWidget 46219
#define sipName_titleBarWidget &sipStrings_QtWidgets[46219]
#define sipNameNr_topLevelWidget 46234
#define sipName_topLevelWidget &sipStrings_QtWidgets[46234]
#define sipNameNr_ungrabKeyboard 46249
#define sipName_ungrabKeyboard &sipStrings_QtWidgets[46249]
#define sipNameNr_updateBehavior 46264
#define sipName_updateBehavior &sipStrings_QtWidgets[46264]
#define sipNameNr_updateGeometry 46279
#define sipName_updateGeometry &sipStrings_QtWidgets[46279]
#define sipNameNr_updatesEnabled 46294
#define sipName_updatesEnabled &sipStrings_QtWidgets[46294]
#define sipNameNr_verticalHeader 46309
#define sipName_verticalHeader &sipStrings_QtWidgets[46309]
#define sipNameNr_verticalOffset 46324
#define sipName_verticalOffset &sipStrings_QtWidgets[46324]
#define sipNameNr_verticalPolicy 46339
#define sipName_verticalPolicy &sipStrings_QtWidgets[46339]
#define sipNameNr_visibleChanged 46354
#define sipName_visibleChanged &sipStrings_QtWidgets[46354]
#define sipNameNr_visualItemRect 46369
#define sipName_visualItemRect &sipStrings_QtWidgets[46369]
#define sipNameNr_windowFilePath 46384
#define sipName_windowFilePath &sipStrings_QtWidgets[46384]
#define sipNameNr_windowIconText 46399
#define sipName_windowIconText &sipStrings_QtWidgets[46399]
#define sipNameNr_windowModality 46414
#define sipName_windowModality &sipStrings_QtWidgets[46414]
#define sipNameNr_AdjustIgnored 46429
#define sipName_AdjustIgnored &sipStrings_QtWidgets[46429]
#define sipNameNr_AndroidLayout 46443
#define sipName_AndroidLayout &sipStrings_QtWidgets[46443]
#define sipNameNr_AnimatedDocks 46457
#define sipName_AnimatedDocks &sipStrings_QtWidgets[46457]
#define sipNameNr_AnimationHint 46471
#define sipName_AnimationHint &sipStrings_QtWidgets[46471]
#define sipNameNr_AnyKeyPressed 46485
#define sipName_AnyKeyPressed &sipStrings_QtWidgets[46485]
#define sipNameNr_ButtonFeature 734
#define sipName_ButtonFeature &sipStrings_QtWidgets[734]
#define sipNameNr_ButtonSymbols 5521
#define sipName_ButtonSymbols &sipStrings_QtWidgets[5521]
#define sipNameNr_CC_CustomBase 46499
#define sipName_CC_CustomBase &sipStrings_QtWidgets[46499]
#define sipNameNr_CC_ToolButton 46513
#define sipName_CC_ToolButton &sipStrings_QtWidgets[46513]
#define sipNameNr_CE_CustomBase 46527
#define sipName_CE_CustomBase &sipStrings_QtWidgets[46527]
#define sipNameNr_CE_FocusFrame 46541
#define sipName_CE_FocusFrame &sipStrings_QtWidgets[46541]
#define sipNameNr_CE_PushButton 46555
#define sipName_CE_PushButton &sipStrings_QtWidgets[46555]
#define sipNameNr_CE_RubberBand 46569
#define sipName_CE_RubberBand &sipStrings_QtWidgets[46569]
#define sipNameNr_CE_ToolBoxTab 46583
#define sipName_CE_ToolBoxTab &sipStrings_QtWidgets[46583]
#define sipNameNr_CT_CustomBase 46597
#define sipName_CT_CustomBase &sipStrings_QtWidgets[46597]
#define sipNameNr_CT_PushButton 46611
#define sipName_CT_PushButton &sipStrings_QtWidgets[46611]
#define sipNameNr_CT_ToolButton 46625
#define sipName_CT_ToolButton &sipStrings_QtWidgets[46625]
#define sipNameNr_CacheModeFlag 8336
#define sipName_CacheModeFlag &sipStrings_QtWidgets[8336]
#define sipNameNr_CancelGesture 46639
#define sipName_CancelGesture &sipStrings_QtWidgets[46639]
#define sipNameNr_CornerWidgets 6686
#define sipName_CornerWidgets &sipStrings_QtWidgets[6686]
#define sipNameNr_CreationOrder 46653
#define sipName_CreationOrder &sipStrings_QtWidgets[46653]
#define sipNameNr_CustomButton1 30791
#define sipName_CustomButton1 &sipStrings_QtWidgets[30791]
#define sipNameNr_CustomButton2 30809
#define sipName_CustomButton2 &sipStrings_QtWidgets[30809]
#define sipNameNr_CustomButton3 30827
#define sipName_CustomButton3 &sipStrings_QtWidgets[30827]
#define sipNameNr_DefaultButton 6779
#define sipName_DefaultButton &sipStrings_QtWidgets[6779]
#define sipNameNr_DirectoryOnly 46667
#define sipName_DirectoryOnly &sipStrings_QtWidgets[46667]
#define sipNameNr_DoubleClicked 10838
#define sipName_DoubleClicked &sipStrings_QtWidgets[10838]
#define sipNameNr_DraggingState 46681
#define sipName_DraggingState &sipStrings_QtWidgets[46681]
#define sipNameNr_EnsureVisible 46695
#define sipName_EnsureVisible &sipStrings_QtWidgets[46695]
#define sipNameNr_ExistingFiles 46709
#define sipName_ExistingFiles &sipStrings_QtWidgets[46709]
#define sipNameNr_FinishGesture 46723
#define sipName_FinishGesture &sipStrings_QtWidgets[46723]
#define sipNameNr_FrameFeatures 5130
#define sipName_FrameFeatures &sipStrings_QtWidgets[5130]
#define sipNameNr_HasDecoration 46737
#define sipName_HasDecoration &sipStrings_QtWidgets[46737]
#define sipNameNr_ItemIsMovable 46751
#define sipName_ItemIsMovable &sipStrings_QtWidgets[46751]
#define sipNameNr_IteratorFlags 2020
#define sipName_IteratorFlags &sipStrings_QtWidgets[2020]
#define sipNameNr_MinuteSection 46765
#define sipName_MinuteSection &sipStrings_QtWidgets[46765]
#define sipNameNr_NotSelectable 46779
#define sipName_NotSelectable &sipStrings_QtWidgets[46779]
#define sipNameNr_PE_CustomBase 46793
#define sipName_PE_CustomBase &sipStrings_QtWidgets[46793]
#define sipNameNr_PM_CustomBase 46807
#define sipName_PM_CustomBase &sipStrings_QtWidgets[46807]
#define sipNameNr_PanelModality 8307
#define sipName_PanelModality &sipStrings_QtWidgets[8307]
#define sipNameNr_PartialUpdate 38625
#define sipName_PartialUpdate &sipStrings_QtWidgets[38625]
#define sipNameNr_PixmapPadMode 6531
#define sipName_PixmapPadMode &sipStrings_QtWidgets[6531]
#define sipNameNr_PositionAtTop 46821
#define sipName_PositionAtTop &sipStrings_QtWidgets[46821]
#define sipNameNr_QDateTimeEdit 46835
#define sipName_QDateTimeEdit &sipStrings_QtWidgets[46835]
#define sipNameNr_QErrorMessage 46849
#define sipName_QErrorMessage &sipStrings_QtWidgets[46849]
#define sipNameNr_QFontComboBox 46863
#define sipName_QFontComboBox &sipStrings_QtWidgets[46863]
#define sipNameNr_QFrame__Shape 46877
#define sipName_QFrame__Shape &sipStrings_QtWidgets[46877]
#define sipNameNr_QGestureEvent 46891
#define sipName_QGestureEvent &sipStrings_QtWidgets[46891]
#define sipNameNr_QGraphicsItem 46905
#define sipName_QGraphicsItem &sipStrings_QtWidgets[46905]
#define sipNameNr_QGraphicsView 46919
#define sipName_QGraphicsView &sipStrings_QtWidgets[46919]
#define sipNameNr_QItemDelegate 46933
#define sipName_QItemDelegate &sipStrings_QtWidgets[46933]
#define sipNameNr_46947 46947
#define sipName_46947 &sipStrings_QtWidgets[46947]
#define sipNameNr_QMdiSubWindow 46961
#define sipName_QMdiSubWindow &sipStrings_QtWidgets[46961]
#define sipNameNr_QOpenGLWidget 46975
#define sipName_QOpenGLWidget &sipStrings_QtWidgets[46975]
#define sipNameNr_QPinchGesture 46989
#define sipName_QPinchGesture &sipStrings_QtWidgets[46989]
#define sipNameNr_QSplashScreen 47003
#define sipName_QSplashScreen &sipStrings_QtWidgets[47003]
#define sipNameNr_QStyle__State 47017
#define sipName_QStyle__State &sipStrings_QtWidgets[47017]
#define sipNameNr_QStyleFactory 47031
#define sipName_QStyleFactory &sipStrings_QtWidgets[47031]
#define sipNameNr_QStylePainter 47045
#define sipName_QStylePainter &sipStrings_QtWidgets[47045]
#define sipNameNr_QSwipeGesture 47059
#define sipName_QSwipeGesture &sipStrings_QtWidgets[47059]
#define sipNameNr_QWidgetAction 47073
#define sipName_QWidgetAction &sipStrings_QtWidgets[47073]
#define sipNameNr_RowWrapPolicy 10298
#define sipName_RowWrapPolicy &sipStrings_QtWidgets[10298]
#define sipNameNr_SC_CustomBase 47087
#define sipName_SC_CustomBase &sipStrings_QtWidgets[47087]
#define sipNameNr_SC_DialGroove 47101
#define sipName_SC_DialGroove &sipStrings_QtWidgets[47101]
#define sipNameNr_SC_DialHandle 47115
#define sipName_SC_DialHandle &sipStrings_QtWidgets[47115]
#define sipNameNr_SC_ToolButton 47129
#define sipName_SC_ToolButton &sipStrings_QtWidgets[47129]
#define sipNameNr_SE_CustomBase 47143
#define sipName_SE_CustomBase &sipStrings_QtWidgets[47143]
#define sipNameNr_SH_CustomBase 47157
#define sipName_SH_CustomBase &sipStrings_QtWidgets[47157]
#define sipNameNr_SO_CustomBase 47171
#define sipName_SO_CustomBase &sipStrings_QtWidgets[47171]
#define sipNameNr_SO_DockWidget 47185
#define sipName_SO_DockWidget &sipStrings_QtWidgets[47185]
#define sipNameNr_SO_RubberBand 47199
#define sipName_SO_RubberBand &sipStrings_QtWidgets[47199]
#define sipNameNr_SO_TabBarBase 47213
#define sipName_SO_TabBarBase &sipStrings_QtWidgets[47213]
#define sipNameNr_SO_ToolButton 47227
#define sipName_SO_ToolButton &sipStrings_QtWidgets[47227]
#define sipNameNr_SP_ArrowRight 47241
#define sipName_SP_ArrowRight &sipStrings_QtWidgets[47241]
#define sipNameNr_SP_CustomBase 47255
#define sipName_SP_CustomBase &sipStrings_QtWidgets[47255]
#define sipNameNr_SP_MediaPause 47269
#define sipName_SP_MediaPause &sipStrings_QtWidgets[47269]
#define sipNameNr_ScalableFonts 34811
#define sipName_ScalableFonts &sipStrings_QtWidgets[34811]
#define sipNameNr_ScrollPerItem 47283
#define sipName_ScrollPerItem &sipStrings_QtWidgets[47283]
#define sipNameNr_SecondSection 47297
#define sipName_SecondSection &sipStrings_QtWidgets[47297]
#define sipNameNr_SelectColumns 47311
#define sipName_SelectColumns &sipStrings_QtWidgets[47311]
#define sipNameNr_SelectLeftTab 47325
#define sipName_SelectLeftTab &sipStrings_QtWidgets[47325]
#define sipNameNr_SelectionMode 4800
#define sipName_SelectionMode &sipStrings_QtWidgets[4800]
#define sipNameNr_ShortDayNames 47339
#define sipName_ShortDayNames &sipStrings_QtWidgets[47339]
#define sipNameNr_ShowIndicator 30701
#define sipName_ShowIndicator &sipStrings_QtWidgets[30701]
#define sipNameNr_SortIndicator 4529
#define sipName_SortIndicator &sipStrings_QtWidgets[4529]
#define sipNameNr_StackingOrder 47353
#define sipName_StackingOrder &sipStrings_QtWidgets[47353]
#define sipNameNr_State_Editing 47367
#define sipName_State_Editing &sipStrings_QtWidgets[47367]
#define sipNameNr_State_Enabled 47381
#define sipName_State_Enabled &sipStrings_QtWidgets[47381]
#define sipNameNr_State_Sibling 47395
#define sipName_State_Sibling &sipStrings_QtWidgets[47395]
#define sipNameNr_State_UpArrow 47409
#define sipName_State_UpArrow &sipStrings_QtWidgets[47409]
#define sipNameNr_StepUpEnabled 47423
#define sipName_StepUpEnabled &sipStrings_QtWidgets[47423]
#define sipNameNr_SubWindowView 47437
#define sipName_SubWindowView &sipStrings_QtWidgets[47437]
#define sipNameNr_TakeRowResult 10325
#define sipName_TakeRowResult &sipStrings_QtWidgets[10325]
#define sipNameNr_UnsortedModel 47451
#define sipName_UnsortedModel &sipStrings_QtWidgets[47451]
#define sipNameNr_WizardOptions 16908
#define sipName_WizardOptions &sipStrings_QtWidgets[16908]
#define sipNameNr_aboutToResize 47465
#define sipName_aboutToResize &sipStrings_QtWidgets[47465]
#define sipNameNr_addDockWidget 47479
#define sipName_addDockWidget &sipStrings_QtWidgets[47479]
#define sipNameNr_addSimpleText 47493
#define sipName_addSimpleText &sipStrings_QtWidgets[47493]
#define sipNameNr_addSpacerItem 47507
#define sipName_addSpacerItem &sipStrings_QtWidgets[47507]
#define sipNameNr_alignmentRect 47521
#define sipName_alignmentRect &sipStrings_QtWidgets[47521]
#define sipNameNr_anchorClicked 47535
#define sipName_anchorClicked &sipStrings_QtWidgets[47535]
#define sipNameNr_autoExclusive 47549
#define sipName_autoExclusive &sipStrings_QtWidgets[47549]
#define sipNameNr_blockingPanel 47563
#define sipName_blockingPanel &sipStrings_QtWidgets[47563]
#define sipNameNr_buttonClicked 47577
#define sipName_buttonClicked &sipStrings_QtWidgets[47577]
#define sipNameNr_buttonDownPos 47591
#define sipName_buttonDownPos &sipStrings_QtWidgets[47591]
#define sipNameNr_buttonPressed 47605
#define sipName_buttonPressed &sipStrings_QtWidgets[47605]
#define sipNameNr_buttonSymbols 47619
#define sipName_buttonSymbols &sipStrings_QtWidgets[47619]
#define sipNameNr_buttonToggled 47633
#define sipName_buttonToggled &sipStrings_QtWidgets[47633]
#define sipNameNr_calendarPopup 47647
#define sipName_calendarPopup &sipStrings_QtWidgets[47647]
#define sipNameNr_cellActivated 47661
#define sipName_cellActivated &sipStrings_QtWidgets[47661]
#define sipNameNr_centerButtons 47675
#define sipName_centerButtons &sipStrings_QtWidgets[47675]
#define sipNameNr_centralWidget 47689
#define sipName_centralWidget &sipStrings_QtWidgets[47689]
#define sipNameNr_changedSignal 47703
#define sipName_changedSignal &sipStrings_QtWidgets[47703]
#define sipNameNr_checkOverflow 47717
#define sipName_checkOverflow &sipStrings_QtWidgets[47717]
#define sipNameNr_checkStateSet 47731
#define sipName_checkStateSet &sipStrings_QtWidgets[47731]
#define sipNameNr_checkedAction 47745
#define sipName_checkedAction &sipStrings_QtWidgets[47745]
#define sipNameNr_checkedButton 47759
#define sipName_checkedButton &sipStrings_QtWidgets[47759]
#define sipNameNr_clearContents 47773
#define sipName_clearContents &sipStrings_QtWidgets[47773]
#define sipNameNr_clearEditText 47787
#define sipName_clearEditText &sipStrings_QtWidgets[47787]
#define sipNameNr_clickedButton 47801
#define sipName_clickedButton &sipStrings_QtWidgets[47801]
#define sipNameNr_colorSelected 47815
#define sipName_colorSelected &sipStrings_QtWidgets[47815]
#define sipNameNr_columnResized 47829
#define sipName_columnResized &sipStrings_QtWidgets[47829]
#define sipNameNr_columnSpacing 47843
#define sipName_columnSpacing &sipStrings_QtWidgets[47843]
#define sipNameNr_columnStretch 47857
#define sipName_columnStretch &sipStrings_QtWidgets[47857]
#define sipNameNr_comboBoxItems 47871
#define sipName_comboBoxItems &sipStrings_QtWidgets[47871]
#define sipNameNr_connectNotify 35984
#define sipName_connectNotify &sipStrings_QtWidgets[35984]
#define sipNameNr_contentOffset 47885
#define sipName_contentOffset &sipStrings_QtWidgets[47885]
#define sipNameNr_copyAvailable 47899
#define sipName_copyAvailable &sipStrings_QtWidgets[47899]
#define sipNameNr_cornerWidgets 47913
#define sipName_cornerWidgets &sipStrings_QtWidgets[47913]
#define sipNameNr_currentColumn 47927
#define sipName_currentColumn &sipStrings_QtWidgets[47927]
#define sipNameNr_currentWidget 47941
#define sipName_currentWidget &sipStrings_QtWidgets[47941]
#define sipNameNr_cursorForward 47955
#define sipName_cursorForward &sipStrings_QtWidgets[47955]
#define sipNameNr_defaultAction 47969
#define sipName_defaultAction &sipStrings_QtWidgets[47969]
#define sipNameNr_defaultButton 47983
#define sipName_defaultButton &sipStrings_QtWidgets[47983]
#define sipNameNr_defaultSuffix 47997
#define sipName_defaultSuffix &sipStrings_QtWidgets[47997]
#define sipNameNr_defaultWidget 48011
#define sipName_defaultWidget &sipStrings_QtWidgets[48011]
#define sipNameNr_destroyEditor 48025
#define sipName_destroyEditor &sipStrings_QtWidgets[48025]
#define sipNameNr_destroyWindow 48039
#define sipName_destroyWindow &sipStrings_QtWidgets[48039]
#define sipNameNr_displayFormat 48053
#define sipName_displayFormat &sipStrings_QtWidgets[48053]
#define sipNameNr_documentTitle 48067
#define sipName_documentTitle &sipStrings_QtWidgets[48067]
#define sipNameNr_doubleClicked 48081
#define sipName_doubleClicked &sipStrings_QtWidgets[48081]
#define sipNameNr_doubleMaximum 48095
#define sipName_doubleMaximum &sipStrings_QtWidgets[48095]
#define sipNameNr_doubleMinimum 48109
#define sipName_doubleMinimum &sipStrings_QtWidgets[48109]
#define sipNameNr_dragMoveEvent 48123
#define sipName_dragMoveEvent &sipStrings_QtWidgets[48123]
#define sipNameNr_drawPrimitive 48137
#define sipName_drawPrimitive &sipStrings_QtWidgets[48137]
#define sipNameNr_ensureVisible 48151
#define sipName_ensureVisible &sipStrings_QtWidgets[48151]
#define sipNameNr_expandToDepth 48165
#define sipName_expandToDepth &sipStrings_QtWidgets[48165]
#define sipNameNr_filesSelected 48179
#define sipName_filesSelected &sipStrings_QtWidgets[48179]
#define sipNameNr_finalPosition 48193
#define sipName_finalPosition &sipStrings_QtWidgets[48193]
#define sipNameNr_focusOutEvent 48207
#define sipName_focusOutEvent &sipStrings_QtWidgets[48207]
#define sipNameNr_fontPointSize 48221
#define sipName_fontPointSize &sipStrings_QtWidgets[48221]
#define sipNameNr_fontUnderline 48235
#define sipName_fontUnderline &sipStrings_QtWidgets[48235]
#define sipNameNr_formAlignment 48249
#define sipName_formAlignment &sipStrings_QtWidgets[48249]
#define sipNameNr_frameGeometry 48263
#define sipName_frameGeometry &sipStrings_QtWidgets[48263]
#define sipNameNr_hasAutoScroll 48277
#define sipName_hasAutoScroll &sipStrings_QtWidgets[48277]
#define sipNameNr_helpRequested 48291
#define sipName_helpRequested &sipStrings_QtWidgets[48291]
#define sipNameNr_iconAlignment 48305
#define sipName_iconAlignment &sipStrings_QtWidgets[48305]
#define sipNameNr_indexFromItem 48319
#define sipName_indexFromItem &sipStrings_QtWidgets[48319]
#define sipNameNr_initialFilter 48333
#define sipName_initialFilter &sipStrings_QtWidgets[48333]
#define sipNameNr_inputRejected 48347
#define sipName_inputRejected &sipStrings_QtWidgets[48347]
#define sipNameNr_insertActions 48361
#define sipName_insertActions &sipStrings_QtWidgets[48361]
#define sipNameNr_insertColumns 48375
#define sipName_insertColumns &sipStrings_QtWidgets[48375]
#define sipNameNr_insertSection 48389
#define sipName_insertSection &sipStrings_QtWidgets[48389]
#define sipNameNr_insertSpacing 48403
#define sipName_insertSpacing &sipStrings_QtWidgets[48403]
#define sipNameNr_insertStretch 48417
#define sipName_insertStretch &sipStrings_QtWidgets[48417]
#define sipNameNr_insertToolBar 48431
#define sipName_insertToolBar &sipStrings_QtWidgets[48431]
#define sipNameNr_interpretText 48445
#define sipName_interpretText &sipStrings_QtWidgets[48445]
#define sipNameNr_isAccelerated 48459
#define sipName_isAccelerated &sipStrings_QtWidgets[48459]
#define sipNameNr_isAreaAllowed 48473
#define sipName_isAreaAllowed &sipStrings_QtWidgets[48473]
#define sipNameNr_isCollapsible 48487
#define sipName_isCollapsible &sipStrings_QtWidgets[48487]
#define sipNameNr_isGridVisible 48501
#define sipName_isGridVisible &sipStrings_QtWidgets[48501]
#define sipNameNr_isIndexHidden 48515
#define sipName_isIndexHidden &sipStrings_QtWidgets[48515]
#define sipNameNr_isInteractive 48529
#define sipName_isInteractive &sipStrings_QtWidgets[48529]
#define sipNameNr_isItemEnabled 48543
#define sipName_isItemEnabled &sipStrings_QtWidgets[48543]
#define sipNameNr_isLeftToRight 48557
#define sipName_isLeftToRight &sipStrings_QtWidgets[48557]
#define sipNameNr_isRightToLeft 48571
#define sipName_isRightToLeft &sipStrings_QtWidgets[48571]
#define sipNameNr_isTextVisible 48585
#define sipName_isTextVisible &sipStrings_QtWidgets[48585]
#define sipNameNr_isTransformed 48599
#define sipName_isTransformed &sipStrings_QtWidgets[48599]
#define sipNameNr_itemActivated 48613
#define sipName_itemActivated &sipStrings_QtWidgets[48613]
#define sipNameNr_itemAlignment 48627
#define sipName_itemAlignment &sipStrings_QtWidgets[48627]
#define sipNameNr_itemCollapsed 48641
#define sipName_itemCollapsed &sipStrings_QtWidgets[48641]
#define sipNameNr_itemFromIndex 48655
#define sipName_itemFromIndex &sipStrings_QtWidgets[48655]
#define sipNameNr_itemPrototype 48669
#define sipName_itemPrototype &sipStrings_QtWidgets[48669]
#define sipNameNr_itemTransform 48683
#define sipName_itemTransform &sipStrings_QtWidgets[48683]
#define sipNameNr_keyPressEvent 48697
#define sipName_keyPressEvent &sipStrings_QtWidgets[48697]
#define sipNameNr_labelForField 48711
#define sipName_labelForField &sipStrings_QtWidgets[48711]
#define sipNameNr_lastScreenPos 48725
#define sipName_lastScreenPos &sipStrings_QtWidgets[48725]
#define sipNameNr_layoutSpacing 48739
#define sipName_layoutSpacing &sipStrings_QtWidgets[48739]
#define sipNameNr_linkActivated 48753
#define sipName_linkActivated &sipStrings_QtWidgets[48753]
#define sipNameNr_mapFromGlobal 48767
#define sipName_mapFromGlobal &sipStrings_QtWidgets[48767]
#define sipNameNr_mapFromParent 48781
#define sipName_mapFromParent &sipStrings_QtWidgets[48781]
#define sipNameNr_mapRectToItem 48795
#define sipName_mapRectToItem &sipStrings_QtWidgets[48795]
#define sipNameNr_mappedSection 48809
#define sipName_mappedSection &sipStrings_QtWidgets[48809]
#define sipNameNr_maximumHeight 48823
#define sipName_maximumHeight &sipStrings_QtWidgets[48823]
#define sipNameNr_minimumHeight 48837
#define sipName_minimumHeight &sipStrings_QtWidgets[48837]
#define sipNameNr_offsetChanged 48851
#define sipName_offsetChanged &sipStrings_QtWidgets[48851]
#define sipNameNr_originChanged 48865
#define sipName_originChanged &sipStrings_QtWidgets[48865]
#define sipNameNr_overwriteMode 48879
#define sipName_overwriteMode &sipStrings_QtWidgets[48879]
#define sipNameNr_ownedByLayout 48893
#define sipName_ownedByLayout &sipStrings_QtWidgets[48893]
#define sipNameNr_panelModality 48907
#define sipName_panelModality &sipStrings_QtWidgets[48907]
#define sipNameNr_parentChanged 48921
#define sipName_parentChanged &sipStrings_QtWidgets[48921]
#define sipNameNr_pathFromIndex 48935
#define sipName_pathFromIndex &sipStrings_QtWidgets[48935]
#define sipNameNr_pixelPerMeter 48949
#define sipName_pixelPerMeter &sipStrings_QtWidgets[48949]
#define sipNameNr_preferredSize 48963
#define sipName_preferredSize &sipStrings_QtWidgets[48963]
#define sipNameNr_previewWidget 48977
#define sipName_previewWidget &sipStrings_QtWidgets[48977]
#define sipNameNr_primaryScreen 48991
#define sipName_primaryScreen &sipStrings_QtWidgets[48991]
#define sipNameNr_qDrawWinPanel 49005
#define sipName_qDrawWinPanel &sipStrings_QtWidgets[49005]
#define sipNameNr_redoAvailable 49019
#define sipName_redoAvailable &sipStrings_QtWidgets[49019]
#define sipNameNr_registerField 49033
#define sipName_registerField &sipStrings_QtWidgets[49033]
#define sipNameNr_releaseWidget 49047
#define sipName_releaseWidget &sipStrings_QtWidgets[49047]
#define sipNameNr_removeColumns 49061
#define sipName_removeColumns &sipStrings_QtWidgets[49061]
#define sipNameNr_removeMapping 49075
#define sipName_removeMapping &sipStrings_QtWidgets[49075]
#define sipNameNr_removeToolBar 49089
#define sipName_removeToolBar &sipStrings_QtWidgets[49089]
#define sipNameNr_replaceWidget 49103
#define sipName_replaceWidget &sipStrings_QtWidgets[49103]
#define sipNameNr_requestUpdate 49117
#define sipName_requestUpdate &sipStrings_QtWidgets[49117]
#define sipNameNr_requestWidget 49131
#define sipName_requestWidget &sipStrings_QtWidgets[49131]
#define sipNameNr_resizeSection 49145
#define sipName_resizeSection &sipStrings_QtWidgets[49145]
#define sipNameNr_returnPressed 49159
#define sipName_returnPressed &sipStrings_QtWidgets[49159]
#define sipNameNr_rootDirectory 49173
#define sipName_rootDirectory &sipStrings_QtWidgets[49173]
#define sipNameNr_rotationAngle 49187
#define sipName_rotationAngle &sipStrings_QtWidgets[49187]
#define sipNameNr_rowWrapPolicy 49201
#define sipName_rowWrapPolicy &sipStrings_QtWidgets[49201]
#define sipNameNr_sectionsMoved 49215
#define sipName_sectionsMoved &sipStrings_QtWidgets[49215]
#define sipNameNr_selectedColor 49229
#define sipName_selectedColor &sipStrings_QtWidgets[49229]
#define sipNameNr_selectedFiles 49243
#define sipName_selectedFiles &sipStrings_QtWidgets[49243]
#define sipNameNr_selectedItems 49257
#define sipName_selectedItems &sipStrings_QtWidgets[49257]
#define sipNameNr_selectionArea 49271
#define sipName_selectionArea &sipStrings_QtWidgets[49271]
#define sipNameNr_selectionMode 49285
#define sipName_selectionMode &sipStrings_QtWidgets[49285]
#define sipNameNr_setAcceptMode 49299
#define sipName_setAcceptMode &sipStrings_QtWidgets[49299]
#define sipNameNr_setAutoRepeat 49313
#define sipName_setAutoRepeat &sipStrings_QtWidgets[49313]
#define sipNameNr_setAutoScroll 49327
#define sipName_setAutoScroll &sipStrings_QtWidgets[49327]
#define sipNameNr_setBackground 49341
#define sipName_setBackground &sipStrings_QtWidgets[49341]
#define sipNameNr_setBlurRadius 49355
#define sipName_setBlurRadius &sipStrings_QtWidgets[49355]
#define sipNameNr_setButtonText 49369
#define sipName_setButtonText &sipStrings_QtWidgets[49369]
#define sipNameNr_setCellWidget 49383
#define sipName_setCellWidget &sipStrings_QtWidgets[49383]
#define sipNameNr_setCheckState 49397
#define sipName_setCheckState &sipStrings_QtWidgets[49397]
#define sipNameNr_setCommitPage 49411
#define sipName_setCommitPage &sipStrings_QtWidgets[49411]
#define sipNameNr_setCurrentRow 49425
#define sipName_setCurrentRow &sipStrings_QtWidgets[49425]
#define sipNameNr_setDigitCount 49439
#define sipName_setDigitCount &sipStrings_QtWidgets[49439]
#define sipNameNr_setDoubleStep 49453
#define sipName_setDoubleStep &sipStrings_QtWidgets[49453]
#define sipNameNr_setDropAction 49467
#define sipName_setDropAction &sipStrings_QtWidgets[49467]
#define sipNameNr_setEditorData 49481
#define sipName_setEditorData &sipStrings_QtWidgets[49481]
#define sipNameNr_setEmptyLabel 49495
#define sipName_setEmptyLabel &sipStrings_QtWidgets[49495]
#define sipNameNr_setFilterMode 49509
#define sipName_setFilterMode &sipStrings_QtWidgets[49509]
#define sipNameNr_setFixedWidth 49523
#define sipName_setFixedWidth &sipStrings_QtWidgets[49523]
#define sipNameNr_setFocusProxy 49537
#define sipName_setFocusProxy &sipStrings_QtWidgets[49537]
#define sipNameNr_setFontFamily 49551
#define sipName_setFontFamily &sipStrings_QtWidgets[49551]
#define sipNameNr_setFontItalic 49565
#define sipName_setFontItalic &sipStrings_QtWidgets[49565]
#define sipNameNr_setFontWeight 49579
#define sipName_setFontWeight &sipStrings_QtWidgets[49579]
#define sipNameNr_setForeground 49593
#define sipName_setForeground &sipStrings_QtWidgets[49593]
#define sipNameNr_setFrameShape 49607
#define sipName_setFrameShape &sipStrings_QtWidgets[49607]
#define sipNameNr_setFrameStyle 49621
#define sipName_setFrameStyle &sipStrings_QtWidgets[49621]
#define sipNameNr_setHeaderData 49635
#define sipName_setHeaderData &sipStrings_QtWidgets[49635]
#define sipNameNr_setHeaderItem 49649
#define sipName_setHeaderItem &sipStrings_QtWidgets[49649]
#define sipNameNr_setIconPixmap 49663
#define sipName_setIconPixmap &sipStrings_QtWidgets[49663]
#define sipNameNr_setIntMaximum 49677
#define sipName_setIntMaximum &sipStrings_QtWidgets[49677]
#define sipNameNr_setIntMinimum 49691
#define sipName_setIntMinimum &sipStrings_QtWidgets[49691]
#define sipNameNr_setItemWidget 49705
#define sipName_setItemWidget &sipStrings_QtWidgets[49705]
#define sipNameNr_setLastOffset 49719
#define sipName_setLastOffset &sipStrings_QtWidgets[49719]
#define sipNameNr_setLayoutMode 49733
#define sipName_setLayoutMode &sipStrings_QtWidgets[49733]
#define sipNameNr_setMenuWidget 49747
#define sipName_setMenuWidget &sipStrings_QtWidgets[49747]
#define sipNameNr_setNameFilter 49761
#define sipName_setNameFilter &sipStrings_QtWidgets[49761]
#define sipNameNr_setParentItem 49775
#define sipName_setParentItem &sipStrings_QtWidgets[49775]
#define sipNameNr_setProxyModel 49789
#define sipName_setProxyModel &sipStrings_QtWidgets[49789]
#define sipNameNr_setRenderHint 49803
#define sipName_setRenderHint &sipStrings_QtWidgets[49803]
#define sipNameNr_setResizeMode 49817
#define sipName_setResizeMode &sipStrings_QtWidgets[49817]
#define sipNameNr_setRowSpacing 49831
#define sipName_setRowSpacing &sipStrings_QtWidgets[49831]
#define sipNameNr_setRowStretch 49845
#define sipName_setRowStretch &sipStrings_QtWidgets[49845]
#define sipNameNr_setRubberBand 49859
#define sipName_setRubberBand &sipStrings_QtWidgets[49859]
#define sipNameNr_setSideWidget 49873
#define sipName_setSideWidget &sipStrings_QtWidgets[49873]
#define sipNameNr_setSingleStep 49887
#define sipName_setSingleStep &sipStrings_QtWidgets[49887]
#define sipNameNr_setSizePolicy 49901
#define sipName_setSizePolicy &sipStrings_QtWidgets[49901]
#define sipNameNr_setSliderDown 49915
#define sipName_setSliderDown &sipStrings_QtWidgets[49915]
#define sipNameNr_setStartAngle 49929
#define sipName_setStartAngle &sipStrings_QtWidgets[49929]
#define sipNameNr_setStyleSheet 49943
#define sipName_setStyleSheet &sipStrings_QtWidgets[49943]
#define sipNameNr_setSwipeAngle 49957
#define sipName_setSwipeAngle &sipStrings_QtWidgets[49957]
#define sipNameNr_setSystemMenu 49971
#define sipName_setSystemMenu &sipStrings_QtWidgets[49971]
#define sipNameNr_setTabEnabled 49985
#define sipName_setTabEnabled &sipStrings_QtWidgets[49985]
#define sipNameNr_setTabToolTip 49999
#define sipName_setTabToolTip &sipStrings_QtWidgets[49999]
#define sipNameNr_setTabVisible 50013
#define sipName_setTabVisible &sipStrings_QtWidgets[50013]
#define sipNameNr_setTextCursor 50027
#define sipName_setTextCursor &sipStrings_QtWidgets[50027]
#define sipNameNr_setTextFormat 50041
#define sipName_setTextFormat &sipStrings_QtWidgets[50041]
#define sipNameNr_setWindowFlag 50055
#define sipName_setWindowFlag &sipStrings_QtWidgets[50055]
#define sipNameNr_setWindowIcon 50069
#define sipName_setWindowIcon &sipStrings_QtWidgets[50069]
#define sipNameNr_setWindowRole 50083
#define sipName_setWindowRole &sipStrings_QtWidgets[50083]
#define sipNameNr_setWrapAround 50097
#define sipName_setWrapAround &sipStrings_QtWidgets[50097]
#define sipNameNr_setupViewport 50111
#define sipName_setupViewport &sipStrings_QtWidgets[50111]
#define sipNameNr_sharedPainter 50125
#define sipName_sharedPainter &sipStrings_QtWidgets[50125]
#define sipNameNr_showMaximized 50139
#define sipName_showMaximized &sipStrings_QtWidgets[50139]
#define sipNameNr_showMinimized 50153
#define sipName_showMinimized &sipStrings_QtWidgets[50153]
#define sipNameNr_showNextMonth 50167
#define sipName_showNextMonth &sipStrings_QtWidgets[50167]
#define sipNameNr_sizeIncrement 50181
#define sipName_sizeIncrement &sipStrings_QtWidgets[50181]
#define sipNameNr_sliderPressed 50195
#define sipName_sliderPressed &sipStrings_QtWidgets[50195]
#define sipNameNr_sortIndicator 50209
#define sipName_sortIndicator &sipStrings_QtWidgets[50209]
#define sipNameNr_sourceChanged 50223
#define sipName_sourceChanged &sipStrings_QtWidgets[50223]
#define sipNameNr_splitterMoved 50237
#define sipName_splitterMoved &sipStrings_QtWidgets[50237]
#define sipNameNr_standardColor 50251
#define sipName_standardColor &sipStrings_QtWidgets[50251]
#define sipNameNr_startDragTime 50265
#define sipName_startDragTime &sipStrings_QtWidgets[50265]
#define sipNameNr_stretchFactor 50279
#define sipName_stretchFactor &sipStrings_QtWidgets[50279]
#define sipNameNr_subWidgetRect 50293
#define sipName_subWidgetRect &sipStrings_QtWidgets[50293]
#define sipNameNr_subWindowList 50307
#define sipName_subWindowList &sipStrings_QtWidgets[50307]
#define sipNameNr_tabBarClicked 50321
#define sipName_tabBarClicked &sipStrings_QtWidgets[50321]
#define sipNameNr_testAttribute 50335
#define sipName_testAttribute &sipStrings_QtWidgets[50335]
#define sipNameNr_textActivated 50349
#define sipName_textActivated &sipStrings_QtWidgets[50349]
#define sipNameNr_textAlignment 50363
#define sipName_textAlignment &sipStrings_QtWidgets[50363]
#define sipNameNr_textElideMode 50377
#define sipName_textElideMode &sipStrings_QtWidgets[50377]
#define sipNameNr_textFromValue 50391
#define sipName_textFromValue &sipStrings_QtWidgets[50391]
#define sipNameNr_textureFormat 50405
#define sipName_textureFormat &sipStrings_QtWidgets[50405]
#define sipNameNr_thresholdTime 50419
#define sipName_thresholdTime &sipStrings_QtWidgets[50419]
#define sipNameNr_titleBarFlags 50433
#define sipName_titleBarFlags &sipStrings_QtWidgets[50433]
#define sipNameNr_titleBarState 50447
#define sipName_titleBarState &sipStrings_QtWidgets[50447]
#define sipNameNr_totalSizeHint 50461
#define sipName_totalSizeHint &sipStrings_QtWidgets[50461]
#define sipNameNr_triggerAction 50475
#define sipName_triggerAction &sipStrings_QtWidgets[50475]
#define sipNameNr_undoAvailable 50489
#define sipName_undoAvailable &sipStrings_QtWidgets[50489]
#define sipNameNr_ungrabGesture 50503
#define sipName_ungrabGesture &sipStrings_QtWidgets[50503]
#define sipNameNr_updateRequest 50517
#define sipName_updateRequest &sipStrings_QtWidgets[50517]
#define sipNameNr_updateSection 50531
#define sipName_updateSection &sipStrings_QtWidgets[50531]
#define sipNameNr_valueFromText 50545
#define sipName_valueFromText &sipStrings_QtWidgets[50545]
#define sipNameNr_viewportEvent 50559
#define sipName_viewportEvent &sipStrings_QtWidgets[50559]
#define sipNameNr_visibleRegion 50573
#define sipName_visibleRegion &sipStrings_QtWidgets[50573]
#define sipNameNr_visualIndexAt 50587
#define sipName_visualIndexAt &sipStrings_QtWidgets[50587]
#define sipNameNr_widgetRemoved 50601
#define sipName_widgetRemoved &sipStrings_QtWidgets[50601]
#define sipNameNr_windowOpacity 50615
#define sipName_windowOpacity &sipStrings_QtWidgets[50615]
#define sipNameNr_writingSystem 50629
#define sipName_writingSystem &sipStrings_QtWidgets[50629]
#define sipNameNr_xScaleChanged 50643
#define sipName_xScaleChanged &sipStrings_QtWidgets[50643]
#define sipNameNr_yScaleChanged 50657
#define sipName_yScaleChanged &sipStrings_QtWidgets[50657]
#define sipNameNr_zScaleChanged 50671
#define sipName_zScaleChanged &sipStrings_QtWidgets[50671]
#define sipNameNr_BannerPixmap 50685
#define sipName_BannerPixmap &sipStrings_QtWidgets[50685]
#define sipNameNr_BspTreeIndex 50698
#define sipName_BspTreeIndex &sipStrings_QtWidgets[50698]
#define sipNameNr_ButtonLayout 6346
#define sipName_ButtonLayout &sipStrings_QtWidgets[6346]
#define sipNameNr_CC_ScrollBar 50711
#define sipName_CC_ScrollBar &sipStrings_QtWidgets[50711]
#define sipNameNr_CE_TabBarTab 50724
#define sipName_CE_TabBarTab &sipStrings_QtWidgets[50724]
#define sipNameNr_CT_ScrollBar 50737
#define sipName_CT_ScrollBar &sipStrings_QtWidgets[50737]
#define sipNameNr_CT_TabBarTab 50750
#define sipName_CT_TabBarTab &sipStrings_QtWidgets[50750]
#define sipNameNr_CT_TabWidget 50763
#define sipName_CT_TabWidget &sipStrings_QtWidgets[50763]
#define sipNameNr_CancelButton 3340
#define sipName_CancelButton &sipStrings_QtWidgets[3340]
#define sipNameNr_ClassicStyle 50776
#define sipName_ClassicStyle &sipStrings_QtWidgets[50776]
#define sipNameNr_CommitButton 50789
#define sipName_CommitButton &sipStrings_QtWidgets[50789]
#define sipNameNr_ContentsType 21544
#define sipName_ContentsType &sipStrings_QtWidgets[21544]
#define sipNameNr_ControlTypes 11650
#define sipName_ControlTypes &sipStrings_QtWidgets[11650]
#define sipNameNr_CornerWidget 7659
#define sipName_CornerWidget &sipStrings_QtWidgets[7659]
#define sipNameNr_CursorAction 5426
#define sipName_CursorAction &sipStrings_QtWidgets[5426]
#define sipNameNr_DelayedPopup 50802
#define sipName_DelayedPopup &sipStrings_QtWidgets[50802]
#define sipNameNr_DontUseSheet 50815
#define sipName_DontUseSheet &sipStrings_QtWidgets[50815]
#define sipNameNr_DontWrapRows 50828
#define sipName_DontWrapRows &sipStrings_QtWidgets[50828]
#define sipNameNr_DragDisabled 50841
#define sipName_DragDisabled &sipStrings_QtWidgets[50841]
#define sipNameNr_DragDropMode 5458
#define sipName_DragDropMode &sipStrings_QtWidgets[5458]
#define sipNameNr_DrawChildren 50854
#define sipName_DrawChildren &sipStrings_QtWidgets[50854]
#define sipNameNr_DropDisabled 50867
#define sipName_DropDisabled &sipStrings_QtWidgets[50867]
#define sipNameNr_EditNextItem 50880
#define sipName_EditNextItem &sipStrings_QtWidgets[50880]
#define sipNameNr_EditTriggers 5490
#define sipName_EditTriggers &sipStrings_QtWidgets[5490]
#define sipNameNr_EditingState 50893
#define sipName_EditingState &sipStrings_QtWidgets[50893]
#define sipNameNr_ExistingFile 50906
#define sipName_ExistingFile &sipStrings_QtWidgets[50906]
#define sipNameNr_FileIconRole 50919
#define sipName_FileIconRole &sipStrings_QtWidgets[50919]
#define sipNameNr_FileNameRole 50932
#define sipName_FileNameRole &sipStrings_QtWidgets[50932]
#define sipNameNr_FilePathRole 50945
#define sipName_FilePathRole &sipStrings_QtWidgets[50945]
#define sipNameNr_FinishButton 50958
#define sipName_FinishButton &sipStrings_QtWidgets[50958]
#define sipNameNr_FrameFeature 5842
#define sipName_FrameFeature &sipStrings_QtWidgets[5842]
#define sipNameNr_HighPriority 50971
#define sipName_HighPriority &sipStrings_QtWidgets[50971]
#define sipNameNr_InputRelease 50984
#define sipName_InputRelease &sipStrings_QtWidgets[50984]
#define sipNameNr_InsertPolicy 14467
#define sipName_InsertPolicy &sipStrings_QtWidgets[14467]
#define sipNameNr_InstantPopup 50997
#define sipName_InstantPopup &sipStrings_QtWidgets[50997]
#define sipNameNr_InternalMove 51010
#define sipName_InternalMove &sipStrings_QtWidgets[51010]
#define sipNameNr_IteratorFlag 2745
#define sipName_IteratorFlag &sipStrings_QtWidgets[2745]
#define sipNameNr_LineWrapMode 8424
#define sipName_LineWrapMode &sipStrings_QtWidgets[8424]
#define sipNameNr_LongDayNames 51023
#define sipName_LongDayNames &sipStrings_QtWidgets[51023]
#define sipNameNr_ManualSubmit 51036
#define sipName_ManualSubmit &sipStrings_QtWidgets[51036]
#define sipNameNr_MayBeGesture 51049
#define sipName_MayBeGesture &sipStrings_QtWidgets[51049]
#define sipNameNr_MenuItemType 3947
#define sipName_MenuItemType &sipStrings_QtWidgets[3947]
#define sipNameNr_ModelSorting 12908
#define sipName_ModelSorting &sipStrings_QtWidgets[12908]
#define sipNameNr_MonthSection 51062
#define sipName_MonthSection &sipStrings_QtWidgets[51062]
#define sipNameNr_MovePageDown 51075
#define sipName_MovePageDown &sipStrings_QtWidgets[51075]
#define sipNameNr_MovePrevious 51088
#define sipName_MovePrevious &sipStrings_QtWidgets[51088]
#define sipNameNr_NonExclusive 51101
#define sipName_NonExclusive &sipStrings_QtWidgets[51101]
#define sipNameNr_NotCheckable 51114
#define sipName_NotCheckable &sipStrings_QtWidgets[51114]
#define sipNameNr_PE_FrameMenu 51127
#define sipName_PE_FrameMenu &sipStrings_QtWidgets[51127]
#define sipNameNr_PE_PanelMenu 51140
#define sipName_PE_PanelMenu &sipStrings_QtWidgets[51140]
#define sipNameNr_QActionGroup 51153
#define sipName_QActionGroup &sipStrings_QtWidgets[51153]
#define sipNameNr_QApplication 51166
#define sipName_QApplication &sipStrings_QtWidgets[51166]
#define sipNameNr_QButtonGroup 51179
#define sipName_QButtonGroup &sipStrings_QtWidgets[51179]
#define sipNameNr_QColorDialog 51192
#define sipName_QColorDialog &sipStrings_QtWidgets[51192]
#define sipNameNr_QCommonStyle 51205
#define sipName_QCommonStyle &sipStrings_QtWidgets[51205]
#define sipNameNr_QInputDialog 51218
#define sipName_QInputDialog &sipStrings_QtWidgets[51218]
#define sipNameNr_QProgressBar 51231
#define sipName_QProgressBar &sipStrings_QtWidgets[51231]
#define sipNameNr_QRadioButton 51244
#define sipName_QRadioButton &sipStrings_QtWidgets[51244]
#define sipNameNr_QStyleOption 51257
#define sipName_QStyleOption &sipStrings_QtWidgets[51257]
#define sipNameNr_QTableWidget 51270
#define sipName_QTableWidget &sipStrings_QtWidgets[51270]
#define sipNameNr_QTextBrowser 51283
#define sipName_QTextBrowser &sipStrings_QtWidgets[51283]
#define sipNameNr_QUndoCommand 51296
#define sipName_QUndoCommand &sipStrings_QtWidgets[51296]
#define sipNameNr_RoundedNorth 51309
#define sipName_RoundedNorth &sipStrings_QtWidgets[51309]
#define sipNameNr_RoundedSouth 51322
#define sipName_RoundedSouth &sipStrings_QtWidgets[51322]
#define sipNameNr_SC_SpinBoxUp 51335
#define sipName_SC_SpinBoxUp &sipStrings_QtWidgets[51335]
#define sipNameNr_SH_Menu_Mask 51348
#define sipName_SH_Menu_Mask &sipStrings_QtWidgets[51348]
#define sipNameNr_SO_FocusRect 51361
#define sipName_SO_FocusRect &sipStrings_QtWidgets[51361]
#define sipNameNr_SP_ArrowBack 51374
#define sipName_SP_ArrowBack &sipStrings_QtWidgets[51374]
#define sipNameNr_SP_ArrowDown 51387
#define sipName_SP_ArrowDown &sipStrings_QtWidgets[51387]
#define sipNameNr_SP_ArrowLeft 51400
#define sipName_SP_ArrowLeft &sipStrings_QtWidgets[51400]
#define sipNameNr_SP_MediaPlay 51413
#define sipName_SP_MediaPlay &sipStrings_QtWidgets[51413]
#define sipNameNr_SP_MediaStop 51426
#define sipName_SP_MediaStop &sipStrings_QtWidgets[51426]
#define sipNameNr_SP_TrashIcon 51439
#define sipName_SP_TrashIcon &sipStrings_QtWidgets[51439]
#define sipNameNr_ScrollMetric 4394
#define sipName_ScrollMetric &sipStrings_QtWidgets[4394]
#define sipNameNr_SegmentStyle 13108
#define sipName_SegmentStyle &sipStrings_QtWidgets[13108]
#define sipNameNr_SetFixedSize 51452
#define sipName_SetFixedSize &sipStrings_QtWidgets[51452]
#define sipNameNr_ShowDirsOnly 51465
#define sipName_ShowDirsOnly &sipStrings_QtWidgets[51465]
#define sipNameNr_SliderAction 7359
#define sipName_SliderAction &sipStrings_QtWidgets[7359]
#define sipNameNr_SliderChange 7389
#define sipName_SliderChange &sipStrings_QtWidgets[7389]
#define sipNameNr_SpanningRole 51478
#define sipName_SpanningRole &sipStrings_QtWidgets[51478]
#define sipNameNr_StackingMode 8453
#define sipName_StackingMode &sipStrings_QtWidgets[8453]
#define sipNameNr_State_Active 51491
#define sipName_State_Active &sipStrings_QtWidgets[51491]
#define sipNameNr_State_Bottom 51504
#define sipName_State_Bottom &sipStrings_QtWidgets[51504]
#define sipNameNr_State_Raised 51517
#define sipName_State_Raised &sipStrings_QtWidgets[51517]
#define sipNameNr_State_Sunken 51530
#define sipName_State_Sunken &sipStrings_QtWidgets[51530]
#define sipNameNr_State_Window 51543
#define sipName_State_Window &sipStrings_QtWidgets[51543]
#define sipNameNr_SubmitPolicy 5586
#define sipName_SubmitPolicy &sipStrings_QtWidgets[5586]
#define sipNameNr_TickPosition 18984
#define sipName_TickPosition &sipStrings_QtWidgets[18984]
#define sipNameNr_TouchGesture 51556
#define sipName_TouchGesture &sipStrings_QtWidgets[51556]
#define sipNameNr_UpDownArrows 51569
#define sipName_UpDownArrows &sipStrings_QtWidgets[51569]
#define sipNameNr_VerticalTabs 51582
#define sipName_VerticalTabs &sipStrings_QtWidgets[51582]
#define sipNameNr_WizardButton 19028
#define sipName_WizardButton &sipStrings_QtWidgets[19028]
#define sipNameNr_WizardOption 19050
#define sipName_WizardOption &sipStrings_QtWidgets[19050]
#define sipNameNr_WizardPixmap 19072
#define sipName_WizardPixmap &sipStrings_QtWidgets[19072]
#define sipNameNr_WrapLongRows 51595
#define sipName_WrapLongRows &sipStrings_QtWidgets[51595]
#define sipNameNr_acceleration 51608
#define sipName_acceleration &sipStrings_QtWidgets[51608]
#define sipNameNr_activeAction 51621
#define sipName_activeAction &sipStrings_QtWidgets[51621]
#define sipNameNr_activeWindow 51634
#define sipName_activeWindow &sipStrings_QtWidgets[51634]
#define sipNameNr_addSeparator 51647
#define sipName_addSeparator &sipStrings_QtWidgets[51647]
#define sipNameNr_addSubWindow 51660
#define sipName_addSubWindow &sipStrings_QtWidgets[51660]
#define sipNameNr_allowedAreas 51673
#define sipName_allowedAreas &sipStrings_QtWidgets[51673]
#define sipNameNr_angleChanged 51686
#define sipName_angleChanged &sipStrings_QtWidgets[51686]
#define sipNameNr_animateClick 51699
#define sipName_animateClick &sipStrings_QtWidgets[51699]
#define sipNameNr_boundingRect 51712
#define sipName_boundingRect &sipStrings_QtWidgets[51712]
#define sipNameNr_bspTreeDepth 51725
#define sipName_bspTreeDepth &sipStrings_QtWidgets[51725]
#define sipNameNr_canFetchMore 51738
#define sipName_canFetchMore &sipStrings_QtWidgets[51738]
#define sipNameNr_centerCursor 51751
#define sipName_centerCursor &sipStrings_QtWidgets[51751]
#define sipNameNr_childrenRect 51764
#define sipName_childrenRect &sipStrings_QtWidgets[51764]
#define sipNameNr_cleanChanged 51777
#define sipName_cleanChanged &sipStrings_QtWidgets[51777]
#define sipNameNr_clearHistory 51790
#define sipName_clearHistory &sipStrings_QtWidgets[51790]
#define sipNameNr_clearMapping 51803
#define sipName_clearMapping &sipStrings_QtWidgets[51803]
#define sipNameNr_clearMessage 51816
#define sipName_clearMessage &sipStrings_QtWidgets[51816]
#define sipNameNr_collapseItem 51829
#define sipName_collapseItem &sipStrings_QtWidgets[51829]
#define sipNameNr_colorChanged 51842
#define sipName_colorChanged &sipStrings_QtWidgets[51842]
#define sipNameNr_columnWidths 51855
#define sipName_columnWidths &sipStrings_QtWidgets[51855]
#define sipNameNr_contentsRect 51868
#define sipName_contentsRect &sipStrings_QtWidgets[51868]
#define sipNameNr_controlTypes 51881
#define sipName_controlTypes &sipStrings_QtWidgets[51881]
#define sipNameNr_cornerWidget 51894
#define sipName_cornerWidget &sipStrings_QtWidgets[51894]
#define sipNameNr_createAction 51907
#define sipName_createAction &sipStrings_QtWidgets[51907]
#define sipNameNr_createColumn 51920
#define sipName_createColumn &sipStrings_QtWidgets[51920]
#define sipNameNr_createEditor 51933
#define sipName_createEditor &sipStrings_QtWidgets[51933]
#define sipNameNr_createHandle 51946
#define sipName_createHandle &sipStrings_QtWidgets[51946]
#define sipNameNr_createWidget 51959
#define sipName_createWidget &sipStrings_QtWidgets[51959]
#define sipNameNr_currentColor 51972
#define sipName_currentColor &sipStrings_QtWidgets[51972]
#define sipNameNr_currentIndex 51985
#define sipName_currentIndex &sipStrings_QtWidgets[51985]
#define sipNameNr_deleteWidget 51998
#define sipName_deleteWidget &sipStrings_QtWidgets[51998]
#define sipNameNr_detailedText 52011
#define sipName_detailedText &sipStrings_QtWidgets[52011]
#define sipNameNr_dialWrapping 52024
#define sipName_dialWrapping &sipStrings_QtWidgets[52024]
#define sipNameNr_directoryUrl 52037
#define sipName_directoryUrl &sipStrings_QtWidgets[52037]
#define sipNameNr_documentMode 52050
#define sipName_documentMode &sipStrings_QtWidgets[52050]
#define sipNameNr_documentSize 52063
#define sipName_documentSize &sipStrings_QtWidgets[52063]
#define sipNameNr_dragDropMode 52076
#define sipName_dragDropMode &sipStrings_QtWidgets[52076]
#define sipNameNr_drawBranches 52089
#define sipName_drawBranches &sipStrings_QtWidgets[52089]
#define sipNameNr_drawContents 52102
#define sipName_drawContents &sipStrings_QtWidgets[52102]
#define sipNameNr_drawItemText 52115
#define sipName_drawItemText &sipStrings_QtWidgets[52115]
#define sipNameNr_dropMimeData 52128
#define sipName_dropMimeData &sipStrings_QtWidgets[52128]
#define sipNameNr_editTriggers 52141
#define sipName_editTriggers &sipStrings_QtWidgets[52141]
#define sipNameNr_escapeButton 52154
#define sipName_escapeButton &sipStrings_QtWidgets[52154]
#define sipNameNr_fileNameHint 52167
#define sipName_fileNameHint &sipStrings_QtWidgets[52167]
#define sipNameNr_fileSelected 52180
#define sipName_fileSelected &sipStrings_QtWidgets[52180]
#define sipNameNr_focusChanged 52193
#define sipName_focusChanged &sipStrings_QtWidgets[52193]
#define sipNameNr_focusInEvent 52206
#define sipName_focusInEvent &sipStrings_QtWidgets[52206]
#define sipNameNr_focusOnTouch 52219
#define sipName_focusOnTouch &sipStrings_QtWidgets[52219]
#define sipNameNr_fontSelected 52232
#define sipName_fontSelected &sipStrings_QtWidgets[52232]
#define sipNameNr_frameSwapped 52245
#define sipName_frameSwapped &sipStrings_QtWidgets[52245]
#define sipNameNr_grabKeyboard 46251
#define sipName_grabKeyboard &sipStrings_QtWidgets[46251]
#define sipNameNr_grabShortcut 52258
#define sipName_grabShortcut &sipStrings_QtWidgets[52258]
#define sipNameNr_graphicsItem 52271
#define sipName_graphicsItem &sipStrings_QtWidgets[52271]
#define sipNameNr_historyTitle 52284
#define sipName_historyTitle &sipStrings_QtWidgets[52284]
#define sipNameNr_iconProvider 52297
#define sipName_iconProvider &sipStrings_QtWidgets[52297]
#define sipNameNr_indexChanged 52310
#define sipName_indexChanged &sipStrings_QtWidgets[52310]
#define sipNameNr_indexOfChild 52323
#define sipName_indexOfChild &sipStrings_QtWidgets[52323]
#define sipNameNr_indexesMoved 52336
#define sipName_indexesMoved &sipStrings_QtWidgets[52336]
#define sipNameNr_initializeGL 52349
#define sipName_initializeGL &sipStrings_QtWidgets[52349]
#define sipNameNr_insertAction 52362
#define sipName_insertAction &sipStrings_QtWidgets[52362]
#define sipNameNr_insertColumn 52375
#define sipName_insertColumn &sipStrings_QtWidgets[52375]
#define sipNameNr_insertLayout 52388
#define sipName_insertLayout &sipStrings_QtWidgets[52388]
#define sipNameNr_insertPolicy 52401
#define sipName_insertPolicy &sipStrings_QtWidgets[52401]
#define sipNameNr_insertWidget 52414
#define sipName_insertWidget &sipStrings_QtWidgets[52414]
#define sipNameNr_isAncestorOf 52427
#define sipName_isAncestorOf &sipStrings_QtWidgets[52427]
#define sipNameNr_isCommitPage 52440
#define sipName_isCommitPage &sipStrings_QtWidgets[52440]
#define sipNameNr_isFullScreen 52453
#define sipName_isFullScreen &sipStrings_QtWidgets[52453]
#define sipNameNr_isObscuredBy 52466
#define sipName_isObscuredBy &sipStrings_QtWidgets[52466]
#define sipNameNr_isSliderDown 52479
#define sipName_isSliderDown &sipStrings_QtWidgets[52479]
#define sipNameNr_isTabEnabled 52492
#define sipName_isTabEnabled &sipStrings_QtWidgets[52492]
#define sipNameNr_isTabVisible 52505
#define sipName_isTabVisible &sipStrings_QtWidgets[52505]
#define sipNameNr_isUnderMouse 52518
#define sipName_isUnderMouse &sipStrings_QtWidgets[52518]
#define sipNameNr_itemDelegate 52531
#define sipName_itemDelegate &sipStrings_QtWidgets[52531]
#define sipNameNr_itemExpanded 52544
#define sipName_itemExpanded &sipStrings_QtWidgets[52544]
#define sipNameNr_itemInserted 52557
#define sipName_itemInserted &sipStrings_QtWidgets[52557]
#define sipNameNr_itemTextRect 52570
#define sipName_itemTextRect &sipStrings_QtWidgets[52570]
#define sipNameNr_lastModified 52583
#define sipName_lastModified &sipStrings_QtWidgets[52583]
#define sipNameNr_lastScenePos 52596
#define sipName_lastScenePos &sipStrings_QtWidgets[52596]
#define sipNameNr_lineWrapMode 52609
#define sipName_lineWrapMode &sipStrings_QtWidgets[52609]
#define sipNameNr_loadResource 52622
#define sipName_loadResource &sipStrings_QtWidgets[52622]
#define sipNameNr_logicalIndex 52635
#define sipName_logicalIndex &sipStrings_QtWidgets[52635]
#define sipNameNr_mapFromScene 52648
#define sipName_mapFromScene &sipStrings_QtWidgets[52648]
#define sipNameNr_maxIconWidth 52661
#define sipName_maxIconWidth &sipStrings_QtWidgets[52661]
#define sipNameNr_maximumWidth 52674
#define sipName_maximumWidth &sipStrings_QtWidgets[52674]
#define sipNameNr_menuItemType 52687
#define sipName_menuItemType &sipStrings_QtWidgets[52687]
#define sipNameNr_midLineWidth 52700
#define sipName_midLineWidth &sipStrings_QtWidgets[52700]
#define sipNameNr_minimumWidth 52713
#define sipName_minimumWidth &sipStrings_QtWidgets[52713]
#define sipNameNr_modelSorting 52726
#define sipName_modelSorting &sipStrings_QtWidgets[52726]
#define sipNameNr_modifierMask 52739
#define sipName_modifierMask &sipStrings_QtWidgets[52739]
#define sipNameNr_mouseGrabber 52752
#define sipName_mouseGrabber &sipStrings_QtWidgets[52752]
#define sipNameNr_moveSplitter 52765
#define sipName_moveSplitter &sipStrings_QtWidgets[52765]
#define sipNameNr_okButtonText 52778
#define sipName_okButtonText &sipStrings_QtWidgets[52778]
#define sipNameNr_onTransition 52791
#define sipName_onTransition &sipStrings_QtWidgets[52791]
#define sipNameNr_opaqueResize 52804
#define sipName_opaqueResize &sipStrings_QtWidgets[52804]
#define sipNameNr_orientations 52817
#define sipName_orientations &sipStrings_QtWidgets[52817]
#define sipNameNr_originCorner 52830
#define sipName_originCorner &sipStrings_QtWidgets[52830]
#define sipNameNr_paintSection 52843
#define sipName_paintSection &sipStrings_QtWidgets[52843]
#define sipNameNr_parentObject 52856
#define sipName_parentObject &sipStrings_QtWidgets[52856]
#define sipNameNr_parentWidget 52869
#define sipName_parentWidget &sipStrings_QtWidgets[52869]
#define sipNameNr_rangeChanged 52882
#define sipName_rangeChanged &sipStrings_QtWidgets[52882]
#define sipNameNr_rectForIndex 52895
#define sipName_rectForIndex &sipStrings_QtWidgets[52895]
#define sipNameNr_releaseMouse 52908
#define sipName_releaseMouse &sipStrings_QtWidgets[52908]
#define sipNameNr_removeAction 52921
#define sipName_removeAction &sipStrings_QtWidgets[52921]
#define sipNameNr_removeButton 52934
#define sipName_removeButton &sipStrings_QtWidgets[52934]
#define sipNameNr_removeColumn 52947
#define sipName_removeColumn &sipStrings_QtWidgets[52947]
#define sipNameNr_removeWidget 52960
#define sipName_removeWidget &sipStrings_QtWidgets[52960]
#define sipNameNr_repeatAction 52973
#define sipName_repeatAction &sipStrings_QtWidgets[52973]
#define sipNameNr_resizeAnchor 52986
#define sipName_resizeAnchor &sipStrings_QtWidgets[52986]
#define sipNameNr_restoreState 52999
#define sipName_restoreState &sipStrings_QtWidgets[52999]
#define sipNameNr_rowAlignment 13458
#define sipName_rowAlignment &sipStrings_QtWidgets[13458]
#define sipNameNr_rowsInserted 53012
#define sipName_rowsInserted &sipStrings_QtWidgets[53012]
#define sipNameNr_saveGeometry 53025
#define sipName_saveGeometry &sipStrings_QtWidgets[53025]
#define sipNameNr_scaleChanged 53038
#define sipName_scaleChanged &sipStrings_QtWidgets[53038]
#define sipNameNr_screenNumber 53051
#define sipName_screenNumber &sipStrings_QtWidgets[53051]
#define sipNameNr_scrollMetric 53064
#define sipName_scrollMetric &sipStrings_QtWidgets[53064]
#define sipNameNr_scrollToItem 53077
#define sipName_scrollToItem &sipStrings_QtWidgets[53077]
#define sipNameNr_sectionCount 53090
#define sipName_sectionCount &sipStrings_QtWidgets[53090]
#define sipNameNr_sectionMoved 53103
#define sipName_sectionMoved &sipStrings_QtWidgets[53103]
#define sipNameNr_segmentStyle 53116
#define sipName_segmentStyle &sipStrings_QtWidgets[53116]
#define sipNameNr_selectColumn 53129
#define sipName_selectColumn &sipStrings_QtWidgets[53129]
#define sipNameNr_selectedDate 53142
#define sipName_selectedDate &sipStrings_QtWidgets[53142]
#define sipNameNr_selectedFont 53155
#define sipName_selectedFont &sipStrings_QtWidgets[53155]
#define sipNameNr_selectedText 53168
#define sipName_selectedText &sipStrings_QtWidgets[53168]
#define sipNameNr_selectedUrls 53181
#define sipName_selectedUrls &sipStrings_QtWidgets[53181]
#define sipNameNr_selectionEnd 53194
#define sipName_selectionEnd &sipStrings_QtWidgets[53194]
#define sipNameNr_setAlignment 53207
#define sipName_setAlignment &sipStrings_QtWidgets[53207]
#define sipNameNr_setArrowType 53220
#define sipName_setArrowType &sipStrings_QtWidgets[53220]
#define sipNameNr_setAttribute 53233
#define sipName_setAttribute &sipStrings_QtWidgets[53233]
#define sipNameNr_setAutoClose 53246
#define sipName_setAutoClose &sipStrings_QtWidgets[53246]
#define sipNameNr_setAutoRaise 53259
#define sipName_setAutoRaise &sipStrings_QtWidgets[53259]
#define sipNameNr_setAutoReset 53272
#define sipName_setAutoReset &sipStrings_QtWidgets[53272]
#define sipNameNr_setBaseStyle 53285
#define sipName_setBaseStyle &sipStrings_QtWidgets[53285]
#define sipNameNr_setBatchSize 53298
#define sipName_setBatchSize &sipStrings_QtWidgets[53298]
#define sipNameNr_setBlurHints 53311
#define sipName_setBlurHints &sipStrings_QtWidgets[53311]
#define sipNameNr_setCacheMode 53324
#define sipName_setCacheMode &sipStrings_QtWidgets[53324]
#define sipNameNr_setCheckable 53337
#define sipName_setCheckable &sipStrings_QtWidgets[53337]
#define sipNameNr_setCleanIcon 53350
#define sipName_setCleanIcon &sipStrings_QtWidgets[53350]
#define sipNameNr_setColorSpec 53363
#define sipName_setColorSpec &sipStrings_QtWidgets[53363]
#define sipNameNr_setCompleter 53376
#define sipName_setCompleter &sipStrings_QtWidgets[53376]
#define sipNameNr_setDateRange 53389
#define sipName_setDateRange &sipStrings_QtWidgets[53389]
#define sipNameNr_setDefaultUp 53402
#define sipName_setDefaultUp &sipStrings_QtWidgets[53402]
#define sipNameNr_setDirection 53415
#define sipName_setDirection &sipStrings_QtWidgets[53415]
#define sipNameNr_setDirectory 53428
#define sipName_setDirectory &sipStrings_QtWidgets[53428]
#define sipNameNr_setElideMode 53441
#define sipName_setElideMode &sipStrings_QtWidgets[53441]
#define sipNameNr_setExclusive 53454
#define sipName_setExclusive &sipStrings_QtWidgets[53454]
#define sipNameNr_setExpanding 53467
#define sipName_setExpanding &sipStrings_QtWidgets[53467]
#define sipNameNr_setFinalPage 53480
#define sipName_setFinalPage &sipStrings_QtWidgets[53480]
#define sipNameNr_setFixedSize 53493
#define sipName_setFixedSize &sipStrings_QtWidgets[53493]
#define sipNameNr_setFloatable 53506
#define sipName_setFloatable &sipStrings_QtWidgets[53506]
#define sipNameNr_setFocusItem 53519
#define sipName_setFocusItem &sipStrings_QtWidgets[53519]
#define sipNameNr_setFrameRect 53532
#define sipName_setFrameRect &sipStrings_QtWidgets[53532]
#define sipNameNr_setGridStyle 53545
#define sipName_setGridStyle &sipStrings_QtWidgets[53545]
#define sipNameNr_setInputMask 53558
#define sipName_setInputMask &sipStrings_QtWidgets[53558]
#define sipNameNr_setInputMode 53571
#define sipName_setInputMode &sipStrings_QtWidgets[53571]
#define sipNameNr_setLabelText 53584
#define sipName_setLabelText &sipStrings_QtWidgets[53584]
#define sipNameNr_setLineWidth 53597
#define sipName_setLineWidth &sipStrings_QtWidgets[53597]
#define sipNameNr_setMaxLength 53610
#define sipName_setMaxLength &sipStrings_QtWidgets[53610]
#define sipNameNr_setModelData 53623
#define sipName_setModelData &sipStrings_QtWidgets[53623]
#define sipNameNr_setNumDigits 53636
#define sipName_setNumDigits &sipStrings_QtWidgets[53636]
#define sipNameNr_setOpenLinks 53649
#define sipName_setOpenLinks &sipStrings_QtWidgets[53649]
#define sipNameNr_setPlainText 53662
#define sipName_setPlainText &sipStrings_QtWidgets[53662]
#define sipNameNr_setPopupMode 53675
#define sipName_setPopupMode &sipStrings_QtWidgets[53675]
#define sipNameNr_setRootIndex 53688
#define sipName_setRootIndex &sipStrings_QtWidgets[53688]
#define sipNameNr_setRowHeight 53701
#define sipName_setRowHeight &sipStrings_QtWidgets[53701]
#define sipNameNr_setRowHidden 53714
#define sipName_setRowHidden &sipStrings_QtWidgets[53714]
#define sipNameNr_setSceneRect 53727
#define sipName_setSceneRect &sipStrings_QtWidgets[53727]
#define sipNameNr_setSelection 53740
#define sipName_setSelection &sipStrings_QtWidgets[53740]
#define sipNameNr_setSeparator 53753
#define sipName_setSeparator &sipStrings_QtWidgets[53753]
#define sipNameNr_setShapeMode 53766
#define sipName_setShapeMode &sipStrings_QtWidgets[53766]
#define sipNameNr_setShortcuts 53779
#define sipName_setShortcuts &sipStrings_QtWidgets[53779]
#define sipNameNr_setSpanAngle 53792
#define sipName_setSpanAngle &sipStrings_QtWidgets[53792]
#define sipNameNr_setStatusBar 53805
#define sipName_setStatusBar &sipStrings_QtWidgets[53805]
#define sipNameNr_setStatusTip 53818
#define sipName_setStatusTip &sipStrings_QtWidgets[53818]
#define sipNameNr_setTabButton 53831
#define sipName_setTabButton &sipStrings_QtWidgets[53831]
#define sipNameNr_setTextColor 53844
#define sipName_setTextColor &sipStrings_QtWidgets[53844]
#define sipNameNr_setTextValue 53857
#define sipName_setTextValue &sipStrings_QtWidgets[53857]
#define sipNameNr_setTextWidth 53870
#define sipName_setTextWidth &sipStrings_QtWidgets[53870]
#define sipNameNr_setTimeRange 53883
#define sipName_setTimeRange &sipStrings_QtWidgets[53883]
#define sipNameNr_setTransform 44751
#define sipName_setTransform &sipStrings_QtWidgets[44751]
#define sipNameNr_setUndoLimit 53896
#define sipName_setUndoLimit &sipStrings_QtWidgets[53896]
#define sipNameNr_setValidator 53909
#define sipName_setValidator &sipStrings_QtWidgets[53909]
#define sipNameNr_setWhatsThis 53922
#define sipName_setWhatsThis &sipStrings_QtWidgets[53922]
#define sipNameNr_showNextYear 53935
#define sipName_showNextYear &sipStrings_QtWidgets[53935]
#define sipNameNr_sliderChange 53948
#define sipName_sliderChange &sipStrings_QtWidgets[53948]
#define sipNameNr_sortByColumn 53961
#define sipName_sortByColumn &sipStrings_QtWidgets[53961]
#define sipNameNr_sortChildren 53974
#define sipName_sortChildren &sipStrings_QtWidgets[53974]
#define sipNameNr_sourcePixmap 53987
#define sipName_sourcePixmap &sipStrings_QtWidgets[53987]
#define sipNameNr_sourceRegion 54000
#define sipName_sourceRegion &sipStrings_QtWidgets[54000]
#define sipNameNr_stackingMode 54013
#define sipName_stackingMode &sipStrings_QtWidgets[54013]
#define sipNameNr_standardIcon 54026
#define sipName_standardIcon &sipStrings_QtWidgets[54026]
#define sipNameNr_stateChanged 54039
#define sipName_stateChanged &sipStrings_QtWidgets[54039]
#define sipNameNr_submitPolicy 54052
#define sipName_submitPolicy &sipStrings_QtWidgets[54052]
#define sipNameNr_swapSections 54065
#define sipName_swapSections &sipStrings_QtWidgets[54065]
#define sipNameNr_tabStopWidth 54078
#define sipName_tabStopWidth &sipStrings_QtWidgets[54078]
#define sipNameNr_tabTextColor 54091
#define sipName_tabTextColor &sipStrings_QtWidgets[54091]
#define sipNameNr_tabWhatsThis 54104
#define sipName_tabWhatsThis &sipStrings_QtWidgets[54104]
#define sipNameNr_tabsClosable 54117
#define sipName_tabsClosable &sipStrings_QtWidgets[54117]
#define sipNameNr_takeChildren 54130
#define sipName_takeChildren &sipStrings_QtWidgets[54130]
#define sipNameNr_targetOffset 54143
#define sipName_targetOffset &sipStrings_QtWidgets[54143]
#define sipNameNr_textEchoMode 54156
#define sipName_textEchoMode &sipStrings_QtWidgets[54156]
#define sipNameNr_tickInterval 54169
#define sipName_tickInterval &sipStrings_QtWidgets[54169]
#define sipNameNr_tickPosition 54182
#define sipName_tickPosition &sipStrings_QtWidgets[54182]
#define sipNameNr_toolBarBreak 54195
#define sipName_toolBarBreak &sipStrings_QtWidgets[54195]
#define sipNameNr_topLevelItem 54208
#define sipName_topLevelItem &sipStrings_QtWidgets[54208]
#define sipNameNr_treePosition 54221
#define sipName_treePosition &sipStrings_QtWidgets[54221]
#define sipNameNr_unsetHotSpot 54234
#define sipName_unsetHotSpot &sipStrings_QtWidgets[54234]
#define sipNameNr_unsetSpacing 54247
#define sipName_unsetSpacing &sipStrings_QtWidgets[54247]
#define sipNameNr_urlsSelected 54260
#define sipName_urlsSelected &sipStrings_QtWidgets[54260]
#define sipNameNr_validatePage 54273
#define sipName_validatePage &sipStrings_QtWidgets[54273]
#define sipNameNr_valueChanged 54286
#define sipName_valueChanged &sipStrings_QtWidgets[54286]
#define sipNameNr_visitedPages 54299
#define sipName_visitedPages &sipStrings_QtWidgets[54299]
#define sipNameNr_visualColumn 54312
#define sipName_visualColumn &sipStrings_QtWidgets[54312]
#define sipNameNr_windowHandle 54325
#define sipName_windowHandle &sipStrings_QtWidgets[54325]
#define sipNameNr_wordWrapMode 54338
#define sipName_wordWrapMode &sipStrings_QtWidgets[54338]
#define sipNameNr_AboutQtRole 54351
#define sipName_AboutQtRole &sipStrings_QtWidgets[54351]
#define sipNameNr_ActionEvent 21419
#define sipName_ActionEvent &sipStrings_QtWidgets[21419]
#define sipNameNr_AmPmSection 54363
#define sipName_AmPmSection &sipStrings_QtWidgets[54363]
#define sipNameNr_AreaOptions 18919
#define sipName_AreaOptions &sipStrings_QtWidgets[18919]
#define sipNameNr_BottomToTop 54375
#define sipName_BottomToTop &sipStrings_QtWidgets[54375]
#define sipNameNr_CC_ComboBox 54387
#define sipName_CC_ComboBox &sipStrings_QtWidgets[54387]
#define sipNameNr_CC_GroupBox 54399
#define sipName_CC_GroupBox &sipStrings_QtWidgets[54399]
#define sipNameNr_CC_TitleBar 54411
#define sipName_CC_TitleBar &sipStrings_QtWidgets[54411]
#define sipNameNr_CE_CheckBox 54423
#define sipName_CE_CheckBox &sipStrings_QtWidgets[54423]
#define sipNameNr_CE_MenuItem 54435
#define sipName_CE_MenuItem &sipStrings_QtWidgets[54435]
#define sipNameNr_CE_SizeGrip 54447
#define sipName_CE_SizeGrip &sipStrings_QtWidgets[54447]
#define sipNameNr_CE_Splitter 54459
#define sipName_CE_Splitter &sipStrings_QtWidgets[54459]
#define sipNameNr_CT_CheckBox 54471
#define sipName_CT_CheckBox &sipStrings_QtWidgets[54471]
#define sipNameNr_CT_ComboBox 54483
#define sipName_CT_ComboBox &sipStrings_QtWidgets[54483]
#define sipNameNr_CT_GroupBox 54495
#define sipName_CT_GroupBox &sipStrings_QtWidgets[54495]
#define sipNameNr_CT_LineEdit 54507
#define sipName_CT_LineEdit &sipStrings_QtWidgets[54507]
#define sipNameNr_CT_MenuItem 54519
#define sipName_CT_MenuItem &sipStrings_QtWidgets[54519]
#define sipNameNr_CT_SizeGrip 54531
#define sipName_CT_SizeGrip &sipStrings_QtWidgets[54531]
#define sipNameNr_CT_Splitter 54543
#define sipName_CT_Splitter &sipStrings_QtWidgets[54543]
#define sipNameNr_ChangeFlags 8280
#define sipName_ChangeFlags &sipStrings_QtWidgets[8280]
#define sipNameNr_ControlType 13209
#define sipName_ControlType &sipStrings_QtWidgets[13209]
#define sipNameNr_CustomColor 45277
#define sipName_CustomColor &sipStrings_QtWidgets[45277]
#define sipNameNr_DefaultItem 54555
#define sipName_DefaultItem &sipStrings_QtWidgets[54555]
#define sipNameNr_DefaultType 54567
#define sipName_DefaultType &sipStrings_QtWidgets[54567]
#define sipNameNr_DialogLabel 12934
#define sipName_DialogLabel &sipStrings_QtWidgets[12934]
#define sipNameNr_DockOptions 13159
#define sipName_DockOptions &sipStrings_QtWidgets[13159]
#define sipNameNr_DoubleClick 15884
#define sipName_DoubleClick &sipStrings_QtWidgets[15884]
#define sipNameNr_DoubleInput 54579
#define sipName_DoubleInput &sipStrings_QtWidgets[54579]
#define sipNameNr_DragEnabled 45367
#define sipName_DragEnabled &sipStrings_QtWidgets[45367]
#define sipNameNr_DropEnabled 54591
#define sipName_DropEnabled &sipStrings_QtWidgets[54591]
#define sipNameNr_EditTrigger 6285
#define sipName_EditTrigger &sipStrings_QtWidgets[6285]
#define sipNameNr_EndEditHint 3843
#define sipName_EndEditHint &sipStrings_QtWidgets[3843]
#define sipNameNr_FirstButton 54603
#define sipName_FirstButton &sipStrings_QtWidgets[54603]
#define sipNameNr_FontFilters 10273
#define sipName_FontFilters &sipStrings_QtWidgets[10273]
#define sipNameNr_GnomeLayout 54615
#define sipName_GnomeLayout &sipStrings_QtWidgets[54615]
#define sipNameNr_HasChildren 54627
#define sipName_HasChildren &sipStrings_QtWidgets[54627]
#define sipNameNr_HourSection 54639
#define sipName_HourSection &sipStrings_QtWidgets[54639]
#define sipNameNr_Information 13709
#define sipName_Information &sipStrings_QtWidgets[13709]
#define sipNameNr_InsertAtTop 54651
#define sipName_InsertAtTop &sipStrings_QtWidgets[54651]
#define sipNameNr_Interactive 45532
#define sipName_Interactive &sipStrings_QtWidgets[45532]
#define sipNameNr_InvalidRole 54663
#define sipName_InvalidRole &sipStrings_QtWidgets[54663]
#define sipNameNr_ItemIsPanel 54675
#define sipName_ItemIsPanel &sipStrings_QtWidgets[54675]
#define sipNameNr_LeftToRight 48559
#define sipName_LeftToRight &sipStrings_QtWidgets[48559]
#define sipNameNr_LowPriority 54687
#define sipName_LowPriority &sipStrings_QtWidgets[54687]
#define sipNameNr_MSecSection 54699
#define sipName_MSecSection &sipStrings_QtWidgets[54699]
#define sipNameNr_MessageIcon 8541
#define sipName_MessageIcon &sipStrings_QtWidgets[8541]
#define sipNameNr_MiddleClick 54711
#define sipName_MiddleClick &sipStrings_QtWidgets[54711]
#define sipNameNr_ModernStyle 54723
#define sipName_ModernStyle &sipStrings_QtWidgets[54723]
#define sipNameNr_NoDirection 54735
#define sipName_NoDirection &sipStrings_QtWidgets[54735]
#define sipNameNr_NoSelection 54747
#define sipName_NoSelection &sipStrings_QtWidgets[54747]
#define sipNameNr_NormalColor 54759
#define sipName_NormalColor &sipStrings_QtWidgets[54759]
#define sipNameNr_NotAdjacent 54771
#define sipName_NotAdjacent &sipStrings_QtWidgets[54771]
#define sipNameNr_NotEditable 54783
#define sipName_NotEditable &sipStrings_QtWidgets[54783]
#define sipNameNr_PixelMetric 24733
#define sipName_PixelMetric &sipStrings_QtWidgets[24733]
#define sipNameNr_QColumnView 54795
#define sipName_QColumnView &sipStrings_QtWidgets[54795]
#define sipNameNr_QDockWidget 54807
#define sipName_QDockWidget &sipStrings_QtWidgets[54807]
#define sipNameNr_QFileDialog 54819
#define sipName_QFileDialog &sipStrings_QtWidgets[54819]
#define sipNameNr_QFocusFrame 54831
#define sipName_QFocusFrame &sipStrings_QtWidgets[54831]
#define sipNameNr_QFontDialog 54843
#define sipName_QFontDialog &sipStrings_QtWidgets[54843]
#define sipNameNr_QFormLayout 54855
#define sipName_QFormLayout &sipStrings_QtWidgets[54855]
#define sipNameNr_QGridLayout 54867
#define sipName_QGridLayout &sipStrings_QtWidgets[54867]
#define sipNameNr_QHBoxLayout 54879
#define sipName_QHBoxLayout &sipStrings_QtWidgets[54879]
#define sipNameNr_QHeaderView 54891
#define sipName_QHeaderView &sipStrings_QtWidgets[54891]
#define sipNameNr_QLayoutItem 54903
#define sipName_QLayoutItem &sipStrings_QtWidgets[54903]
#define sipNameNr_QListWidget 54915
#define sipName_QListWidget &sipStrings_QtWidgets[54915]
#define sipNameNr_QMainWindow 54927
#define sipName_QMainWindow &sipStrings_QtWidgets[54927]
#define sipNameNr_QMessageBox 54939
#define sipName_QMessageBox &sipStrings_QtWidgets[54939]
#define sipNameNr_QPanGesture 54951
#define sipName_QPanGesture &sipStrings_QtWidgets[54951]
#define sipNameNr_QProxyStyle 54963
#define sipName_QProxyStyle &sipStrings_QtWidgets[54963]
#define sipNameNr_QPushButton 54975
#define sipName_QPushButton &sipStrings_QtWidgets[54975]
#define sipNameNr_QRubberBand 54987
#define sipName_QRubberBand &sipStrings_QtWidgets[54987]
#define sipNameNr_QScrollArea 54999
#define sipName_QScrollArea &sipStrings_QtWidgets[54999]
#define sipNameNr_QSizePolicy 55011
#define sipName_QSizePolicy &sipStrings_QtWidgets[55011]
#define sipNameNr_QSpacerItem 55023
#define sipName_QSpacerItem &sipStrings_QtWidgets[55023]
#define sipNameNr_QTapGesture 55035
#define sipName_QTapGesture &sipStrings_QtWidgets[55035]
#define sipNameNr_QToolButton 55047
#define sipName_QToolButton &sipStrings_QtWidgets[55047]
#define sipNameNr_QTreeWidget 55059
#define sipName_QTreeWidget &sipStrings_QtWidgets[55059]
#define sipNameNr_QVBoxLayout 55071
#define sipName_QVBoxLayout &sipStrings_QtWidgets[55071]
#define sipNameNr_QWidgetItem 55083
#define sipName_QWidgetItem &sipStrings_QtWidgets[55083]
#define sipNameNr_QWizardPage 55095
#define sipName_QWizardPage &sipStrings_QtWidgets[55095]
#define sipNameNr_QualityHint 55107
#define sipName_QualityHint &sipStrings_QtWidgets[55107]
#define sipNameNr_RadioButton 14276
#define sipName_RadioButton &sipStrings_QtWidgets[14276]
#define sipNameNr_RenderFlags 21734
#define sipName_RenderFlags &sipStrings_QtWidgets[21734]
#define sipNameNr_RightToLeft 48573
#define sipName_RightToLeft &sipStrings_QtWidgets[48573]
#define sipNameNr_RoundedEast 55119
#define sipName_RoundedEast &sipStrings_QtWidgets[55119]
#define sipNameNr_RoundedWest 55131
#define sipName_RoundedWest &sipStrings_QtWidgets[55131]
#define sipNameNr_SO_ComboBox 55143
#define sipName_SO_ComboBox &sipStrings_QtWidgets[55143]
#define sipNameNr_SO_GroupBox 55155
#define sipName_SO_GroupBox &sipStrings_QtWidgets[55155]
#define sipNameNr_SO_MenuItem 55167
#define sipName_SO_MenuItem &sipStrings_QtWidgets[55167]
#define sipNameNr_SO_SizeGrip 55179
#define sipName_SO_SizeGrip &sipStrings_QtWidgets[55179]
#define sipNameNr_SO_TitleBar 55191
#define sipName_SO_TitleBar &sipStrings_QtWidgets[55191]
#define sipNameNr_SO_ViewItem 55203
#define sipName_SO_ViewItem &sipStrings_QtWidgets[55203]
#define sipNameNr_SP_FileIcon 55215
#define sipName_SP_FileIcon &sipStrings_QtWidgets[55215]
#define sipNameNr_SceneLayers 9366
#define sipName_SceneLayers &sipStrings_QtWidgets[9366]
#define sipNameNr_SelectItems 55227
#define sipName_SelectItems &sipStrings_QtWidgets[55227]
#define sipNameNr_Shadow_Mask 55239
#define sipName_Shadow_Mask &sipStrings_QtWidgets[55239]
#define sipNameNr_State_Small 55251
#define sipName_State_Small &sipStrings_QtWidgets[55251]
#define sipNameNr_StepEnabled 7420
#define sipName_StepEnabled &sipStrings_QtWidgets[7420]
#define sipNameNr_StyledPanel 55263
#define sipName_StyledPanel &sipStrings_QtWidgets[55263]
#define sipNameNr_SubControls 24753
#define sipName_SubControls &sipStrings_QtWidgets[24753]
#define sipNameNr_TabFeatures 8483
#define sipName_TabFeatures &sipStrings_QtWidgets[8483]
#define sipNameNr_TabPosition 5198
#define sipName_TabPosition &sipStrings_QtWidgets[5198]
#define sipNameNr_TopToBottom 55275
#define sipName_TopToBottom &sipStrings_QtWidgets[55275]
#define sipNameNr_WidgetWidth 55287
#define sipName_WidgetWidth &sipStrings_QtWidgets[55287]
#define sipNameNr_WindowOrder 18941
#define sipName_WindowOrder &sipStrings_QtWidgets[18941]
#define sipNameNr_WizardStyle 21755
#define sipName_WizardStyle &sipStrings_QtWidgets[21755]
#define sipNameNr_WrapAllRows 55299
#define sipName_WrapAllRows &sipStrings_QtWidgets[55299]
#define sipNameNr_YearSection 55311
#define sipName_YearSection &sipStrings_QtWidgets[55311]
#define sipNameNr_aboutToHide 55323
#define sipName_aboutToHide &sipStrings_QtWidgets[55323]
#define sipNameNr_aboutToShow 55335
#define sipName_aboutToShow &sipStrings_QtWidgets[55335]
#define sipNameNr_acceptDrops 55347
#define sipName_acceptDrops &sipStrings_QtWidgets[55347]
#define sipNameNr_actionEvent 55359
#define sipName_actionEvent &sipStrings_QtWidgets[55359]
#define sipNameNr_actionGroup 55371
#define sipName_actionGroup &sipStrings_QtWidgets[55371]
#define sipNameNr_activePanel 55383
#define sipName_activePanel &sipStrings_QtWidgets[55383]
#define sipNameNr_activeStack 55395
#define sipName_activeStack &sipStrings_QtWidgets[55395]
#define sipNameNr_addChildren 55407
#define sipName_addChildren &sipStrings_QtWidgets[55407]
#define sipNameNr_alignedRect 55419
#define sipName_alignedRect &sipStrings_QtWidgets[55419]
#define sipNameNr_autoDefault 55431
#define sipName_autoDefault &sipStrings_QtWidgets[55431]
#define sipNameNr_axisChanged 55443
#define sipName_axisChanged &sipStrings_QtWidgets[55443]
#define sipNameNr_bottomToTop 55455
#define sipName_bottomToTop &sipStrings_QtWidgets[55455]
#define sipNameNr_cellChanged 55467
#define sipName_cellChanged &sipStrings_QtWidgets[55467]
#define sipNameNr_cellClicked 55479
#define sipName_cellClicked &sipStrings_QtWidgets[55479]
#define sipNameNr_cellEntered 55491
#define sipName_cellEntered &sipStrings_QtWidgets[55491]
#define sipNameNr_cellPressed 55503
#define sipName_cellPressed &sipStrings_QtWidgets[55503]
#define sipNameNr_centerPoint 55515
#define sipName_centerPoint &sipStrings_QtWidgets[55515]
#define sipNameNr_changeEvent 55527
#define sipName_changeEvent &sipStrings_QtWidgets[55527]
#define sipNameNr_changeFlags 55539
#define sipName_changeFlags &sipStrings_QtWidgets[55539]
#define sipNameNr_cleanupPage 55551
#define sipName_cleanupPage &sipStrings_QtWidgets[55551]
#define sipNameNr_closeEditor 55563
#define sipName_closeEditor &sipStrings_QtWidgets[55563]
#define sipNameNr_collapseAll 55575
#define sipName_collapseAll &sipStrings_QtWidgets[55575]
#define sipNameNr_columnCount 55587
#define sipName_columnCount &sipStrings_QtWidgets[55587]
#define sipNameNr_columnMoved 55599
#define sipName_columnMoved &sipStrings_QtWidgets[55599]
#define sipNameNr_columnWidth 55611
#define sipName_columnWidth &sipStrings_QtWidgets[55611]
#define sipNameNr_contextMenu 55623
#define sipName_contextMenu &sipStrings_QtWidgets[55623]
#define sipNameNr_controlType 55635
#define sipName_controlType &sipStrings_QtWidgets[55635]
#define sipNameNr_currentData 55647
#define sipName_currentData &sipStrings_QtWidgets[55647]
#define sipNameNr_currentFont 55659
#define sipName_currentFont &sipStrings_QtWidgets[55659]
#define sipNameNr_currentIcon 55671
#define sipName_currentIcon &sipStrings_QtWidgets[55671]
#define sipNameNr_currentItem 55683
#define sipName_currentItem &sipStrings_QtWidgets[55683]
#define sipNameNr_currentPage 55695
#define sipName_currentPage &sipStrings_QtWidgets[55695]
#define sipNameNr_currentText 55707
#define sipName_currentText &sipStrings_QtWidgets[55707]
#define sipNameNr_cursorWidth 55719
#define sipName_cursorWidth &sipStrings_QtWidgets[55719]
#define sipNameNr_customColor 55731
#define sipName_customColor &sipStrings_QtWidgets[55731]
#define sipNameNr_customCount 55743
#define sipName_customCount &sipStrings_QtWidgets[55743]
#define sipNameNr_customEvent 55755
#define sipName_customEvent &sipStrings_QtWidgets[55755]
#define sipNameNr_dataChanged 55767
#define sipName_dataChanged &sipStrings_QtWidgets[55767]
#define sipNameNr_dateChanged 55779
#define sipName_dateChanged &sipStrings_QtWidgets[55779]
#define sipNameNr_description 55791
#define sipName_description &sipStrings_QtWidgets[55791]
#define sipNameNr_displayText 55803
#define sipName_displayText &sipStrings_QtWidgets[55803]
#define sipNameNr_doSetSource 55815
#define sipName_doSetSource &sipStrings_QtWidgets[55815]
#define sipNameNr_dockOptions 55827
#define sipName_dockOptions &sipStrings_QtWidgets[55827]
#define sipNameNr_doneCurrent 55839
#define sipName_doneCurrent &sipStrings_QtWidgets[55839]
#define sipNameNr_doubleValue 55851
#define sipName_doubleValue &sipStrings_QtWidgets[55851]
#define sipNameNr_dragEnabled 55863
#define sipName_dragEnabled &sipStrings_QtWidgets[55863]
#define sipNameNr_drawControl 55875
#define sipName_drawControl &sipStrings_QtWidgets[55875]
#define sipNameNr_drawDisplay 55887
#define sipName_drawDisplay &sipStrings_QtWidgets[55887]
#define sipNameNr_editorEvent 55899
#define sipName_editorEvent &sipStrings_QtWidgets[55899]
#define sipNameNr_eventFilter 55911
#define sipName_eventFilter &sipStrings_QtWidgets[55911]
#define sipNameNr_exposedRect 55923
#define sipName_exposedRect &sipStrings_QtWidgets[55923]
#define sipNameNr_fileRenamed 55935
#define sipName_fileRenamed &sipStrings_QtWidgets[55935]
#define sipNameNr_focusPolicy 55947
#define sipName_focusPolicy &sipStrings_QtWidgets[55947]
#define sipNameNr_focusReason 55959
#define sipName_focusReason &sipStrings_QtWidgets[55959]
#define sipNameNr_focusWidget 55971
#define sipName_focusWidget &sipStrings_QtWidgets[55971]
#define sipNameNr_fontFilters 55983
#define sipName_fontFilters &sipStrings_QtWidgets[55983]
#define sipNameNr_fontMetrics 55995
#define sipName_fontMetrics &sipStrings_QtWidgets[55995]
#define sipNameNr_frameShadow 56007
#define sipName_frameShadow &sipStrings_QtWidgets[56007]
#define sipNameNr_gestureType 56019
#define sipName_gestureType &sipStrings_QtWidgets[56019]
#define sipNameNr_globalStrut 56031
#define sipName_globalStrut &sipStrings_QtWidgets[56031]
#define sipNameNr_grabGesture 50505
#define sipName_grabGesture &sipStrings_QtWidgets[50505]
#define sipNameNr_handleInput 56043
#define sipName_handleInput &sipStrings_QtWidgets[56043]
#define sipNameNr_handleWidth 56055
#define sipName_handleWidth &sipStrings_QtWidgets[56055]
#define sipNameNr_hasChildren 56067
#define sipName_hasChildren &sipStrings_QtWidgets[56067]
#define sipNameNr_hasClipping 56079
#define sipName_hasClipping &sipStrings_QtWidgets[56079]
#define sipNameNr_hasScroller 56091
#define sipName_hasScroller &sipStrings_QtWidgets[56091]
#define sipNameNr_hasTracking 56103
#define sipName_hasTracking &sipStrings_QtWidgets[56103]
#define sipNameNr_hideSection 56115
#define sipName_hideSection &sipStrings_QtWidgets[56115]
#define sipNameNr_highlighted 56127
#define sipName_highlighted &sipStrings_QtWidgets[56127]
#define sipNameNr_hitTestPath 56139
#define sipName_hitTestPath &sipStrings_QtWidgets[56139]
#define sipNameNr_indentation 56151
#define sipName_indentation &sipStrings_QtWidgets[56151]
#define sipNameNr_indexWidget 56163
#define sipName_indexWidget &sipStrings_QtWidgets[56163]
#define sipNameNr_information 56175
#define sipName_information &sipStrings_QtWidgets[56175]
#define sipNameNr_initPainter 56187
#define sipName_initPainter &sipStrings_QtWidgets[56187]
#define sipNameNr_insertChild 56199
#define sipName_insertChild &sipStrings_QtWidgets[56199]
#define sipNameNr_insertItems 56211
#define sipName_insertItems &sipStrings_QtWidgets[56211]
#define sipNameNr_isActivated 56223
#define sipName_isActivated &sipStrings_QtWidgets[56223]
#define sipNameNr_isCheckable 56235
#define sipName_isCheckable &sipStrings_QtWidgets[56235]
#define sipNameNr_isDefaultUp 56247
#define sipName_isDefaultUp &sipStrings_QtWidgets[56247]
#define sipNameNr_isEnabledTo 56259
#define sipName_isEnabledTo &sipStrings_QtWidgets[56259]
#define sipNameNr_isExclusive 56271
#define sipName_isExclusive &sipStrings_QtWidgets[56271]
#define sipNameNr_isFinalPage 56283
#define sipName_isFinalPage &sipStrings_QtWidgets[56283]
#define sipNameNr_isFloatable 56295
#define sipName_isFloatable &sipStrings_QtWidgets[56295]
#define sipNameNr_isMaximized 56307
#define sipName_isMaximized &sipStrings_QtWidgets[56307]
#define sipNameNr_isMinimized 56319
#define sipName_isMinimized &sipStrings_QtWidgets[56319]
#define sipNameNr_isRowHidden 56331
#define sipName_isRowHidden &sipStrings_QtWidgets[56331]
#define sipNameNr_isSeparator 56343
#define sipName_isSeparator &sipStrings_QtWidgets[56343]
#define sipNameNr_isVisibleTo 56355
#define sipName_isVisibleTo &sipStrings_QtWidgets[56355]
#define sipNameNr_itemChanged 56367
#define sipName_itemChanged &sipStrings_QtWidgets[56367]
#define sipNameNr_itemClicked 56379
#define sipName_itemClicked &sipStrings_QtWidgets[56379]
#define sipNameNr_itemEntered 56391
#define sipName_itemEntered &sipStrings_QtWidgets[56391]
#define sipNameNr_itemPressed 56403
#define sipName_itemPressed &sipStrings_QtWidgets[56403]
#define sipNameNr_itemRemoved 56415
#define sipName_itemRemoved &sipStrings_QtWidgets[56415]
#define sipNameNr_itemSpacing 56427
#define sipName_itemSpacing &sipStrings_QtWidgets[56427]
#define sipNameNr_itemToolTip 56439
#define sipName_itemToolTip &sipStrings_QtWidgets[56439]
#define sipNameNr_keySequence 56451
#define sipName_keySequence &sipStrings_QtWidgets[56451]
#define sipNameNr_linkHovered 56463
#define sipName_linkHovered &sipStrings_QtWidgets[56463]
#define sipNameNr_makeCurrent 56475
#define sipName_makeCurrent &sipStrings_QtWidgets[56475]
#define sipNameNr_mapFromItem 56487
#define sipName_mapFromItem &sipStrings_QtWidgets[56487]
#define sipNameNr_mapToGlobal 56499
#define sipName_mapToGlobal &sipStrings_QtWidgets[56499]
#define sipNameNr_mapToParent 56511
#define sipName_mapToParent &sipStrings_QtWidgets[56511]
#define sipNameNr_maximumDate 56523
#define sipName_maximumDate &sipStrings_QtWidgets[56523]
#define sipNameNr_maximumSize 56535
#define sipName_maximumSize &sipStrings_QtWidgets[56535]
#define sipNameNr_maximumTime 56547
#define sipName_maximumTime &sipStrings_QtWidgets[56547]
#define sipNameNr_minimumDate 56559
#define sipName_minimumDate &sipStrings_QtWidgets[56559]
#define sipNameNr_minimumSize 56571
#define sipName_minimumSize &sipStrings_QtWidgets[56571]
#define sipNameNr_minimumTime 56583
#define sipName_minimumTime &sipStrings_QtWidgets[56583]
#define sipNameNr_modelColumn 56595
#define sipName_modelColumn &sipStrings_QtWidgets[56595]
#define sipNameNr_moveColumns 49063
#define sipName_moveColumns &sipStrings_QtWidgets[49063]
#define sipNameNr_moveSection 56607
#define sipName_moveSection &sipStrings_QtWidgets[56607]
#define sipNameNr_nameFilters 56619
#define sipName_nameFilters &sipStrings_QtWidgets[56619]
#define sipNameNr_nativeEvent 56631
#define sipName_nativeEvent &sipStrings_QtWidgets[56631]
#define sipNameNr_notchTarget 56643
#define sipName_notchTarget &sipStrings_QtWidgets[56643]
#define sipNameNr_opacityMask 56655
#define sipName_opacityMask &sipStrings_QtWidgets[56655]
#define sipNameNr_orientation 56667
#define sipName_orientation &sipStrings_QtWidgets[56667]
#define sipNameNr_pageRemoved 56679
#define sipName_pageRemoved &sipStrings_QtWidgets[56679]
#define sipNameNr_paintEngine 56691
#define sipName_paintEngine &sipStrings_QtWidgets[56691]
#define sipNameNr_permissions 56703
#define sipName_permissions &sipStrings_QtWidgets[56703]
#define sipNameNr_pixelMetric 56715
#define sipName_pixelMetric &sipStrings_QtWidgets[56715]
#define sipNameNr_polishEvent 56727
#define sipName_polishEvent &sipStrings_QtWidgets[56727]
#define sipNameNr_removeChild 56739
#define sipName_removeChild &sipStrings_QtWidgets[56739]
#define sipNameNr_removeStack 56751
#define sipName_removeStack &sipStrings_QtWidgets[56751]
#define sipNameNr_renderHints 56763
#define sipName_renderHints &sipStrings_QtWidgets[56763]
#define sipNameNr_resetFormat 56775
#define sipName_resetFormat &sipStrings_QtWidgets[56775]
#define sipNameNr_resizeDocks 56787
#define sipName_resizeDocks &sipStrings_QtWidgets[56787]
#define sipNameNr_resizeEvent 56799
#define sipName_resizeEvent &sipStrings_QtWidgets[56799]
#define sipNameNr_rightColumn 56811
#define sipName_rightColumn &sipStrings_QtWidgets[56811]
#define sipNameNr_rowsRemoved 56823
#define sipName_rowsRemoved &sipStrings_QtWidgets[56823]
#define sipNameNr_scaleFactor 56835
#define sipName_scaleFactor &sipStrings_QtWidgets[56835]
#define sipNameNr_screenCount 56847
#define sipName_screenCount &sipStrings_QtWidgets[56847]
#define sipNameNr_scrollToTop 56859
#define sipName_scrollToTop &sipStrings_QtWidgets[56859]
#define sipNameNr_searchPaths 56871
#define sipName_searchPaths &sipStrings_QtWidgets[56871]
#define sipNameNr_sectionSize 56883
#define sipName_sectionSize &sipStrings_QtWidgets[56883]
#define sipNameNr_sectionText 56895
#define sipName_sectionText &sipStrings_QtWidgets[56895]
#define sipNameNr_setAccepted 56907
#define sipName_setAccepted &sipStrings_QtWidgets[56907]
#define sipNameNr_setAnimated 56919
#define sipName_setAnimated &sipStrings_QtWidgets[56919]
#define sipNameNr_setAutoHide 56931
#define sipName_setAutoHide &sipStrings_QtWidgets[56931]
#define sipNameNr_setBaseSize 56943
#define sipName_setBaseSize &sipStrings_QtWidgets[56943]
#define sipNameNr_setCalendar 56955
#define sipName_setCalendar &sipStrings_QtWidgets[56955]
#define sipNameNr_setCheckBox 56967
#define sipName_setCheckBox &sipStrings_QtWidgets[56967]
#define sipNameNr_setClipping 56979
#define sipName_setClipping &sipStrings_QtWidgets[56979]
#define sipNameNr_setDateTime 56991
#define sipName_setDateTime &sipStrings_QtWidgets[56991]
#define sipNameNr_setDecimals 57003
#define sipName_setDecimals &sipStrings_QtWidgets[57003]
#define sipNameNr_setDisabled 57015
#define sipName_setDisabled &sipStrings_QtWidgets[57015]
#define sipNameNr_setDocument 57027
#define sipName_setDocument &sipStrings_QtWidgets[57027]
#define sipNameNr_setDragMode 57039
#define sipName_setDragMode &sipStrings_QtWidgets[57039]
#define sipNameNr_setDrawBase 57051
#define sipName_setDrawBase &sipStrings_QtWidgets[57051]
#define sipNameNr_setEchoMode 57063
#define sipName_setEchoMode &sipStrings_QtWidgets[57063]
#define sipNameNr_setEditText 57075
#define sipName_setEditText &sipStrings_QtWidgets[57075]
#define sipNameNr_setEditable 57087
#define sipName_setEditable &sipStrings_QtWidgets[57087]
#define sipNameNr_setExpanded 57099
#define sipName_setExpanded &sipStrings_QtWidgets[57099]
#define sipNameNr_setFeatures 57111
#define sipName_setFeatures &sipStrings_QtWidgets[57111]
#define sipNameNr_setFileMode 57123
#define sipName_setFileMode &sipStrings_QtWidgets[57123]
#define sipNameNr_setFillRule 57135
#define sipName_setFillRule &sipStrings_QtWidgets[57135]
#define sipNameNr_setFloating 57147
#define sipName_setFloating &sipStrings_QtWidgets[57147]
#define sipNameNr_setGeometry 57159
#define sipName_setGeometry &sipStrings_QtWidgets[57159]
#define sipNameNr_setGridSize 57171
#define sipName_setGridSize &sipStrings_QtWidgets[57171]
#define sipNameNr_setIconSize 57183
#define sipName_setIconSize &sipStrings_QtWidgets[57183]
#define sipNameNr_setIconText 57195
#define sipName_setIconText &sipStrings_QtWidgets[57195]
#define sipNameNr_setIntRange 57207
#define sipName_setIntRange &sipStrings_QtWidgets[57207]
#define sipNameNr_setIntValue 57219
#define sipName_setIntValue &sipStrings_QtWidgets[57219]
#define sipNameNr_setItemData 57231
#define sipName_setItemData &sipStrings_QtWidgets[57231]
#define sipNameNr_setItemIcon 57243
#define sipName_setItemIcon &sipStrings_QtWidgets[57243]
#define sipNameNr_setItemText 57255
#define sipName_setItemText &sipStrings_QtWidgets[57255]
#define sipNameNr_setLineEdit 57267
#define sipName_setLineEdit &sipStrings_QtWidgets[57267]
#define sipNameNr_setMarkdown 57279
#define sipName_setMarkdown &sipStrings_QtWidgets[57279]
#define sipNameNr_setMaxCount 57291
#define sipName_setMaxCount &sipStrings_QtWidgets[57291]
#define sipNameNr_setMenuRole 57303
#define sipName_setMenuRole &sipStrings_QtWidgets[57303]
#define sipNameNr_setModified 57315
#define sipName_setModified &sipStrings_QtWidgets[57315]
#define sipNameNr_setMovement 57327
#define sipName_setMovement &sipStrings_QtWidgets[57327]
#define sipNameNr_setObsolete 57339
#define sipName_setObsolete &sipStrings_QtWidgets[57339]
#define sipNameNr_setPageStep 57351
#define sipName_setPageStep &sipStrings_QtWidgets[57351]
#define sipNameNr_setPosition 57363
#define sipName_setPosition &sipStrings_QtWidgets[57363]
#define sipNameNr_setPriority 57375
#define sipName_setPriority &sipStrings_QtWidgets[57375]
#define sipNameNr_setReadOnly 57387
#define sipName_setReadOnly &sipStrings_QtWidgets[57387]
#define sipNameNr_setRootPath 57399
#define sipName_setRootPath &sipStrings_QtWidgets[57399]
#define sipNameNr_setRotation 57411
#define sipName_setRotation &sipStrings_QtWidgets[57411]
#define sipNameNr_setRowCount 57423
#define sipName_setRowCount &sipStrings_QtWidgets[57423]
#define sipNameNr_setSelected 57435
#define sipName_setSelected &sipStrings_QtWidgets[57435]
#define sipNameNr_setShortcut 57447
#define sipName_setShortcut &sipStrings_QtWidgets[57447]
#define sipNameNr_setShowGrid 57459
#define sipName_setShowGrid &sipStrings_QtWidgets[57459]
#define sipNameNr_setSizeHint 57471
#define sipName_setSizeHint &sipStrings_QtWidgets[57471]
#define sipNameNr_setStepType 57483
#define sipName_setStepType &sipStrings_QtWidgets[57483]
#define sipNameNr_setStrength 57495
#define sipName_setStrength &sipStrings_QtWidgets[57495]
#define sipNameNr_setSubTitle 57507
#define sipName_setSubTitle &sipStrings_QtWidgets[57507]
#define sipNameNr_setTabOrder 57519
#define sipName_setTabOrder &sipStrings_QtWidgets[57519]
#define sipNameNr_setTabShape 57531
#define sipName_setTabShape &sipStrings_QtWidgets[57531]
#define sipNameNr_setTimeSpec 57543
#define sipName_setTimeSpec &sipStrings_QtWidgets[57543]
#define sipNameNr_setTracking 57555
#define sipName_setTracking &sipStrings_QtWidgets[57555]
#define sipNameNr_setTristate 57567
#define sipName_setTristate &sipStrings_QtWidgets[57567]
#define sipNameNr_setViewMode 57579
#define sipName_setViewMode &sipStrings_QtWidgets[57579]
#define sipNameNr_setViewport 57591
#define sipName_setViewport &sipStrings_QtWidgets[57591]
#define sipNameNr_setWordWrap 57603
#define sipName_setWordWrap &sipStrings_QtWidgets[57603]
#define sipNameNr_setWrapping 57615
#define sipName_setWrapping &sipStrings_QtWidgets[57615]
#define sipNameNr_showMessage 57627
#define sipName_showMessage &sipStrings_QtWidgets[57627]
#define sipNameNr_showSection 57639
#define sipName_showSection &sipStrings_QtWidgets[57639]
#define sipNameNr_sidebarUrls 57651
#define sipName_sidebarUrls &sipStrings_QtWidgets[57651]
#define sipNameNr_sliderMoved 57663
#define sipName_sliderMoved &sipStrings_QtWidgets[57663]
#define sipNameNr_sliderValue 57675
#define sipName_sliderValue &sipStrings_QtWidgets[57675]
#define sipNameNr_sourceState 57687
#define sipName_sourceState &sipStrings_QtWidgets[57687]
#define sipNameNr_stackBefore 57699
#define sipName_stackBefore &sipStrings_QtWidgets[57699]
#define sipNameNr_stepEnabled 57711
#define sipName_stepEnabled &sipStrings_QtWidgets[57711]
#define sipNameNr_stickyFocus 57723
#define sipName_stickyFocus &sipStrings_QtWidgets[57723]
#define sipNameNr_styleObject 57735
#define sipName_styleObject &sipStrings_QtWidgets[57735]
#define sipNameNr_subControls 57747
#define sipName_subControls &sipStrings_QtWidgets[57747]
#define sipNameNr_tabInserted 57759
#define sipName_tabInserted &sipStrings_QtWidgets[57759]
#define sipNameNr_tabPosition 57771
#define sipName_tabPosition &sipStrings_QtWidgets[57771]
#define sipNameNr_tabSizeHint 57783
#define sipName_tabSizeHint &sipStrings_QtWidgets[57783]
#define sipNameNr_tableWidget 57795
#define sipName_tableWidget &sipStrings_QtWidgets[57795]
#define sipNameNr_tabletEvent 57807
#define sipName_tabletEvent &sipStrings_QtWidgets[57807]
#define sipNameNr_tabsMovable 57819
#define sipName_tabsMovable &sipStrings_QtWidgets[57819]
#define sipNameNr_textChanged 57831
#define sipName_textChanged &sipStrings_QtWidgets[57831]
#define sipNameNr_textMargins 57843
#define sipName_textMargins &sipStrings_QtWidgets[57843]
#define sipNameNr_textVisible 57855
#define sipName_textVisible &sipStrings_QtWidgets[57855]
#define sipNameNr_timeChanged 57867
#define sipName_timeChanged &sipStrings_QtWidgets[57867]
#define sipNameNr_titleFormat 57879
#define sipName_titleFormat &sipStrings_QtWidgets[57879]
#define sipNameNr_toPlainText 57891
#define sipName_toPlainText &sipStrings_QtWidgets[57891]
#define sipNameNr_toolBarArea 57903
#define sipName_toolBarArea &sipStrings_QtWidgets[57903]
#define sipNameNr_ungrabMouse 57915
#define sipName_ungrabMouse &sipStrings_QtWidgets[57915]
#define sipNameNr_unsetCursor 57927
#define sipName_unsetCursor &sipStrings_QtWidgets[57927]
#define sipNameNr_unsetLocale 57939
#define sipName_unsetLocale &sipStrings_QtWidgets[57939]
#define sipNameNr_updateCells 57951
#define sipName_updateCells &sipStrings_QtWidgets[57951]
#define sipNameNr_updateScene 57963
#define sipName_updateScene &sipStrings_QtWidgets[57963]
#define sipNameNr_urlSelected 57975
#define sipName_urlSelected &sipStrings_QtWidgets[57975]
#define sipNameNr_viewOptions 57987
#define sipName_viewOptions &sipStrings_QtWidgets[57987]
#define sipNameNr_visualIndex 57999
#define sipName_visualIndex &sipStrings_QtWidgets[57999]
#define sipNameNr_wasCanceled 58011
#define sipName_wasCanceled &sipStrings_QtWidgets[58011]
#define sipNameNr_widgetEvent 58023
#define sipName_widgetEvent &sipStrings_QtWidgets[58023]
#define sipNameNr_windowFlags 58035
#define sipName_windowFlags &sipStrings_QtWidgets[58035]
#define sipNameNr_windowState 58047
#define sipName_windowState &sipStrings_QtWidgets[58047]
#define sipNameNr_windowTitle 58059
#define sipName_windowTitle &sipStrings_QtWidgets[58059]
#define sipNameNr_wizardStyle 58071
#define sipName_wizardStyle &sipStrings_QtWidgets[58071]
#define sipNameNr_AcceptMode 14517
#define sipName_AcceptMode &sipStrings_QtWidgets[14517]
#define sipNameNr_AcceptOpen 58083
#define sipName_AcceptOpen &sipStrings_QtWidgets[58083]
#define sipNameNr_AcceptRole 58094
#define sipName_AcceptRole &sipStrings_QtWidgets[58094]
#define sipNameNr_AcceptSave 58105
#define sipName_AcceptSave &sipStrings_QtWidgets[58105]
#define sipNameNr_ActionRole 58116
#define sipName_ActionRole &sipStrings_QtWidgets[58116]
#define sipNameNr_AreaOption 21525
#define sipName_AreaOption &sipStrings_QtWidgets[21525]
#define sipNameNr_AutoSubmit 58127
#define sipName_AutoSubmit &sipStrings_QtWidgets[58127]
#define sipNameNr_BackButton 58138
#define sipName_BackButton &sipStrings_QtWidgets[58138]
#define sipNameNr_ButtonMask 58149
#define sipName_ButtonMask &sipStrings_QtWidgets[58149]
#define sipNameNr_ButtonRole 8252
#define sipName_ButtonRole &sipStrings_QtWidgets[8252]
#define sipNameNr_CC_SpinBox 58160
#define sipName_CC_SpinBox &sipStrings_QtWidgets[58160]
#define sipNameNr_CE_ToolBar 58171
#define sipName_CE_ToolBar &sipStrings_QtWidgets[58171]
#define sipNameNr_CT_MenuBar 58182
#define sipName_CT_MenuBar &sipStrings_QtWidgets[58182]
#define sipNameNr_CT_SpinBox 58193
#define sipName_CT_SpinBox &sipStrings_QtWidgets[58193]
#define sipNameNr_CancelNone 58204
#define sipName_CancelNone &sipStrings_QtWidgets[58204]
#define sipNameNr_ChangeFlag 9339
#define sipName_ChangeFlag &sipStrings_QtWidgets[9339]
#define sipNameNr_DaySection 58215
#define sipName_DaySection &sipStrings_QtWidgets[58215]
#define sipNameNr_DialogCode 24454
#define sipName_DialogCode &sipStrings_QtWidgets[24454]
#define sipNameNr_DockOption 14853
#define sipName_DockOption &sipStrings_QtWidgets[14853]
#define sipNameNr_ExpandFlag 58226
#define sipName_ExpandFlag &sipStrings_QtWidgets[58226]
#define sipNameNr_FontFilter 11496
#define sipName_FontFilter &sipStrings_QtWidgets[11496]
#define sipNameNr_FrameRates 5812
#define sipName_FrameRates &sipStrings_QtWidgets[5812]
#define sipNameNr_HasDisplay 58237
#define sipName_HasDisplay &sipStrings_QtWidgets[58237]
#define sipNameNr_HelpButton 8571
#define sipName_HelpButton &sipStrings_QtWidgets[8571]
#define sipNameNr_IgnoreFlag 58248
#define sipName_IgnoreFlag &sipStrings_QtWidgets[58248]
#define sipNameNr_IgnoreMask 58259
#define sipName_IgnoreMask &sipStrings_QtWidgets[58259]
#define sipNameNr_InputPress 58270
#define sipName_InputPress &sipStrings_QtWidgets[58270]
#define sipNameNr_LastButton 58281
#define sipName_LastButton &sipStrings_QtWidgets[58281]
#define sipNameNr_LayoutMode 18876
#define sipName_LayoutMode &sipStrings_QtWidgets[18876]
#define sipNameNr_LogoPixmap 58292
#define sipName_LogoPixmap &sipStrings_QtWidgets[58292]
#define sipNameNr_MovePageUp 58303
#define sipName_MovePageUp &sipStrings_QtWidgets[58303]
#define sipNameNr_NextButton 58314
#define sipName_NextButton &sipStrings_QtWidgets[58314]
#define sipNameNr_NoChildren 58325
#define sipName_NoChildren &sipStrings_QtWidgets[58325]
#define sipNameNr_NoDragDrop 58336
#define sipName_NoDragDrop &sipStrings_QtWidgets[58336]
#define sipNameNr_NotChecked 58347
#define sipName_NotChecked &sipStrings_QtWidgets[58347]
#define sipNameNr_OnViewport 58358
#define sipName_OnViewport &sipStrings_QtWidgets[58358]
#define sipNameNr_OnlyOneTab 58369
#define sipName_OnlyOneTab &sipStrings_QtWidgets[58369]
#define sipNameNr_OptionType 308
#define sipName_OptionType &sipStrings_QtWidgets[308]
#define sipNameNr_PanelModal 58380
#define sipName_PanelModal &sipStrings_QtWidgets[58380]
#define sipNameNr_PolicyFlag 14925
#define sipName_PolicyFlag &sipStrings_QtWidgets[14925]
#define sipNameNr_PopupDelay 11938
#define sipName_PopupDelay &sipStrings_QtWidgets[11938]
#define sipNameNr_PushButton 46558
#define sipName_PushButton &sipStrings_QtWidgets[46558]
#define sipNameNr_QBoxLayout 58391
#define sipName_QBoxLayout &sipStrings_QtWidgets[58391]
#define sipNameNr_QCompleter 58402
#define sipName_QCompleter &sipStrings_QtWidgets[58402]
#define sipNameNr_QLCDNumber 58413
#define sipName_QLCDNumber &sipStrings_QtWidgets[58413]
#define sipNameNr_QScrollBar 58424
#define sipName_QScrollBar &sipStrings_QtWidgets[58424]
#define sipNameNr_QStatusBar 58435
#define sipName_QStatusBar &sipStrings_QtWidgets[58435]
#define sipNameNr_QTabWidget 58446
#define sipName_QTabWidget &sipStrings_QtWidgets[58446]
#define sipNameNr_QTableView 58457
#define sipName_QTableView &sipStrings_QtWidgets[58457]
#define sipNameNr_QUndoGroup 58468
#define sipName_QUndoGroup &sipStrings_QtWidgets[58468]
#define sipNameNr_QUndoStack 58479
#define sipName_QUndoStack &sipStrings_QtWidgets[58479]
#define sipNameNr_QWhatsThis 58490
#define sipName_QWhatsThis &sipStrings_QtWidgets[58490]
#define sipNameNr_RejectRole 58501
#define sipName_RejectRole &sipStrings_QtWidgets[58501]
#define sipNameNr_RenderFlag 24874
#define sipName_RenderFlag &sipStrings_QtWidgets[24874]
#define sipNameNr_ResizeMode 14685
#define sipName_ResizeMode &sipStrings_QtWidgets[14685]
#define sipNameNr_ResultFlag 6472
#define sipName_ResultFlag &sipStrings_QtWidgets[6472]
#define sipNameNr_SH_Default 58512
#define sipName_SH_Default &sipStrings_QtWidgets[58512]
#define sipNameNr_SH_Variant 58523
#define sipName_SH_Variant &sipStrings_QtWidgets[58523]
#define sipNameNr_SO_Complex 58534
#define sipName_SO_Complex &sipStrings_QtWidgets[58534]
#define sipNameNr_SO_Default 58545
#define sipName_SO_Default &sipStrings_QtWidgets[58545]
#define sipNameNr_SO_SpinBox 58556
#define sipName_SO_SpinBox &sipStrings_QtWidgets[58556]
#define sipNameNr_SO_ToolBar 58567
#define sipName_SO_ToolBar &sipStrings_QtWidgets[58567]
#define sipNameNr_SO_ToolBox 58578
#define sipName_SO_ToolBox &sipStrings_QtWidgets[58578]
#define sipNameNr_SP_ArrowUp 58589
#define sipName_SP_ArrowUp &sipStrings_QtWidgets[58589]
#define sipNameNr_SP_DirIcon 58600
#define sipName_SP_DirIcon &sipStrings_QtWidgets[58600]
#define sipNameNr_SceneLayer 10382
#define sipName_SceneLayer &sipStrings_QtWidgets[10382]
#define sipNameNr_SceneModal 58611
#define sipName_SceneModal &sipStrings_QtWidgets[58611]
#define sipNameNr_ScrollHint 7301
#define sipName_ScrollHint &sipStrings_QtWidgets[7301]
#define sipNameNr_ScrollMode 7331
#define sipName_ScrollMode &sipStrings_QtWidgets[7331]
#define sipNameNr_SelectRows 58622
#define sipName_SelectRows &sipStrings_QtWidgets[58622]
#define sipNameNr_Selectable 34678
#define sipName_Selectable &sipStrings_QtWidgets[34678]
#define sipNameNr_Shape_Mask 58633
#define sipName_Shape_Mask &sipStrings_QtWidgets[58633]
#define sipNameNr_ShrinkFlag 58644
#define sipName_ShrinkFlag &sipStrings_QtWidgets[58644]
#define sipNameNr_SinglePass 58655
#define sipName_SinglePass &sipStrings_QtWidgets[58655]
#define sipNameNr_SliderMove 58666
#define sipName_SliderMove &sipStrings_QtWidgets[58666]
#define sipNameNr_State_Item 58677
#define sipName_State_Item &sipStrings_QtWidgets[58677]
#define sipNameNr_State_Mini 58688
#define sipName_State_Mini &sipStrings_QtWidgets[58688]
#define sipNameNr_State_None 58699
#define sipName_State_None &sipStrings_QtWidgets[58699]
#define sipNameNr_State_Open 58710
#define sipName_State_Open &sipStrings_QtWidgets[58710]
#define sipNameNr_SubControl 27807
#define sipName_SubControl &sipStrings_QtWidgets[27807]
#define sipNameNr_SubElement 27826
#define sipName_SubElement &sipStrings_QtWidgets[27826]
#define sipNameNr_TabFeature 9479
#define sipName_TabFeature &sipStrings_QtWidgets[9479]
#define sipNameNr_TabbedView 58721
#define sipName_TabbedView &sipStrings_QtWidgets[58721]
#define sipNameNr_TicksAbove 58732
#define sipName_TicksAbove &sipStrings_QtWidgets[58732]
#define sipNameNr_TicksBelow 58743
#define sipName_TicksBelow &sipStrings_QtWidgets[58743]
#define sipNameNr_TicksRight 58754
#define sipName_TicksRight &sipStrings_QtWidgets[58754]
#define sipNameNr_ToolButton 16888
#define sipName_ToolButton &sipStrings_QtWidgets[16888]
#define sipNameNr_Triangular 58765
#define sipName_Triangular &sipStrings_QtWidgets[58765]
#define sipNameNr_Unselected 58776
#define sipName_Unselected &sipStrings_QtWidgets[58776]
#define sipNameNr___invert__ 58787
#define sipName___invert__ &sipStrings_QtWidgets[58787]
#define sipNameNr___lshift__ 58798
#define sipName___lshift__ &sipStrings_QtWidgets[58798]
#define sipNameNr___rshift__ 58809
#define sipName___rshift__ &sipStrings_QtWidgets[58809]
#define sipNameNr_acceptMode 58820
#define sipName_acceptMode &sipStrings_QtWidgets[58820]
#define sipNameNr_actionText 58831
#define sipName_actionText &sipStrings_QtWidgets[58831]
#define sipNameNr_addActions 58842
#define sipName_addActions &sipStrings_QtWidgets[58842]
#define sipNameNr_addAnchors 58853
#define sipName_addAnchors &sipStrings_QtWidgets[58853]
#define sipNameNr_addEllipse 58864
#define sipName_addEllipse &sipStrings_QtWidgets[58864]
#define sipNameNr_addMapping 58875
#define sipName_addMapping &sipStrings_QtWidgets[58875]
#define sipNameNr_addPolygon 58886
#define sipName_addPolygon &sipStrings_QtWidgets[58886]
#define sipNameNr_addSection 58897
#define sipName_addSection &sipStrings_QtWidgets[58897]
#define sipNameNr_addSpacing 58908
#define sipName_addSpacing &sipStrings_QtWidgets[58908]
#define sipNameNr_addStretch 58919
#define sipName_addStretch &sipStrings_QtWidgets[58919]
#define sipNameNr_addToGroup 58930
#define sipName_addToGroup &sipStrings_QtWidgets[58930]
#define sipNameNr_addToolBar 58941
#define sipName_addToolBar &sipStrings_QtWidgets[58941]
#define sipNameNr_adjustSize 58952
#define sipName_adjustSize &sipStrings_QtWidgets[58952]
#define sipNameNr_allWidgets 58963
#define sipName_allWidgets &sipStrings_QtWidgets[58963]
#define sipNameNr_appendHtml 58974
#define sipName_appendHtml &sipStrings_QtWidgets[58974]
#define sipNameNr_autoRepeat 58985
#define sipName_autoRepeat &sipStrings_QtWidgets[58985]
#define sipNameNr_background 58996
#define sipName_background &sipStrings_QtWidgets[58996]
#define sipNameNr_beginMacro 59007
#define sipName_beginMacro &sipStrings_QtWidgets[59007]
#define sipNameNr_blockCount 59018
#define sipName_blockCount &sipStrings_QtWidgets[59018]
#define sipNameNr_blurRadius 59029
#define sipName_blurRadius &sipStrings_QtWidgets[59029]
#define sipNameNr_buttonRole 59040
#define sipName_buttonRole &sipStrings_QtWidgets[59040]
#define sipNameNr_buttonText 59051
#define sipName_buttonText &sipStrings_QtWidgets[59051]
#define sipNameNr_cellWidget 59062
#define sipName_cellWidget &sipStrings_QtWidgets[59062]
#define sipNameNr_changeSize 59073
#define sipName_changeSize &sipStrings_QtWidgets[59073]
#define sipNameNr_checkState 59084
#define sipName_checkState &sipStrings_QtWidgets[59084]
#define sipNameNr_childCount 59095
#define sipName_childCount &sipStrings_QtWidgets[59095]
#define sipNameNr_childEvent 59106
#define sipName_childEvent &sipStrings_QtWidgets[59106]
#define sipNameNr_childItems 59117
#define sipName_childItems &sipStrings_QtWidgets[59117]
#define sipNameNr_cleanIndex 59128
#define sipName_cleanIndex &sipStrings_QtWidgets[59128]
#define sipNameNr_clearFocus 59139
#define sipName_clearFocus &sipStrings_QtWidgets[59139]
#define sipNameNr_clearSpans 59150
#define sipName_clearSpans &sipStrings_QtWidgets[59150]
#define sipNameNr_closeEvent 59161
#define sipName_closeEvent &sipStrings_QtWidgets[59161]
#define sipNameNr_columnSpan 59172
#define sipName_columnSpan &sipStrings_QtWidgets[59172]
#define sipNameNr_commitData 59183
#define sipName_commitData &sipStrings_QtWidgets[59183]
#define sipNameNr_constraint 59194
#define sipName_constraint &sipStrings_QtWidgets[59194]
#define sipNameNr_currentRow 59205
#define sipName_currentRow &sipStrings_QtWidgets[59205]
#define sipNameNr_cursorRect 59216
#define sipName_cursorRect &sipStrings_QtWidgets[59216]
#define sipNameNr_digitCount 59227
#define sipName_digitCount &sipStrings_QtWidgets[59227]
#define sipNameNr_doubleStep 59238
#define sipName_doubleStep &sipStrings_QtWidgets[59238]
#define sipNameNr_drawSource 59249
#define sipName_drawSource &sipStrings_QtWidgets[59249]
#define sipNameNr_dropAction 59260
#define sipName_dropAction &sipStrings_QtWidgets[59260]
#define sipNameNr_emptyLabel 59271
#define sipName_emptyLabel &sipStrings_QtWidgets[59271]
#define sipNameNr_enterEvent 59282
#define sipName_enterEvent &sipStrings_QtWidgets[59282]
#define sipNameNr_expandItem 59293
#define sipName_expandItem &sipStrings_QtWidgets[59293]
#define sipNameNr_filterMode 59304
#define sipName_filterMode &sipStrings_QtWidgets[59304]
#define sipNameNr_focusProxy 59315
#define sipName_focusProxy &sipStrings_QtWidgets[59315]
#define sipNameNr_fontFamily 59326
#define sipName_fontFamily &sipStrings_QtWidgets[59326]
#define sipNameNr_fontItalic 59337
#define sipName_fontItalic &sipStrings_QtWidgets[59337]
#define sipNameNr_fontWeight 59348
#define sipName_fontWeight &sipStrings_QtWidgets[59348]
#define sipNameNr_foreground 59359
#define sipName_foreground &sipStrings_QtWidgets[59359]
#define sipNameNr_frameShape 59370
#define sipName_frameShape &sipStrings_QtWidgets[59370]
#define sipNameNr_frameStyle 59381
#define sipName_frameStyle &sipStrings_QtWidgets[59381]
#define sipNameNr_frameWidth 59392
#define sipName_frameWidth &sipStrings_QtWidgets[59392]
#define sipNameNr_hasHotSpot 59403
#define sipName_hasHotSpot &sipStrings_QtWidgets[59403]
#define sipNameNr_headerData 59414
#define sipName_headerData &sipStrings_QtWidgets[59414]
#define sipNameNr_headerItem 59425
#define sipName_headerItem &sipStrings_QtWidgets[59425]
#define sipNameNr_hideColumn 59436
#define sipName_hideColumn &sipStrings_QtWidgets[59436]
#define sipNameNr_hideOrShow 59447
#define sipName_hideOrShow &sipStrings_QtWidgets[59447]
#define sipNameNr_historyUrl 59458
#define sipName_historyUrl &sipStrings_QtWidgets[59458]
#define sipNameNr_iconPixmap 59469
#define sipName_iconPixmap &sipStrings_QtWidgets[59469]
#define sipNameNr_idReleased 59480
#define sipName_idReleased &sipStrings_QtWidgets[59480]
#define sipNameNr_indexAbove 59491
#define sipName_indexAbove &sipStrings_QtWidgets[59491]
#define sipNameNr_indexBelow 59502
#define sipName_indexBelow &sipStrings_QtWidgets[59502]
#define sipNameNr_initialize 59513
#define sipName_initialize &sipStrings_QtWidgets[59513]
#define sipNameNr_insertHtml 59524
#define sipName_insertHtml &sipStrings_QtWidgets[59524]
#define sipNameNr_insertItem 59535
#define sipName_insertItem &sipStrings_QtWidgets[59535]
#define sipNameNr_insertMenu 59546
#define sipName_insertMenu &sipStrings_QtWidgets[59546]
#define sipNameNr_insertRows 59557
#define sipName_insertRows &sipStrings_QtWidgets[59557]
#define sipNameNr_intMaximum 59568
#define sipName_intMaximum &sipStrings_QtWidgets[59568]
#define sipNameNr_intMinimum 59579
#define sipName_intMinimum &sipStrings_QtWidgets[59579]
#define sipNameNr_invalidate 59590
#define sipName_invalidate &sipStrings_QtWidgets[59590]
#define sipNameNr_isAccepted 59601
#define sipName_isAccepted &sipStrings_QtWidgets[59601]
#define sipNameNr_isAnimated 59612
#define sipName_isAnimated &sipStrings_QtWidgets[59612]
#define sipNameNr_isComplete 59623
#define sipName_isComplete &sipStrings_QtWidgets[59623]
#define sipNameNr_isDisabled 59634
#define sipName_isDisabled &sipStrings_QtWidgets[59634]
#define sipNameNr_isEditable 59645
#define sipName_isEditable &sipStrings_QtWidgets[59645]
#define sipNameNr_isExpanded 59656
#define sipName_isExpanded &sipStrings_QtWidgets[59656]
#define sipNameNr_isFloating 59667
#define sipName_isFloating &sipStrings_QtWidgets[59667]
#define sipNameNr_isModified 59678
#define sipName_isModified &sipStrings_QtWidgets[59678]
#define sipNameNr_isObscured 59689
#define sipName_isObscured &sipStrings_QtWidgets[59689]
#define sipNameNr_isObsolete 59700
#define sipName_isObsolete &sipStrings_QtWidgets[59700]
#define sipNameNr_isReadOnly 59711
#define sipName_isReadOnly &sipStrings_QtWidgets[59711]
#define sipNameNr_isSelected 59722
#define sipName_isSelected &sipStrings_QtWidgets[59722]
#define sipNameNr_isTristate 59733
#define sipName_isTristate &sipStrings_QtWidgets[59733]
#define sipNameNr_isWrapping 59744
#define sipName_isWrapping &sipStrings_QtWidgets[59744]
#define sipNameNr_itemChange 59755
#define sipName_itemChange &sipStrings_QtWidgets[59755]
#define sipNameNr_itemWidget 59766
#define sipName_itemWidget &sipStrings_QtWidgets[59766]
#define sipNameNr_lastOffset 59777
#define sipName_lastOffset &sipStrings_QtWidgets[59777]
#define sipNameNr_layoutMode 59788
#define sipName_layoutMode &sipStrings_QtWidgets[59788]
#define sipNameNr_leaveEvent 59799
#define sipName_leaveEvent &sipStrings_QtWidgets[59799]
#define sipNameNr_leftColumn 59810
#define sipName_leftColumn &sipStrings_QtWidgets[59810]
#define sipNameNr_listWidget 59821
#define sipName_listWidget &sipStrings_QtWidgets[59821]
#define sipNameNr_mapToScene 59832
#define sipName_mapToScene &sipStrings_QtWidgets[59832]
#define sipNameNr_menuAction 59843
#define sipName_menuAction &sipStrings_QtWidgets[59843]
#define sipNameNr_menuWidget 59854
#define sipName_menuWidget &sipStrings_QtWidgets[59854]
#define sipNameNr_monthShown 59865
#define sipName_monthShown &sipStrings_QtWidgets[59865]
#define sipNameNr_moveCursor 59876
#define sipName_moveCursor &sipStrings_QtWidgets[59876]
#define sipNameNr_myComputer 59887
#define sipName_myComputer &sipStrings_QtWidgets[59887]
#define sipNameNr_opaqueArea 59898
#define sipName_opaqueArea &sipStrings_QtWidgets[59898]
#define sipNameNr_paintEvent 59909
#define sipName_paintEvent &sipStrings_QtWidgets[59909]
#define sipNameNr_parentItem 59920
#define sipName_parentItem &sipStrings_QtWidgets[59920]
#define sipNameNr_proxyModel 59931
#define sipName_proxyModel &sipStrings_QtWidgets[59931]
#define sipNameNr_removeItem 59942
#define sipName_removeItem &sipStrings_QtWidgets[59942]
#define sipNameNr_removePage 59953
#define sipName_removePage &sipStrings_QtWidgets[59953]
#define sipNameNr_removeRows 59964
#define sipName_removeRows &sipStrings_QtWidgets[59964]
#define sipNameNr_repeatTime 59975
#define sipName_repeatTime &sipStrings_QtWidgets[59975]
#define sipNameNr_resetClean 59986
#define sipName_resetClean &sipStrings_QtWidgets[59986]
#define sipNameNr_resizeMode 59997
#define sipName_resizeMode &sipStrings_QtWidgets[59997]
#define sipNameNr_returnData 60008
#define sipName_returnData &sipStrings_QtWidgets[60008]
#define sipNameNr_rowResized 60019
#define sipName_rowResized &sipStrings_QtWidgets[60019]
#define sipNameNr_rowSpacing 60030
#define sipName_rowSpacing &sipStrings_QtWidgets[60030]
#define sipNameNr_rowStretch 60041
#define sipName_rowStretch &sipStrings_QtWidgets[60041]
#define sipNameNr_sceneEvent 60052
#define sipName_sceneEvent &sipStrings_QtWidgets[60052]
#define sipNameNr_selectFile 60063
#define sipName_selectFile &sipStrings_QtWidgets[60063]
#define sipNameNr_setBinMode 60074
#define sipName_setBinMode &sipStrings_QtWidgets[60074]
#define sipNameNr_setChecked 60085
#define sipName_setChecked &sipStrings_QtWidgets[60085]
#define sipNameNr_setContext 60096
#define sipName_setContext &sipStrings_QtWidgets[60096]
#define sipNameNr_setDecMode 60107
#define sipName_setDecMode &sipStrings_QtWidgets[60107]
#define sipNameNr_setDefault 60118
#define sipName_setDefault &sipStrings_QtWidgets[60118]
#define sipNameNr_setEnabled 60129
#define sipName_setEnabled &sipStrings_QtWidgets[60129]
#define sipNameNr_setHexMode 60140
#define sipName_setHexMode &sipStrings_QtWidgets[60140]
#define sipNameNr_setHistory 60151
#define sipName_setHistory &sipStrings_QtWidgets[60151]
#define sipNameNr_setHotSpot 54236
#define sipName_setHotSpot &sipStrings_QtWidgets[54236]
#define sipNameNr_setIntStep 60162
#define sipName_setIntStep &sipStrings_QtWidgets[60162]
#define sipNameNr_setMaximum 60173
#define sipName_setMaximum &sipStrings_QtWidgets[60173]
#define sipNameNr_setMenuBar 60184
#define sipName_setMenuBar &sipStrings_QtWidgets[60184]
#define sipNameNr_setMinimum 60195
#define sipName_setMinimum &sipStrings_QtWidgets[60195]
#define sipNameNr_setMovable 60206
#define sipName_setMovable &sipStrings_QtWidgets[60206]
#define sipNameNr_setOctMode 60217
#define sipName_setOctMode &sipStrings_QtWidgets[60217]
#define sipNameNr_setOpacity 60228
#define sipName_setOpacity &sipStrings_QtWidgets[60228]
#define sipNameNr_setOptions 60239
#define sipName_setOptions &sipStrings_QtWidgets[60239]
#define sipNameNr_setPalette 60250
#define sipName_setPalette &sipStrings_QtWidgets[60250]
#define sipNameNr_setPicture 60261
#define sipName_setPicture &sipStrings_QtWidgets[60261]
#define sipNameNr_setPolygon 60272
#define sipName_setPolygon &sipStrings_QtWidgets[60272]
#define sipNameNr_setSorting 60283
#define sipName_setSorting &sipStrings_QtWidgets[60283]
#define sipNameNr_setSpacing 54249
#define sipName_setSpacing &sipStrings_QtWidgets[54249]
#define sipNameNr_setStartId 60294
#define sipName_setStartId &sipStrings_QtWidgets[60294]
#define sipNameNr_setStretch 60305
#define sipName_setStretch &sipStrings_QtWidgets[60305]
#define sipNameNr_setTabData 60316
#define sipName_setTabData &sipStrings_QtWidgets[60316]
#define sipNameNr_setTabIcon 60327
#define sipName_setTabIcon &sipStrings_QtWidgets[60327]
#define sipNameNr_setTabText 60338
#define sipName_setTabText &sipStrings_QtWidgets[60338]
#define sipNameNr_setTimeout 60349
#define sipName_setTimeout &sipStrings_QtWidgets[60349]
#define sipNameNr_setToolTip 60360
#define sipName_setToolTip &sipStrings_QtWidgets[60360]
#define sipNameNr_setVisible 60371
#define sipName_setVisible &sipStrings_QtWidgets[60371]
#define sipNameNr_setXOffset 60382
#define sipName_setXOffset &sipStrings_QtWidgets[60382]
#define sipNameNr_setYOffset 60393
#define sipName_setYOffset &sipStrings_QtWidgets[60393]
#define sipNameNr_showColumn 60404
#define sipName_showColumn &sipStrings_QtWidgets[60404]
#define sipNameNr_showNormal 60415
#define sipName_showNormal &sipStrings_QtWidgets[60415]
#define sipNameNr_showShaded 60426
#define sipName_showShaded &sipStrings_QtWidgets[60426]
#define sipNameNr_sideWidget 60437
#define sipName_sideWidget &sipStrings_QtWidgets[60437]
#define sipNameNr_singleStep 60448
#define sipName_singleStep &sipStrings_QtWidgets[60448]
#define sipNameNr_sizePolicy 60459
#define sipName_sizePolicy &sipStrings_QtWidgets[60459]
#define sipNameNr_sortColumn 60470
#define sipName_sortColumn &sipStrings_QtWidgets[60470]
#define sipNameNr_sourceType 60481
#define sipName_sourceType &sipStrings_QtWidgets[60481]
#define sipNameNr_spacerItem 60492
#define sipName_spacerItem &sipStrings_QtWidgets[60492]
#define sipNameNr_stackUnder 60503
#define sipName_stackUnder &sipStrings_QtWidgets[60503]
#define sipNameNr_startAngle 60514
#define sipName_startAngle &sipStrings_QtWidgets[60514]
#define sipNameNr_styleSheet 60525
#define sipName_styleSheet &sipStrings_QtWidgets[60525]
#define sipNameNr_swipeAngle 60536
#define sipName_swipeAngle &sipStrings_QtWidgets[60536]
#define sipNameNr_systemMenu 60547
#define sipName_systemMenu &sipStrings_QtWidgets[60547]
#define sipNameNr_tabBarRect 60558
#define sipName_tabBarRect &sipStrings_QtWidgets[60558]
#define sipNameNr_tabBarSize 60569
#define sipName_tabBarSize &sipStrings_QtWidgets[60569]
#define sipNameNr_tabRemoved 60580
#define sipName_tabRemoved &sipStrings_QtWidgets[60580]
#define sipNameNr_tabToolTip 60591
#define sipName_tabToolTip &sipStrings_QtWidgets[60591]
#define sipNameNr_takeWidget 60602
#define sipName_takeWidget &sipStrings_QtWidgets[60602]
#define sipNameNr_testOption 60613
#define sipName_testOption &sipStrings_QtWidgets[60613]
#define sipNameNr_textCursor 60624
#define sipName_textCursor &sipStrings_QtWidgets[60624]
#define sipNameNr_textEdited 60635
#define sipName_textEdited &sipStrings_QtWidgets[60635]
#define sipNameNr_textFormat 60646
#define sipName_textFormat &sipStrings_QtWidgets[60646]
#define sipNameNr_timerEvent 60657
#define sipName_timerEvent &sipStrings_QtWidgets[60657]
#define sipNameNr_toMarkdown 60668
#define sipName_toMarkdown &sipStrings_QtWidgets[60668]
#define sipNameNr_toPrevious 60679
#define sipName_toPrevious &sipStrings_QtWidgets[60679]
#define sipNameNr_topLevelAt 60690
#define sipName_topLevelAt &sipStrings_QtWidgets[60690]
#define sipNameNr_transposed 60701
#define sipName_transposed &sipStrings_QtWidgets[60701]
#define sipNameNr_treeWidget 60712
#define sipName_treeWidget &sipStrings_QtWidgets[60712]
#define sipNameNr_underMouse 60723
#define sipName_underMouse &sipStrings_QtWidgets[60723]
#define sipNameNr_updateCell 60734
#define sipName_updateCell &sipStrings_QtWidgets[60734]
#define sipNameNr_upsideDown 60745
#define sipName_upsideDown &sipStrings_QtWidgets[60745]
#define sipNameNr_visitedIds 60756
#define sipName_visitedIds &sipStrings_QtWidgets[60756]
#define sipNameNr_visualRect 60767
#define sipName_visualRect &sipStrings_QtWidgets[60767]
#define sipNameNr_wheelEvent 60778
#define sipName_wheelEvent &sipStrings_QtWidgets[60778]
#define sipNameNr_windowIcon 60789
#define sipName_windowIcon &sipStrings_QtWidgets[60789]
#define sipNameNr_windowRole 60800
#define sipName_windowRole &sipStrings_QtWidgets[60800]
#define sipNameNr_windowType 60811
#define sipName_windowType &sipStrings_QtWidgets[60811]
#define sipNameNr_wrapAround 60822
#define sipName_wrapAround &sipStrings_QtWidgets[60822]
#define sipNameNr_AboutRole 60833
#define sipName_AboutRole &sipStrings_QtWidgets[60833]
#define sipNameNr_AboveItem 60843
#define sipName_AboveItem &sipStrings_QtWidgets[60843]
#define sipNameNr_AeroStyle 60853
#define sipName_AeroStyle &sipStrings_QtWidgets[60853]
#define sipNameNr_AllLayers 60863
#define sipName_AllLayers &sipStrings_QtWidgets[60863]
#define sipNameNr_Alternate 60873
#define sipName_Alternate &sipStrings_QtWidgets[60873]
#define sipNameNr_ApplyRole 60883
#define sipName_ApplyRole &sipStrings_QtWidgets[60883]
#define sipNameNr_Beginning 60893
#define sipName_Beginning &sipStrings_QtWidgets[60893]
#define sipNameNr_BelowItem 60903
#define sipName_BelowItem &sipStrings_QtWidgets[60903]
#define sipNameNr_BlurHints 6504
#define sipName_BlurHints &sipStrings_QtWidgets[6504]
#define sipNameNr_ButtonBox 35019
#define sipName_ButtonBox &sipStrings_QtWidgets[35019]
#define sipNameNr_CC_Slider 60913
#define sipName_CC_Slider &sipStrings_QtWidgets[60913]
#define sipNameNr_CE_Header 60923
#define sipName_CE_Header &sipStrings_QtWidgets[60923]
#define sipNameNr_CT_Slider 60933
#define sipName_CT_Slider &sipStrings_QtWidgets[60933]
#define sipNameNr_CacheMode 12986
#define sipName_CacheMode &sipStrings_QtWidgets[12986]
#define sipNameNr_CacheNone 60943
#define sipName_CacheNone &sipStrings_QtWidgets[60943]
#define sipNameNr_CheckType 5877
#define sipName_CheckType &sipStrings_QtWidgets[5877]
#define sipNameNr_ColorSpec 14446
#define sipName_ColorSpec &sipStrings_QtWidgets[14446]
#define sipNameNr_Direction 7692
#define sipName_Direction &sipStrings_QtWidgets[7692]
#define sipNameNr_Directory 22576
#define sipName_Directory &sipStrings_QtWidgets[22576]
#define sipNameNr_EmptyArea 40
#define sipName_EmptyArea &sipStrings_QtWidgets[40]
#define sipNameNr_Exclusive 36838
#define sipName_Exclusive &sipStrings_QtWidgets[36838]
#define sipNameNr_Expanding 34764
#define sipName_Expanding &sipStrings_QtWidgets[34764]
#define sipNameNr_FieldRole 60953
#define sipName_FieldRole &sipStrings_QtWidgets[60953]
#define sipNameNr_FrameRate 60963
#define sipName_FrameRate &sipStrings_QtWidgets[60963]
#define sipNameNr_InputMode 14710
#define sipName_InputMode &sipStrings_QtWidgets[14710]
#define sipNameNr_InputMove 60973
#define sipName_InputMove &sipStrings_QtWidgets[60973]
#define sipNameNr_ItemLayer 60983
#define sipName_ItemLayer &sipStrings_QtWidgets[60983]
#define sipNameNr_KdeLayout 60993
#define sipName_KdeLayout &sipStrings_QtWidgets[60993]
#define sipNameNr_LabelRole 61003
#define sipName_LabelRole &sipStrings_QtWidgets[61003]
#define sipNameNr_MacLayout 61013
#define sipName_MacLayout &sipStrings_QtWidgets[61013]
#define sipNameNr_ManyColor 61023
#define sipName_ManyColor &sipStrings_QtWidgets[61023]
#define sipNameNr_MaskShape 27219
#define sipName_MaskShape &sipStrings_QtWidgets[27219]
#define sipNameNr_MoveRight 61033
#define sipName_MoveRight &sipStrings_QtWidgets[61033]
#define sipNameNr_NoButtons 61043
#define sipName_NoButtons &sipStrings_QtWidgets[61043]
#define sipNameNr_NoSection 61053
#define sipName_NoSection &sipStrings_QtWidgets[61053]
#define sipNameNr_NotHidden 61063
#define sipName_NotHidden &sipStrings_QtWidgets[61063]
#define sipNameNr_PE_Widget 61073
#define sipName_PE_Widget &sipStrings_QtWidgets[61073]
#define sipNameNr_PlusMinus 61083
#define sipName_PlusMinus &sipStrings_QtWidgets[61083]
#define sipNameNr_Preferred 61093
#define sipName_Preferred &sipStrings_QtWidgets[61093]
#define sipNameNr_QCheckBox 61103
#define sipName_QCheckBox &sipStrings_QtWidgets[61103]
#define sipNameNr_QComboBox 61113
#define sipName_QComboBox &sipStrings_QtWidgets[61113]
#define sipNameNr_QDateEdit 61123
#define sipName_QDateEdit &sipStrings_QtWidgets[61123]
#define sipNameNr_QDirModel 61133
#define sipName_QDirModel &sipStrings_QtWidgets[61133]
#define sipNameNr_QGroupBox 61143
#define sipName_QGroupBox &sipStrings_QtWidgets[61143]
#define sipNameNr_QLineEdit 61153
#define sipName_QLineEdit &sipStrings_QtWidgets[61153]
#define sipNameNr_QListView 61163
#define sipName_QListView &sipStrings_QtWidgets[61163]
#define sipNameNr_QScroller 61173
#define sipName_QScroller &sipStrings_QtWidgets[61173]
#define sipNameNr_QShortcut 61183
#define sipName_QShortcut &sipStrings_QtWidgets[61183]
#define sipNameNr_QSizeGrip 61193
#define sipName_QSizeGrip &sipStrings_QtWidgets[61193]
#define sipNameNr_QSplitter 61203
#define sipName_QSplitter &sipStrings_QtWidgets[61203]
#define sipNameNr_QTextEdit 61213
#define sipName_QTextEdit &sipStrings_QtWidgets[61213]
#define sipNameNr_QTimeEdit 61223
#define sipName_QTimeEdit &sipStrings_QtWidgets[61223]
#define sipNameNr_QTreeView 61233
#define sipName_QTreeView &sipStrings_QtWidgets[61233]
#define sipNameNr_QUndoView 61243
#define sipName_QUndoView &sipStrings_QtWidgets[61243]
#define sipNameNr_Rectangle 61253
#define sipName_Rectangle &sipStrings_QtWidgets[61253]
#define sipNameNr_ResetRole 61263
#define sipName_ResetRole &sipStrings_QtWidgets[61263]
#define sipNameNr_RightSide 61273
#define sipName_RightSide &sipStrings_QtWidgets[61273]
#define sipNameNr_SO_Button 61283
#define sipName_SO_Button &sipStrings_QtWidgets[61283]
#define sipNameNr_SO_Header 61293
#define sipName_SO_Header &sipStrings_QtWidgets[61293]
#define sipNameNr_SO_Slider 61303
#define sipName_SO_Slider &sipStrings_QtWidgets[61303]
#define sipNameNr_Scrolling 5909
#define sipName_Scrolling &sipStrings_QtWidgets[5909]
#define sipNameNr_Separator 8166
#define sipName_Separator &sipStrings_QtWidgets[8166]
#define sipNameNr_ShapeMode 6566
#define sipName_ShapeMode &sipStrings_QtWidgets[6566]
#define sipNameNr_StateFlag 31461
#define sipName_StateFlag &sipStrings_QtWidgets[31461]
#define sipNameNr_State_Off 61313
#define sipName_State_Off &sipStrings_QtWidgets[61313]
#define sipNameNr_State_Top 61323
#define sipName_State_Top &sipStrings_QtWidgets[61323]
#define sipNameNr_StyleHint 31479
#define sipName_StyleHint &sipStrings_QtWidgets[31479]
#define sipNameNr_StyleMask 31317
#define sipName_StyleMask &sipStrings_QtWidgets[31317]
#define sipNameNr_TabWidget 31011
#define sipName_TabWidget &sipStrings_QtWidgets[31011]
#define sipNameNr_TextInput 8833
#define sipName_TextInput &sipStrings_QtWidgets[8833]
#define sipNameNr_TicksLeft 61333
#define sipName_TicksLeft &sipStrings_QtWidgets[61333]
#define sipNameNr_WinLayout 61343
#define sipName_WinLayout &sipStrings_QtWidgets[61343]
#define sipNameNr___index__ 61353
#define sipName___index__ &sipStrings_QtWidgets[61353]
#define sipNameNr_activated 61363
#define sipName_activated &sipStrings_QtWidgets[61363]
#define sipNameNr_addAction 61373
#define sipName_addAction &sipStrings_QtWidgets[61373]
#define sipNameNr_addAnchor 61383
#define sipName_addAnchor &sipStrings_QtWidgets[61383]
#define sipNameNr_addButton 61393
#define sipName_addButton &sipStrings_QtWidgets[61393]
#define sipNameNr_addLayout 61403
#define sipName_addLayout &sipStrings_QtWidgets[61403]
#define sipNameNr_addPixmap 61413
#define sipName_addPixmap &sipStrings_QtWidgets[61413]
#define sipNameNr_addWidget 61423
#define sipName_addWidget &sipStrings_QtWidgets[61423]
#define sipNameNr_alignment 61433
#define sipName_alignment &sipStrings_QtWidgets[61433]
#define sipNameNr_arrowType 61443
#define sipName_arrowType &sipStrings_QtWidgets[61443]
#define sipNameNr_autoClose 61453
#define sipName_autoClose &sipStrings_QtWidgets[61453]
#define sipNameNr_autoRaise 61463
#define sipName_autoRaise &sipStrings_QtWidgets[61463]
#define sipNameNr_autoReset 61473
#define sipName_autoReset &sipStrings_QtWidgets[61473]
#define sipNameNr_backspace 61483
#define sipName_backspace &sipStrings_QtWidgets[61483]
#define sipNameNr_baseStyle 61493
#define sipName_baseStyle &sipStrings_QtWidgets[61493]
#define sipNameNr_batchSize 61503
#define sipName_batchSize &sipStrings_QtWidgets[61503]
#define sipNameNr_blurHints 61513
#define sipName_blurHints &sipStrings_QtWidgets[61513]
#define sipNameNr_bottomRow 61523
#define sipName_bottomRow &sipStrings_QtWidgets[61523]
#define sipNameNr_cacheMode 61533
#define sipName_cacheMode &sipStrings_QtWidgets[61533]
#define sipNameNr_checkType 61543
#define sipName_checkType &sipStrings_QtWidgets[61543]
#define sipNameNr_checkedId 61553
#define sipName_checkedId &sipStrings_QtWidgets[61553]
#define sipNameNr_className 61563
#define sipName_className &sipStrings_QtWidgets[61563]
#define sipNameNr_cleanIcon 61573
#define sipName_cleanIcon &sipStrings_QtWidgets[61573]
#define sipNameNr_cleanText 61583
#define sipName_cleanText &sipStrings_QtWidgets[61583]
#define sipNameNr_clearMask 61593
#define sipName_clearMask &sipStrings_QtWidgets[61593]
#define sipNameNr_collapsed 61603
#define sipName_collapsed &sipStrings_QtWidgets[61603]
#define sipNameNr_colorSpec 61613
#define sipName_colorSpec &sipStrings_QtWidgets[61613]
#define sipNameNr_completer 61623
#define sipName_completer &sipStrings_QtWidgets[61623]
#define sipNameNr_currentId 61633
#define sipName_currentId &sipStrings_QtWidgets[61633]
#define sipNameNr_direction 61643
#define sipName_direction &sipStrings_QtWidgets[61643]
#define sipNameNr_directory 61653
#define sipName_directory &sipStrings_QtWidgets[61653]
#define sipNameNr_drawCheck 61663
#define sipName_drawCheck &sipStrings_QtWidgets[61663]
#define sipNameNr_drawFocus 61673
#define sipName_drawFocus &sipStrings_QtWidgets[61673]
#define sipNameNr_drawFrame 61683
#define sipName_drawFrame &sipStrings_QtWidgets[61683]
#define sipNameNr_dropEvent 61693
#define sipName_dropEvent &sipStrings_QtWidgets[61693]
#define sipNameNr_elideMode 61703
#define sipName_elideMode &sipStrings_QtWidgets[61703]
#define sipNameNr_eventTest 61713
#define sipName_eventTest &sipStrings_QtWidgets[61713]
#define sipNameNr_exclusive 61723
#define sipName_exclusive &sipStrings_QtWidgets[61723]
#define sipNameNr_expandAll 61733
#define sipName_expandAll &sipStrings_QtWidgets[61733]
#define sipNameNr_expanding 61743
#define sipName_expanding &sipStrings_QtWidgets[61743]
#define sipNameNr_fetchMore 61753
#define sipName_fetchMore &sipStrings_QtWidgets[61753]
#define sipNameNr_fieldItem 61763
#define sipName_fieldItem &sipStrings_QtWidgets[61763]
#define sipNameNr_findItems 61773
#define sipName_findItems &sipStrings_QtWidgets[61773]
#define sipNameNr_fitInView 61783
#define sipName_fitInView &sipStrings_QtWidgets[61783]
#define sipNameNr_floatable 61793
#define sipName_floatable &sipStrings_QtWidgets[61793]
#define sipNameNr_focusItem 61803
#define sipName_focusItem &sipStrings_QtWidgets[61803]
#define sipNameNr_forceShow 61813
#define sipName_forceShow &sipStrings_QtWidgets[61813]
#define sipNameNr_frameRect 61823
#define sipName_frameRect &sipStrings_QtWidgets[61823]
#define sipNameNr_frameSize 61833
#define sipName_frameSize &sipStrings_QtWidgets[61833]
#define sipNameNr_getDouble 61843
#define sipName_getDouble &sipStrings_QtWidgets[61843]
#define sipNameNr_grabMouse 57917
#define sipName_grabMouse &sipStrings_QtWidgets[57917]
#define sipNameNr_gridStyle 61853
#define sipName_gridStyle &sipStrings_QtWidgets[61853]
#define sipNameNr_hasCursor 61863
#define sipName_hasCursor &sipStrings_QtWidgets[61863]
#define sipNameNr_helpEvent 61873
#define sipName_helpEvent &sipStrings_QtWidgets[61873]
#define sipNameNr_hideEvent 61883
#define sipName_hideEvent &sipStrings_QtWidgets[61883]
#define sipNameNr_hidePopup 61893
#define sipName_hidePopup &sipStrings_QtWidgets[61893]
#define sipNameNr_hitButton 61903
#define sipName_hitButton &sipStrings_QtWidgets[61903]
#define sipNameNr_idClicked 61913
#define sipName_idClicked &sipStrings_QtWidgets[61913]
#define sipNameNr_idPressed 61923
#define sipName_idPressed &sipStrings_QtWidgets[61923]
#define sipNameNr_idToggled 61933
#define sipName_idToggled &sipStrings_QtWidgets[61933]
#define sipNameNr_inputMask 61943
#define sipName_inputMask &sipStrings_QtWidgets[61943]
#define sipNameNr_inputMode 61953
#define sipName_inputMode &sipStrings_QtWidgets[61953]
#define sipNameNr_insertRow 61963
#define sipName_insertRow &sipStrings_QtWidgets[61963]
#define sipNameNr_insertTab 61973
#define sipName_insertTab &sipStrings_QtWidgets[61973]
#define sipNameNr_isChecked 61983
#define sipName_isChecked &sipStrings_QtWidgets[61983]
#define sipNameNr_isClipped 61993
#define sipName_isClipped &sipStrings_QtWidgets[61993]
#define sipNameNr_isDefault 62003
#define sipName_isDefault &sipStrings_QtWidgets[62003]
#define sipNameNr_isEnabled 62013
#define sipName_isEnabled &sipStrings_QtWidgets[62013]
#define sipNameNr_isMovable 62023
#define sipName_isMovable &sipStrings_QtWidgets[62023]
#define sipNameNr_isVisible 62033
#define sipName_isVisible &sipStrings_QtWidgets[62033]
#define sipNameNr_itemAbove 62043
#define sipName_itemAbove &sipStrings_QtWidgets[62043]
#define sipNameNr_itemBelow 62053
#define sipName_itemBelow &sipStrings_QtWidgets[62053]
#define sipNameNr_labelItem 62063
#define sipName_labelItem &sipStrings_QtWidgets[62063]
#define sipNameNr_labelText 62073
#define sipName_labelText &sipStrings_QtWidgets[62073]
#define sipNameNr_lineWidth 62083
#define sipName_lineWidth &sipStrings_QtWidgets[62083]
#define sipNameNr_mapToItem 62093
#define sipName_mapToItem &sipStrings_QtWidgets[62093]
#define sipNameNr_maxLength 62103
#define sipName_maxLength &sipStrings_QtWidgets[62103]
#define sipNameNr_mergeWith 62113
#define sipName_mergeWith &sipStrings_QtWidgets[62113]
#define sipNameNr_mimeTypes 62123
#define sipName_mimeTypes &sipStrings_QtWidgets[62123]
#define sipNameNr_modifiers 62133
#define sipName_modifiers &sipStrings_QtWidgets[62133]
#define sipNameNr_moveEvent 62143
#define sipName_moveEvent &sipStrings_QtWidgets[62143]
#define sipNameNr_notchSize 62153
#define sipName_notchSize &sipStrings_QtWidgets[62153]
#define sipNameNr_openLinks 62163
#define sipName_openLinks &sipStrings_QtWidgets[62163]
#define sipNameNr_pageAdded 62173
#define sipName_pageAdded &sipStrings_QtWidgets[62173]
#define sipNameNr_pageCount 62183
#define sipName_pageCount &sipStrings_QtWidgets[62183]
#define sipNameNr_paintCell 62193
#define sipName_paintCell &sipStrings_QtWidgets[62193]
#define sipNameNr_popupMode 62203
#define sipName_popupMode &sipStrings_QtWidgets[62203]
#define sipNameNr_popupRect 62213
#define sipName_popupRect &sipStrings_QtWidgets[62213]
#define sipNameNr_qtHandler 62223
#define sipName_qtHandler &sipStrings_QtWidgets[62223]
#define sipNameNr_recognize 62233
#define sipName_recognize &sipStrings_QtWidgets[62233]
#define sipNameNr_rectangle 62243
#define sipName_rectangle &sipStrings_QtWidgets[62243]
#define sipNameNr_removeRow 62253
#define sipName_removeRow &sipStrings_QtWidgets[62253]
#define sipNameNr_removeTab 62263
#define sipName_removeTab &sipStrings_QtWidgets[62263]
#define sipNameNr_roleNames 62273
#define sipName_roleNames &sipStrings_QtWidgets[62273]
#define sipNameNr_rootIndex 62283
#define sipName_rootIndex &sipStrings_QtWidgets[62283]
#define sipNameNr_rowHeight 62293
#define sipName_rowHeight &sipStrings_QtWidgets[62293]
#define sipNameNr_saveState 62303
#define sipName_saveState &sipStrings_QtWidgets[62303]
#define sipNameNr_sceneRect 62313
#define sipName_sceneRect &sipStrings_QtWidgets[62313]
#define sipNameNr_screenPos 62323
#define sipName_screenPos &sipStrings_QtWidgets[62323]
#define sipNameNr_sectionAt 62333
#define sipName_sectionAt &sipStrings_QtWidgets[62333]
#define sipNameNr_selectAll 62343
#define sipName_selectAll &sipStrings_QtWidgets[62343]
#define sipNameNr_selectRow 62353
#define sipName_selectRow &sipStrings_QtWidgets[62353]
#define sipNameNr_selectUrl 62363
#define sipName_selectUrl &sipStrings_QtWidgets[62363]
#define sipNameNr_sendEvent 62373
#define sipName_sendEvent &sipStrings_QtWidgets[62373]
#define sipNameNr_setActive 62383
#define sipName_setActive &sipStrings_QtWidgets[62383]
#define sipNameNr_setButton 22114
#define sipName_setButton &sipStrings_QtWidgets[22114]
#define sipNameNr_setCorner 62393
#define sipName_setCorner &sipStrings_QtWidgets[62393]
#define sipNameNr_setCursor 57929
#define sipName_setCursor &sipStrings_QtWidgets[57929]
#define sipNameNr_setFilter 62403
#define sipName_setFilter &sipStrings_QtWidgets[62403]
#define sipNameNr_setFormat 56777
#define sipName_setFormat &sipStrings_QtWidgets[56777]
#define sipNameNr_setHeader 62413
#define sipName_setHeader &sipStrings_QtWidgets[62413]
#define sipNameNr_setHidden 62423
#define sipName_setHidden &sipStrings_QtWidgets[62423]
#define sipNameNr_setIndent 62433
#define sipName_setIndent &sipStrings_QtWidgets[62433]
#define sipNameNr_setLayout 62443
#define sipName_setLayout &sipStrings_QtWidgets[62443]
#define sipNameNr_setLocale 57941
#define sipName_setLocale &sipStrings_QtWidgets[57941]
#define sipNameNr_setMargin 62453
#define sipName_setMargin &sipStrings_QtWidgets[62453]
#define sipNameNr_setOffset 62463
#define sipName_setOffset &sipStrings_QtWidgets[62463]
#define sipNameNr_setOption 62473
#define sipName_setOption &sipStrings_QtWidgets[62473]
#define sipNameNr_setOrigin 62483
#define sipName_setOrigin &sipStrings_QtWidgets[62483]
#define sipNameNr_setParent 62493
#define sipName_setParent &sipStrings_QtWidgets[62493]
#define sipNameNr_setPixmap 62503
#define sipName_setPixmap &sipStrings_QtWidgets[62503]
#define sipNameNr_setPrefix 62513
#define sipName_setPrefix &sipStrings_QtWidgets[62513]
#define sipNameNr_setResult 62523
#define sipName_setResult &sipStrings_QtWidgets[62523]
#define sipNameNr_setSource 62533
#define sipName_setSource &sipStrings_QtWidgets[62533]
#define sipNameNr_setSuffix 62543
#define sipName_setSuffix &sipStrings_QtWidgets[62543]
#define sipNameNr_setTabBar 62553
#define sipName_setTabBar &sipStrings_QtWidgets[62553]
#define sipNameNr_setWidget 62563
#define sipName_setWidget &sipStrings_QtWidgets[62563]
#define sipNameNr_setXScale 62573
#define sipName_setXScale &sipStrings_QtWidgets[62573]
#define sipNameNr_setYScale 62583
#define sipName_setYScale &sipStrings_QtWidgets[62583]
#define sipNameNr_setZScale 62593
#define sipName_setZScale &sipStrings_QtWidgets[62593]
#define sipNameNr_setZValue 62603
#define sipName_setZValue &sipStrings_QtWidgets[62603]
#define sipNameNr_shapeMode 62613
#define sipName_shapeMode &sipStrings_QtWidgets[62613]
#define sipNameNr_shortcuts 62623
#define sipName_shortcuts &sipStrings_QtWidgets[62623]
#define sipNameNr_showEvent 62633
#define sipName_showEvent &sipStrings_QtWidgets[62633]
#define sipNameNr_showPopup 62643
#define sipName_showPopup &sipStrings_QtWidgets[62643]
#define sipNameNr_showToday 62653
#define sipName_showToday &sipStrings_QtWidgets[62653]
#define sipNameNr_sortItems 62663
#define sipName_sortItems &sipStrings_QtWidgets[62663]
#define sipNameNr_spanAngle 62673
#define sipName_spanAngle &sipStrings_QtWidgets[62673]
#define sipNameNr_splitPath 62683
#define sipName_splitPath &sipStrings_QtWidgets[62683]
#define sipNameNr_startDrag 62693
#define sipName_startDrag &sipStrings_QtWidgets[62693]
#define sipNameNr_statusBar 62703
#define sipName_statusBar &sipStrings_QtWidgets[62703]
#define sipNameNr_statusTip 62713
#define sipName_statusTip &sipStrings_QtWidgets[62713]
#define sipNameNr_styleHint 62723
#define sipName_styleHint &sipStrings_QtWidgets[62723]
#define sipNameNr_tabButton 62733
#define sipName_tabButton &sipStrings_QtWidgets[62733]
#define sipNameNr_takeChild 62743
#define sipName_takeChild &sipStrings_QtWidgets[62743]
#define sipNameNr_textColor 62753
#define sipName_textColor &sipStrings_QtWidgets[62753]
#define sipNameNr_textValue 62763
#define sipName_textValue &sipStrings_QtWidgets[62763]
#define sipNameNr_textWidth 62773
#define sipName_textWidth &sipStrings_QtWidgets[62773]
#define sipNameNr_timestamp 62783
#define sipName_timestamp &sipStrings_QtWidgets[62783]
#define sipNameNr_transform 62793
#define sipName_transform &sipStrings_QtWidgets[62793]
#define sipNameNr_translate 62803
#define sipName_translate &sipStrings_QtWidgets[62803]
#define sipNameNr_transpose 62813
#define sipName_transpose &sipStrings_QtWidgets[62813]
#define sipNameNr_triggered 62823
#define sipName_triggered &sipStrings_QtWidgets[62823]
#define sipNameNr_undoLimit 62833
#define sipName_undoLimit &sipStrings_QtWidgets[62833]
#define sipNameNr_validator 62843
#define sipName_validator &sipStrings_QtWidgets[62843]
#define sipNameNr_visualPos 62853
#define sipName_visualPos &sipStrings_QtWidgets[62853]
#define sipNameNr_visualRow 62863
#define sipName_visualRow &sipStrings_QtWidgets[62863]
#define sipNameNr_whatsThis 62873
#define sipName_whatsThis &sipStrings_QtWidgets[62873]
#define sipNameNr_yearShown 62883
#define sipName_yearShown &sipStrings_QtWidgets[62883]
#define sipNameNr_Accepted 56910
#define sipName_Accepted &sipStrings_QtWidgets[56910]
#define sipNameNr_AllFonts 62893
#define sipName_AllFonts &sipStrings_QtWidgets[62893]
#define sipNameNr_AutoNone 62902
#define sipName_AutoNone &sipStrings_QtWidgets[62902]
#define sipNameNr_BlurHint 7543
#define sipName_BlurHint &sipStrings_QtWidgets[7543]
#define sipNameNr_CheckBox 21086
#define sipName_CheckBox &sipStrings_QtWidgets[21086]
#define sipNameNr_ComboBox 21590
#define sipName_ComboBox &sipStrings_QtWidgets[21590]
#define sipNameNr_Computer 59889
#define sipName_Computer &sipStrings_QtWidgets[59889]
#define sipNameNr_Critical 19494
#define sipName_Critical &sipStrings_QtWidgets[19494]
#define sipNameNr_Disabled 6877
#define sipName_Disabled &sipStrings_QtWidgets[6877]
#define sipNameNr_DragDrop 58338
#define sipName_DragDrop &sipStrings_QtWidgets[58338]
#define sipNameNr_DragMode 14663
#define sipName_DragMode &sipStrings_QtWidgets[14663]
#define sipNameNr_DragOnly 62911
#define sipName_DragOnly &sipStrings_QtWidgets[62911]
#define sipNameNr_Dragging 38406
#define sipName_Dragging &sipStrings_QtWidgets[38406]
#define sipNameNr_DropOnly 62920
#define sipName_DropOnly &sipStrings_QtWidgets[62920]
#define sipNameNr_EchoMode 24616
#define sipName_EchoMode &sipStrings_QtWidgets[24616]
#define sipNameNr_Editable 26216
#define sipName_Editable &sipStrings_QtWidgets[26216]
#define sipNameNr_FileMode 18702
#define sipName_FileMode &sipStrings_QtWidgets[18702]
#define sipNameNr_FileName 40086
#define sipName_FileName &sipStrings_QtWidgets[40086]
#define sipNameNr_FileType 62929
#define sipName_FileType &sipStrings_QtWidgets[62929]
#define sipNameNr_FlagMask 62938
#define sipName_FlagMask &sipStrings_QtWidgets[62938]
#define sipNameNr_GroupBox 21611
#define sipName_GroupBox &sipStrings_QtWidgets[21611]
#define sipNameNr_GrowFlag 62947
#define sipName_GrowFlag &sipStrings_QtWidgets[62947]
#define sipNameNr_HasFrame 62956
#define sipName_HasFrame &sipStrings_QtWidgets[62956]
#define sipNameNr_HelpRole 62965
#define sipName_HelpRole &sipStrings_QtWidgets[62965]
#define sipNameNr_IconMode 62974
#define sipName_IconMode &sipStrings_QtWidgets[62974]
#define sipNameNr_IconType 9313
#define sipName_IconType &sipStrings_QtWidgets[9313]
#define sipNameNr_Inactive 62983
#define sipName_Inactive &sipStrings_QtWidgets[62983]
#define sipNameNr_IntInput 62992
#define sipName_IntInput &sipStrings_QtWidgets[62992]
#define sipNameNr_ItemRole 18746
#define sipName_ItemRole &sipStrings_QtWidgets[18746]
#define sipNameNr_ItemType 3951
#define sipName_ItemType &sipStrings_QtWidgets[3951]
#define sipNameNr_Keyboard 40774
#define sipName_Keyboard &sipStrings_QtWidgets[40774]
#define sipNameNr_LeftSide 63001
#define sipName_LeftSide &sipStrings_QtWidgets[63001]
#define sipNameNr_LineEdit 34850
#define sipName_LineEdit &sipStrings_QtWidgets[34850]
#define sipNameNr_ListMode 63010
#define sipName_ListMode &sipStrings_QtWidgets[63010]
#define sipNameNr_MacStyle 63019
#define sipName_MacStyle &sipStrings_QtWidgets[63019]
#define sipNameNr_MenuRole 31246
#define sipName_MenuRole &sipStrings_QtWidgets[31246]
#define sipNameNr_MoveDown 63028
#define sipName_MoveDown &sipStrings_QtWidgets[63028]
#define sipNameNr_MoveHome 63037
#define sipName_MoveHome &sipStrings_QtWidgets[63037]
#define sipNameNr_MoveLeft 63046
#define sipName_MoveLeft &sipStrings_QtWidgets[63046]
#define sipNameNr_MoveNext 63055
#define sipName_MoveNext &sipStrings_QtWidgets[63055]
#define sipNameNr_Movement 24656
#define sipName_Movement &sipStrings_QtWidgets[24656]
#define sipNameNr_NoAnchor 63064
#define sipName_NoAnchor &sipStrings_QtWidgets[63064]
#define sipNameNr_NoButton 31696
#define sipName_NoButton &sipStrings_QtWidgets[31696]
#define sipNameNr_NoInsert 63073
#define sipName_NoInsert &sipStrings_QtWidgets[63073]
#define sipNameNr_NonModal 63082
#define sipName_NonModal &sipStrings_QtWidgets[63082]
#define sipNameNr_PE_Frame 63091
#define sipName_PE_Frame &sipStrings_QtWidgets[63091]
#define sipNameNr_Password 63100
#define sipName_Password &sipStrings_QtWidgets[63100]
#define sipNameNr_Position 822
#define sipName_Position &sipStrings_QtWidgets[822]
#define sipNameNr_Priority 31264
#define sipName_Priority &sipStrings_QtWidgets[31264]
#define sipNameNr_QGesture 63109
#define sipName_QGesture &sipStrings_QtWidgets[63109]
#define sipNameNr_QMdiArea 63118
#define sipName_QMdiArea &sipStrings_QtWidgets[63118]
#define sipNameNr_QMenuBar 63127
#define sipName_QMenuBar &sipStrings_QtWidgets[63127]
#define sipNameNr_QSpinBox 63136
#define sipName_QSpinBox &sipStrings_QtWidgets[63136]
#define sipNameNr_QToolBar 63145
#define sipName_QToolBar &sipStrings_QtWidgets[63145]
#define sipNameNr_QToolBox 63154
#define sipName_QToolBox &sipStrings_QtWidgets[63154]
#define sipNameNr_QToolTip 63163
#define sipName_QToolTip &sipStrings_QtWidgets[63163]
#define sipNameNr_Question 19516
#define sipName_Question &sipStrings_QtWidgets[19516]
#define sipNameNr_QuitRole 63172
#define sipName_QuitRole &sipStrings_QtWidgets[63172]
#define sipNameNr_ReadOnly 43360
#define sipName_ReadOnly &sipStrings_QtWidgets[43360]
#define sipNameNr_Rejected 48352
#define sipName_Rejected &sipStrings_QtWidgets[48352]
#define sipNameNr_SO_Frame 63181
#define sipName_SO_Frame &sipStrings_QtWidgets[63181]
#define sipNameNr_Scroller 38246
#define sipName_Scroller &sipStrings_QtWidgets[38246]
#define sipNameNr_Sections 13512
#define sipName_Sections &sipStrings_QtWidgets[13512]
#define sipNameNr_Selected 4091
#define sipName_Selected &sipStrings_QtWidgets[4091]
#define sipNameNr_SnapTime 63190
#define sipName_SnapTime &sipStrings_QtWidgets[63190]
#define sipNameNr_SortDown 63199
#define sipName_SortDown &sipStrings_QtWidgets[63199]
#define sipNameNr_StackAll 63208
#define sipName_StackAll &sipStrings_QtWidgets[63208]
#define sipNameNr_StackOne 63217
#define sipName_StackOne &sipStrings_QtWidgets[63217]
#define sipNameNr_Standard 63226
#define sipName_Standard &sipStrings_QtWidgets[63226]
#define sipNameNr_State_On 63235
#define sipName_State_On &sipStrings_QtWidgets[63235]
#define sipNameNr_StepNone 63244
#define sipName_StepNone &sipStrings_QtWidgets[63244]
#define sipNameNr_StepType 10195
#define sipName_StepType &sipStrings_QtWidgets[10195]
#define sipNameNr_TabShape 21716
#define sipName_TabShape &sipStrings_QtWidgets[21716]
#define sipNameNr_Trashcan 63253
#define sipName_Trashcan &sipStrings_QtWidgets[63253]
#define sipNameNr_UserFlag 63262
#define sipName_UserFlag &sipStrings_QtWidgets[63262]
#define sipNameNr_UserType 63271
#define sipName_UserType &sipStrings_QtWidgets[63271]
#define sipNameNr_ViewMode 18724
#define sipName_ViewMode &sipStrings_QtWidgets[18724]
#define sipNameNr_WinPanel 49010
#define sipName_WinPanel &sipStrings_QtWidgets[49010]
#define sipNameNr_WrapText 63280
#define sipName_WrapText &sipStrings_QtWidgets[63280]
#define sipNameNr_YesToAll 63289
#define sipName_YesToAll &sipStrings_QtWidgets[63289]
#define sipNameNr___bool__ 63298
#define sipName___bool__ &sipStrings_QtWidgets[63298]
#define sipNameNr___hash__ 63307
#define sipName___hash__ &sipStrings_QtWidgets[63307]
#define sipNameNr___iadd__ 63316
#define sipName___iadd__ &sipStrings_QtWidgets[63316]
#define sipNameNr___iand__ 63325
#define sipName___iand__ &sipStrings_QtWidgets[63325]
#define sipNameNr___isub__ 63334
#define sipName___isub__ &sipStrings_QtWidgets[63334]
#define sipNameNr___ixor__ 63343
#define sipName___ixor__ &sipStrings_QtWidgets[63343]
#define sipNameNr_accepted 63352
#define sipName_accepted &sipStrings_QtWidgets[63352]
#define sipNameNr_actionAt 63361
#define sipName_actionAt &sipStrings_QtWidgets[63361]
#define sipNameNr_activate 63370
#define sipName_activate &sipStrings_QtWidgets[63370]
#define sipNameNr_addChild 63379
#define sipName_addChild &sipStrings_QtWidgets[63379]
#define sipNameNr_addItems 63388
#define sipName_addItems &sipStrings_QtWidgets[63388]
#define sipNameNr_addStack 63397
#define sipName_addStack &sipStrings_QtWidgets[63397]
#define sipNameNr_addStrut 63406
#define sipName_addStrut &sipStrings_QtWidgets[63406]
#define sipNameNr_anchorAt 63415
#define sipName_anchorAt &sipStrings_QtWidgets[63415]
#define sipNameNr_autoHide 63424
#define sipName_autoHide &sipStrings_QtWidgets[63424]
#define sipNameNr_backward 63433
#define sipName_backward &sipStrings_QtWidgets[63433]
#define sipNameNr_baseSize 63442
#define sipName_baseSize &sipStrings_QtWidgets[63442]
#define sipNameNr_calendar 63451
#define sipName_calendar &sipStrings_QtWidgets[63451]
#define sipNameNr_canPaste 63460
#define sipName_canPaste &sipStrings_QtWidgets[63460]
#define sipNameNr_canceled 63469
#define sipName_canceled &sipStrings_QtWidgets[63469]
#define sipNameNr_cellRect 63478
#define sipName_cellRect &sipStrings_QtWidgets[63478]
#define sipNameNr_centerOn 63487
#define sipName_centerOn &sipStrings_QtWidgets[63487]
#define sipNameNr_checkBox 63496
#define sipName_checkBox &sipStrings_QtWidgets[63496]
#define sipNameNr_clipPath 63505
#define sipName_clipPath &sipStrings_QtWidgets[63505]
#define sipNameNr_closable 63514
#define sipName_closable &sipStrings_QtWidgets[63514]
#define sipNameNr_collapse 63523
#define sipName_collapse &sipStrings_QtWidgets[63523]
#define sipNameNr_columnAt 63532
#define sipName_columnAt &sipStrings_QtWidgets[63532]
#define sipNameNr_complete 63541
#define sipName_complete &sipStrings_QtWidgets[63541]
#define sipNameNr_contains 63550
#define sipName_contains &sipStrings_QtWidgets[63550]
#define sipNameNr_critical 63559
#define sipName_critical &sipStrings_QtWidgets[63559]
#define sipNameNr_dateTime 63568
#define sipName_dateTime &sipStrings_QtWidgets[63568]
#define sipNameNr_decimals 63577
#define sipName_decimals &sipStrings_QtWidgets[63577]
#define sipNameNr_deselect 63586
#define sipName_deselect &sipStrings_QtWidgets[63586]
#define sipNameNr_document 63595
#define sipName_document &sipStrings_QtWidgets[63595]
#define sipNameNr_dragMode 63604
#define sipName_dragMode &sipStrings_QtWidgets[63604]
#define sipNameNr_drawBase 63613
#define sipName_drawBase &sipStrings_QtWidgets[63613]
#define sipNameNr_drawTree 63622
#define sipName_drawTree &sipStrings_QtWidgets[63622]
#define sipNameNr_echoMode 63631
#define sipName_echoMode &sipStrings_QtWidgets[63631]
#define sipNameNr_editItem 63640
#define sipName_editItem &sipStrings_QtWidgets[63640]
#define sipNameNr_editable 63649
#define sipName_editable &sipStrings_QtWidgets[63649]
#define sipNameNr_endMacro 63658
#define sipName_endMacro &sipStrings_QtWidgets[63658]
#define sipNameNr_expanded 63667
#define sipName_expanded &sipStrings_QtWidgets[63667]
#define sipNameNr_features 63676
#define sipName_features &sipStrings_QtWidgets[63676]
#define sipNameNr_fileIcon 63685
#define sipName_fileIcon &sipStrings_QtWidgets[63685]
#define sipNameNr_fileInfo 63694
#define sipName_fileInfo &sipStrings_QtWidgets[63694]
#define sipNameNr_fileMode 63703
#define sipName_fileMode &sipStrings_QtWidgets[63703]
#define sipNameNr_fileName 63712
#define sipName_fileName &sipStrings_QtWidgets[63712]
#define sipNameNr_filePath 63721
#define sipName_filePath &sipStrings_QtWidgets[63721]
#define sipNameNr_fillRule 63730
#define sipName_fillRule &sipStrings_QtWidgets[63730]
#define sipNameNr_findData 63739
#define sipName_findData &sipStrings_QtWidgets[63739]
#define sipNameNr_findText 63748
#define sipName_findText &sipStrings_QtWidgets[63748]
#define sipNameNr_finished 63757
#define sipName_finished &sipStrings_QtWidgets[63757]
#define sipNameNr_fontInfo 63766
#define sipName_fontInfo &sipStrings_QtWidgets[63766]
#define sipNameNr_geometry 63775
#define sipName_geometry &sipStrings_QtWidgets[63775]
#define sipNameNr_gestures 63784
#define sipName_gestures &sipStrings_QtWidgets[63784]
#define sipNameNr_getColor 63793
#define sipName_getColor &sipStrings_QtWidgets[63793]
#define sipNameNr_getRange 63802
#define sipName_getRange &sipStrings_QtWidgets[63802]
#define sipNameNr_gridSize 63811
#define sipName_gridSize &sipStrings_QtWidgets[63811]
#define sipNameNr_hasFocus 63820
#define sipName_hasFocus &sipStrings_QtWidgets[63820]
#define sipNameNr_hasFrame 63829
#define sipName_hasFrame &sipStrings_QtWidgets[63829]
#define sipNameNr_hideText 63838
#define sipName_hideText &sipStrings_QtWidgets[63838]
#define sipNameNr_iconSize 63847
#define sipName_iconSize &sipStrings_QtWidgets[63847]
#define sipNameNr_iconText 63856
#define sipName_iconText &sipStrings_QtWidgets[63856]
#define sipNameNr_initFrom 63865
#define sipName_initFrom &sipStrings_QtWidgets[63865]
#define sipNameNr_intValue 63874
#define sipName_intValue &sipStrings_QtWidgets[63874]
#define sipNameNr_isActive 63883
#define sipName_isActive &sipStrings_QtWidgets[63883]
#define sipNameNr_isHidden 63892
#define sipName_isHidden &sipStrings_QtWidgets[63892]
#define sipNameNr_isLayout 63901
#define sipName_isLayout &sipStrings_QtWidgets[63901]
#define sipNameNr_isShaded 63910
#define sipName_isShaded &sipStrings_QtWidgets[63910]
#define sipNameNr_isWidget 63919
#define sipName_isWidget &sipStrings_QtWidgets[63919]
#define sipNameNr_isWindow 63928
#define sipName_isWindow &sipStrings_QtWidgets[63928]
#define sipNameNr_itemData 63937
#define sipName_itemData &sipStrings_QtWidgets[63937]
#define sipNameNr_itemIcon 63946
#define sipName_itemIcon &sipStrings_QtWidgets[63946]
#define sipNameNr_itemText 63955
#define sipName_itemText &sipStrings_QtWidgets[63955]
#define sipNameNr_lineEdit 63964
#define sipName_lineEdit &sipStrings_QtWidgets[63964]
#define sipNameNr_maxCount 63973
#define sipName_maxCount &sipStrings_QtWidgets[63973]
#define sipNameNr_menuRect 63982
#define sipName_menuRect &sipStrings_QtWidgets[63982]
#define sipNameNr_menuRole 63991
#define sipName_menuRole &sipStrings_QtWidgets[63991]
#define sipNameNr_mimeData 64000
#define sipName_mimeData &sipStrings_QtWidgets[64000]
#define sipNameNr_moveRows 59966
#define sipName_moveRows &sipStrings_QtWidgets[59966]
#define sipNameNr_movement 64009
#define sipName_movement &sipStrings_QtWidgets[64009]
#define sipNameNr_overflow 64018
#define sipName_overflow &sipStrings_QtWidgets[64018]
#define sipNameNr_pageStep 64027
#define sipName_pageStep &sipStrings_QtWidgets[64027]
#define sipNameNr_position 64036
#define sipName_position &sipStrings_QtWidgets[64036]
#define sipNameNr_priority 64045
#define sipName_priority &sipStrings_QtWidgets[64045]
#define sipNameNr_progress 64054
#define sipName_progress &sipStrings_QtWidgets[64054]
#define sipNameNr_property 64063
#define sipName_property &sipStrings_QtWidgets[64063]
#define sipNameNr_question 64072
#define sipName_question &sipStrings_QtWidgets[64072]
#define sipNameNr_redoText 64081
#define sipName_redoText &sipStrings_QtWidgets[64081]
#define sipNameNr_reexpand 64090
#define sipName_reexpand &sipStrings_QtWidgets[64090]
#define sipNameNr_reformat 64099
#define sipName_reformat &sipStrings_QtWidgets[64099]
#define sipNameNr_rejected 64108
#define sipName_rejected &sipStrings_QtWidgets[64108]
#define sipNameNr_released 64117
#define sipName_released &sipStrings_QtWidgets[64117]
#define sipNameNr_removeAt 64126
#define sipName_removeAt &sipStrings_QtWidgets[64126]
#define sipNameNr_resizeGL 64135
#define sipName_resizeGL &sipStrings_QtWidgets[64135]
#define sipNameNr_rootPath 64144
#define sipName_rootPath &sipStrings_QtWidgets[64144]
#define sipNameNr_rotation 64153
#define sipName_rotation &sipStrings_QtWidgets[64153]
#define sipNameNr_rowCount 64162
#define sipName_rowCount &sipStrings_QtWidgets[64162]
#define sipNameNr_rowMoved 64171
#define sipName_rowMoved &sipStrings_QtWidgets[64171]
#define sipNameNr_scenePos 64180
#define sipName_scenePos &sipStrings_QtWidgets[64180]
#define sipNameNr_scrollTo 64189
#define sipName_scrollTo &sipStrings_QtWidgets[64189]
#define sipNameNr_scroller 64198
#define sipName_scroller &sipStrings_QtWidgets[64198]
#define sipNameNr_setAngle 64207
#define sipName_setAngle &sipStrings_QtWidgets[64207]
#define sipNameNr_setBrush 64216
#define sipName_setBrush &sipStrings_QtWidgets[64216]
#define sipNameNr_setBuddy 64225
#define sipName_setBuddy &sipStrings_QtWidgets[64225]
#define sipNameNr_setClean 59988
#define sipName_setClean &sipStrings_QtWidgets[59988]
#define sipNameNr_setColor 64234
#define sipName_setColor &sipStrings_QtWidgets[64234]
#define sipNameNr_setField 64243
#define sipName_setField &sipStrings_QtWidgets[64243]
#define sipNameNr_setFlags 64252
#define sipName_setFlags &sipStrings_QtWidgets[64252]
#define sipNameNr_setFocus 64261
#define sipName_setFocus &sipStrings_QtWidgets[64261]
#define sipNameNr_setFrame 64270
#define sipName_setFrame &sipStrings_QtWidgets[64270]
#define sipNameNr_setGroup 64279
#define sipName_setGroup &sipStrings_QtWidgets[64279]
#define sipNameNr_setIndex 64288
#define sipName_setIndex &sipStrings_QtWidgets[64288]
#define sipNameNr_setLabel 64297
#define sipName_setLabel &sipStrings_QtWidgets[64297]
#define sipNameNr_setModal 64306
#define sipName_setModal &sipStrings_QtWidgets[64306]
#define sipNameNr_setModel 64315
#define sipName_setModel &sipStrings_QtWidgets[64315]
#define sipNameNr_setMovie 64324
#define sipName_setMovie &sipStrings_QtWidgets[64324]
#define sipNameNr_setPopup 64333
#define sipName_setPopup &sipStrings_QtWidgets[64333]
#define sipNameNr_setRange 64342
#define sipName_setRange &sipStrings_QtWidgets[64342]
#define sipNameNr_setScale 64351
#define sipName_setScale &sipStrings_QtWidgets[64351]
#define sipNameNr_setScene 64360
#define sipName_setScene &sipStrings_QtWidgets[64360]
#define sipNameNr_setShape 64369
#define sipName_setShape &sipStrings_QtWidgets[64369]
#define sipNameNr_setSizes 64378
#define sipName_setSizes &sipStrings_QtWidgets[64378]
#define sipNameNr_setStack 64387
#define sipName_setStack &sipStrings_QtWidgets[64387]
#define sipNameNr_setState 64396
#define sipName_setState &sipStrings_QtWidgets[64396]
#define sipNameNr_setStyle 64405
#define sipName_setStyle &sipStrings_QtWidgets[64405]
#define sipNameNr_setTitle 64414
#define sipName_setTitle &sipStrings_QtWidgets[64414]
#define sipNameNr_setValue 64423
#define sipName_setValue &sipStrings_QtWidgets[64423]
#define sipNameNr_shortcut 64432
#define sipName_shortcut &sipStrings_QtWidgets[64432]
#define sipNameNr_showGrid 64441
#define sipName_showGrid &sipStrings_QtWidgets[64441]
#define sipNameNr_showMenu 64450
#define sipName_showMenu &sipStrings_QtWidgets[64450]
#define sipNameNr_showText 64459
#define sipName_showText &sipStrings_QtWidgets[64459]
#define sipNameNr_sizeHint 64468
#define sipName_sizeHint &sipStrings_QtWidgets[64468]
#define sipNameNr_splitter 64477
#define sipName_splitter &sipStrings_QtWidgets[64477]
#define sipNameNr_stepDown 64486
#define sipName_stepDown &sipStrings_QtWidgets[64486]
#define sipNameNr_stepType 64495
#define sipName_stepType &sipStrings_QtWidgets[64495]
#define sipNameNr_strength 64504
#define sipName_strength &sipStrings_QtWidgets[64504]
#define sipNameNr_subTitle 64513
#define sipName_subTitle &sipStrings_QtWidgets[64513]
#define sipNameNr_tabIndex 64522
#define sipName_tabIndex &sipStrings_QtWidgets[64522]
#define sipNameNr_tabMoved 64531
#define sipName_tabMoved &sipStrings_QtWidgets[64531]
#define sipNameNr_tabShape 64540
#define sipName_tabShape &sipStrings_QtWidgets[64540]
#define sipNameNr_tabWidth 64549
#define sipName_tabWidth &sipStrings_QtWidgets[64549]
#define sipNameNr_takeItem 64558
#define sipName_takeItem &sipStrings_QtWidgets[64558]
#define sipNameNr_textRole 64567
#define sipName_textRole &sipStrings_QtWidgets[64567]
#define sipNameNr_timeSpec 64576
#define sipName_timeSpec &sipStrings_QtWidgets[64576]
#define sipNameNr_undoText 64585
#define sipName_undoText &sipStrings_QtWidgets[64585]
#define sipNameNr_unpolish 64594
#define sipName_unpolish &sipStrings_QtWidgets[64594]
#define sipNameNr_userData 64603
#define sipName_userData &sipStrings_QtWidgets[64603]
#define sipNameNr_validate 59592
#define sipName_validate &sipStrings_QtWidgets[59592]
#define sipNameNr_velocity 64612
#define sipName_velocity &sipStrings_QtWidgets[64612]
#define sipNameNr_viewMode 64621
#define sipName_viewMode &sipStrings_QtWidgets[64621]
#define sipNameNr_viewport 64630
#define sipName_viewport &sipStrings_QtWidgets[64630]
#define sipNameNr_widgetAt 64639
#define sipName_widgetAt &sipStrings_QtWidgets[64639]
#define sipNameNr_wordWrap 64648
#define sipName_wordWrap &sipStrings_QtWidgets[64648]
#define sipNameNr_wrapping 64657
#define sipName_wrapping &sipStrings_QtWidgets[64657]
#define sipNameNr_xChanged 25576
#define sipName_xChanged &sipStrings_QtWidgets[25576]
#define sipNameNr_yChanged 34270
#define sipName_yChanged &sipStrings_QtWidgets[34270]
#define sipNameNr_zChanged 64666
#define sipName_zChanged &sipStrings_QtWidgets[64666]
#define sipNameNr_AnyFile 64675
#define sipName_AnyFile &sipStrings_QtWidgets[64675]
#define sipNameNr_AutoAll 64683
#define sipName_AutoAll &sipStrings_QtWidgets[64683]
#define sipNameNr_Batched 64691
#define sipName_Batched &sipStrings_QtWidgets[64691]
#define sipNameNr_CC_Dial 64699
#define sipName_CC_Dial &sipStrings_QtWidgets[64699]
#define sipNameNr_CT_Menu 64707
#define sipName_CT_Menu &sipStrings_QtWidgets[64707]
#define sipNameNr_Checked 58350
#define sipName_Checked &sipStrings_QtWidgets[58350]
#define sipNameNr_Context 27088
#define sipName_Context &sipStrings_QtWidgets[27088]
#define sipNameNr_Default 45071
#define sipName_Default &sipStrings_QtWidgets[45071]
#define sipNameNr_Desktop 36398
#define sipName_Desktop &sipStrings_QtWidgets[36398]
#define sipNameNr_Discard 64715
#define sipName_Discard &sipStrings_QtWidgets[64715]
#define sipNameNr_Enabled 7424
#define sipName_Enabled &sipStrings_QtWidgets[7424]
#define sipNameNr_HasMenu 64723
#define sipName_HasMenu &sipStrings_QtWidgets[64723]
#define sipNameNr_Ignored 46435
#define sipName_Ignored &sipStrings_QtWidgets[46435]
#define sipNameNr_Invalid 64731
#define sipName_Invalid &sipStrings_QtWidgets[64731]
#define sipNameNr_Maximum 37112
#define sipName_Maximum &sipStrings_QtWidgets[37112]
#define sipNameNr_Minimum 37129
#define sipName_Minimum &sipStrings_QtWidgets[37129]
#define sipNameNr_Movable 17880
#define sipName_Movable &sipStrings_QtWidgets[17880]
#define sipNameNr_MoveEnd 64739
#define sipName_MoveEnd &sipStrings_QtWidgets[64739]
#define sipNameNr_Network 64747
#define sipName_Network &sipStrings_QtWidgets[64747]
#define sipNameNr_NoCache 64755
#define sipName_NoCache &sipStrings_QtWidgets[64755]
#define sipNameNr_NoFrame 64763
#define sipName_NoFrame &sipStrings_QtWidgets[64763]
#define sipNameNr_NoIndex 64771
#define sipName_NoIndex &sipStrings_QtWidgets[64771]
#define sipNameNr_NoState 64779
#define sipName_NoState &sipStrings_QtWidgets[64779]
#define sipNameNr_NoTicks 64787
#define sipName_NoTicks &sipStrings_QtWidgets[64787]
#define sipNameNr_NoToAll 64795
#define sipName_NoToAll &sipStrings_QtWidgets[64795]
#define sipNameNr_OnlyOne 64803
#define sipName_OnlyOne &sipStrings_QtWidgets[64803]
#define sipNameNr_Options 4872
#define sipName_Options &sipStrings_QtWidgets[4872]
#define sipNameNr_Outline 64811
#define sipName_Outline &sipStrings_QtWidgets[64811]
#define sipNameNr_Pressed 42566
#define sipName_Pressed &sipStrings_QtWidgets[42566]
#define sipNameNr_QAction 64819
#define sipName_QAction &sipStrings_QtWidgets[64819]
#define sipNameNr_QDialog 64827
#define sipName_QDialog &sipStrings_QtWidgets[64827]
#define sipNameNr_QLayout 64835
#define sipName_QLayout &sipStrings_QtWidgets[64835]
#define sipNameNr_QSlider 64843
#define sipName_QSlider &sipStrings_QtWidgets[64843]
#define sipNameNr_QTabBar 64851
#define sipName_QTabBar &sipStrings_QtWidgets[64851]
#define sipNameNr_QWidget 64859
#define sipName_QWidget &sipStrings_QtWidgets[64859]
#define sipNameNr_QWizard 64867
#define sipName_QWizard &sipStrings_QtWidgets[64867]
#define sipNameNr_Rounded 64875
#define sipName_Rounded &sipStrings_QtWidgets[64875]
#define sipNameNr_SC_None 64883
#define sipName_SC_None &sipStrings_QtWidgets[64883]
#define sipNameNr_SH_Mask 64891
#define sipName_SH_Mask &sipStrings_QtWidgets[64891]
#define sipNameNr_SaveAll 64899
#define sipName_SaveAll &sipStrings_QtWidgets[64899]
#define sipNameNr_Section 16684
#define sipName_Section &sipStrings_QtWidgets[16684]
#define sipNameNr_SpinBox 24797
#define sipName_SpinBox &sipStrings_QtWidgets[24797]
#define sipNameNr_Stretch 23229
#define sipName_Stretch &sipStrings_QtWidgets[23229]
#define sipNameNr_SubMenu 64907
#define sipName_SubMenu &sipStrings_QtWidgets[64907]
#define sipNameNr_TearOff 64915
#define sipName_TearOff &sipStrings_QtWidgets[64915]
#define sipNameNr_Trigger 6289
#define sipName_Trigger &sipStrings_QtWidgets[6289]
#define sipNameNr_Unknown 64923
#define sipName_Unknown &sipStrings_QtWidgets[64923]
#define sipNameNr_Version 89
#define sipName_Version &sipStrings_QtWidgets[89]
#define sipNameNr_Warning 22200
#define sipName_Warning &sipStrings_QtWidgets[22200]
#define sipNameNr_YesRole 64931
#define sipName_YesRole &sipStrings_QtWidgets[64931]
#define sipNameNr___and__ 64939
#define sipName___and__ &sipStrings_QtWidgets[64939]
#define sipNameNr___int__ 64947
#define sipName___int__ &sipStrings_QtWidgets[64947]
#define sipNameNr___ior__ 64955
#define sipName___ior__ &sipStrings_QtWidgets[64955]
#define sipNameNr___len__ 64963
#define sipName___len__ &sipStrings_QtWidgets[64963]
#define sipNameNr___xor__ 64971
#define sipName___xor__ &sipStrings_QtWidgets[64971]
#define sipNameNr_aboutQt 64979
#define sipName_aboutQt &sipStrings_QtWidgets[64979]
#define sipNameNr_actions 64987
#define sipName_actions &sipStrings_QtWidgets[64987]
#define sipNameNr_addItem 64995
#define sipName_addItem &sipStrings_QtWidgets[64995]
#define sipNameNr_addLine 65003
#define sipName_addLine &sipStrings_QtWidgets[65003]
#define sipNameNr_addMenu 65011
#define sipName_addMenu &sipStrings_QtWidgets[65011]
#define sipNameNr_addPage 65019
#define sipName_addPage &sipStrings_QtWidgets[65019]
#define sipNameNr_addPath 65027
#define sipName_addPath &sipStrings_QtWidgets[65027]
#define sipNameNr_addRect 65035
#define sipName_addRect &sipStrings_QtWidgets[65035]
#define sipNameNr_addText 65043
#define sipName_addText &sipStrings_QtWidgets[65043]
#define sipNameNr_advance 65051
#define sipName_advance &sipStrings_QtWidgets[65051]
#define sipNameNr_applyTo 65059
#define sipName_applyTo &sipStrings_QtWidgets[65059]
#define sipNameNr_buttons 65067
#define sipName_buttons &sipStrings_QtWidgets[65067]
#define sipNameNr_canRedo 65075
#define sipName_canRedo &sipStrings_QtWidgets[65075]
#define sipNameNr_canUndo 65083
#define sipName_canUndo &sipStrings_QtWidgets[65083]
#define sipNameNr_caption 65091
#define sipName_caption &sipStrings_QtWidgets[65091]
#define sipNameNr_changed 65099
#define sipName_changed &sipStrings_QtWidgets[65099]
#define sipNameNr_checked 65107
#define sipName_checked &sipStrings_QtWidgets[65107]
#define sipNameNr_childAt 65115
#define sipName_childAt &sipStrings_QtWidgets[65115]
#define sipNameNr_clicked 65123
#define sipName_clicked &sipStrings_QtWidgets[65123]
#define sipNameNr_combine 65131
#define sipName_combine &sipStrings_QtWidgets[65131]
#define sipNameNr_command 65139
#define sipName_command &sipStrings_QtWidgets[65139]
#define sipNameNr_context 65147
#define sipName_context &sipStrings_QtWidgets[65147]
#define sipNameNr_current 65155
#define sipName_current &sipStrings_QtWidgets[65155]
#define sipNameNr_desktop 65163
#define sipName_desktop &sipStrings_QtWidgets[65163]
#define sipNameNr_destroy 65171
#define sipName_destroy &sipStrings_QtWidgets[65171]
#define sipNameNr_devType 65179
#define sipName_devType &sipStrings_QtWidgets[65179]
#define sipNameNr_display 65187
#define sipName_display &sipStrings_QtWidgets[65187]
#define sipNameNr_drawRow 65195
#define sipName_drawRow &sipStrings_QtWidgets[65195]
#define sipNameNr_enabled 65203
#define sipName_enabled &sipStrings_QtWidgets[65203]
#define sipNameNr_entered 65211
#define sipName_entered &sipStrings_QtWidgets[65211]
#define sipNameNr_forward 65219
#define sipName_forward &sipStrings_QtWidgets[65219]
#define sipNameNr_gesture 65227
#define sipName_gesture &sipStrings_QtWidgets[65227]
#define sipNameNr_getFont 65235
#define sipName_getFont &sipStrings_QtWidgets[65235]
#define sipNameNr_getItem 35174
#define sipName_getItem &sipStrings_QtWidgets[35174]
#define sipNameNr_getText 65243
#define sipName_getText &sipStrings_QtWidgets[65243]
#define sipNameNr_hPolicy 6444
#define sipName_hPolicy &sipStrings_QtWidgets[6444]
#define sipNameNr_hideRow 65251
#define sipName_hideRow &sipStrings_QtWidgets[65251]
#define sipNameNr_history 65259
#define sipName_history &sipStrings_QtWidgets[65259]
#define sipNameNr_hitTest 65267
#define sipName_hitTest &sipStrings_QtWidgets[65267]
#define sipNameNr_hotSpot 65275
#define sipName_hotSpot &sipStrings_QtWidgets[65275]
#define sipNameNr_hovered 65283
#define sipName_hovered &sipStrings_QtWidgets[65283]
#define sipNameNr_indexAt 65291
#define sipName_indexAt &sipStrings_QtWidgets[65291]
#define sipNameNr_indexOf 65299
#define sipName_indexOf &sipStrings_QtWidgets[65299]
#define sipNameNr_initial 65307
#define sipName_initial &sipStrings_QtWidgets[65307]
#define sipNameNr_intStep 65315
#define sipName_intStep &sipStrings_QtWidgets[65315]
#define sipNameNr_isClean 65323
#define sipName_isClean &sipStrings_QtWidgets[65323]
#define sipNameNr_isEmpty 65331
#define sipName_isEmpty &sipStrings_QtWidgets[65331]
#define sipNameNr_isModal 65339
#define sipName_isModal &sipStrings_QtWidgets[65339]
#define sipNameNr_isPanel 65347
#define sipName_isPanel &sipStrings_QtWidgets[65347]
#define sipNameNr_isValid 65355
#define sipName_isValid &sipStrings_QtWidgets[65355]
#define sipNameNr_lastPos 65363
#define sipName_lastPos &sipStrings_QtWidgets[65363]
#define sipNameNr_mapFrom 65371
#define sipName_mapFrom &sipStrings_QtWidgets[65371]
#define sipNameNr_maximum 65379
#define sipName_maximum &sipStrings_QtWidgets[65379]
#define sipNameNr_mdiArea 65387
#define sipName_mdiArea &sipStrings_QtWidgets[65387]
#define sipNameNr_menuBar 65395
#define sipName_menuBar &sipStrings_QtWidgets[65395]
#define sipNameNr_message 65403
#define sipName_message &sipStrings_QtWidgets[65403]
#define sipNameNr_minimum 65411
#define sipName_minimum &sipStrings_QtWidgets[65411]
#define sipNameNr_movable 65419
#define sipName_movable &sipStrings_QtWidgets[65419]
#define sipNameNr_moveTab 62265
#define sipName_moveTab &sipStrings_QtWidgets[62265]
#define sipNameNr_newSize 65427
#define sipName_newSize &sipStrings_QtWidgets[65427]
#define sipNameNr_oldSize 65435
#define sipName_oldSize &sipStrings_QtWidgets[65435]
#define sipNameNr_opacity 65443
#define sipName_opacity &sipStrings_QtWidgets[65443]
#define sipNameNr_options 65451
#define sipName_options &sipStrings_QtWidgets[65451]
#define sipNameNr_pageIds 65459
#define sipName_pageIds &sipStrings_QtWidgets[65459]
#define sipNameNr_paintGL 65467
#define sipName_paintGL &sipStrings_QtWidgets[65467]
#define sipNameNr_palette 65475
#define sipName_palette &sipStrings_QtWidgets[65475]
#define sipNameNr_picture 65483
#define sipName_picture &sipStrings_QtWidgets[65483]
#define sipNameNr_polygon 65491
#define sipName_polygon &sipStrings_QtWidgets[65491]
#define sipNameNr_pressed 65499
#define sipName_pressed &sipStrings_QtWidgets[65499]
#define sipNameNr_refresh 65507
#define sipName_refresh &sipStrings_QtWidgets[65507]
#define sipNameNr_repaint 65515
#define sipName_repaint &sipStrings_QtWidgets[65515]
#define sipNameNr_resized 65523
#define sipName_resized &sipStrings_QtWidgets[65523]
#define sipNameNr_restart 65531
#define sipName_restart &sipStrings_QtWidgets[65531]
#define sipNameNr_rowSpan 65539
#define sipName_rowSpan &sipStrings_QtWidgets[65539]
#define sipNameNr_section 65547
#define sipName_section &sipStrings_QtWidgets[65547]
#define sipNameNr_setAxis 65555
#define sipName_setAxis &sipStrings_QtWidgets[65555]
#define sipNameNr_setData 65563
#define sipName_setData &sipStrings_QtWidgets[65563]
#define sipNameNr_setDate 65571
#define sipName_setDate &sipStrings_QtWidgets[65571]
#define sipNameNr_setDown 65579
#define sipName_setDown &sipStrings_QtWidgets[65579]
#define sipNameNr_setFlag 65587
#define sipName_setFlag &sipStrings_QtWidgets[65587]
#define sipNameNr_setFlat 65595
#define sipName_setFlat &sipStrings_QtWidgets[65595]
#define sipNameNr_setFlow 65603
#define sipName_setFlow &sipStrings_QtWidgets[65603]
#define sipNameNr_setFont 65611
#define sipName_setFont &sipStrings_QtWidgets[65611]
#define sipNameNr_setHtml 65619
#define sipName_setHtml &sipStrings_QtWidgets[65619]
#define sipNameNr_setIcon 65627
#define sipName_setIcon &sipStrings_QtWidgets[65627]
#define sipNameNr_setItem 65635
#define sipName_setItem &sipStrings_QtWidgets[65635]
#define sipNameNr_setLine 65643
#define sipName_setLine &sipStrings_QtWidgets[65643]
#define sipNameNr_setMask 65651
#define sipName_setMask &sipStrings_QtWidgets[65651]
#define sipNameNr_setMenu 65659
#define sipName_setMenu &sipStrings_QtWidgets[65659]
#define sipNameNr_setMode 65667
#define sipName_setMode &sipStrings_QtWidgets[65667]
#define sipNameNr_setPage 65675
#define sipName_setPage &sipStrings_QtWidgets[65675]
#define sipNameNr_setPath 65683
#define sipName_setPath &sipStrings_QtWidgets[65683]
#define sipNameNr_setRect 65691
#define sipName_setRect &sipStrings_QtWidgets[65691]
#define sipNameNr_setSpan 65699
#define sipName_setSpan &sipStrings_QtWidgets[65699]
#define sipNameNr_setText 65707
#define sipName_setText &sipStrings_QtWidgets[65707]
#define sipNameNr_setTime 65715
#define sipName_setTime &sipStrings_QtWidgets[65715]
#define sipNameNr_setView 65723
#define sipName_setView &sipStrings_QtWidgets[65723]
#define sipNameNr_showRow 65731
#define sipName_showRow &sipStrings_QtWidgets[65731]
#define sipNameNr_sibling 65739
#define sipName_sibling &sipStrings_QtWidgets[65739]
#define sipNameNr_sorting 65747
#define sipName_sorting &sipStrings_QtWidgets[65747]
#define sipNameNr_spacing 65755
#define sipName_spacing &sipStrings_QtWidgets[65755]
#define sipNameNr_startId 65763
#define sipName_startId &sipStrings_QtWidgets[65763]
#define sipNameNr_stretch 65771
#define sipName_stretch &sipStrings_QtWidgets[65771]
#define sipNameNr_tabData 65779
#define sipName_tabData &sipStrings_QtWidgets[65779]
#define sipNameNr_tabIcon 65787
#define sipName_tabIcon &sipStrings_QtWidgets[65787]
#define sipNameNr_tabRect 65795
#define sipName_tabRect &sipStrings_QtWidgets[65795]
#define sipNameNr_tabText 65803
#define sipName_tabText &sipStrings_QtWidgets[65803]
#define sipNameNr_takeRow 65811
#define sipName_takeRow &sipStrings_QtWidgets[65811]
#define sipNameNr_timeout 65819
#define sipName_timeout &sipStrings_QtWidgets[65819]
#define sipNameNr_toFirst 65827
#define sipName_toFirst &sipStrings_QtWidgets[65827]
#define sipNameNr_toggled 65835
#define sipName_toggled &sipStrings_QtWidgets[65835]
#define sipNameNr_toolTip 65843
#define sipName_toolTip &sipStrings_QtWidgets[65843]
#define sipNameNr_trigger 65851
#define sipName_trigger &sipStrings_QtWidgets[65851]
#define sipNameNr_vPolicy 65859
#define sipName_vPolicy &sipStrings_QtWidgets[65859]
#define sipNameNr_variant 65867
#define sipName_variant &sipStrings_QtWidgets[65867]
#define sipNameNr_version 65875
#define sipName_version &sipStrings_QtWidgets[65875]
#define sipNameNr_warning 65883
#define sipName_warning &sipStrings_QtWidgets[65883]
#define sipNameNr_xMargin 65891
#define sipName_xMargin &sipStrings_QtWidgets[65891]
#define sipNameNr_xOffset 65899
#define sipName_xOffset &sipStrings_QtWidgets[65899]
#define sipNameNr_yMargin 65907
#define sipName_yMargin &sipStrings_QtWidgets[65907]
#define sipNameNr_yOffset 65915
#define sipName_yOffset &sipStrings_QtWidgets[65915]
#define sipNameNr_zoomOut 65923
#define sipName_zoomOut &sipStrings_QtWidgets[65923]
#define sipNameNr_Accept 65931
#define sipName_Accept &sipStrings_QtWidgets[65931]
#define sipNameNr_Adjust 65938
#define sipName_Adjust &sipStrings_QtWidgets[65938]
#define sipNameNr_Bottom 34971
#define sipName_Bottom &sipStrings_QtWidgets[34971]
#define sipNameNr_Cancel 65945
#define sipName_Cancel &sipStrings_QtWidgets[65945]
#define sipNameNr_Custom 65952
#define sipName_Custom &sipStrings_QtWidgets[65952]
#define sipNameNr_Detail 65959
#define sipName_Detail &sipStrings_QtWidgets[65959]
#define sipNameNr_Escape 65966
#define sipName_Escape &sipStrings_QtWidgets[65966]
#define sipNameNr_Filled 65973
#define sipName_Filled &sipStrings_QtWidgets[65973]
#define sipNameNr_Folder 17398
#define sipName_Folder &sipStrings_QtWidgets[17398]
#define sipNameNr_Hidden 15961
#define sipName_Hidden &sipStrings_QtWidgets[15961]
#define sipNameNr_Ignore 65980
#define sipName_Ignore &sipStrings_QtWidgets[65980]
#define sipNameNr_LookIn 65987
#define sipName_LookIn &sipStrings_QtWidgets[65987]
#define sipNameNr_Margin 4196
#define sipName_Margin &sipStrings_QtWidgets[4196]
#define sipNameNr_Middle 65994
#define sipName_Middle &sipStrings_QtWidgets[65994]
#define sipNameNr_MoveUp 66001
#define sipName_MoveUp &sipStrings_QtWidgets[66001]
#define sipNameNr_NoDrag 66008
#define sipName_NoDrag &sipStrings_QtWidgets[66008]
#define sipNameNr_NoEcho 66015
#define sipName_NoEcho &sipStrings_QtWidgets[66015]
#define sipNameNr_NoHint 66022
#define sipName_NoHint &sipStrings_QtWidgets[66022]
#define sipNameNr_NoIcon 66029
#define sipName_NoIcon &sipStrings_QtWidgets[66029]
#define sipNameNr_NoRole 66036
#define sipName_NoRole &sipStrings_QtWidgets[66036]
#define sipNameNr_NoWrap 66043
#define sipName_NoWrap &sipStrings_QtWidgets[66043]
#define sipNameNr_Normal 60419
#define sipName_Normal &sipStrings_QtWidgets[60419]
#define sipNameNr_OnItem 66050
#define sipName_OnItem &sipStrings_QtWidgets[66050]
#define sipNameNr_Option 5560
#define sipName_Option &sipStrings_QtWidgets[5560]
#define sipNameNr_Policy 2219
#define sipName_Policy &sipStrings_QtWidgets[2219]
#define sipNameNr_QFrame 66057
#define sipName_QFrame &sipStrings_QtWidgets[66057]
#define sipNameNr_QLabel 66064
#define sipName_QLabel &sipStrings_QtWidgets[66064]
#define sipNameNr_QStyle 66071
#define sipName_QStyle &sipStrings_QtWidgets[66071]
#define sipNameNr_Raised 51523
#define sipName_Raised &sipStrings_QtWidgets[51523]
#define sipNameNr_Reason 1754
#define sipName_Reason &sipStrings_QtWidgets[1754]
#define sipNameNr_Reject 66078
#define sipName_Reject &sipStrings_QtWidgets[66078]
#define sipNameNr_Result 10332
#define sipName_Result &sipStrings_QtWidgets[10332]
#define sipNameNr_SC_All 66085
#define sipName_SC_All &sipStrings_QtWidgets[66085]
#define sipNameNr_SO_Tab 66092
#define sipName_SO_Tab &sipStrings_QtWidgets[66092]
#define sipNameNr_Shadow 42807
#define sipName_Shadow &sipStrings_QtWidgets[42807]
#define sipNameNr_Slider 5302
#define sipName_Slider &sipStrings_QtWidgets[5302]
#define sipNameNr_SortUp 66099
#define sipName_SortUp &sipStrings_QtWidgets[66099]
#define sipNameNr_Static 66106
#define sipName_Static &sipStrings_QtWidgets[66106]
#define sipNameNr_Sunken 51536
#define sipName_Sunken &sipStrings_QtWidgets[51536]
#define sipNameNr_YesAll 66113
#define sipName_YesAll &sipStrings_QtWidgets[66113]
#define sipNameNr___eq__ 66120
#define sipName___eq__ &sipStrings_QtWidgets[66120]
#define sipNameNr___ge__ 66127
#define sipName___ge__ &sipStrings_QtWidgets[66127]
#define sipNameNr___lt__ 66134
#define sipName___lt__ &sipStrings_QtWidgets[66134]
#define sipNameNr___ne__ 66141
#define sipName___ne__ &sipStrings_QtWidgets[66141]
#define sipNameNr___or__ 66148
#define sipName___or__ &sipStrings_QtWidgets[66148]
#define sipNameNr_accept 66155
#define sipName_accept &sipStrings_QtWidgets[66155]
#define sipNameNr_action 66162
#define sipName_action &sipStrings_QtWidgets[66162]
#define sipNameNr_active 45537
#define sipName_active &sipStrings_QtWidgets[45537]
#define sipNameNr_addRow 66169
#define sipName_addRow &sipStrings_QtWidgets[66169]
#define sipNameNr_addTab 66176
#define sipName_addTab &sipStrings_QtWidgets[66176]
#define sipNameNr_anchor 66183
#define sipName_anchor &sipStrings_QtWidgets[66183]
#define sipNameNr_append 66190
#define sipName_append &sipStrings_QtWidgets[66190]
#define sipNameNr_button 66197
#define sipName_button &sipStrings_QtWidgets[66197]
#define sipNameNr_cancel 66204
#define sipName_cancel &sipStrings_QtWidgets[66204]
#define sipNameNr_column 66211
#define sipName_column &sipStrings_QtWidgets[66211]
#define sipNameNr_corner 66218
#define sipName_corner &sipStrings_QtWidgets[66218]
#define sipNameNr_create 66225
#define sipName_create &sipStrings_QtWidgets[66225]
#define sipNameNr_cursor 66232
#define sipName_cursor &sipStrings_QtWidgets[66232]
#define sipNameNr_expand 64092
#define sipName_expand &sipStrings_QtWidgets[64092]
#define sipNameNr_filter 66239
#define sipName_filter &sipStrings_QtWidgets[66239]
#define sipNameNr_finish 66246
#define sipName_finish &sipStrings_QtWidgets[66246]
#define sipNameNr_format 64101
#define sipName_format &sipStrings_QtWidgets[64101]
#define sipNameNr_getInt 66253
#define sipName_getInt &sipStrings_QtWidgets[66253]
#define sipNameNr_handle 66260
#define sipName_handle &sipStrings_QtWidgets[66260]
#define sipNameNr_header 66267
#define sipName_header &sipStrings_QtWidgets[66267]
#define sipNameNr_height 66274
#define sipName_height &sipStrings_QtWidgets[66274]
#define sipNameNr_ignore 66281
#define sipName_ignore &sipStrings_QtWidgets[66281]
#define sipNameNr_indent 66288
#define sipName_indent &sipStrings_QtWidgets[66288]
#define sipNameNr_insert 66295
#define sipName_insert &sipStrings_QtWidgets[66295]
#define sipNameNr_isDown 66302
#define sipName_isDown &sipStrings_QtWidgets[66302]
#define sipNameNr_isFlat 66309
#define sipName_isFlat &sipStrings_QtWidgets[66309]
#define sipNameNr_itemAt 66316
#define sipName_itemAt &sipStrings_QtWidgets[66316]
#define sipNameNr_layers 66323
#define sipName_layers &sipStrings_QtWidgets[66323]
#define sipNameNr_layout 66330
#define sipName_layout &sipStrings_QtWidgets[66330]
#define sipNameNr_length 66337
#define sipName_length &sipStrings_QtWidgets[66337]
#define sipNameNr_locale 66344
#define sipName_locale &sipStrings_QtWidgets[66344]
#define sipNameNr_margin 66351
#define sipName_margin &sipStrings_QtWidgets[66351]
#define sipNameNr_member 66358
#define sipName_member &sipStrings_QtWidgets[66358]
#define sipNameNr_metric 66365
#define sipName_metric &sipStrings_QtWidgets[66365]
#define sipNameNr_moveBy 66372
#define sipName_moveBy &sipStrings_QtWidgets[66372]
#define sipNameNr_newPos 66379
#define sipName_newPos &sipStrings_QtWidgets[66379]
#define sipNameNr_nextId 66386
#define sipName_nextId &sipStrings_QtWidgets[66386]
#define sipNameNr_notify 66393
#define sipName_notify &sipStrings_QtWidgets[66393]
#define sipNameNr_offset 66400
#define sipName_offset &sipStrings_QtWidgets[66400]
#define sipNameNr_oldPos 66407
#define sipName_oldPos &sipStrings_QtWidgets[66407]
#define sipNameNr_opaque 66414
#define sipName_opaque &sipStrings_QtWidgets[66414]
#define sipNameNr_option 66421
#define sipName_option &sipStrings_QtWidgets[66421]
#define sipNameNr_origin 66428
#define sipName_origin &sipStrings_QtWidgets[66428]
#define sipNameNr_parent 66435
#define sipName_parent &sipStrings_QtWidgets[66435]
#define sipNameNr_pixmap 66442
#define sipName_pixmap &sipStrings_QtWidgets[66442]
#define sipNameNr_polish 64596
#define sipName_polish &sipStrings_QtWidgets[64596]
#define sipNameNr_prefix 66449
#define sipName_prefix &sipStrings_QtWidgets[66449]
#define sipNameNr_print_ 66456
#define sipName_print_ &sipStrings_QtWidgets[66456]
#define sipNameNr_raise_ 66463
#define sipName_raise_ &sipStrings_QtWidgets[66463]
#define sipNameNr_reason 66470
#define sipName_reason &sipStrings_QtWidgets[66470]
#define sipNameNr_region 66477
#define sipName_region &sipStrings_QtWidgets[66477]
#define sipNameNr_reject 66484
#define sipName_reject &sipStrings_QtWidgets[66484]
#define sipNameNr_reload 66491
#define sipName_reload &sipStrings_QtWidgets[66491]
#define sipNameNr_remove 66498
#define sipName_remove &sipStrings_QtWidgets[66498]
#define sipNameNr_render 66505
#define sipName_render &sipStrings_QtWidgets[66505]
#define sipNameNr_resize 66512
#define sipName_resize &sipStrings_QtWidgets[66512]
#define sipNameNr_result 66519
#define sipName_result &sipStrings_QtWidgets[66519]
#define sipNameNr_revert 66526
#define sipName_revert &sipStrings_QtWidgets[66526]
#define sipNameNr_rotate 66533
#define sipName_rotate &sipStrings_QtWidgets[66533]
#define sipNameNr_screen 66540
#define sipName_screen &sipStrings_QtWidgets[66540]
#define sipNameNr_scroll 66547
#define sipName_scroll &sipStrings_QtWidgets[66547]
#define sipNameNr_setBar 66554
#define sipName_setBar &sipStrings_QtWidgets[66554]
#define sipNameNr_setKey 66561
#define sipName_setKey &sipStrings_QtWidgets[66561]
#define sipNameNr_setNum 66568
#define sipName_setNum &sipStrings_QtWidgets[66568]
#define sipNameNr_setPen 66575
#define sipName_setPen &sipStrings_QtWidgets[66575]
#define sipNameNr_setPos 66582
#define sipName_setPos &sipStrings_QtWidgets[66582]
#define sipNameNr_source 52628
#define sipName_source &sipStrings_QtWidgets[52628]
#define sipNameNr_stacks 66589
#define sipName_stacks &sipStrings_QtWidgets[66589]
#define sipNameNr_stepBy 66596
#define sipName_stepBy &sipStrings_QtWidgets[66596]
#define sipNameNr_stepUp 66603
#define sipName_stepUp &sipStrings_QtWidgets[66603]
#define sipNameNr_submit 66610
#define sipName_submit &sipStrings_QtWidgets[66610]
#define sipNameNr_suffix 66617
#define sipName_suffix &sipStrings_QtWidgets[66617]
#define sipNameNr_sunken 66624
#define sipName_sunken &sipStrings_QtWidgets[66624]
#define sipNameNr_system 66631
#define sipName_system &sipStrings_QtWidgets[66631]
#define sipNameNr_tabBar 66638
#define sipName_tabBar &sipStrings_QtWidgets[66638]
#define sipNameNr_takeAt 66645
#define sipName_takeAt &sipStrings_QtWidgets[66645]
#define sipNameNr_target 66652
#define sipName_target &sipStrings_QtWidgets[66652]
#define sipNameNr_toHtml 66659
#define sipName_toHtml &sipStrings_QtWidgets[66659]
#define sipNameNr_toLast 66666
#define sipName_toLast &sipStrings_QtWidgets[66666]
#define sipNameNr_toNext 66673
#define sipName_toNext &sipStrings_QtWidgets[66673]
#define sipNameNr_toggle 66680
#define sipName_toggle &sipStrings_QtWidgets[66680]
#define sipNameNr_topRow 66687
#define sipName_topRow &sipStrings_QtWidgets[66687]
#define sipNameNr_update 66694
#define sipName_update &sipStrings_QtWidgets[66694]
#define sipNameNr_widget 66701
#define sipName_widget &sipStrings_QtWidgets[66701]
#define sipNameNr_window 66708
#define sipName_window &sipStrings_QtWidgets[66708]
#define sipNameNr_wizard 66715
#define sipName_wizard &sipStrings_QtWidgets[66715]
#define sipNameNr_xScale 66722
#define sipName_xScale &sipStrings_QtWidgets[66722]
#define sipNameNr_yScale 66729
#define sipName_yScale &sipStrings_QtWidgets[66729]
#define sipNameNr_zScale 66736
#define sipName_zScale &sipStrings_QtWidgets[66736]
#define sipNameNr_zValue 66743
#define sipName_zValue &sipStrings_QtWidgets[66743]
#define sipNameNr_zoomIn 66750
#define sipName_zoomIn &sipStrings_QtWidgets[66750]
#define sipNameNr_Abort 66757
#define sipName_Abort &sipStrings_QtWidgets[66757]
#define sipNameNr_Apply 66763
#define sipName_Apply &sipStrings_QtWidgets[66763]
#define sipNameNr_Arrow 9176
#define sipName_Arrow &sipStrings_QtWidgets[9176]
#define sipNameNr_Close 21152
#define sipName_Close &sipStrings_QtWidgets[21152]
#define sipNameNr_Drive 66769
#define sipName_Drive &sipStrings_QtWidgets[66769]
#define sipNameNr_Fixed 66775
#define sipName_Fixed &sipStrings_QtWidgets[66775]
#define sipNameNr_Fps20 66781
#define sipName_Fps20 &sipStrings_QtWidgets[66781]
#define sipNameNr_Fps30 66787
#define sipName_Fps30 &sipStrings_QtWidgets[66787]
#define sipNameNr_Fps60 66793
#define sipName_Fps60 &sipStrings_QtWidgets[66793]
#define sipNameNr_Frame 6818
#define sipName_Frame &sipStrings_QtWidgets[6818]
#define sipNameNr_HLine 66799
#define sipName_HLine &sipStrings_QtWidgets[66799]
#define sipNameNr_Hover 66805
#define sipName_Hover &sipStrings_QtWidgets[66805]
#define sipNameNr_Input 8837
#define sipName_Input &sipStrings_QtWidgets[8837]
#define sipNameNr_Label 12940
#define sipName_Label &sipStrings_QtWidgets[12940]
#define sipNameNr_Mouse 34377
#define sipName_Mouse &sipStrings_QtWidgets[34377]
#define sipNameNr_NoAll 66811
#define sipName_NoAll &sipStrings_QtWidgets[66811]
#define sipNameNr_NoPad 66817
#define sipName_NoPad &sipStrings_QtWidgets[66817]
#define sipNameNr_None_ 66823
#define sipName_None_ &sipStrings_QtWidgets[66823]
#define sipNameNr_North 39417
#define sipName_North &sipStrings_QtWidgets[39417]
#define sipNameNr_Other 66829
#define sipName_Other &sipStrings_QtWidgets[66829]
#define sipNameNr_Panel 4435
#define sipName_Panel &sipStrings_QtWidgets[4435]
#define sipNameNr_Plain 66835
#define sipName_Plain &sipStrings_QtWidgets[66835]
#define sipNameNr_QDial 66841
#define sipName_QDial &sipStrings_QtWidgets[66841]
#define sipNameNr_QMenu 66847
#define sipName_QMenu &sipStrings_QtWidgets[66847]
#define sipNameNr_Reset 53279
#define sipName_Reset &sipStrings_QtWidgets[53279]
#define sipNameNr_Retry 66853
#define sipName_Retry &sipStrings_QtWidgets[66853]
#define sipNameNr_Right 9512
#define sipName_Right &sipStrings_QtWidgets[9512]
#define sipNameNr_Roles 14546
#define sipName_Roles &sipStrings_QtWidgets[14546]
#define sipNameNr_Shape 9036
#define sipName_Shape &sipStrings_QtWidgets[9036]
#define sipNameNr_South 39433
#define sipName_South &sipStrings_QtWidgets[39433]
#define sipNameNr_State 12890
#define sipName_State &sipStrings_QtWidgets[12890]
#define sipNameNr_VLine 66859
#define sipName_VLine &sipStrings_QtWidgets[66859]
#define sipNameNr_about 66865
#define sipName_about &sipStrings_QtWidgets[66865]
#define sipNameNr_alert 66871
#define sipName_alert &sipStrings_QtWidgets[66871]
#define sipNameNr_angle 61257
#define sipName_angle &sipStrings_QtWidgets[61257]
#define sipNameNr_begin 66877
#define sipName_begin &sipStrings_QtWidgets[66877]
#define sipNameNr_brush 66883
#define sipName_brush &sipStrings_QtWidgets[66883]
#define sipNameNr_buddy 66889
#define sipName_buddy &sipStrings_QtWidgets[66889]
#define sipNameNr_child 66895
#define sipName_child &sipStrings_QtWidgets[66895]
#define sipNameNr_clear 66901
#define sipName_clear &sipStrings_QtWidgets[66901]
#define sipNameNr_click 66907
#define sipName_click &sipStrings_QtWidgets[66907]
#define sipNameNr_clone 66913
#define sipName_clone &sipStrings_QtWidgets[66913]
#define sipNameNr_close 66919
#define sipName_close &sipStrings_QtWidgets[66919]
#define sipNameNr_color 66925
#define sipName_color &sipStrings_QtWidgets[66925]
#define sipNameNr_count 66931
#define sipName_count &sipStrings_QtWidgets[66931]
#define sipNameNr_delta 66937
#define sipName_delta &sipStrings_QtWidgets[66937]
#define sipNameNr_depth 66943
#define sipName_depth &sipStrings_QtWidgets[66943]
#define sipNameNr_event 66949
#define sipName_event &sipStrings_QtWidgets[66949]
#define sipNameNr_exec_ 66955
#define sipName_exec_ &sipStrings_QtWidgets[66955]
#define sipNameNr_field 66961
#define sipName_field &sipStrings_QtWidgets[66961]
#define sipNameNr_fixup 66967
#define sipName_fixup &sipStrings_QtWidgets[66967]
#define sipNameNr_flags 66973
#define sipName_flags &sipStrings_QtWidgets[66973]
#define sipNameNr_frame 66979
#define sipName_frame &sipStrings_QtWidgets[66979]
#define sipNameNr_group 66985
#define sipName_group &sipStrings_QtWidgets[66985]
#define sipNameNr_hover 66991
#define sipName_hover &sipStrings_QtWidgets[66991]
#define sipNameNr_index 66997
#define sipName_index &sipStrings_QtWidgets[66997]
#define sipNameNr_isDir 67003
#define sipName_isDir &sipStrings_QtWidgets[67003]
#define sipNameNr_items 67009
#define sipName_items &sipStrings_QtWidgets[67009]
#define sipNameNr_lower 67015
#define sipName_lower &sipStrings_QtWidgets[67015]
#define sipNameNr_mapTo 67021
#define sipName_mapTo &sipStrings_QtWidgets[67021]
#define sipNameNr_match 67027
#define sipName_match &sipStrings_QtWidgets[67027]
#define sipNameNr_mkdir 67033
#define sipName_mkdir &sipStrings_QtWidgets[67033]
#define sipNameNr_model 67039
#define sipName_model &sipStrings_QtWidgets[67039]
#define sipNameNr_movie 67045
#define sipName_movie &sipStrings_QtWidgets[67045]
#define sipNameNr_msecs 67051
#define sipName_msecs &sipStrings_QtWidgets[67051]
#define sipNameNr_order 16663
#define sipName_order &sipStrings_QtWidgets[16663]
#define sipNameNr_paint 65517
#define sipName_paint &sipStrings_QtWidgets[65517]
#define sipNameNr_panel 67057
#define sipName_panel &sipStrings_QtWidgets[67057]
#define sipNameNr_paste 67063
#define sipName_paste &sipStrings_QtWidgets[67063]
#define sipNameNr_popup 67069
#define sipName_popup &sipStrings_QtWidgets[67069]
#define sipNameNr_print 67075
#define sipName_print &sipStrings_QtWidgets[67075]
#define sipNameNr_proxy 67081
#define sipName_proxy &sipStrings_QtWidgets[67081]
#define sipNameNr_range 67087
#define sipName_range &sipStrings_QtWidgets[67087]
#define sipNameNr_reset 67093
#define sipName_reset &sipStrings_QtWidgets[67093]
#define sipNameNr_rmdir 67099
#define sipName_rmdir &sipStrings_QtWidgets[67099]
#define sipNameNr_roles 67105
#define sipName_roles &sipStrings_QtWidgets[67105]
#define sipNameNr_rowAt 67111
#define sipName_rowAt &sipStrings_QtWidgets[67111]
#define sipNameNr_scale 67117
#define sipName_scale &sipStrings_QtWidgets[67117]
#define sipNameNr_scene 67123
#define sipName_scene &sipStrings_QtWidgets[67123]
#define sipNameNr_setId 67129
#define sipName_setId &sipStrings_QtWidgets[67129]
#define sipNameNr_shape 67135
#define sipName_shape &sipStrings_QtWidgets[67135]
#define sipNameNr_shear 67141
#define sipName_shear &sipStrings_QtWidgets[67141]
#define sipNameNr_sizes 10873
#define sipName_sizes &sipStrings_QtWidgets[10873]
#define sipNameNr_stack 67147
#define sipName_stack &sipStrings_QtWidgets[67147]
#define sipNameNr_state 57573
#define sipName_state &sipStrings_QtWidgets[57573]
#define sipNameNr_steps 67153
#define sipName_steps &sipStrings_QtWidgets[67153]
#define sipNameNr_style 67159
#define sipName_style &sipStrings_QtWidgets[67159]
#define sipNameNr_tabAt 67165
#define sipName_tabAt &sipStrings_QtWidgets[67165]
#define sipNameNr_title 67171
#define sipName_title &sipStrings_QtWidgets[67171]
#define sipNameNr_value 67177
#define sipName_value &sipStrings_QtWidgets[67177]
#define sipNameNr_views 67183
#define sipName_views &sipStrings_QtWidgets[67183]
#define sipNameNr_width 67189
#define sipName_width &sipStrings_QtWidgets[67189]
#define sipNameNr_winId 67195
#define sipName_winId &sipStrings_QtWidgets[67195]
#define sipNameNr_write 20837
#define sipName_write &sipStrings_QtWidgets[20837]
#define sipNameNr_Down 9983
#define sipName_Down &sipStrings_QtWidgets[9983]
#define sipNameNr_East 43409
#define sipName_East &sipStrings_QtWidgets[43409]
#define sipNameNr_File 50914
#define sipName_File &sipStrings_QtWidgets[50914]
#define sipNameNr_Flat 65598
#define sipName_Flat &sipStrings_QtWidgets[65598]
#define sipNameNr_Flow 38954
#define sipName_Flow &sipStrings_QtWidgets[38954]
#define sipNameNr_Free 67201
#define sipName_Free &sipStrings_QtWidgets[67201]
#define sipNameNr_Help 67206
#define sipName_Help &sipStrings_QtWidgets[67206]
#define sipNameNr_Icon 2145
#define sipName_Icon &sipStrings_QtWidgets[2145]
#define sipNameNr_Left 10604
#define sipName_Left &sipStrings_QtWidgets[10604]
#define sipNameNr_Line 23900
#define sipName_Line &sipStrings_QtWidgets[23900]
#define sipNameNr_List 42344
#define sipName_List &sipStrings_QtWidgets[42344]
#define sipNameNr_Menu 6106
#define sipName_Menu &sipStrings_QtWidgets[6106]
#define sipNameNr_Mode 4334
#define sipName_Mode &sipStrings_QtWidgets[4334]
#define sipNameNr_Open 17561
#define sipName_Open &sipStrings_QtWidgets[17561]
#define sipNameNr_Save 58111
#define sipName_Save &sipStrings_QtWidgets[58111]
#define sipNameNr_Snap 67211
#define sipName_Snap &sipStrings_QtWidgets[67211]
#define sipNameNr_Type 314
#define sipName_Type &sipStrings_QtWidgets[314]
#define sipNameNr_West 43424
#define sipName_West &sipStrings_QtWidgets[43424]
#define sipNameNr_area 67216
#define sipName_area &sipStrings_QtWidgets[67216]
#define sipNameNr_axis 67221
#define sipName_axis &sipStrings_QtWidgets[67221]
#define sipNameNr_back 67226
#define sipName_back &sipStrings_QtWidgets[67226]
#define sipNameNr_beep 67231
#define sipName_beep &sipStrings_QtWidgets[67231]
#define sipNameNr_copy 67236
#define sipName_copy &sipStrings_QtWidgets[67236]
#define sipNameNr_data 67241
#define sipName_data &sipStrings_QtWidgets[67241]
#define sipNameNr_date 9848
#define sipName_date &sipStrings_QtWidgets[9848]
#define sipNameNr_del_ 67246
#define sipName_del_ &sipStrings_QtWidgets[67246]
#define sipNameNr_done 67251
#define sipName_done &sipStrings_QtWidgets[67251]
#define sipNameNr_draw 67256
#define sipName_draw &sipStrings_QtWidgets[67256]
#define sipNameNr_echo 67261
#define sipName_echo &sipStrings_QtWidgets[67261]
#define sipNameNr_edit 67266
#define sipName_edit &sipStrings_QtWidgets[67266]
#define sipNameNr_exec 67271
#define sipName_exec &sipStrings_QtWidgets[67271]
#define sipNameNr_fill 67276
#define sipName_fill &sipStrings_QtWidgets[67276]
#define sipNameNr_find 67281
#define sipName_find &sipStrings_QtWidgets[67281]
#define sipNameNr_flow 47726
#define sipName_flow &sipStrings_QtWidgets[47726]
#define sipNameNr_font 67286
#define sipName_font &sipStrings_QtWidgets[67286]
#define sipNameNr_grab 67291
#define sipName_grab &sipStrings_QtWidgets[67291]
#define sipNameNr_hide 67296
#define sipName_hide &sipStrings_QtWidgets[67296]
#define sipNameNr_hint 67301
#define sipName_hint &sipStrings_QtWidgets[67301]
#define sipNameNr_home 67306
#define sipName_home &sipStrings_QtWidgets[67306]
#define sipNameNr_icon 67311
#define sipName_icon &sipStrings_QtWidgets[67311]
#define sipNameNr_item 67316
#define sipName_item &sipStrings_QtWidgets[67316]
#define sipNameNr_keys 67321
#define sipName_keys &sipStrings_QtWidgets[67321]
#define sipNameNr_line 37183
#define sipName_line &sipStrings_QtWidgets[37183]
#define sipNameNr_mask 67326
#define sipName_mask &sipStrings_QtWidgets[67326]
#define sipNameNr_menu 67331
#define sipName_menu &sipStrings_QtWidgets[67331]
#define sipNameNr_mode 67336
#define sipName_mode &sipStrings_QtWidgets[67336]
#define sipNameNr_move 8925
#define sipName_move &sipStrings_QtWidgets[8925]
#define sipNameNr_next 67341
#define sipName_next &sipStrings_QtWidgets[67341]
#define sipNameNr_open 67346
#define sipName_open &sipStrings_QtWidgets[67346]
#define sipNameNr_page 67351
#define sipName_page &sipStrings_QtWidgets[67351]
#define sipNameNr_path 67356
#define sipName_path &sipStrings_QtWidgets[67356]
#define sipNameNr_push 67361
#define sipName_push &sipStrings_QtWidgets[67361]
#define sipNameNr_qApp 67366
#define sipName_qApp &sipStrings_QtWidgets[67366]
#define sipNameNr_read 67371
#define sipName_read &sipStrings_QtWidgets[67371]
#define sipNameNr_rect 67376
#define sipName_rect &sipStrings_QtWidgets[67376]
#define sipNameNr_redo 67381
#define sipName_redo &sipStrings_QtWidgets[67381]
#define sipNameNr_role 67386
#define sipName_role &sipStrings_QtWidgets[67386]
#define sipNameNr_setX 67391
#define sipName_setX &sipStrings_QtWidgets[67391]
#define sipNameNr_setY 67396
#define sipName_setY &sipStrings_QtWidgets[67396]
#define sipNameNr_show 67401
#define sipName_show &sipStrings_QtWidgets[67401]
#define sipNameNr_size 13616
#define sipName_size &sipStrings_QtWidgets[13616]
#define sipNameNr_sort 67406
#define sipName_sort &sipStrings_QtWidgets[67406]
#define sipNameNr_span 67411
#define sipName_span &sipStrings_QtWidgets[67411]
#define sipNameNr_step 67416
#define sipName_step &sipStrings_QtWidgets[67416]
#define sipNameNr_stop 67421
#define sipName_stop &sipStrings_QtWidgets[67421]
#define sipNameNr_text 27091
#define sipName_text &sipStrings_QtWidgets[27091]
#define sipNameNr_time 67426
#define sipName_time &sipStrings_QtWidgets[67426]
#define sipNameNr_type 37234
#define sipName_type &sipStrings_QtWidgets[37234]
#define sipNameNr_undo 67431
#define sipName_undo &sipStrings_QtWidgets[67431]
#define sipNameNr_view 67436
#define sipName_view &sipStrings_QtWidgets[67436]
#define sipNameNr_All 55583
#define sipName_All &sipStrings_QtWidgets[55583]
#define sipNameNr_Bin 67441
#define sipName_Bin &sipStrings_QtWidgets[67441]
#define sipNameNr_Box 21091
#define sipName_Box &sipStrings_QtWidgets[21091]
#define sipNameNr_Dec 67445
#define sipName_Dec &sipStrings_QtWidgets[67445]
#define sipNameNr_End 35450
#define sipName_End &sipStrings_QtWidgets[35450]
#define sipNameNr_Hex 67449
#define sipName_Hex &sipStrings_QtWidgets[67449]
#define sipNameNr_Oct 67453
#define sipName_Oct &sipStrings_QtWidgets[67453]
#define sipNameNr_Top 46831
#define sipName_Top &sipStrings_QtWidgets[46831]
#define sipNameNr_Yes 67457
#define sipName_Yes &sipStrings_QtWidgets[67457]
#define sipNameNr_cut 22015
#define sipName_cut &sipStrings_QtWidgets[22015]
#define sipNameNr_end 66193
#define sipName_end &sipStrings_QtWidgets[66193]
#define sipNameNr_key 67461
#define sipName_key &sipStrings_QtWidgets[67461]
#define sipNameNr_max 67465
#define sipName_max &sipStrings_QtWidgets[67465]
#define sipNameNr_min 67469
#define sipName_min &sipStrings_QtWidgets[67469]
#define sipNameNr_pen 17562
#define sipName_pen &sipStrings_QtWidgets[17562]
#define sipNameNr_pos 67473
#define sipName_pos &sipStrings_QtWidgets[67473]
#define sipNameNr_row 9178
#define sipName_row &sipStrings_QtWidgets[9178]
#define sipNameNr_No 67477
#define sipName_No &sipStrings_QtWidgets[67477]
#define sipNameNr_Ok 67480
#define sipName_Ok &sipStrings_QtWidgets[67480]
#define sipNameNr_Up 24242
#define sipName_Up &sipStrings_QtWidgets[24242]
#define sipNameNr_at 404
#define sipName_at &sipStrings_QtWidgets[404]
#define sipNameNr_id 57468
#define sipName_id &sipStrings_QtWidgets[57468]
#define sipNameNr_ok 67483
#define sipName_ok &sipStrings_QtWidgets[67483]
#define sipNameNr_on 94
#define sipName_on &sipStrings_QtWidgets[94]
#define sipNameNr_x 17817
#define sipName_x &sipStrings_QtWidgets[17817]
#define sipNameNr_y 2224
#define sipName_y &sipStrings_QtWidgets[2224]

#define sipMalloc                   sipAPI_QtWidgets->api_malloc
#define sipFree                     sipAPI_QtWidgets->api_free
#define sipBuildResult              sipAPI_QtWidgets->api_build_result
#define sipCallMethod               sipAPI_QtWidgets->api_call_method
#define sipCallProcedureMethod      sipAPI_QtWidgets->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtWidgets->api_call_error_handler
#define sipParseResultEx            sipAPI_QtWidgets->api_parse_result_ex
#define sipParseResult              sipAPI_QtWidgets->api_parse_result
#define sipParseArgs                sipAPI_QtWidgets->api_parse_args
#define sipParseKwdArgs             sipAPI_QtWidgets->api_parse_kwd_args
#define sipParsePair                sipAPI_QtWidgets->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtWidgets->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtWidgets->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtWidgets->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtWidgets->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtWidgets->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtWidgets->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtWidgets->api_add_exception
#define sipNoFunction               sipAPI_QtWidgets->api_no_function
#define sipNoMethod                 sipAPI_QtWidgets->api_no_method
#define sipAbstractMethod           sipAPI_QtWidgets->api_abstract_method
#define sipBadClass                 sipAPI_QtWidgets->api_bad_class
#define sipBadCatcherResult         sipAPI_QtWidgets->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtWidgets->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtWidgets->api_bad_operator_arg
#define sipTrace                    sipAPI_QtWidgets->api_trace
#define sipTransferBack             sipAPI_QtWidgets->api_transfer_back
#define sipTransferTo               sipAPI_QtWidgets->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtWidgets->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtWidgets->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtWidgets->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtWidgets->api_voidptr_type
#define sipGetPyObject              sipAPI_QtWidgets->api_get_pyobject
#define sipGetAddress               sipAPI_QtWidgets->api_get_address
#define sipGetMixinAddress          sipAPI_QtWidgets->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtWidgets->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtWidgets->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtWidgets->api_call_hook
#define sipEndThread                sipAPI_QtWidgets->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtWidgets->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtWidgets->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtWidgets->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtWidgets->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtWidgets->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtWidgets->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtWidgets->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtWidgets->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtWidgets->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtWidgets->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtWidgets->api_convert_to_bool
#define sipReleaseType              sipAPI_QtWidgets->api_release_type
#define sipConvertFromType          sipAPI_QtWidgets->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtWidgets->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtWidgets->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtWidgets->api_convert_from_enum
#define sipGetState                 sipAPI_QtWidgets->api_get_state
#define sipExportSymbol             sipAPI_QtWidgets->api_export_symbol
#define sipImportSymbol             sipAPI_QtWidgets->api_import_symbol
#define sipFindType                 sipAPI_QtWidgets->api_find_type
#define sipBytes_AsChar             sipAPI_QtWidgets->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtWidgets->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtWidgets->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtWidgets->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtWidgets->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtWidgets->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtWidgets->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtWidgets->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtWidgets->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtWidgets->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtWidgets->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtWidgets->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtWidgets->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtWidgets->api_get_reference
#define sipKeepReference            sipAPI_QtWidgets->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtWidgets->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtWidgets->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtWidgets->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtWidgets->api_type_scope
#define sipResolveTypedef           sipAPI_QtWidgets->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtWidgets->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtWidgets->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtWidgets->api_init_mixin
#define sipExportModule             sipAPI_QtWidgets->api_export_module
#define sipInitModule               sipAPI_QtWidgets->api_init_module
#define sipGetInterpreter           sipAPI_QtWidgets->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtWidgets->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtWidgets->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtWidgets->api_py_type_dict
#define sipPyTypeName               sipAPI_QtWidgets->api_py_type_name
#define sipGetCFunction             sipAPI_QtWidgets->api_get_c_function
#define sipGetMethod                sipAPI_QtWidgets->api_get_method
#define sipFromMethod               sipAPI_QtWidgets->api_from_method
#define sipGetDate                  sipAPI_QtWidgets->api_get_date
#define sipFromDate                 sipAPI_QtWidgets->api_from_date
#define sipGetDateTime              sipAPI_QtWidgets->api_get_datetime
#define sipFromDateTime             sipAPI_QtWidgets->api_from_datetime
#define sipGetTime                  sipAPI_QtWidgets->api_get_time
#define sipFromTime                 sipAPI_QtWidgets->api_from_time
#define sipIsUserType               sipAPI_QtWidgets->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtWidgets->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtWidgets->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtWidgets->api_unicode_write
#define sipUnicodeData              sipAPI_QtWidgets->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtWidgets->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtWidgets->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtWidgets->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtWidgets->api_is_derived_class
#define sipGetUserObject            sipAPI_QtWidgets->api_get_user_object
#define sipSetUserObject            sipAPI_QtWidgets->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtWidgets->api_register_event_handler
#define sipConvertToArray           sipAPI_QtWidgets->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtWidgets->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtWidgets->api_enable_gc
#define sipPrintObject              sipAPI_QtWidgets->api_print_object
#define sipLong_AsChar              sipAPI_QtWidgets->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtWidgets->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtWidgets->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtWidgets->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtWidgets->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtWidgets->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtWidgets->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtWidgets->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtWidgets->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtWidgets->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtWidgets->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtWidgets->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtWidgets->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtWidgets->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtWidgets->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtWidgets->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtWidgets->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtWidgets->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtWidgets->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtWidgets->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtWidgets->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtWidgets->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtWidgets->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtWidgets->api_connect_rx
#define sipConvertRx                sipAPI_QtWidgets->api_convert_rx
#define sipDisconnectRx             sipAPI_QtWidgets->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtWidgets->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtWidgets->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtWidgets->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtWidgets->api_same_slot
#define sipSaveSlot                 sipAPI_QtWidgets->api_save_slot
#define sipVisitSlot                sipAPI_QtWidgets->api_visit_slot
#define sipIsPyMethod               sipAPI_QtWidgets->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtWidgets[];

#define sipType_QWidget sipExportedTypes_QtWidgets[463]

#define sipType_QWidget_RenderFlag sipExportedTypes_QtWidgets[464]

extern sipClassTypeDef sipTypeDef_QtWidgets_QWidget;

#define sipType_QAbstractButton sipExportedTypes_QtWidgets[0]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractButton;

#define sipType_QAbstractItemDelegate sipExportedTypes_QtWidgets[2]

#define sipType_QAbstractItemDelegate_EndEditHint sipExportedTypes_QtWidgets[3]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractItemDelegate;

#define sipType_QFrame sipExportedTypes_QtWidgets[103]

#define sipType_QFrame_StyleMask sipExportedTypes_QtWidgets[106]

#define sipType_QFrame_Shape sipExportedTypes_QtWidgets[105]

#define sipType_QFrame_Shadow sipExportedTypes_QtWidgets[104]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFrame;

#define sipType_QAbstractScrollArea sipExportedTypes_QtWidgets[15]

#define sipType_QAbstractScrollArea_SizeAdjustPolicy sipExportedTypes_QtWidgets[16]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractScrollArea;

#define sipType_QAbstractItemView sipExportedTypes_QtWidgets[4]

#define sipType_QAbstractItemView_DropIndicatorPosition sipExportedTypes_QtWidgets[7]

#define sipType_QAbstractItemView_State sipExportedTypes_QtWidgets[14]

#define sipType_QAbstractItemView_CursorAction sipExportedTypes_QtWidgets[5]

#define sipType_QAbstractItemView_SelectionMode sipExportedTypes_QtWidgets[13]

#define sipType_QAbstractItemView_SelectionBehavior sipExportedTypes_QtWidgets[12]

#define sipType_QAbstractItemView_ScrollMode sipExportedTypes_QtWidgets[11]

#define sipType_QAbstractItemView_ScrollHint sipExportedTypes_QtWidgets[10]

#define sipType_QAbstractItemView_EditTrigger sipExportedTypes_QtWidgets[8]

#define sipType_QAbstractItemView_DragDropMode sipExportedTypes_QtWidgets[6]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractItemView;

#define sipType_QAbstractItemView_EditTriggers sipExportedTypes_QtWidgets[9]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractItemView_EditTriggers;

#define sipType_QAbstractSlider sipExportedTypes_QtWidgets[17]

#define sipType_QAbstractSlider_SliderChange sipExportedTypes_QtWidgets[19]

#define sipType_QAbstractSlider_SliderAction sipExportedTypes_QtWidgets[18]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractSlider;

#define sipType_QAbstractSpinBox sipExportedTypes_QtWidgets[20]

#define sipType_QAbstractSpinBox_StepType sipExportedTypes_QtWidgets[25]

#define sipType_QAbstractSpinBox_CorrectionMode sipExportedTypes_QtWidgets[22]

#define sipType_QAbstractSpinBox_ButtonSymbols sipExportedTypes_QtWidgets[21]

#define sipType_QAbstractSpinBox_StepEnabledFlag sipExportedTypes_QtWidgets[24]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractSpinBox;

#define sipType_QAbstractSpinBox_StepEnabled sipExportedTypes_QtWidgets[23]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractSpinBox_StepEnabled;

#define sipType_QAction sipExportedTypes_QtWidgets[26]

#define sipType_QAction_Priority sipExportedTypes_QtWidgets[29]

#define sipType_QAction_MenuRole sipExportedTypes_QtWidgets[28]

#define sipType_QAction_ActionEvent sipExportedTypes_QtWidgets[27]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAction;

#define sipType_QActionGroup sipExportedTypes_QtWidgets[30]

#define sipType_QActionGroup_ExclusionPolicy sipExportedTypes_QtWidgets[31]

extern sipClassTypeDef sipTypeDef_QtWidgets_QActionGroup;

#define sipType_QApplication sipExportedTypes_QtWidgets[32]

#define sipType_QApplication_ColorSpec sipExportedTypes_QtWidgets[33]

extern sipClassTypeDef sipTypeDef_QtWidgets_QApplication;

#define sipType_QLayoutItem sipExportedTypes_QtWidgets[193]

extern sipClassTypeDef sipTypeDef_QtWidgets_QLayoutItem;

#define sipType_QLayout sipExportedTypes_QtWidgets[191]

#define sipType_QLayout_SizeConstraint sipExportedTypes_QtWidgets[192]

extern sipClassTypeDef sipTypeDef_QtWidgets_QLayout;

#define sipType_QBoxLayout sipExportedTypes_QtWidgets[34]

#define sipType_QBoxLayout_Direction sipExportedTypes_QtWidgets[35]

extern sipClassTypeDef sipTypeDef_QtWidgets_QBoxLayout;

#define sipType_QHBoxLayout sipExportedTypes_QtWidgets[175]

extern sipClassTypeDef sipTypeDef_QtWidgets_QHBoxLayout;

#define sipType_QVBoxLayout sipExportedTypes_QtWidgets[461]

extern sipClassTypeDef sipTypeDef_QtWidgets_QVBoxLayout;

#define sipType_QButtonGroup sipExportedTypes_QtWidgets[36]

extern sipClassTypeDef sipTypeDef_QtWidgets_QButtonGroup;

#define sipType_QCalendarWidget sipExportedTypes_QtWidgets[37]

#define sipType_QCalendarWidget_SelectionMode sipExportedTypes_QtWidgets[39]

#define sipType_QCalendarWidget_VerticalHeaderFormat sipExportedTypes_QtWidgets[40]

#define sipType_QCalendarWidget_HorizontalHeaderFormat sipExportedTypes_QtWidgets[38]

extern sipClassTypeDef sipTypeDef_QtWidgets_QCalendarWidget;

#define sipType_QCheckBox sipExportedTypes_QtWidgets[41]

extern sipClassTypeDef sipTypeDef_QtWidgets_QCheckBox;

#define sipType_QDialog sipExportedTypes_QtWidgets[62]

#define sipType_QDialog_DialogCode sipExportedTypes_QtWidgets[63]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDialog;

#define sipType_QColorDialog sipExportedTypes_QtWidgets[42]

#define sipType_QColorDialog_ColorDialogOption sipExportedTypes_QtWidgets[43]

extern sipClassTypeDef sipTypeDef_QtWidgets_QColorDialog;

#define sipType_QColorDialog_ColorDialogOptions sipExportedTypes_QtWidgets[44]

extern sipClassTypeDef sipTypeDef_QtWidgets_QColorDialog_ColorDialogOptions;

#define sipType_QColumnView sipExportedTypes_QtWidgets[45]

extern sipClassTypeDef sipTypeDef_QtWidgets_QColumnView;

#define sipType_QComboBox sipExportedTypes_QtWidgets[46]

#define sipType_QComboBox_SizeAdjustPolicy sipExportedTypes_QtWidgets[48]

#define sipType_QComboBox_InsertPolicy sipExportedTypes_QtWidgets[47]

extern sipClassTypeDef sipTypeDef_QtWidgets_QComboBox;

#define sipType_QPushButton sipExportedTypes_QtWidgets[258]

extern sipClassTypeDef sipTypeDef_QtWidgets_QPushButton;

#define sipType_QCommandLinkButton sipExportedTypes_QtWidgets[49]

extern sipClassTypeDef sipTypeDef_QtWidgets_QCommandLinkButton;

#define sipType_QStyle sipExportedTypes_QtWidgets[290]

#define sipType_QStyle_RequestSoftwareInputPanel sipExportedTypes_QtWidgets[296]

#define sipType_QStyle_StandardPixmap sipExportedTypes_QtWidgets[297]

#define sipType_QStyle_StyleHint sipExportedTypes_QtWidgets[300]

#define sipType_QStyle_ContentsType sipExportedTypes_QtWidgets[292]

#define sipType_QStyle_PixelMetric sipExportedTypes_QtWidgets[294]

#define sipType_QStyle_SubControl sipExportedTypes_QtWidgets[301]

#define sipType_QStyle_ComplexControl sipExportedTypes_QtWidgets[291]

#define sipType_QStyle_SubElement sipExportedTypes_QtWidgets[303]

#define sipType_QStyle_ControlElement sipExportedTypes_QtWidgets[293]

#define sipType_QStyle_PrimitiveElement sipExportedTypes_QtWidgets[295]

#define sipType_QStyle_StateFlag sipExportedTypes_QtWidgets[299]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyle;

#define sipType_QCommonStyle sipExportedTypes_QtWidgets[50]

extern sipClassTypeDef sipTypeDef_QtWidgets_QCommonStyle;

#define sipType_QCompleter sipExportedTypes_QtWidgets[51]

#define sipType_QCompleter_ModelSorting sipExportedTypes_QtWidgets[53]

#define sipType_QCompleter_CompletionMode sipExportedTypes_QtWidgets[52]

extern sipClassTypeDef sipTypeDef_QtWidgets_QCompleter;

#define sipType_QDataWidgetMapper sipExportedTypes_QtWidgets[54]

#define sipType_QDataWidgetMapper_SubmitPolicy sipExportedTypes_QtWidgets[55]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDataWidgetMapper;

#define sipType_QDateTimeEdit sipExportedTypes_QtWidgets[57]

#define sipType_QDateTimeEdit_Section sipExportedTypes_QtWidgets[58]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDateTimeEdit;

#define sipType_QDateTimeEdit_Sections sipExportedTypes_QtWidgets[59]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDateTimeEdit_Sections;

#define sipType_QTimeEdit sipExportedTypes_QtWidgets[443]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTimeEdit;

#define sipType_QDateEdit sipExportedTypes_QtWidgets[56]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDateEdit;

#define sipType_QDesktopWidget sipExportedTypes_QtWidgets[60]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDesktopWidget;

#define sipType_QDial sipExportedTypes_QtWidgets[61]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDial;

#define sipType_QDialogButtonBox sipExportedTypes_QtWidgets[64]

#define sipType_QDialogButtonBox_StandardButton sipExportedTypes_QtWidgets[67]

#define sipType_QDialogButtonBox_ButtonRole sipExportedTypes_QtWidgets[66]

#define sipType_QDialogButtonBox_ButtonLayout sipExportedTypes_QtWidgets[65]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDialogButtonBox;

#define sipType_QDialogButtonBox_StandardButtons sipExportedTypes_QtWidgets[68]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDialogButtonBox_StandardButtons;

#define sipType_QDirModel sipExportedTypes_QtWidgets[69]

#define sipType_QDirModel_Roles sipExportedTypes_QtWidgets[70]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDirModel;

#define sipType_QDockWidget sipExportedTypes_QtWidgets[71]

#define sipType_QDockWidget_DockWidgetFeature sipExportedTypes_QtWidgets[72]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDockWidget;

#define sipType_QDockWidget_DockWidgetFeatures sipExportedTypes_QtWidgets[73]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDockWidget_DockWidgetFeatures;

#define sipType_QErrorMessage sipExportedTypes_QtWidgets[75]

extern sipClassTypeDef sipTypeDef_QtWidgets_QErrorMessage;

#define sipType_QFileDialog sipExportedTypes_QtWidgets[76]

#define sipType_QFileDialog_Option sipExportedTypes_QtWidgets[80]

#define sipType_QFileDialog_DialogLabel sipExportedTypes_QtWidgets[78]

#define sipType_QFileDialog_AcceptMode sipExportedTypes_QtWidgets[77]

#define sipType_QFileDialog_FileMode sipExportedTypes_QtWidgets[79]

#define sipType_QFileDialog_ViewMode sipExportedTypes_QtWidgets[82]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFileDialog;

#define sipType_QFileDialog_Options sipExportedTypes_QtWidgets[81]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFileDialog_Options;

#define sipType_QFileIconProvider sipExportedTypes_QtWidgets[83]

#define sipType_QFileIconProvider_Option sipExportedTypes_QtWidgets[85]

#define sipType_QFileIconProvider_IconType sipExportedTypes_QtWidgets[84]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFileIconProvider;

#define sipType_QFileIconProvider_Options sipExportedTypes_QtWidgets[86]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFileIconProvider_Options;

#define sipType_QFileSystemModel sipExportedTypes_QtWidgets[87]

#define sipType_QFileSystemModel_Option sipExportedTypes_QtWidgets[88]

#define sipType_QFileSystemModel_Roles sipExportedTypes_QtWidgets[90]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFileSystemModel;

#define sipType_QFileSystemModel_Options sipExportedTypes_QtWidgets[89]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFileSystemModel_Options;

#define sipType_QFocusFrame sipExportedTypes_QtWidgets[91]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFocusFrame;

#define sipType_QFontComboBox sipExportedTypes_QtWidgets[92]

#define sipType_QFontComboBox_FontFilter sipExportedTypes_QtWidgets[93]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFontComboBox;

#define sipType_QFontComboBox_FontFilters sipExportedTypes_QtWidgets[94]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFontComboBox_FontFilters;

#define sipType_QFontDialog sipExportedTypes_QtWidgets[95]

#define sipType_QFontDialog_FontDialogOption sipExportedTypes_QtWidgets[96]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFontDialog;

#define sipType_QFontDialog_FontDialogOptions sipExportedTypes_QtWidgets[97]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFontDialog_FontDialogOptions;

#define sipType_QFormLayout sipExportedTypes_QtWidgets[98]

#define sipType_QFormLayout_ItemRole sipExportedTypes_QtWidgets[100]

#define sipType_QFormLayout_RowWrapPolicy sipExportedTypes_QtWidgets[101]

#define sipType_QFormLayout_FieldGrowthPolicy sipExportedTypes_QtWidgets[99]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFormLayout;

#define sipType_QFormLayout_TakeRowResult sipExportedTypes_QtWidgets[102]

extern sipClassTypeDef sipTypeDef_QtWidgets_QFormLayout_TakeRowResult;

#define sipType_QGesture sipExportedTypes_QtWidgets[107]

#define sipType_QGesture_GestureCancelPolicy sipExportedTypes_QtWidgets[108]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGesture;

#define sipType_QPanGesture sipExportedTypes_QtWidgets[247]

extern sipClassTypeDef sipTypeDef_QtWidgets_QPanGesture;

#define sipType_QPinchGesture sipExportedTypes_QtWidgets[248]

#define sipType_QPinchGesture_ChangeFlag sipExportedTypes_QtWidgets[249]

extern sipClassTypeDef sipTypeDef_QtWidgets_QPinchGesture;

#define sipType_QPinchGesture_ChangeFlags sipExportedTypes_QtWidgets[250]

extern sipClassTypeDef sipTypeDef_QtWidgets_QPinchGesture_ChangeFlags;

#define sipType_QSwipeGesture sipExportedTypes_QtWidgets[418]

#define sipType_QSwipeGesture_SwipeDirection sipExportedTypes_QtWidgets[419]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSwipeGesture;

#define sipType_QTapGesture sipExportedTypes_QtWidgets[436]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTapGesture;

#define sipType_QTapAndHoldGesture sipExportedTypes_QtWidgets[435]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTapAndHoldGesture;

#define sipType_QGestureEvent sipExportedTypes_QtWidgets[109]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGestureEvent;

#define sipType_QGestureRecognizer sipExportedTypes_QtWidgets[110]

#define sipType_QGestureRecognizer_ResultFlag sipExportedTypes_QtWidgets[112]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGestureRecognizer;

#define sipType_QGestureRecognizer_Result sipExportedTypes_QtWidgets[111]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGestureRecognizer_Result;

#define sipType_QGraphicsAnchor sipExportedTypes_QtWidgets[113]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsAnchor;

#define sipType_QGraphicsLayoutItem sipExportedTypes_QtWidgets[134]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsLayoutItem;

#define sipType_QGraphicsLayout sipExportedTypes_QtWidgets[133]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsLayout;

#define sipType_QGraphicsAnchorLayout sipExportedTypes_QtWidgets[114]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsAnchorLayout;

#define sipType_QGraphicsEffect sipExportedTypes_QtWidgets[120]

#define sipType_QGraphicsEffect_PixmapPadMode sipExportedTypes_QtWidgets[123]

#define sipType_QGraphicsEffect_ChangeFlag sipExportedTypes_QtWidgets[121]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsEffect;

#define sipType_QGraphicsEffect_ChangeFlags sipExportedTypes_QtWidgets[122]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsEffect_ChangeFlags;

#define sipType_QGraphicsColorizeEffect sipExportedTypes_QtWidgets[118]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsColorizeEffect;

#define sipType_QGraphicsBlurEffect sipExportedTypes_QtWidgets[115]

#define sipType_QGraphicsBlurEffect_BlurHint sipExportedTypes_QtWidgets[116]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsBlurEffect;

#define sipType_QGraphicsBlurEffect_BlurHints sipExportedTypes_QtWidgets[117]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsBlurEffect_BlurHints;

#define sipType_QGraphicsDropShadowEffect sipExportedTypes_QtWidgets[119]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsDropShadowEffect;

#define sipType_QGraphicsOpacityEffect sipExportedTypes_QtWidgets[138]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsOpacityEffect;

#define sipType_QGraphicsGridLayout sipExportedTypes_QtWidgets[125]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsGridLayout;

#define sipType_QGraphicsItem sipExportedTypes_QtWidgets[126]

#define sipType_QGraphicsItem_PanelModality sipExportedTypes_QtWidgets[131]

#define sipType_QGraphicsItem_GraphicsItemFlag sipExportedTypes_QtWidgets[129]

#define sipType_QGraphicsItem_GraphicsItemChange sipExportedTypes_QtWidgets[128]

#define sipType_QGraphicsItem_CacheMode sipExportedTypes_QtWidgets[127]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsItem;

#define sipType_QGraphicsItem_GraphicsItemFlags sipExportedTypes_QtWidgets[130]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsItem_GraphicsItemFlags;

#define sipType_QAbstractGraphicsShapeItem sipExportedTypes_QtWidgets[1]

extern sipClassTypeDef sipTypeDef_QtWidgets_QAbstractGraphicsShapeItem;

#define sipType_QGraphicsPathItem sipExportedTypes_QtWidgets[139]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsPathItem;

#define sipType_QGraphicsRectItem sipExportedTypes_QtWidgets[144]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsRectItem;

#define sipType_QGraphicsEllipseItem sipExportedTypes_QtWidgets[124]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsEllipseItem;

#define sipType_QGraphicsPolygonItem sipExportedTypes_QtWidgets[142]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsPolygonItem;

#define sipType_QGraphicsLineItem sipExportedTypes_QtWidgets[135]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsLineItem;

#define sipType_QGraphicsPixmapItem sipExportedTypes_QtWidgets[140]

#define sipType_QGraphicsPixmapItem_ShapeMode sipExportedTypes_QtWidgets[141]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsPixmapItem;

#define sipType_QGraphicsSimpleTextItem sipExportedTypes_QtWidgets[161]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSimpleTextItem;

#define sipType_QGraphicsItemGroup sipExportedTypes_QtWidgets[132]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsItemGroup;

#define sipType_QGraphicsObject sipExportedTypes_QtWidgets[137]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsObject;

#define sipType_QGraphicsTextItem sipExportedTypes_QtWidgets[162]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsTextItem;

#define sipType_QGraphicsLinearLayout sipExportedTypes_QtWidgets[136]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsLinearLayout;

#define sipType_QGraphicsWidget sipExportedTypes_QtWidgets[172]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsWidget;

#define sipType_QGraphicsProxyWidget sipExportedTypes_QtWidgets[143]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsProxyWidget;

#define sipType_QGraphicsScene sipExportedTypes_QtWidgets[147]

#define sipType_QGraphicsScene_SceneLayer sipExportedTypes_QtWidgets[149]

#define sipType_QGraphicsScene_ItemIndexMethod sipExportedTypes_QtWidgets[148]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsScene;

#define sipType_QGraphicsScene_SceneLayers sipExportedTypes_QtWidgets[150]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsScene_SceneLayers;

#define sipType_QGraphicsSceneEvent sipExportedTypes_QtWidgets[154]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneEvent;

#define sipType_QGraphicsSceneMouseEvent sipExportedTypes_QtWidgets[157]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneMouseEvent;

#define sipType_QGraphicsSceneWheelEvent sipExportedTypes_QtWidgets[160]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneWheelEvent;

#define sipType_QGraphicsSceneContextMenuEvent sipExportedTypes_QtWidgets[151]

#define sipType_QGraphicsSceneContextMenuEvent_Reason sipExportedTypes_QtWidgets[152]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneContextMenuEvent;

#define sipType_QGraphicsSceneHoverEvent sipExportedTypes_QtWidgets[156]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneHoverEvent;

#define sipType_QGraphicsSceneHelpEvent sipExportedTypes_QtWidgets[155]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneHelpEvent;

#define sipType_QGraphicsSceneDragDropEvent sipExportedTypes_QtWidgets[153]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneDragDropEvent;

#define sipType_QGraphicsSceneResizeEvent sipExportedTypes_QtWidgets[159]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneResizeEvent;

#define sipType_QGraphicsSceneMoveEvent sipExportedTypes_QtWidgets[158]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsSceneMoveEvent;

#define sipType_QGraphicsTransform sipExportedTypes_QtWidgets[163]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsTransform;

#define sipType_QGraphicsScale sipExportedTypes_QtWidgets[146]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsScale;

#define sipType_QGraphicsRotation sipExportedTypes_QtWidgets[145]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsRotation;

#define sipType_QGraphicsView sipExportedTypes_QtWidgets[164]

#define sipType_QGraphicsView_OptimizationFlag sipExportedTypes_QtWidgets[168]

#define sipType_QGraphicsView_ViewportUpdateMode sipExportedTypes_QtWidgets[171]

#define sipType_QGraphicsView_ViewportAnchor sipExportedTypes_QtWidgets[170]

#define sipType_QGraphicsView_DragMode sipExportedTypes_QtWidgets[167]

#define sipType_QGraphicsView_CacheModeFlag sipExportedTypes_QtWidgets[166]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsView;

#define sipType_QGraphicsView_CacheMode sipExportedTypes_QtWidgets[165]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsView_CacheMode;

#define sipType_QGraphicsView_OptimizationFlags sipExportedTypes_QtWidgets[169]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGraphicsView_OptimizationFlags;

#define sipType_QGridLayout sipExportedTypes_QtWidgets[173]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGridLayout;

#define sipType_QGroupBox sipExportedTypes_QtWidgets[174]

extern sipClassTypeDef sipTypeDef_QtWidgets_QGroupBox;

#define sipType_QHeaderView sipExportedTypes_QtWidgets[176]

#define sipType_QHeaderView_ResizeMode sipExportedTypes_QtWidgets[177]

extern sipClassTypeDef sipTypeDef_QtWidgets_QHeaderView;

#define sipType_QInputDialog sipExportedTypes_QtWidgets[178]

#define sipType_QInputDialog_InputMode sipExportedTypes_QtWidgets[181]

#define sipType_QInputDialog_InputDialogOption sipExportedTypes_QtWidgets[179]

extern sipClassTypeDef sipTypeDef_QtWidgets_QInputDialog;

#define sipType_QInputDialog_InputDialogOptions sipExportedTypes_QtWidgets[180]

extern sipClassTypeDef sipTypeDef_QtWidgets_QInputDialog_InputDialogOptions;

#define sipType_QItemDelegate sipExportedTypes_QtWidgets[182]

extern sipClassTypeDef sipTypeDef_QtWidgets_QItemDelegate;

#define sipType_QItemEditorCreatorBase sipExportedTypes_QtWidgets[183]

extern sipClassTypeDef sipTypeDef_QtWidgets_QItemEditorCreatorBase;

#define sipType_QItemEditorFactory sipExportedTypes_QtWidgets[184]

extern sipClassTypeDef sipTypeDef_QtWidgets_QItemEditorFactory;

#define sipType_QKeyEventTransition sipExportedTypes_QtWidgets[185]

extern sipClassTypeDef sipTypeDef_QtWidgets_QKeyEventTransition;

#define sipType_QKeySequenceEdit sipExportedTypes_QtWidgets[186]

extern sipClassTypeDef sipTypeDef_QtWidgets_QKeySequenceEdit;

#define sipType_QLabel sipExportedTypes_QtWidgets[190]

extern sipClassTypeDef sipTypeDef_QtWidgets_QLabel;

#define sipType_QSpacerItem sipExportedTypes_QtWidgets[281]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSpacerItem;

#define sipType_QWidgetItem sipExportedTypes_QtWidgets[467]

extern sipClassTypeDef sipTypeDef_QtWidgets_QWidgetItem;

#define sipType_QLCDNumber sipExportedTypes_QtWidgets[187]

#define sipType_QLCDNumber_SegmentStyle sipExportedTypes_QtWidgets[189]

#define sipType_QLCDNumber_Mode sipExportedTypes_QtWidgets[188]

extern sipClassTypeDef sipTypeDef_QtWidgets_QLCDNumber;

#define sipType_QLineEdit sipExportedTypes_QtWidgets[194]

#define sipType_QLineEdit_ActionPosition sipExportedTypes_QtWidgets[195]

#define sipType_QLineEdit_EchoMode sipExportedTypes_QtWidgets[196]

extern sipClassTypeDef sipTypeDef_QtWidgets_QLineEdit;

#define sipType_QListView sipExportedTypes_QtWidgets[216]

#define sipType_QListView_ViewMode sipExportedTypes_QtWidgets[221]

#define sipType_QListView_LayoutMode sipExportedTypes_QtWidgets[218]

#define sipType_QListView_ResizeMode sipExportedTypes_QtWidgets[220]

#define sipType_QListView_Flow sipExportedTypes_QtWidgets[217]

#define sipType_QListView_Movement sipExportedTypes_QtWidgets[219]

extern sipClassTypeDef sipTypeDef_QtWidgets_QListView;

#define sipType_QListWidgetItem sipExportedTypes_QtWidgets[223]

#define sipType_QListWidgetItem_ItemType sipExportedTypes_QtWidgets[224]

extern sipClassTypeDef sipTypeDef_QtWidgets_QListWidgetItem;

#define sipType_QListWidget sipExportedTypes_QtWidgets[222]

extern sipClassTypeDef sipTypeDef_QtWidgets_QListWidget;

#define sipType_QMainWindow sipExportedTypes_QtWidgets[225]

#define sipType_QMainWindow_DockOption sipExportedTypes_QtWidgets[226]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMainWindow;

#define sipType_QMainWindow_DockOptions sipExportedTypes_QtWidgets[227]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMainWindow_DockOptions;

#define sipType_QMdiArea sipExportedTypes_QtWidgets[229]

#define sipType_QMdiArea_WindowOrder sipExportedTypes_QtWidgets[233]

#define sipType_QMdiArea_ViewMode sipExportedTypes_QtWidgets[232]

#define sipType_QMdiArea_AreaOption sipExportedTypes_QtWidgets[230]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMdiArea;

#define sipType_QMdiArea_AreaOptions sipExportedTypes_QtWidgets[231]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMdiArea_AreaOptions;

#define sipType_QMdiSubWindow sipExportedTypes_QtWidgets[234]

#define sipType_QMdiSubWindow_SubWindowOption sipExportedTypes_QtWidgets[235]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMdiSubWindow;

#define sipType_QMdiSubWindow_SubWindowOptions sipExportedTypes_QtWidgets[236]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMdiSubWindow_SubWindowOptions;

#define sipType_QMenu sipExportedTypes_QtWidgets[237]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMenu;

#define sipType_QMenuBar sipExportedTypes_QtWidgets[238]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMenuBar;

#define sipType_QMessageBox sipExportedTypes_QtWidgets[239]

#define sipType_QMessageBox_StandardButton sipExportedTypes_QtWidgets[242]

#define sipType_QMessageBox_Icon sipExportedTypes_QtWidgets[241]

#define sipType_QMessageBox_ButtonRole sipExportedTypes_QtWidgets[240]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMessageBox;

#define sipType_QMessageBox_StandardButtons sipExportedTypes_QtWidgets[243]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMessageBox_StandardButtons;

#define sipType_QMouseEventTransition sipExportedTypes_QtWidgets[244]

extern sipClassTypeDef sipTypeDef_QtWidgets_QMouseEventTransition;

#define sipType_QOpenGLWidget sipExportedTypes_QtWidgets[245]

#define sipType_QOpenGLWidget_UpdateBehavior sipExportedTypes_QtWidgets[246]

extern sipClassTypeDef sipTypeDef_QtWidgets_QOpenGLWidget;

#define sipType_QPlainTextEdit sipExportedTypes_QtWidgets[252]

#define sipType_QPlainTextEdit_LineWrapMode sipExportedTypes_QtWidgets[253]

extern sipClassTypeDef sipTypeDef_QtWidgets_QPlainTextEdit;

#define sipType_QPlainTextDocumentLayout sipExportedTypes_QtWidgets[251]

extern sipClassTypeDef sipTypeDef_QtWidgets_QPlainTextDocumentLayout;

#define sipType_QProgressBar sipExportedTypes_QtWidgets[254]

#define sipType_QProgressBar_Direction sipExportedTypes_QtWidgets[255]

extern sipClassTypeDef sipTypeDef_QtWidgets_QProgressBar;

#define sipType_QProgressDialog sipExportedTypes_QtWidgets[256]

extern sipClassTypeDef sipTypeDef_QtWidgets_QProgressDialog;

#define sipType_QProxyStyle sipExportedTypes_QtWidgets[257]

extern sipClassTypeDef sipTypeDef_QtWidgets_QProxyStyle;

#define sipType_QRadioButton sipExportedTypes_QtWidgets[259]

extern sipClassTypeDef sipTypeDef_QtWidgets_QRadioButton;

#define sipType_QRubberBand sipExportedTypes_QtWidgets[260]

#define sipType_QRubberBand_Shape sipExportedTypes_QtWidgets[261]

extern sipClassTypeDef sipTypeDef_QtWidgets_QRubberBand;

#define sipType_QScrollArea sipExportedTypes_QtWidgets[262]

extern sipClassTypeDef sipTypeDef_QtWidgets_QScrollArea;

#define sipType_QScrollBar sipExportedTypes_QtWidgets[263]

extern sipClassTypeDef sipTypeDef_QtWidgets_QScrollBar;

#define sipType_QScroller sipExportedTypes_QtWidgets[264]

#define sipType_QScroller_Input sipExportedTypes_QtWidgets[265]

#define sipType_QScroller_ScrollerGestureType sipExportedTypes_QtWidgets[266]

#define sipType_QScroller_State sipExportedTypes_QtWidgets[267]

extern sipClassTypeDef sipTypeDef_QtWidgets_QScroller;

#define sipType_QScrollerProperties sipExportedTypes_QtWidgets[268]

#define sipType_QScrollerProperties_ScrollMetric sipExportedTypes_QtWidgets[271]

#define sipType_QScrollerProperties_FrameRates sipExportedTypes_QtWidgets[269]

#define sipType_QScrollerProperties_OvershootPolicy sipExportedTypes_QtWidgets[270]

extern sipClassTypeDef sipTypeDef_QtWidgets_QScrollerProperties;

#define sipType_QShortcut sipExportedTypes_QtWidgets[272]

extern sipClassTypeDef sipTypeDef_QtWidgets_QShortcut;

#define sipType_QSizeGrip sipExportedTypes_QtWidgets[273]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSizeGrip;

#define sipType_QSizePolicy sipExportedTypes_QtWidgets[274]

#define sipType_QSizePolicy_ControlType sipExportedTypes_QtWidgets[275]

#define sipType_QSizePolicy_Policy sipExportedTypes_QtWidgets[277]

#define sipType_QSizePolicy_PolicyFlag sipExportedTypes_QtWidgets[278]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSizePolicy;

#define sipType_QSizePolicy_ControlTypes sipExportedTypes_QtWidgets[276]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSizePolicy_ControlTypes;

#define sipType_QSlider sipExportedTypes_QtWidgets[279]

#define sipType_QSlider_TickPosition sipExportedTypes_QtWidgets[280]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSlider;

#define sipType_QSpinBox sipExportedTypes_QtWidgets[282]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSpinBox;

#define sipType_QDoubleSpinBox sipExportedTypes_QtWidgets[74]

extern sipClassTypeDef sipTypeDef_QtWidgets_QDoubleSpinBox;

#define sipType_QSplashScreen sipExportedTypes_QtWidgets[283]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSplashScreen;

#define sipType_QSplitter sipExportedTypes_QtWidgets[284]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSplitter;

#define sipType_QSplitterHandle sipExportedTypes_QtWidgets[285]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSplitterHandle;

#define sipType_QStackedLayout sipExportedTypes_QtWidgets[286]

#define sipType_QStackedLayout_StackingMode sipExportedTypes_QtWidgets[287]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStackedLayout;

#define sipType_QStackedWidget sipExportedTypes_QtWidgets[288]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStackedWidget;

#define sipType_QStatusBar sipExportedTypes_QtWidgets[289]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStatusBar;

#define sipType_QStyle_State sipExportedTypes_QtWidgets[298]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyle_State;

#define sipType_QStyle_SubControls sipExportedTypes_QtWidgets[302]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyle_SubControls;

#define sipType_QStyledItemDelegate sipExportedTypes_QtWidgets[417]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyledItemDelegate;

#define sipType_QStyleFactory sipExportedTypes_QtWidgets[304]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleFactory;

#define sipType_QStyleOption sipExportedTypes_QtWidgets[315]

#define sipType_QStyleOption_StyleOptionVersion sipExportedTypes_QtWidgets[318]

#define sipType_QStyleOption_StyleOptionType sipExportedTypes_QtWidgets[317]

#define sipType_QStyleOption_OptionType sipExportedTypes_QtWidgets[316]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOption;

#define sipType_QStyleOptionFocusRect sipExportedTypes_QtWidgets[333]

#define sipType_QStyleOptionFocusRect_StyleOptionVersion sipExportedTypes_QtWidgets[335]

#define sipType_QStyleOptionFocusRect_StyleOptionType sipExportedTypes_QtWidgets[334]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionFocusRect;

#define sipType_QStyleOptionFrame sipExportedTypes_QtWidgets[336]

#define sipType_QStyleOptionFrame_FrameFeature sipExportedTypes_QtWidgets[337]

#define sipType_QStyleOptionFrame_StyleOptionVersion sipExportedTypes_QtWidgets[340]

#define sipType_QStyleOptionFrame_StyleOptionType sipExportedTypes_QtWidgets[339]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionFrame;

#define sipType_QStyleOptionFrame_FrameFeatures sipExportedTypes_QtWidgets[338]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionFrame_FrameFeatures;

#define sipType_QStyleOptionTabWidgetFrame sipExportedTypes_QtWidgets[387]

#define sipType_QStyleOptionTabWidgetFrame_StyleOptionVersion sipExportedTypes_QtWidgets[389]

#define sipType_QStyleOptionTabWidgetFrame_StyleOptionType sipExportedTypes_QtWidgets[388]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTabWidgetFrame;

#define sipType_QStyleOptionTabBarBase sipExportedTypes_QtWidgets[382]

#define sipType_QStyleOptionTabBarBase_StyleOptionVersion sipExportedTypes_QtWidgets[384]

#define sipType_QStyleOptionTabBarBase_StyleOptionType sipExportedTypes_QtWidgets[383]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTabBarBase;

#define sipType_QStyleOptionHeader sipExportedTypes_QtWidgets[347]

#define sipType_QStyleOptionHeader_SortIndicator sipExportedTypes_QtWidgets[350]

#define sipType_QStyleOptionHeader_SelectedPosition sipExportedTypes_QtWidgets[349]

#define sipType_QStyleOptionHeader_SectionPosition sipExportedTypes_QtWidgets[348]

#define sipType_QStyleOptionHeader_StyleOptionVersion sipExportedTypes_QtWidgets[352]

#define sipType_QStyleOptionHeader_StyleOptionType sipExportedTypes_QtWidgets[351]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionHeader;

#define sipType_QStyleOptionButton sipExportedTypes_QtWidgets[319]

#define sipType_QStyleOptionButton_ButtonFeature sipExportedTypes_QtWidgets[320]

#define sipType_QStyleOptionButton_StyleOptionVersion sipExportedTypes_QtWidgets[323]

#define sipType_QStyleOptionButton_StyleOptionType sipExportedTypes_QtWidgets[322]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionButton;

#define sipType_QStyleOptionButton_ButtonFeatures sipExportedTypes_QtWidgets[321]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionButton_ButtonFeatures;

#define sipType_QStyleOptionTab sipExportedTypes_QtWidgets[373]

#define sipType_QStyleOptionTab_TabFeature sipExportedTypes_QtWidgets[379]

#define sipType_QStyleOptionTab_CornerWidget sipExportedTypes_QtWidgets[374]

#define sipType_QStyleOptionTab_SelectedPosition sipExportedTypes_QtWidgets[376]

#define sipType_QStyleOptionTab_TabPosition sipExportedTypes_QtWidgets[381]

#define sipType_QStyleOptionTab_StyleOptionVersion sipExportedTypes_QtWidgets[378]

#define sipType_QStyleOptionTab_StyleOptionType sipExportedTypes_QtWidgets[377]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTab;

#define sipType_QStyleOptionTab_CornerWidgets sipExportedTypes_QtWidgets[375]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTab_CornerWidgets;

#define sipType_QStyleOptionTab_TabFeatures sipExportedTypes_QtWidgets[380]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTab_TabFeatures;

#define sipType_QStyleOptionTabV4 sipExportedTypes_QtWidgets[385]

#define sipType_QStyleOptionTabV4_StyleOptionVersion sipExportedTypes_QtWidgets[386]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTabV4;

#define sipType_QStyleOptionProgressBar sipExportedTypes_QtWidgets[358]

#define sipType_QStyleOptionProgressBar_StyleOptionVersion sipExportedTypes_QtWidgets[360]

#define sipType_QStyleOptionProgressBar_StyleOptionType sipExportedTypes_QtWidgets[359]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionProgressBar;

#define sipType_QStyleOptionMenuItem sipExportedTypes_QtWidgets[353]

#define sipType_QStyleOptionMenuItem_CheckType sipExportedTypes_QtWidgets[354]

#define sipType_QStyleOptionMenuItem_MenuItemType sipExportedTypes_QtWidgets[355]

#define sipType_QStyleOptionMenuItem_StyleOptionVersion sipExportedTypes_QtWidgets[357]

#define sipType_QStyleOptionMenuItem_StyleOptionType sipExportedTypes_QtWidgets[356]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionMenuItem;

#define sipType_QStyleOptionDockWidget sipExportedTypes_QtWidgets[330]

#define sipType_QStyleOptionDockWidget_StyleOptionVersion sipExportedTypes_QtWidgets[332]

#define sipType_QStyleOptionDockWidget_StyleOptionType sipExportedTypes_QtWidgets[331]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionDockWidget;

#define sipType_QStyleOptionViewItem sipExportedTypes_QtWidgets[409]

#define sipType_QStyleOptionViewItem_ViewItemPosition sipExportedTypes_QtWidgets[415]

#define sipType_QStyleOptionViewItem_ViewItemFeature sipExportedTypes_QtWidgets[413]

#define sipType_QStyleOptionViewItem_Position sipExportedTypes_QtWidgets[410]

#define sipType_QStyleOptionViewItem_StyleOptionVersion sipExportedTypes_QtWidgets[412]

#define sipType_QStyleOptionViewItem_StyleOptionType sipExportedTypes_QtWidgets[411]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionViewItem;

#define sipType_QStyleOptionViewItem_ViewItemFeatures sipExportedTypes_QtWidgets[414]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionViewItem_ViewItemFeatures;

#define sipType_QStyleOptionToolBox sipExportedTypes_QtWidgets[399]

#define sipType_QStyleOptionToolBox_SelectedPosition sipExportedTypes_QtWidgets[400]

#define sipType_QStyleOptionToolBox_TabPosition sipExportedTypes_QtWidgets[403]

#define sipType_QStyleOptionToolBox_StyleOptionVersion sipExportedTypes_QtWidgets[402]

#define sipType_QStyleOptionToolBox_StyleOptionType sipExportedTypes_QtWidgets[401]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionToolBox;

#define sipType_QStyleOptionRubberBand sipExportedTypes_QtWidgets[361]

#define sipType_QStyleOptionRubberBand_StyleOptionVersion sipExportedTypes_QtWidgets[363]

#define sipType_QStyleOptionRubberBand_StyleOptionType sipExportedTypes_QtWidgets[362]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionRubberBand;

#define sipType_QStyleOptionComplex sipExportedTypes_QtWidgets[327]

#define sipType_QStyleOptionComplex_StyleOptionVersion sipExportedTypes_QtWidgets[329]

#define sipType_QStyleOptionComplex_StyleOptionType sipExportedTypes_QtWidgets[328]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionComplex;

#define sipType_QStyleOptionSlider sipExportedTypes_QtWidgets[367]

#define sipType_QStyleOptionSlider_StyleOptionVersion sipExportedTypes_QtWidgets[369]

#define sipType_QStyleOptionSlider_StyleOptionType sipExportedTypes_QtWidgets[368]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionSlider;

#define sipType_QStyleOptionSpinBox sipExportedTypes_QtWidgets[370]

#define sipType_QStyleOptionSpinBox_StyleOptionVersion sipExportedTypes_QtWidgets[372]

#define sipType_QStyleOptionSpinBox_StyleOptionType sipExportedTypes_QtWidgets[371]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionSpinBox;

#define sipType_QStyleOptionToolButton sipExportedTypes_QtWidgets[404]

#define sipType_QStyleOptionToolButton_ToolButtonFeature sipExportedTypes_QtWidgets[407]

#define sipType_QStyleOptionToolButton_StyleOptionVersion sipExportedTypes_QtWidgets[406]

#define sipType_QStyleOptionToolButton_StyleOptionType sipExportedTypes_QtWidgets[405]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionToolButton;

#define sipType_QStyleOptionToolButton_ToolButtonFeatures sipExportedTypes_QtWidgets[408]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionToolButton_ToolButtonFeatures;

#define sipType_QStyleOptionComboBox sipExportedTypes_QtWidgets[324]

#define sipType_QStyleOptionComboBox_StyleOptionVersion sipExportedTypes_QtWidgets[326]

#define sipType_QStyleOptionComboBox_StyleOptionType sipExportedTypes_QtWidgets[325]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionComboBox;

#define sipType_QStyleOptionTitleBar sipExportedTypes_QtWidgets[390]

#define sipType_QStyleOptionTitleBar_StyleOptionVersion sipExportedTypes_QtWidgets[392]

#define sipType_QStyleOptionTitleBar_StyleOptionType sipExportedTypes_QtWidgets[391]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionTitleBar;

#define sipType_QStyleHintReturn sipExportedTypes_QtWidgets[305]

#define sipType_QStyleHintReturn_StyleOptionVersion sipExportedTypes_QtWidgets[308]

#define sipType_QStyleHintReturn_StyleOptionType sipExportedTypes_QtWidgets[307]

#define sipType_QStyleHintReturn_HintReturnType sipExportedTypes_QtWidgets[306]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleHintReturn;

#define sipType_QStyleHintReturnMask sipExportedTypes_QtWidgets[309]

#define sipType_QStyleHintReturnMask_StyleOptionVersion sipExportedTypes_QtWidgets[311]

#define sipType_QStyleHintReturnMask_StyleOptionType sipExportedTypes_QtWidgets[310]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleHintReturnMask;

#define sipType_QStyleOptionToolBar sipExportedTypes_QtWidgets[393]

#define sipType_QStyleOptionToolBar_ToolBarFeature sipExportedTypes_QtWidgets[396]

#define sipType_QStyleOptionToolBar_ToolBarPosition sipExportedTypes_QtWidgets[398]

#define sipType_QStyleOptionToolBar_StyleOptionVersion sipExportedTypes_QtWidgets[395]

#define sipType_QStyleOptionToolBar_StyleOptionType sipExportedTypes_QtWidgets[394]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionToolBar;

#define sipType_QStyleOptionToolBar_ToolBarFeatures sipExportedTypes_QtWidgets[397]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionToolBar_ToolBarFeatures;

#define sipType_QStyleOptionGroupBox sipExportedTypes_QtWidgets[344]

#define sipType_QStyleOptionGroupBox_StyleOptionVersion sipExportedTypes_QtWidgets[346]

#define sipType_QStyleOptionGroupBox_StyleOptionType sipExportedTypes_QtWidgets[345]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionGroupBox;

#define sipType_QStyleOptionSizeGrip sipExportedTypes_QtWidgets[364]

#define sipType_QStyleOptionSizeGrip_StyleOptionVersion sipExportedTypes_QtWidgets[366]

#define sipType_QStyleOptionSizeGrip_StyleOptionType sipExportedTypes_QtWidgets[365]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionSizeGrip;

#define sipType_QStyleOptionGraphicsItem sipExportedTypes_QtWidgets[341]

#define sipType_QStyleOptionGraphicsItem_StyleOptionVersion sipExportedTypes_QtWidgets[343]

#define sipType_QStyleOptionGraphicsItem_StyleOptionType sipExportedTypes_QtWidgets[342]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleOptionGraphicsItem;

#define sipType_QStyleHintReturnVariant sipExportedTypes_QtWidgets[312]

#define sipType_QStyleHintReturnVariant_StyleOptionVersion sipExportedTypes_QtWidgets[314]

#define sipType_QStyleHintReturnVariant_StyleOptionType sipExportedTypes_QtWidgets[313]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStyleHintReturnVariant;

#define sipType_QStylePainter sipExportedTypes_QtWidgets[416]

extern sipClassTypeDef sipTypeDef_QtWidgets_QStylePainter;

#define sipType_QSystemTrayIcon sipExportedTypes_QtWidgets[420]

#define sipType_QSystemTrayIcon_MessageIcon sipExportedTypes_QtWidgets[422]

#define sipType_QSystemTrayIcon_ActivationReason sipExportedTypes_QtWidgets[421]

extern sipClassTypeDef sipTypeDef_QtWidgets_QSystemTrayIcon;

#define sipType_QTabBar sipExportedTypes_QtWidgets[423]

#define sipType_QTabBar_SelectionBehavior sipExportedTypes_QtWidgets[425]

#define sipType_QTabBar_ButtonPosition sipExportedTypes_QtWidgets[424]

#define sipType_QTabBar_Shape sipExportedTypes_QtWidgets[426]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTabBar;

#define sipType_QTableView sipExportedTypes_QtWidgets[430]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTableView;

#define sipType_QTableWidgetSelectionRange sipExportedTypes_QtWidgets[434]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTableWidgetSelectionRange;

#define sipType_QTableWidgetItem sipExportedTypes_QtWidgets[432]

#define sipType_QTableWidgetItem_ItemType sipExportedTypes_QtWidgets[433]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTableWidgetItem;

#define sipType_QTableWidget sipExportedTypes_QtWidgets[431]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTableWidget;

#define sipType_QTabWidget sipExportedTypes_QtWidgets[427]

#define sipType_QTabWidget_TabShape sipExportedTypes_QtWidgets[429]

#define sipType_QTabWidget_TabPosition sipExportedTypes_QtWidgets[428]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTabWidget;

#define sipType_QTextEdit sipExportedTypes_QtWidgets[438]

#define sipType_QTextEdit_AutoFormattingFlag sipExportedTypes_QtWidgets[440]

#define sipType_QTextEdit_LineWrapMode sipExportedTypes_QtWidgets[442]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTextEdit;

#define sipType_QTextBrowser sipExportedTypes_QtWidgets[437]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTextBrowser;

#define sipType_QTextEdit_ExtraSelection sipExportedTypes_QtWidgets[441]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTextEdit_ExtraSelection;

#define sipType_QTextEdit_AutoFormatting sipExportedTypes_QtWidgets[439]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTextEdit_AutoFormatting;

#define sipType_QToolBar sipExportedTypes_QtWidgets[444]

extern sipClassTypeDef sipTypeDef_QtWidgets_QToolBar;

#define sipType_QToolBox sipExportedTypes_QtWidgets[445]

extern sipClassTypeDef sipTypeDef_QtWidgets_QToolBox;

#define sipType_QToolButton sipExportedTypes_QtWidgets[446]

#define sipType_QToolButton_ToolButtonPopupMode sipExportedTypes_QtWidgets[447]

extern sipClassTypeDef sipTypeDef_QtWidgets_QToolButton;

#define sipType_QToolTip sipExportedTypes_QtWidgets[448]

extern sipClassTypeDef sipTypeDef_QtWidgets_QToolTip;

#define sipType_QTreeView sipExportedTypes_QtWidgets[449]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTreeView;

#define sipType_QTreeWidgetItem sipExportedTypes_QtWidgets[451]

#define sipType_QTreeWidgetItem_ChildIndicatorPolicy sipExportedTypes_QtWidgets[452]

#define sipType_QTreeWidgetItem_ItemType sipExportedTypes_QtWidgets[453]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTreeWidgetItem;

#define sipType_QTreeWidget sipExportedTypes_QtWidgets[450]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTreeWidget;

#define sipType_QTreeWidgetItemIterator sipExportedTypes_QtWidgets[454]

#define sipType_QTreeWidgetItemIterator_IteratorFlag sipExportedTypes_QtWidgets[455]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTreeWidgetItemIterator;

#define sipType_QTreeWidgetItemIterator_IteratorFlags sipExportedTypes_QtWidgets[456]

extern sipClassTypeDef sipTypeDef_QtWidgets_QTreeWidgetItemIterator_IteratorFlags;

#define sipType_QUndoGroup sipExportedTypes_QtWidgets[458]

extern sipClassTypeDef sipTypeDef_QtWidgets_QUndoGroup;

#define sipType_QUndoCommand sipExportedTypes_QtWidgets[457]

extern sipClassTypeDef sipTypeDef_QtWidgets_QUndoCommand;

#define sipType_QUndoStack sipExportedTypes_QtWidgets[459]

extern sipClassTypeDef sipTypeDef_QtWidgets_QUndoStack;

#define sipType_QUndoView sipExportedTypes_QtWidgets[460]

extern sipClassTypeDef sipTypeDef_QtWidgets_QUndoView;

#define sipType_QWhatsThis sipExportedTypes_QtWidgets[462]

extern sipClassTypeDef sipTypeDef_QtWidgets_QWhatsThis;

#define sipType_QWidget_RenderFlags sipExportedTypes_QtWidgets[465]

extern sipClassTypeDef sipTypeDef_QtWidgets_QWidget_RenderFlags;

#define sipType_QWidgetAction sipExportedTypes_QtWidgets[466]

extern sipClassTypeDef sipTypeDef_QtWidgets_QWidgetAction;

#define sipType_QWizard sipExportedTypes_QtWidgets[468]

#define sipType_QWizard_WizardOption sipExportedTypes_QtWidgets[470]

#define sipType_QWizard_WizardStyle sipExportedTypes_QtWidgets[473]

#define sipType_QWizard_WizardPixmap sipExportedTypes_QtWidgets[472]

#define sipType_QWizard_WizardButton sipExportedTypes_QtWidgets[469]

extern sipClassTypeDef sipTypeDef_QtWidgets_QWizard;

#define sipType_QWizard_WizardOptions sipExportedTypes_QtWidgets[471]

extern sipClassTypeDef sipTypeDef_QtWidgets_QWizard_WizardOptions;

#define sipType_QWizardPage sipExportedTypes_QtWidgets[474]

extern sipClassTypeDef sipTypeDef_QtWidgets_QWizardPage;

#define sipType_QList_0101QUndoStack sipExportedTypes_QtWidgets[213]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QUndoStack;

#define sipType_QList_0101QTreeWidgetItem sipExportedTypes_QtWidgets[212]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QTreeWidgetItem;

#define sipType_QList_0101QTableWidgetItem sipExportedTypes_QtWidgets[209]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QTableWidgetItem;

#define sipType_QList_0100QTableWidgetSelectionRange sipExportedTypes_QtWidgets[210]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0100QTableWidgetSelectionRange;

#define sipType_QList_0101QScroller sipExportedTypes_QtWidgets[208]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QScroller;

#define sipType_QList_0100QTextEdit_ExtraSelection sipExportedTypes_QtWidgets[211]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0100QTextEdit_ExtraSelection;

#define sipType_QList_0101QMdiSubWindow sipExportedTypes_QtWidgets[206]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QMdiSubWindow;

#define sipType_QList_0101QDockWidget sipExportedTypes_QtWidgets[199]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QDockWidget;

#define sipType_QList_0101QListWidgetItem sipExportedTypes_QtWidgets[205]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QListWidgetItem;

#define sipType_QList_0100QRectF sipExportedTypes_QtWidgets[207]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0100QRectF;

#define sipType_QList_0101QGraphicsView sipExportedTypes_QtWidgets[203]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QGraphicsView;

#define sipType_QList_0101QGraphicsTransform sipExportedTypes_QtWidgets[202]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QGraphicsTransform;

#define sipType_QList_0101QGraphicsItem sipExportedTypes_QtWidgets[201]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QGraphicsItem;

#define sipType_QList_0101QGesture sipExportedTypes_QtWidgets[200]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QGesture;

#define sipType_QMap_0100QDate_0100QTextCharFormat sipExportedTypes_QtWidgets[228]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QMap_0100QDate_0100QTextCharFormat;

#define sipType_QList_0101QAbstractButton sipExportedTypes_QtWidgets[197]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QAbstractButton;

#define sipType_QList_0101QGraphicsWidget sipExportedTypes_QtWidgets[204]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QGraphicsWidget;

#define sipType_QList_0101QAction sipExportedTypes_QtWidgets[198]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QAction;

#define sipType_QList_0101QWidget sipExportedTypes_QtWidgets[214]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0101QWidget;

#define sipType_QList_0100QWizard_WizardButton sipExportedTypes_QtWidgets[215]

extern sipMappedTypeDef sipTypeDef_QtWidgets_QList_0100QWizard_WizardButton;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtWidgets;
extern sipExportedModuleDef sipModuleAPI_QtWidgets;
extern sipTypeDef *sipExportedTypes_QtWidgets[];

#define sipType_Qt_ItemSelectionOperation sipImportedTypes_QtWidgets_QtCore[79].it_td

#define sipType_Qt_MouseEventSource sipImportedTypes_QtWidgets_QtCore[86].it_td

#define sipType_Qt_HitTestAccuracy sipImportedTypes_QtWidgets_QtCore[74].it_td

#define sipType_Qt_CursorMoveStyle sipImportedTypes_QtWidgets_QtCore[61].it_td

#define sipType_Qt_GestureType sipImportedTypes_QtWidgets_QtCore[73].it_td

#define sipType_Qt_GestureState sipImportedTypes_QtWidgets_QtCore[72].it_td

#define sipType_Qt_CoordinateSystem sipImportedTypes_QtWidgets_QtCore[59].it_td

#define sipType_Qt_AnchorPoint sipImportedTypes_QtWidgets_QtCore[52].it_td

#define sipType_Qt_WindowFrameSection sipImportedTypes_QtWidgets_QtCore[105].it_td

#define sipType_Qt_SizeHint sipImportedTypes_QtWidgets_QtCore[92].it_td

#define sipType_Qt_Axis sipImportedTypes_QtWidgets_QtCore[55].it_td

#define sipType_Qt_ItemSelectionMode sipImportedTypes_QtWidgets_QtCore[78].it_td

#define sipType_Qt_WindowModality sipImportedTypes_QtWidgets_QtCore[106].it_td

#define sipType_Qt_CheckState sipImportedTypes_QtWidgets_QtCore[57].it_td

#define sipType_Qt_DropAction sipImportedTypes_QtWidgets_QtCore[65].it_td

#define sipType_Qt_LayoutDirection sipImportedTypes_QtWidgets_QtCore[81].it_td

#define sipType_Qt_ToolButtonStyle sipImportedTypes_QtWidgets_QtCore[100].it_td

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtWidgets_QtCore[76].it_td

#define sipType_Qt_ContextMenuPolicy sipImportedTypes_QtWidgets_QtCore[58].it_td

#define sipType_Qt_FocusReason sipImportedTypes_QtWidgets_QtCore[70].it_td

#define sipType_Qt_TransformationMode sipImportedTypes_QtWidgets_QtCore[101].it_td

#define sipType_Qt_FillRule sipImportedTypes_QtWidgets_QtCore[67].it_td

#define sipType_Qt_ShortcutContext sipImportedTypes_QtWidgets_QtCore[91].it_td

#define sipType_Qt_Corner sipImportedTypes_QtWidgets_QtCore[60].it_td

#define sipType_Qt_CaseSensitivity sipImportedTypes_QtWidgets_QtCore[56].it_td

#define sipType_Qt_ScrollBarPolicy sipImportedTypes_QtWidgets_QtCore[90].it_td

#define sipType_Qt_DayOfWeek sipImportedTypes_QtWidgets_QtCore[62].it_td

#define sipType_Qt_TimeSpec sipImportedTypes_QtWidgets_QtCore[97].it_td

#define sipType_Qt_ToolBarArea sipImportedTypes_QtWidgets_QtCore[98].it_td

#define sipType_Qt_DockWidgetArea sipImportedTypes_QtWidgets_QtCore[63].it_td

#define sipType_Qt_AspectRatioMode sipImportedTypes_QtWidgets_QtCore[54].it_td

#define sipType_Qt_TextFormat sipImportedTypes_QtWidgets_QtCore[95].it_td

#define sipType_Qt_UIEffect sipImportedTypes_QtWidgets_QtCore[102].it_td

#define sipType_Qt_PenStyle sipImportedTypes_QtWidgets_QtCore[89].it_td

#define sipType_Qt_ArrowType sipImportedTypes_QtWidgets_QtCore[53].it_td

#define sipType_Qt_WidgetAttribute sipImportedTypes_QtWidgets_QtCore[103].it_td

#define sipType_Qt_WindowType sipImportedTypes_QtWidgets_QtCore[108].it_td

#define sipType_Qt_TextElideMode sipImportedTypes_QtWidgets_QtCore[94].it_td

#define sipType_Qt_SortOrder sipImportedTypes_QtWidgets_QtCore[93].it_td

#define sipType_Qt_FocusPolicy sipImportedTypes_QtWidgets_QtCore[69].it_td

#define sipType_Qt_Orientation sipImportedTypes_QtWidgets_QtCore[87].it_td

#define sipType_Qt_MouseButton sipImportedTypes_QtWidgets_QtCore[83].it_td

#define sipType_Qt_KeyboardModifiers sipImportedTypes_QtWidgets_QtCore[80].it_td

#define sipType_Qt_MouseButtons sipImportedTypes_QtWidgets_QtCore[84].it_td

#define sipType_Qt_Orientations sipImportedTypes_QtWidgets_QtCore[88].it_td

#define sipType_Qt_Alignment sipImportedTypes_QtWidgets_QtCore[51].it_td

#define sipType_Qt_WindowFlags sipImportedTypes_QtWidgets_QtCore[104].it_td

#define sipType_Qt_WindowStates sipImportedTypes_QtWidgets_QtCore[107].it_td

#define sipType_Qt_DockWidgetAreas sipImportedTypes_QtWidgets_QtCore[64].it_td

#define sipType_Qt_ToolBarAreas sipImportedTypes_QtWidgets_QtCore[99].it_td

#define sipType_Qt_DropActions sipImportedTypes_QtWidgets_QtCore[66].it_td

#define sipType_Qt_ItemFlags sipImportedTypes_QtWidgets_QtCore[77].it_td

#define sipType_Qt_MatchFlags sipImportedTypes_QtWidgets_QtCore[82].it_td

#define sipType_Qt_TextInteractionFlags sipImportedTypes_QtWidgets_QtCore[96].it_td

#define sipType_Qt_InputMethodHints sipImportedTypes_QtWidgets_QtCore[75].it_td

#define sipType_Qt_GestureFlags sipImportedTypes_QtWidgets_QtCore[71].it_td

#define sipType_Qt_FindChildOptions sipImportedTypes_QtWidgets_QtCore[68].it_td

#define sipType_Qt_MouseEventFlags sipImportedTypes_QtWidgets_QtCore[85].it_td

#define sipType_QObject sipImportedTypes_QtWidgets_QtCore[34].it_td

#define sipType_QModelIndex sipImportedTypes_QtWidgets_QtCore[33].it_td

#define sipType_QAbstractItemModel sipImportedTypes_QtWidgets_QtCore[0].it_td

#define sipType_QAbstractProxyModel sipImportedTypes_QtWidgets_QtCore[1].it_td

#define sipType_QAbstractTransition sipImportedTypes_QtWidgets_QtCore[2].it_td

#define sipType_QByteArray sipImportedTypes_QtWidgets_QtCore[3].it_td

#define sipType_QCalendar sipImportedTypes_QtWidgets_QtCore[4].it_td

#define sipType_QCoreApplication sipImportedTypes_QtWidgets_QtCore[6].it_td

#define sipType_QEvent sipImportedTypes_QtWidgets_QtCore[13].it_td

#define sipType_QEvent_Type sipImportedTypes_QtWidgets_QtCore[14].it_td

#define sipType_QTimerEvent sipImportedTypes_QtWidgets_QtCore[47].it_td

#define sipType_QChildEvent sipImportedTypes_QtWidgets_QtCore[5].it_td

#define sipType_QDataStream sipImportedTypes_QtWidgets_QtCore[7].it_td

#define sipType_QDate sipImportedTypes_QtWidgets_QtCore[8].it_td

#define sipType_QTime sipImportedTypes_QtWidgets_QtCore[46].it_td

#define sipType_QDateTime sipImportedTypes_QtWidgets_QtCore[9].it_td

#define sipType_QDir sipImportedTypes_QtWidgets_QtCore[10].it_td

#define sipType_QDir_Filters sipImportedTypes_QtWidgets_QtCore[11].it_td

#define sipType_QDir_SortFlags sipImportedTypes_QtWidgets_QtCore[12].it_td

#define sipType_QEventTransition sipImportedTypes_QtWidgets_QtCore[15].it_td

#define sipType_QFileDevice_Permissions sipImportedTypes_QtWidgets_QtCore[16].it_td

#define sipType_QFileInfo sipImportedTypes_QtWidgets_QtCore[17].it_td

#define sipType_QItemSelectionModel sipImportedTypes_QtWidgets_QtCore[20].it_td

#define sipType_QItemSelectionModel_SelectionFlags sipImportedTypes_QtWidgets_QtCore[21].it_td

#define sipType_QItemSelection sipImportedTypes_QtWidgets_QtCore[19].it_td

#define sipType_QLineF sipImportedTypes_QtWidgets_QtCore[22].it_td

#define sipType_QLocale sipImportedTypes_QtWidgets_QtCore[27].it_td

#define sipType_QMargins sipImportedTypes_QtWidgets_QtCore[29].it_td

#define sipType_QMarginsF sipImportedTypes_QtWidgets_QtCore[30].it_td

#define sipType_QMetaMethod sipImportedTypes_QtWidgets_QtCore[31].it_td

#define sipType_QMimeData sipImportedTypes_QtWidgets_QtCore[32].it_td

#define sipType_QPoint sipImportedTypes_QtWidgets_QtCore[35].it_td

#define sipType_QPointF sipImportedTypes_QtWidgets_QtCore[36].it_td

#define sipType_QRect sipImportedTypes_QtWidgets_QtCore[37].it_td

#define sipType_QRectF sipImportedTypes_QtWidgets_QtCore[38].it_td

#define sipType_QRegExp sipImportedTypes_QtWidgets_QtCore[39].it_td

#define sipType_QRegularExpression sipImportedTypes_QtWidgets_QtCore[40].it_td

#define sipType_QSize sipImportedTypes_QtWidgets_QtCore[41].it_td

#define sipType_QSizeF sipImportedTypes_QtWidgets_QtCore[42].it_td

#define sipType_QState sipImportedTypes_QtWidgets_QtCore[43].it_td

#define sipType_QUrl sipImportedTypes_QtWidgets_QtCore[48].it_td

#define sipType_QVariant sipImportedTypes_QtWidgets_QtCore[49].it_td

#define sipType_QList_0100QUrl sipImportedTypes_QtWidgets_QtCore[24].it_td

#define sipType_QHash_1800_0100QByteArray sipImportedTypes_QtWidgets_QtCore[18].it_td

#define sipType_QMap_1800_0100QVariant sipImportedTypes_QtWidgets_QtCore[28].it_td

#define sipType_QList_0100QModelIndex sipImportedTypes_QtWidgets_QtCore[23].it_td

#define sipType_QVector_1800 sipImportedTypes_QtWidgets_QtCore[50].it_td

#define sipType_QStringList sipImportedTypes_QtWidgets_QtCore[45].it_td

#define sipType_QList_2400 sipImportedTypes_QtWidgets_QtCore[26].it_td

#define sipType_QList_1800 sipImportedTypes_QtWidgets_QtCore[25].it_td

#define sipType_QString sipImportedTypes_QtWidgets_QtCore[44].it_td

#define sipType_quintptr sipImportedTypes_QtWidgets_QtCore[109].it_td
extern sipImportedTypeDef sipImportedTypes_QtWidgets_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtWidgets_QtCore[];

#define sipType_QAbstractTextDocumentLayout sipImportedTypes_QtWidgets_QtGui[0].it_td

#define sipType_QAbstractTextDocumentLayout_PaintContext sipImportedTypes_QtWidgets_QtGui[1].it_td

#define sipType_QPaintDevice sipImportedTypes_QtWidgets_QtGui[35].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtWidgets_QtGui[36].it_td

#define sipType_QPixmap sipImportedTypes_QtWidgets_QtGui[47].it_td

#define sipType_QBitmap sipImportedTypes_QtWidgets_QtGui[3].it_td

#define sipType_QColor sipImportedTypes_QtWidgets_QtGui[6].it_td

#define sipType_QBrush sipImportedTypes_QtWidgets_QtGui[4].it_td

#define sipType_QCursor sipImportedTypes_QtWidgets_QtGui[8].it_td

#define sipType_QMouseEvent sipImportedTypes_QtWidgets_QtGui[30].it_td

#define sipType_QWheelEvent sipImportedTypes_QtWidgets_QtGui[73].it_td

#define sipType_QTabletEvent sipImportedTypes_QtWidgets_QtGui[55].it_td

#define sipType_QKeyEvent sipImportedTypes_QtWidgets_QtGui[25].it_td

#define sipType_QFocusEvent sipImportedTypes_QtWidgets_QtGui[13].it_td

#define sipType_QPaintEvent sipImportedTypes_QtWidgets_QtGui[38].it_td

#define sipType_QMoveEvent sipImportedTypes_QtWidgets_QtGui[31].it_td

#define sipType_QResizeEvent sipImportedTypes_QtWidgets_QtGui[51].it_td

#define sipType_QCloseEvent sipImportedTypes_QtWidgets_QtGui[5].it_td

#define sipType_QShowEvent sipImportedTypes_QtWidgets_QtGui[53].it_td

#define sipType_QHideEvent sipImportedTypes_QtWidgets_QtGui[20].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtWidgets_QtGui[7].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtWidgets_QtGui[24].it_td

#define sipType_QDropEvent sipImportedTypes_QtWidgets_QtGui[12].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtWidgets_QtGui[11].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtWidgets_QtGui[9].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtWidgets_QtGui[10].it_td

#define sipType_QHelpEvent sipImportedTypes_QtWidgets_QtGui[19].it_td

#define sipType_QActionEvent sipImportedTypes_QtWidgets_QtGui[2].it_td

#define sipType_QFont sipImportedTypes_QtWidgets_QtGui[14].it_td

#define sipType_QFontDatabase_WritingSystem sipImportedTypes_QtWidgets_QtGui[15].it_td

#define sipType_QFontInfo sipImportedTypes_QtWidgets_QtGui[16].it_td

#define sipType_QFontMetrics sipImportedTypes_QtWidgets_QtGui[17].it_td

#define sipType_QGuiApplication sipImportedTypes_QtWidgets_QtGui[18].it_td

#define sipType_QIcon sipImportedTypes_QtWidgets_QtGui[21].it_td

#define sipType_QIcon_Mode sipImportedTypes_QtWidgets_QtGui[22].it_td

#define sipType_QImage sipImportedTypes_QtWidgets_QtGui[23].it_td

#define sipType_QKeySequence sipImportedTypes_QtWidgets_QtGui[26].it_td

#define sipType_QKeySequence_StandardKey sipImportedTypes_QtWidgets_QtGui[27].it_td

#define sipType_QMatrix4x4 sipImportedTypes_QtWidgets_QtGui[29].it_td

#define sipType_QMovie sipImportedTypes_QtWidgets_QtGui[32].it_td

#define sipType_QOpenGLContext sipImportedTypes_QtWidgets_QtGui[33].it_td

#define sipType_QWindow sipImportedTypes_QtWidgets_QtGui[74].it_td

#define sipType_QPagedPaintDevice sipImportedTypes_QtWidgets_QtGui[34].it_td

#define sipType_QPainter sipImportedTypes_QtWidgets_QtGui[39].it_td

#define sipType_QPainter_RenderHint sipImportedTypes_QtWidgets_QtGui[40].it_td

#define sipType_QPainter_RenderHints sipImportedTypes_QtWidgets_QtGui[41].it_td

#define sipType_QPaintEngine sipImportedTypes_QtWidgets_QtGui[37].it_td

#define sipType_QPainterPath sipImportedTypes_QtWidgets_QtGui[42].it_td

#define sipType_QPalette sipImportedTypes_QtWidgets_QtGui[43].it_td

#define sipType_QPalette_ColorRole sipImportedTypes_QtWidgets_QtGui[44].it_td

#define sipType_QPen sipImportedTypes_QtWidgets_QtGui[45].it_td

#define sipType_QPicture sipImportedTypes_QtWidgets_QtGui[46].it_td

#define sipType_QPolygon sipImportedTypes_QtWidgets_QtGui[48].it_td

#define sipType_QPolygonF sipImportedTypes_QtWidgets_QtGui[49].it_td

#define sipType_QRegion sipImportedTypes_QtWidgets_QtGui[50].it_td

#define sipType_QScreen sipImportedTypes_QtWidgets_QtGui[52].it_td

#define sipType_QSurfaceFormat sipImportedTypes_QtWidgets_QtGui[54].it_td

#define sipType_QTextCursor sipImportedTypes_QtWidgets_QtGui[58].it_td

#define sipType_QTextCursor_MoveOperation sipImportedTypes_QtWidgets_QtGui[60].it_td

#define sipType_QTextCursor_MoveMode sipImportedTypes_QtWidgets_QtGui[59].it_td

#define sipType_QTextDocument sipImportedTypes_QtWidgets_QtGui[61].it_td

#define sipType_QTextDocument_ResourceType sipImportedTypes_QtWidgets_QtGui[64].it_td

#define sipType_QTextDocument_FindFlags sipImportedTypes_QtWidgets_QtGui[62].it_td

#define sipType_QTextDocument_MarkdownFeatures sipImportedTypes_QtWidgets_QtGui[63].it_td

#define sipType_QTextFormat sipImportedTypes_QtWidgets_QtGui[65].it_td

#define sipType_QTextCharFormat sipImportedTypes_QtWidgets_QtGui[57].it_td

#define sipType_QTextInlineObject sipImportedTypes_QtWidgets_QtGui[67].it_td

#define sipType_QTextFrame sipImportedTypes_QtWidgets_QtGui[66].it_td

#define sipType_QTextBlock sipImportedTypes_QtWidgets_QtGui[56].it_td

#define sipType_QTextOption_WrapMode sipImportedTypes_QtWidgets_QtGui[68].it_td

#define sipType_QTransform sipImportedTypes_QtWidgets_QtGui[69].it_td

#define sipType_QValidator sipImportedTypes_QtWidgets_QtGui[70].it_td

#define sipType_QValidator_State sipImportedTypes_QtWidgets_QtGui[71].it_td

#define sipType_QVector3D sipImportedTypes_QtWidgets_QtGui[72].it_td

#define sipType_QList_0100QKeySequence sipImportedTypes_QtWidgets_QtGui[28].it_td
extern sipImportedTypeDef sipImportedTypes_QtWidgets_QtGui[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtWidgets_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtWidgets_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtWidgets_qt_metacast;
#line 310 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qapplication.sip"
// Imports from QtCore.
typedef void (*pyqt5_qtwidgets_cleanup_qobjects_t)();
extern pyqt5_qtwidgets_cleanup_qobjects_t pyqt5_qtwidgets_cleanup_qobjects;

typedef char **(*pyqt5_qtwidgets_from_argv_list_t)(PyObject *, int &);
extern pyqt5_qtwidgets_from_argv_list_t pyqt5_qtwidgets_from_argv_list;

typedef sipErrorState (*pyqt5_qtwidgets_get_connection_parts_t)(PyObject *, QObject *, const char *, bool, QObject **, QByteArray &);
extern pyqt5_qtwidgets_get_connection_parts_t pyqt5_qtwidgets_get_connection_parts;

typedef sipErrorState (*pyqt5_qtwidgets_get_signal_signature_t)(PyObject *, QObject *, QByteArray &);
extern pyqt5_qtwidgets_get_signal_signature_t pyqt5_qtwidgets_get_signal_signature;

typedef void (*pyqt5_qtwidgets_update_argv_list_t)(PyObject *, int, char **);
extern pyqt5_qtwidgets_update_argv_list_t pyqt5_qtwidgets_update_argv_list;

// This is needed for Qt v5.0.0.
#if defined(B0)
#undef B0
#endif
#line 11102 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWidgets/sipAPIQtWidgets.h"

#endif
