/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtGuiAPI_H
#define _QtGuiAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtGui[0]
#define sipNameNr_QOpenGLFramebufferObject__FramebufferRestorePolicy 53
#define sipName_QOpenGLFramebufferObject__FramebufferRestorePolicy &sipStrings_QtGui[53]
#define sipNameNr_QTextCharFormat__FontPropertiesInheritanceBehavior 104
#define sipName_QTextCharFormat__FontPropertiesInheritanceBehavior &sipStrings_QtGui[104]
#define sipNameNr_155 155
#define sipName_155 &sipStrings_QtGui[155]
#define sipNameNr_QAbstractTextDocumentLayout__PaintContext 203
#define sipName_QAbstractTextDocumentLayout__PaintContext &sipStrings_QtGui[203]
#define sipNameNr_QPlatformSurfaceEvent__SurfaceEventType 245
#define sipName_QPlatformSurfaceEvent__SurfaceEventType &sipStrings_QtGui[245]
#define sipNameNr_QAbstractTextDocumentLayout__Selection 285
#define sipName_QAbstractTextDocumentLayout__Selection &sipStrings_QtGui[285]
#define sipNameNr_AddSpaceForLineAndParagraphSeparators 324
#define sipName_AddSpaceForLineAndParagraphSeparators &sipStrings_QtGui[324]
#define sipNameNr_QOpenGLFramebufferObject__Attachment 362
#define sipName_QOpenGLFramebufferObject__Attachment &sipStrings_QtGui[362]
#define sipNameNr_QSurfaceFormat__OpenGLContextProfile 399
#define sipName_QSurfaceFormat__OpenGLContextProfile &sipStrings_QtGui[399]
#define sipNameNr_QIconEngine__AvailableSizesArgument 436
#define sipName_QIconEngine__AvailableSizesArgument &sipStrings_QtGui[436]
#define sipNameNr_472 472
#define sipName_472 &sipStrings_QtGui[472]
#define sipNameNr_508 508
#define sipName_508 &sipStrings_QtGui[508]
#define sipNameNr_QOpenGLTexture__CoordinateDirection 544
#define sipName_QOpenGLTexture__CoordinateDirection &sipStrings_QtGui[544]
#define sipNameNr_RasterOp_NotSourceAndNotDestination 580
#define sipName_RasterOp_NotSourceAndNotDestination &sipStrings_QtGui[580]
#define sipNameNr_mouseQuickSelectionThresholdChanged 616
#define sipName_mouseQuickSelectionThresholdChanged &sipStrings_QtGui[616]
#define sipNameNr_setFallbackSessionManagementEnabled 652
#define sipName_setFallbackSessionManagementEnabled &sipStrings_QtGui[652]
#define sipNameNr_setHighDpiScaleFactorRoundingPolicy 688
#define sipName_setHighDpiScaleFactorRoundingPolicy &sipStrings_QtGui[688]
#define sipNameNr_QOpenGLTexture__ComparisonFunction 724
#define sipName_QOpenGLTexture__ComparisonFunction &sipStrings_QtGui[724]
#define sipNameNr_QTextCharFormat__VerticalAlignment 759
#define sipName_QTextCharFormat__VerticalAlignment &sipStrings_QtGui[759]
#define sipNameNr_QTouchEvent__TouchPoint__InfoFlags 794
#define sipName_QTouchEvent__TouchPoint__InfoFlags &sipStrings_QtGui[794]
#define sipNameNr_RasterOp_NotSourceOrNotDestination 829
#define sipName_RasterOp_NotSourceOrNotDestination &sipStrings_QtGui[829]
#define sipNameNr_RestoreFramebufferBindingToDefault 864
#define sipName_RestoreFramebufferBindingToDefault &sipStrings_QtGui[864]
#define sipNameNr_isFallbackSessionManagementEnabled 899
#define sipName_isFallbackSessionManagementEnabled &sipStrings_QtGui[899]
#define sipNameNr_showShortcutsInContextMenusChanged 934
#define sipName_showShortcutsInContextMenusChanged &sipStrings_QtGui[934]
#define sipNameNr_BlockTrailingHorizontalRulerWidth 969
#define sipName_BlockTrailingHorizontalRulerWidth &sipStrings_QtGui[969]
#define sipNameNr_FontPropertiesInheritanceBehavior 121
#define sipName_FontPropertiesInheritanceBehavior &sipStrings_QtGui[121]
#define sipNameNr_QIconEngine__ScaledPixmapArgument 1003
#define sipName_QIconEngine__ScaledPixmapArgument &sipStrings_QtGui[1003]
#define sipNameNr_QPaintEngine__PaintEngineFeatures 1037
#define sipName_QPaintEngine__PaintEngineFeatures &sipStrings_QtGui[1037]
#define sipNameNr_QTextBlockFormat__LineHeightTypes 1071
#define sipName_QTextBlockFormat__LineHeightTypes &sipStrings_QtGui[1071]
#define sipNameNr_QTouchEvent__TouchPoint__InfoFlag 1105
#define sipName_QTouchEvent__TouchPoint__InfoFlag &sipStrings_QtGui[1105]
#define sipNameNr_1139 1139
#define sipName_1139 &sipStrings_QtGui[1139]
#define sipNameNr_setDefaultInnerTessellationLevels 1173
#define sipName_setDefaultInnerTessellationLevels &sipStrings_QtGui[1173]
#define sipNameNr_setDefaultOuterTessellationLevels 1207
#define sipName_setDefaultOuterTessellationLevels &sipStrings_QtGui[1207]
#define sipNameNr_QImageIOHandler__Transformations 1241
#define sipName_QImageIOHandler__Transformations &sipStrings_QtGui[1241]
#define sipNameNr_QInputMethodEvent__AttributeType 1274
#define sipName_QInputMethodEvent__AttributeType &sipStrings_QtGui[1274]
#define sipNameNr_QOpenGLContext__OpenGLModuleType 1307
#define sipName_QOpenGLContext__OpenGLModuleType &sipStrings_QtGui[1307]
#define sipNameNr_QOpenGLTexture__DepthStencilMode 1340
#define sipName_QOpenGLTexture__DepthStencilMode &sipStrings_QtGui[1340]
#define sipNameNr_QOpenGLTexture__MipMapGeneration 1373
#define sipName_QOpenGLTexture__MipMapGeneration &sipStrings_QtGui[1373]
#define sipNameNr_QOpenGLTexture__SwizzleComponent 1406
#define sipName_QOpenGLTexture__SwizzleComponent &sipStrings_QtGui[1406]
#define sipNameNr_QOpenGLTexture__TextureUnitReset 1439
#define sipName_QOpenGLTexture__TextureUnitReset &sipStrings_QtGui[1439]
#define sipNameNr_QOpenGLVertexArrayObject__Binder 1472
#define sipName_QOpenGLVertexArrayObject__Binder &sipStrings_QtGui[1472]
#define sipNameNr_QPaintEngine__PaintEngineFeature 1505
#define sipName_QPaintEngine__PaintEngineFeature &sipStrings_QtGui[1505]
#define sipNameNr_QPixelFormat__AlphaPremultiplied 1538
#define sipName_QPixelFormat__AlphaPremultiplied &sipStrings_QtGui[1538]
#define sipNameNr_QPixelFormat__TypeInterpretation 1571
#define sipName_QPixelFormat__TypeInterpretation &sipStrings_QtGui[1571]
#define sipNameNr_RasterOp_NotSourceAndDestination 1604
#define sipName_RasterOp_NotSourceAndDestination &sipStrings_QtGui[1604]
#define sipNameNr_RasterOp_NotSourceXorDestination 1637
#define sipName_RasterOp_NotSourceXorDestination &sipStrings_QtGui[1637]
#define sipNameNr_RasterOp_SourceAndNotDestination 1670
#define sipName_RasterOp_SourceAndNotDestination &sipStrings_QtGui[1670]
#define sipNameNr_addCacheableShaderFromSourceCode 1703
#define sipName_addCacheableShaderFromSourceCode &sipStrings_QtGui[1703]
#define sipNameNr_addCacheableShaderFromSourceFile 1736
#define sipName_addCacheableShaderFromSourceFile &sipStrings_QtGui[1736]
#define sipNameNr_highDpiScaleFactorRoundingPolicy 1769
#define sipName_highDpiScaleFactorRoundingPolicy &sipStrings_QtGui[1769]
#define sipNameNr_mousePressAndHoldIntervalChanged 1802
#define sipName_mousePressAndHoldIntervalChanged &sipStrings_QtGui[1802]
#define sipNameNr_BindingTarget2DMultisampleArray 1835
#define sipName_BindingTarget2DMultisampleArray &sipStrings_QtGui[1835]
#define sipNameNr_CompositionMode_DestinationAtop 1867
#define sipName_CompositionMode_DestinationAtop &sipStrings_QtGui[1867]
#define sipNameNr_CompositionMode_DestinationOver 1899
#define sipName_CompositionMode_DestinationOver &sipStrings_QtGui[1899]
#define sipNameNr_QImageIOHandler__Transformation 1931
#define sipName_QImageIOHandler__Transformation &sipStrings_QtGui[1931]
#define sipNameNr_1963 1963
#define sipName_1963 &sipStrings_QtGui[1963]
#define sipNameNr_QOpenGLBuffer__RangeAccessFlags 1995
#define sipName_QOpenGLBuffer__RangeAccessFlags &sipStrings_QtGui[1995]
#define sipNameNr_QOpenGLDebugLogger__LoggingMode 2027
#define sipName_QOpenGLDebugLogger__LoggingMode &sipStrings_QtGui[2027]
#define sipNameNr_QOpenGLDebugMessage__Severities 2059
#define sipName_QOpenGLDebugMessage__Severities &sipStrings_QtGui[2059]
#define sipNameNr_QPaintDevice__PaintDeviceMetric 2091
#define sipName_QPaintDevice__PaintDeviceMetric &sipStrings_QtGui[2091]
#define sipNameNr_QTextCharFormat__UnderlineStyle 2123
#define sipName_QTextCharFormat__UnderlineStyle &sipStrings_QtGui[2123]
#define sipNameNr_QTextDocument__MarkdownFeatures 2155
#define sipName_QTextDocument__MarkdownFeatures &sipStrings_QtGui[2155]
#define sipNameNr_RasterOp_NotSourceOrDestination 2187
#define sipName_RasterOp_NotSourceOrDestination &sipStrings_QtGui[2187]
#define sipNameNr_RasterOp_SourceOrNotDestination 2219
#define sipName_RasterOp_SourceOrNotDestination &sipStrings_QtGui[2219]
#define sipNameNr_TransformationMirrorAndRotate90 2251
#define sipName_TransformationMirrorAndRotate90 &sipStrings_QtGui[2251]
#define sipNameNr_mouseDoubleClickIntervalChanged 2283
#define sipName_mouseDoubleClickIntervalChanged &sipStrings_QtGui[2283]
#define sipNameNr_CompositionMode_DestinationOut 2315
#define sipName_CompositionMode_DestinationOut &sipStrings_QtGui[2315]
#define sipNameNr_QImageReader__ImageReaderError 2346
#define sipName_QImageReader__ImageReaderError &sipStrings_QtGui[2346]
#define sipNameNr_QImageWriter__ImageWriterError 2377
#define sipName_QImageWriter__ImageWriterError &sipStrings_QtGui[2377]
#define sipNameNr_2408 2408
#define sipName_2408 &sipStrings_QtGui[2408]
#define sipNameNr_QOpenGLBuffer__RangeAccessFlag 2439
#define sipName_QOpenGLBuffer__RangeAccessFlag &sipStrings_QtGui[2439]
#define sipNameNr_QOpenGLFramebufferObjectFormat 2470
#define sipName_QOpenGLFramebufferObjectFormat &sipStrings_QtGui[2470]
#define sipNameNr_QOpenGLTexture__ComparisonMode 2501
#define sipName_QOpenGLTexture__ComparisonMode &sipStrings_QtGui[2501]
#define sipNameNr_QSurfaceFormat__RenderableType 2532
#define sipName_QSurfaceFormat__RenderableType &sipStrings_QtGui[2532]
#define sipNameNr_QTextDocument__MarkdownFeature 2563
#define sipName_QTextDocument__MarkdownFeature &sipStrings_QtGui[2563]
#define sipNameNr_QTextDocument__MetaInformation 2594
#define sipName_QTextDocument__MetaInformation &sipStrings_QtGui[2594]
#define sipNameNr_QTransform__TransformationType 2625
#define sipName_QTransform__TransformationType &sipStrings_QtGui[2625]
#define sipNameNr_SRGB8_PunchThrough_Alpha1_ETC2 2656
#define sipName_SRGB8_PunchThrough_Alpha1_ETC2 &sipStrings_QtGui[2656]
#define sipNameNr_ShowLineAndParagraphSeparators 2687
#define sipName_ShowLineAndParagraphSeparators &sipStrings_QtGui[2687]
#define sipNameNr_defaultInnerTessellationLevels 2718
#define sipName_defaultInnerTessellationLevels &sipStrings_QtGui[2718]
#define sipNameNr_defaultOuterTessellationLevels 2749
#define sipName_defaultOuterTessellationLevels &sipStrings_QtGui[2749]
#define sipNameNr_reportContentOrientationChange 2780
#define sipName_reportContentOrientationChange &sipStrings_QtGui[2780]
#define sipNameNr_setAutoMipMapGenerationEnabled 2811
#define sipName_setAutoMipMapGenerationEnabled &sipStrings_QtGui[2811]
#define sipNameNr_setShowShortcutsInContextMenus 2842
#define sipName_setShowShortcutsInContextMenus &sipStrings_QtGui[2842]
#define sipNameNr_CompositionMode_DestinationIn 2873
#define sipName_CompositionMode_DestinationIn &sipStrings_QtGui[2873]
#define sipNameNr_DontRestoreFramebufferBinding 2903
#define sipName_DontRestoreFramebufferBinding &sipStrings_QtGui[2903]
#define sipNameNr_Format_ARGB4444_Premultiplied 2933
#define sipName_Format_ARGB4444_Premultiplied &sipStrings_QtGui[2933]
#define sipNameNr_Format_ARGB6666_Premultiplied 2963
#define sipName_Format_ARGB6666_Premultiplied &sipStrings_QtGui[2963]
#define sipNameNr_Format_ARGB8555_Premultiplied 2993
#define sipName_Format_ARGB8555_Premultiplied &sipStrings_QtGui[2993]
#define sipNameNr_Format_ARGB8565_Premultiplied 3023
#define sipName_Format_ARGB8565_Premultiplied &sipStrings_QtGui[3023]
#define sipNameNr_Format_RGBA8888_Premultiplied 3053
#define sipName_Format_RGBA8888_Premultiplied &sipStrings_QtGui[3053]
#define sipNameNr_QColorSpace__TransferFunction 3083
#define sipName_QColorSpace__TransferFunction &sipStrings_QtGui[3083]
#define sipNameNr_QOpenGLDebugMessage__Severity 3113
#define sipName_QOpenGLDebugMessage__Severity &sipStrings_QtGui[3113]
#define sipNameNr_QOpenGLTexture__BindingTarget 3143
#define sipName_QOpenGLTexture__BindingTarget &sipStrings_QtGui[3143]
#define sipNameNr_QOpenGLTexture__TextureFormat 3173
#define sipName_QOpenGLTexture__TextureFormat &sipStrings_QtGui[3173]
#define sipNameNr_QOpenGLTextureBlitter__Origin 3203
#define sipName_QOpenGLTextureBlitter__Origin &sipStrings_QtGui[3203]
#define sipNameNr_QOpenGLWindow__UpdateBehavior 3233
#define sipName_QOpenGLWindow__UpdateBehavior &sipStrings_QtGui[3233]
#define sipNameNr_QPagedPaintDevice__PdfVersion 3263
#define sipName_QPagedPaintDevice__PdfVersion &sipStrings_QtGui[3263]
#define sipNameNr_QPaintEngine__PolygonDrawMode 3293
#define sipName_QPaintEngine__PolygonDrawMode &sipStrings_QtGui[3293]
#define sipNameNr_QPainter__PixmapFragmentHints 3323
#define sipName_QPainter__PixmapFragmentHints &sipStrings_QtGui[3323]
#define sipNameNr_QSurfaceFormat__FormatOptions 3353
#define sipName_QSurfaceFormat__FormatOptions &sipStrings_QtGui[3353]
#define sipNameNr_QTextFrameFormat__BorderStyle 3383
#define sipName_QTextFrameFormat__BorderStyle &sipStrings_QtGui[3383]
#define sipNameNr_3413 3413
#define sipName_3413 &sipStrings_QtGui[3413]
#define sipNameNr_RGB8_PunchThrough_Alpha1_ETC2 2657
#define sipName_RGB8_PunchThrough_Alpha1_ETC2 &sipStrings_QtGui[2657]
#define sipNameNr_RasterOp_SourceAndDestination 3443
#define sipName_RasterOp_SourceAndDestination &sipStrings_QtGui[3443]
#define sipNameNr_RasterOp_SourceXorDestination 3473
#define sipName_RasterOp_SourceXorDestination &sipStrings_QtGui[3473]
#define sipNameNr_TransformationFlipAndRotate90 3503
#define sipName_TransformationFlipAndRotate90 &sipStrings_QtGui[3503]
#define sipNameNr_applicationDisplayNameChanged 3533
#define sipName_applicationDisplayNameChanged &sipStrings_QtGui[3533]
#define sipNameNr_inputItemClipRectangleChanged 3563
#define sipName_inputItemClipRectangleChanged &sipStrings_QtGui[3563]
#define sipNameNr_isAutoMipMapGenerationEnabled 3593
#define sipName_isAutoMipMapGenerationEnabled &sipStrings_QtGui[3593]
#define sipNameNr_qt_set_sequence_auto_mnemonic 3623
#define sipName_qt_set_sequence_auto_mnemonic &sipStrings_QtGui[3623]
#define sipNameNr_supportsThreadedFontRendering 3653
#define sipName_supportsThreadedFontRendering &sipStrings_QtGui[3653]
#define sipNameNr_Format_A2BGR30_Premultiplied 3683
#define sipName_Format_A2BGR30_Premultiplied &sipStrings_QtGui[3683]
#define sipNameNr_Format_A2RGB30_Premultiplied 3712
#define sipName_Format_A2RGB30_Premultiplied &sipStrings_QtGui[3712]
#define sipNameNr_QColorSpace__NamedColorSpace 3741
#define sipName_QColorSpace__NamedColorSpace &sipStrings_QtGui[3741]
#define sipNameNr_QFontDatabase__WritingSystem 3770
#define sipName_QFontDatabase__WritingSystem &sipStrings_QtGui[3770]
#define sipNameNr_QImageIOHandler__ImageOption 3799
#define sipName_QImageIOHandler__ImageOption &sipStrings_QtGui[3799]
#define sipNameNr_QInputMethodEvent__Attribute 3828
#define sipName_QInputMethodEvent__Attribute &sipStrings_QtGui[3828]
#define sipNameNr_QKeySequence__SequenceFormat 3857
#define sipName_QKeySequence__SequenceFormat &sipStrings_QtGui[3857]
#define sipNameNr_QOpenGLDebugMessage__Sources 3886
#define sipName_QOpenGLDebugMessage__Sources &sipStrings_QtGui[3886]
#define sipNameNr_QOpenGLShader__ShaderTypeBit 3915
#define sipName_QOpenGLShader__ShaderTypeBit &sipStrings_QtGui[3915]
#define sipNameNr_QOpenGLTexture__SwizzleValue 3944
#define sipName_QOpenGLTexture__SwizzleValue &sipStrings_QtGui[3944]
#define sipNameNr_QPainter__PixmapFragmentHint 3973
#define sipName_QPainter__PixmapFragmentHint &sipStrings_QtGui[3973]
#define sipNameNr_QSessionManager__RestartHint 4002
#define sipName_QSessionManager__RestartHint &sipStrings_QtGui[4002]
#define sipNameNr_QStaticText__PerformanceHint 4031
#define sipName_QStaticText__PerformanceHint &sipStrings_QtGui[4031]
#define sipNameNr_QSurfaceFormat__FormatOption 4060
#define sipName_QSurfaceFormat__FormatOption &sipStrings_QtGui[4060]
#define sipNameNr_QSurfaceFormat__SwapBehavior 4089
#define sipName_QSurfaceFormat__SwapBehavior &sipStrings_QtGui[4089]
#define sipNameNr_QTextBlockFormat__MarkerType 4118
#define sipName_QTextBlockFormat__MarkerType &sipStrings_QtGui[4118]
#define sipNameNr_QTouchDevice__CapabilityFlag 4147
#define sipName_QTouchDevice__CapabilityFlag &sipStrings_QtGui[4147]
#define sipNameNr_RasterOp_SourceOrDestination 4176
#define sipName_RasterOp_SourceOrDestination &sipStrings_QtGui[4176]
#define sipNameNr_WrapAtWordBoundaryOrAnywhere 4205
#define sipName_WrapAtWordBoundaryOrAnywhere &sipStrings_QtGui[4205]
#define sipNameNr_keyboardInputIntervalChanged 4234
#define sipName_keyboardInputIntervalChanged &sipStrings_QtGui[4234]
#define sipNameNr_mouseQuickSelectionThreshold 4263
#define sipName_mouseQuickSelectionThreshold &sipStrings_QtGui[4263]
#define sipNameNr_setLeastSignificantByteFirst 4292
#define sipName_setLeastSignificantByteFirst &sipStrings_QtGui[4292]
#define sipNameNr_CompositionMode_Destination 4321
#define sipName_CompositionMode_Destination &sipStrings_QtGui[4321]
#define sipNameNr_FontPropertiesSpecifiedOnly 4349
#define sipName_FontPropertiesSpecifiedOnly &sipStrings_QtGui[4349]
#define sipNameNr_Format_ARGB32_Premultiplied 4377
#define sipName_Format_ARGB32_Premultiplied &sipStrings_QtGui[4377]
#define sipNameNr_Format_RGBA64_Premultiplied 4405
#define sipName_Format_RGBA64_Premultiplied &sipStrings_QtGui[4405]
#define sipNameNr_ImmutableMultisampleStorage 4433
#define sipName_ImmutableMultisampleStorage &sipStrings_QtGui[4433]
#define sipNameNr_ObjectBoundingModeGradients 4461
#define sipName_ObjectBoundingModeGradients &sipStrings_QtGui[4461]
#define sipNameNr_QAbstractTextDocumentLayout 4489
#define sipName_QAbstractTextDocumentLayout &sipStrings_QtGui[4489]
#define sipNameNr_QIconEngine__IconEngineHook 4517
#define sipName_QIconEngine__IconEngineHook &sipStrings_QtGui[4517]
#define sipNameNr_QKeySequence__SequenceMatch 4545
#define sipName_QKeySequence__SequenceMatch &sipStrings_QtGui[4545]
#define sipNameNr_QOpenGLBuffer__UsagePattern 4573
#define sipName_QOpenGLBuffer__UsagePattern &sipStrings_QtGui[4573]
#define sipNameNr_QOpenGLDebugMessage__Source 4601
#define sipName_QOpenGLDebugMessage__Source &sipStrings_QtGui[4601]
#define sipNameNr_QOpenGLPixelTransferOptions 4629
#define sipName_QOpenGLPixelTransferOptions &sipStrings_QtGui[4629]
#define sipNameNr_QOpenGLTexture__CubeMapFace 4657
#define sipName_QOpenGLTexture__CubeMapFace &sipStrings_QtGui[4657]
#define sipNameNr_QOpenGLTexture__PixelFormat 4685
#define sipName_QOpenGLTexture__PixelFormat &sipStrings_QtGui[4685]
#define sipNameNr_QPagedPaintDevice__PageSize 4713
#define sipName_QPagedPaintDevice__PageSize &sipStrings_QtGui[4713]
#define sipNameNr_QPixelFormat__AlphaPosition 4741
#define sipName_QPixelFormat__AlphaPosition &sipStrings_QtGui[4741]
#define sipNameNr_QRegularExpressionValidator 4769
#define sipName_QRegularExpressionValidator &sipStrings_QtGui[4769]
#define sipNameNr_QTextDocument__ResourceType 4797
#define sipName_QTextDocument__ResourceType &sipStrings_QtGui[4797]
#define sipNameNr_QTextFormat__PageBreakFlags 4825
#define sipName_QTextFormat__PageBreakFlags &sipStrings_QtGui[4825]
#define sipNameNr_TableColumnWidthConstraints 4853
#define sipName_TableColumnWidthConstraints &sipStrings_QtGui[4853]
#define sipNameNr_clearColumnWidthConstraints 4881
#define sipName_clearColumnWidthConstraints &sipStrings_QtGui[4881]
#define sipNameNr_hasOpenGLFramebufferObjects 4909
#define sipName_hasOpenGLFramebufferObjects &sipStrings_QtGui[4909]
#define sipNameNr_showShortcutsInContextMenus 4937
#define sipName_showShortcutsInContextMenus &sipStrings_QtGui[4937]
#define sipNameNr_BindingTarget2DMultisample 4965
#define sipName_BindingTarget2DMultisample &sipStrings_QtGui[4965]
#define sipNameNr_CompositionMode_ColorDodge 4992
#define sipName_CompositionMode_ColorDodge &sipStrings_QtGui[4992]
#define sipNameNr_CompositionMode_Difference 5019
#define sipName_CompositionMode_Difference &sipStrings_QtGui[5019]
#define sipNameNr_CompositionMode_SourceAtop 5046
#define sipName_CompositionMode_SourceAtop &sipStrings_QtGui[5046]
#define sipNameNr_CompositionMode_SourceOver 5073
#define sipName_CompositionMode_SourceOver &sipStrings_QtGui[5073]
#define sipNameNr_QDoubleValidator__Notation 5100
#define sipName_QDoubleValidator__Notation &sipStrings_QtGui[5100]
#define sipNameNr_5127 5127
#define sipName_5127 &sipStrings_QtGui[5127]
#define sipNameNr_QOpenGLDebugMessage__Types 5154
#define sipName_QOpenGLDebugMessage__Types &sipStrings_QtGui[5154]
#define sipNameNr_QPageSize__SizeMatchPolicy 5181
#define sipName_QPageSize__SizeMatchPolicy &sipStrings_QtGui[5181]
#define sipNameNr_QPagedPaintDevice__Margins 5208
#define sipName_QPagedPaintDevice__Margins &sipStrings_QtGui[5208]
#define sipNameNr_QRawFont__AntialiasingType 5235
#define sipName_QRawFont__AntialiasingType &sipStrings_QtGui[5235]
#define sipNameNr_QSurfaceFormat__ColorSpace 5262
#define sipName_QSurfaceFormat__ColorSpace &sipStrings_QtGui[5262]
#define sipNameNr_QTabletEvent__TabletDevice 5289
#define sipName_QTabletEvent__TabletDevice &sipStrings_QtGui[5289]
#define sipNameNr_QTextCursor__MoveOperation 5316
#define sipName_QTextCursor__MoveOperation &sipStrings_QtGui[5316]
#define sipNameNr_QTextCursor__SelectionType 5343
#define sipName_QTextCursor__SelectionType &sipStrings_QtGui[5343]
#define sipNameNr_QTextFormat__PageBreakFlag 5370
#define sipName_QTextFormat__PageBreakFlag &sipStrings_QtGui[5370]
#define sipNameNr_QTextFrameFormat__Position 5397
#define sipName_QTextFrameFormat__Position &sipStrings_QtGui[5397]
#define sipNameNr_QTouchDevice__Capabilities 5424
#define sipName_QTouchDevice__Capabilities &sipStrings_QtGui[5424]
#define sipNameNr_TableCellBottomBorderBrush 5451
#define sipName_TableCellBottomBorderBrush &sipStrings_QtGui[5451]
#define sipNameNr_TableCellBottomBorderStyle 5478
#define sipName_TableCellBottomBorderStyle &sipStrings_QtGui[5478]
#define sipNameNr_TextureComparisonOperators 5505
#define sipName_TextureComparisonOperators &sipStrings_QtGui[5505]
#define sipNameNr_addApplicationFontFromData 5532
#define sipName_addApplicationFontFromData &sipStrings_QtGui[5532]
#define sipNameNr_isLeastSignificantBitFirst 5559
#define sipName_isLeastSignificantBitFirst &sipStrings_QtGui[5559]
#define sipNameNr_physicalDotsPerInchChanged 5586
#define sipName_physicalDotsPerInchChanged &sipStrings_QtGui[5586]
#define sipNameNr_setDecideFormatFromContent 5613
#define sipName_setDecideFormatFromContent &sipStrings_QtGui[5613]
#define sipNameNr_transformationToColorSpace 5640
#define sipName_transformationToColorSpace &sipStrings_QtGui[5640]
#define sipNameNr_BindingTargetCubeMapArray 5667
#define sipName_BindingTargetCubeMapArray &sipStrings_QtGui[5667]
#define sipNameNr_CompositionMode_ColorBurn 5693
#define sipName_CompositionMode_ColorBurn &sipStrings_QtGui[5693]
#define sipNameNr_CompositionMode_Exclusion 5719
#define sipName_CompositionMode_Exclusion &sipStrings_QtGui[5719]
#define sipNameNr_CompositionMode_HardLight 5745
#define sipName_CompositionMode_HardLight &sipStrings_QtGui[5745]
#define sipNameNr_CompositionMode_SoftLight 5771
#define sipName_CompositionMode_SoftLight &sipStrings_QtGui[5771]
#define sipNameNr_CompositionMode_SourceOut 5797
#define sipName_CompositionMode_SourceOut &sipStrings_QtGui[5797]
#define sipNameNr_Float32_D32_UInt32_S8_X24 5823
#define sipName_Float32_D32_UInt32_S8_X24 &sipStrings_QtGui[5823]
#define sipNameNr_MarkdownDialectCommonMark 5849
#define sipName_MarkdownDialectCommonMark &sipStrings_QtGui[5849]
#define sipNameNr_PdmDevicePixelRatioScaled 5875
#define sipName_PdmDevicePixelRatioScaled &sipStrings_QtGui[5875]
#define sipNameNr_QContextMenuEvent__Reason 5901
#define sipName_QContextMenuEvent__Reason &sipStrings_QtGui[5901]
#define sipNameNr_QFontDatabase__SystemFont 5927
#define sipName_QFontDatabase__SystemFont &sipStrings_QtGui[5927]
#define sipNameNr_QGradient__CoordinateMode 5953
#define sipName_QGradient__CoordinateMode &sipStrings_QtGui[5953]
#define sipNameNr_QKeySequence__StandardKey 5979
#define sipName_QKeySequence__StandardKey &sipStrings_QtGui[5979]
#define sipNameNr_QOpenGLDebugMessage__Type 6005
#define sipName_QOpenGLDebugMessage__Type &sipStrings_QtGui[6005]
#define sipNameNr_QOpenGLShader__ShaderType 6031
#define sipName_QOpenGLShader__ShaderType &sipStrings_QtGui[6031]
#define sipNameNr_QOpenGLTexture__PixelType 6057
#define sipName_QOpenGLTexture__PixelType &sipStrings_QtGui[6057]
#define sipNameNr_QPainter__CompositionMode 6083
#define sipName_QPainter__CompositionMode &sipStrings_QtGui[6083]
#define sipNameNr_QPainterPath__ElementType 6109
#define sipName_QPainterPath__ElementType &sipStrings_QtGui[6109]
#define sipNameNr_QScrollEvent__ScrollState 6135
#define sipName_QScrollEvent__ScrollState &sipStrings_QtGui[6135]
#define sipNameNr_QTabletEvent__PointerType 6161
#define sipName_QTabletEvent__PointerType &sipStrings_QtGui[6161]
#define sipNameNr_QTextLine__CursorPosition 6187
#define sipName_QTextLine__CursorPosition &sipStrings_QtGui[6187]
#define sipNameNr_RasterOp_ClearDestination 6213
#define sipName_RasterOp_ClearDestination &sipStrings_QtGui[6213]
#define sipNameNr_RestoreFrameBufferBinding 6239
#define sipName_RestoreFrameBufferBinding &sipStrings_QtGui[6239]
#define sipNameNr_SurfaceAboutToBeDestroyed 6265
#define sipName_SurfaceAboutToBeDestroyed &sipStrings_QtGui[6265]
#define sipNameNr_TableCellRightBorderBrush 6291
#define sipName_TableCellRightBorderBrush &sipStrings_QtGui[6291]
#define sipNameNr_TableCellRightBorderStyle 6317
#define sipName_TableCellRightBorderStyle &sipStrings_QtGui[6317]
#define sipNameNr_contentOrientationChanged 6343
#define sipName_contentOrientationChanged &sipStrings_QtGui[6343]
#define sipNameNr_logicalDotsPerInchChanged 6369
#define sipName_logicalDotsPerInchChanged &sipStrings_QtGui[6369]
#define sipNameNr_maxGeometryOutputVertices 6395
#define sipName_maxGeometryOutputVertices &sipStrings_QtGui[6395]
#define sipNameNr_mousePressAndHoldInterval 6421
#define sipName_mousePressAndHoldInterval &sipStrings_QtGui[6421]
#define sipNameNr_primaryOrientationChanged 6447
#define sipName_primaryOrientationChanged &sipStrings_QtGui[6447]
#define sipNameNr_removeAllApplicationFonts 6473
#define sipName_removeAllApplicationFonts &sipStrings_QtGui[6473]
#define sipNameNr_setApplicationDisplayName 6499
#define sipName_setApplicationDisplayName &sipStrings_QtGui[6499]
#define sipNameNr_setColumnWidthConstraints 6525
#define sipName_setColumnWidthConstraints &sipStrings_QtGui[6525]
#define sipNameNr_setDefaultCursorMoveStyle 6551
#define sipName_setDefaultCursorMoveStyle &sipStrings_QtGui[6551]
#define sipNameNr_setHorizontalHeaderLabels 6577
#define sipName_setHorizontalHeaderLabels &sipStrings_QtGui[6577]
#define sipNameNr_setQuitOnLastWindowClosed 6603
#define sipName_setQuitOnLastWindowClosed &sipStrings_QtGui[6603]
#define sipNameNr_supportsExternalOESTarget 6629
#define sipName_supportsExternalOESTarget &sipStrings_QtGui[6629]
#define sipNameNr_CompositionMode_Multiply 6655
#define sipName_CompositionMode_Multiply &sipStrings_QtGui[6655]
#define sipNameNr_CompositionMode_SourceIn 6680
#define sipName_CompositionMode_SourceIn &sipStrings_QtGui[6680]
#define sipNameNr_FramebufferRestorePolicy 79
#define sipName_FramebufferRestorePolicy &sipStrings_QtGui[79]
#define sipNameNr_InsertParagraphSeparator 6705
#define sipName_InsertParagraphSeparator &sipStrings_QtGui[6705]
#define sipNameNr_QAbstractOpenGLFunctions 6730
#define sipName_QAbstractOpenGLFunctions &sipStrings_QtGui[6730]
#define sipNameNr_QFont__HintingPreference 6755
#define sipName_QFont__HintingPreference &sipStrings_QtGui[6755]
#define sipNameNr_QGlyphRun__GlyphRunFlags 6780
#define sipName_QGlyphRun__GlyphRunFlags &sipStrings_QtGui[6780]
#define sipNameNr_QOpenGLFramebufferObject 6805
#define sipName_QOpenGLFramebufferObject &sipStrings_QtGui[6805]
#define sipNameNr_QOpenGLTexture__Features 6830
#define sipName_QOpenGLTexture__Features &sipStrings_QtGui[6830]
#define sipNameNr_QOpenGLTexture__WrapMode 6855
#define sipName_QOpenGLTexture__WrapMode &sipStrings_QtGui[6855]
#define sipNameNr_QOpenGLVertexArrayObject 6880
#define sipName_QOpenGLVertexArrayObject &sipStrings_QtGui[6880]
#define sipNameNr_QPageLayout__Orientation 6905
#define sipName_QPageLayout__Orientation &sipStrings_QtGui[6905]
#define sipNameNr_QPaintEngine__DirtyFlags 6930
#define sipName_QPaintEngine__DirtyFlags &sipStrings_QtGui[6930]
#define sipNameNr_QPainter__PixmapFragment 6955
#define sipName_QPainter__PixmapFragment &sipStrings_QtGui[6955]
#define sipNameNr_QPixelFormat__AlphaUsage 6980
#define sipName_QPixelFormat__AlphaUsage &sipStrings_QtGui[6980]
#define sipNameNr_QPixelFormat__ColorModel 7005
#define sipName_QPixelFormat__ColorModel &sipStrings_QtGui[7005]
#define sipNameNr_QTextDocument__FindFlags 7030
#define sipName_QTextDocument__FindFlags &sipStrings_QtGui[7030]
#define sipNameNr_QTextFormat__ObjectTypes 7055
#define sipName_QTextFormat__ObjectTypes &sipStrings_QtGui[7055]
#define sipNameNr_QTextLayout__FormatRange 7080
#define sipName_QTextLayout__FormatRange &sipStrings_QtGui[7080]
#define sipNameNr_QTouchDevice__DeviceType 7105
#define sipName_QTouchDevice__DeviceType &sipStrings_QtGui[7105]
#define sipNameNr_TableCellLeftBorderBrush 7130
#define sipName_TableCellLeftBorderBrush &sipStrings_QtGui[7130]
#define sipNameNr_TableCellLeftBorderStyle 7155
#define sipName_TableCellLeftBorderStyle &sipStrings_QtGui[7155]
#define sipNameNr_Target2DMultisampleArray 1842
#define sipName_Target2DMultisampleArray &sipStrings_QtGui[1842]
#define sipNameNr_availableGeometryChanged 7180
#define sipName_availableGeometryChanged &sipStrings_QtGui[7180]
#define sipNameNr_availableVirtualGeometry 7205
#define sipName_availableVirtualGeometry &sipStrings_QtGui[7205]
#define sipNameNr_createApplicationMessage 7230
#define sipName_createApplicationMessage &sipStrings_QtGui[7230]
#define sipNameNr_defaultFramebufferObject 7255
#define sipName_defaultFramebufferObject &sipStrings_QtGui[7255]
#define sipNameNr_hasOpenGLFramebufferBlit 7280
#define sipName_hasOpenGLFramebufferBlit &sipStrings_QtGui[7280]
#define sipNameNr_keyboardRectangleChanged 7305
#define sipName_keyboardRectangleChanged &sipStrings_QtGui[7305]
#define sipNameNr_mouseDoubleClickDistance 7330
#define sipName_mouseDoubleClickDistance &sipStrings_QtGui[7330]
#define sipNameNr_mouseDoubleClickInterval 7355
#define sipName_mouseDoubleClickInterval &sipStrings_QtGui[7355]
#define sipNameNr_setAccessibleDescription 7380
#define sipName_setAccessibleDescription &sipStrings_QtGui[7380]
#define sipNameNr_setAutoDetectImageFormat 7405
#define sipName_setAutoDetectImageFormat &sipStrings_QtGui[7405]
#define sipNameNr_setFontHintingPreference 7430
#define sipName_setFontHintingPreference &sipStrings_QtGui[7430]
#define sipNameNr_setFontLetterSpacingType 7455
#define sipName_setFontLetterSpacingType &sipStrings_QtGui[7455]
#define sipNameNr_setInternalTextureFormat 7480
#define sipName_setInternalTextureFormat &sipStrings_QtGui[7480]
#define sipNameNr_setOrientationUpdateMask 7505
#define sipName_setOrientationUpdateMask &sipStrings_QtGui[7505]
#define sipNameNr_startDragDistanceChanged 7530
#define sipName_startDragDistanceChanged &sipStrings_QtGui[7530]
#define sipNameNr_supportedDocumentFormats 7555
#define sipName_supportedDocumentFormats &sipStrings_QtGui[7555]
#define sipNameNr_takeHorizontalHeaderItem 7580
#define sipName_takeHorizontalHeaderItem &sipStrings_QtGui[7580]
#define sipNameNr_CompositionMode_Lighten 7605
#define sipName_CompositionMode_Lighten &sipStrings_QtGui[7605]
#define sipNameNr_CompositionMode_Overlay 7629
#define sipName_CompositionMode_Overlay &sipStrings_QtGui[7629]
#define sipNameNr_CursorBetweenCharacters 7653
#define sipName_CursorBetweenCharacters &sipStrings_QtGui[7653]
#define sipNameNr_HighQualityAntialiasing 7677
#define sipName_HighQualityAntialiasing &sipStrings_QtGui[7677]
#define sipNameNr_QGlyphRun__GlyphRunFlag 7701
#define sipName_QGlyphRun__GlyphRunFlag &sipStrings_QtGui[7701]
#define sipNameNr_7725 7725
#define sipName_7725 &sipStrings_QtGui[7725]
#define sipNameNr_QOpenGLTexture__Feature 7749
#define sipName_QOpenGLTexture__Feature &sipStrings_QtGui[7749]
#define sipNameNr_QPaintEngine__DirtyFlag 7773
#define sipName_QPaintEngine__DirtyFlag &sipStrings_QtGui[7773]
#define sipNameNr_QPixelFormat__ByteOrder 7797
#define sipName_QPixelFormat__ByteOrder &sipStrings_QtGui[7797]
#define sipNameNr_QPixelFormat__YUVLayout 7821
#define sipName_QPixelFormat__YUVLayout &sipStrings_QtGui[7821]
#define sipNameNr_QPointingDeviceUniqueId 7845
#define sipName_QPointingDeviceUniqueId &sipStrings_QtGui[7845]
#define sipNameNr_QStandardItem__ItemType 7869
#define sipName_QStandardItem__ItemType &sipStrings_QtGui[7869]
#define sipNameNr_QTextDocument__FindFlag 7893
#define sipName_QTextDocument__FindFlag &sipStrings_QtGui[7893]
#define sipNameNr_QTextFormat__FormatType 7917
#define sipName_QTextFormat__FormatType &sipStrings_QtGui[7917]
#define sipNameNr_QTextLayout__CursorMode 7941
#define sipName_QTextLayout__CursorMode &sipStrings_QtGui[7941]
#define sipNameNr_QTouchEvent__TouchPoint 7965
#define sipName_QTouchEvent__TouchPoint &sipStrings_QtGui[7965]
#define sipNameNr_QWindowStateChangeEvent 7989
#define sipName_QWindowStateChangeEvent &sipStrings_QtGui[7989]
#define sipNameNr_RasterOp_NotDestination 8013
#define sipName_RasterOp_NotDestination &sipStrings_QtGui[8013]
#define sipNameNr_RasterOp_SetDestination 8037
#define sipName_RasterOp_SetDestination &sipStrings_QtGui[8037]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x10 8061
#define sipName_SRGB8_Alpha8_ASTC_10x10 &sipStrings_QtGui[8061]
#define sipNameNr_SRGB8_Alpha8_ASTC_12x10 8085
#define sipName_SRGB8_Alpha8_ASTC_12x10 &sipStrings_QtGui[8085]
#define sipNameNr_SRGB8_Alpha8_ASTC_12x12 8109
#define sipName_SRGB8_Alpha8_ASTC_12x12 &sipStrings_QtGui[8109]
#define sipNameNr_TableCellTopBorderBrush 8133
#define sipName_TableCellTopBorderBrush &sipStrings_QtGui[8133]
#define sipNameNr_TableCellTopBorderStyle 8157
#define sipName_TableCellTopBorderStyle &sipStrings_QtGui[8157]
#define sipNameNr_TransformationRotate180 8181
#define sipName_TransformationRotate180 &sipStrings_QtGui[8181]
#define sipNameNr_TransformationRotate270 8205
#define sipName_TransformationRotate270 &sipStrings_QtGui[8205]
#define sipNameNr_addShaderFromSourceCode 8229
#define sipName_addShaderFromSourceCode &sipStrings_QtGui[8229]
#define sipNameNr_addShaderFromSourceFile 8253
#define sipName_addShaderFromSourceFile &sipStrings_QtGui[8253]
#define sipNameNr_advancesForGlyphIndexes 8277
#define sipName_advancesForGlyphIndexes &sipStrings_QtGui[8277]
#define sipNameNr_applicationFontFamilies 8301
#define sipName_applicationFontFamilies &sipStrings_QtGui[8301]
#define sipNameNr_applicationStateChanged 8325
#define sipName_applicationStateChanged &sipStrings_QtGui[8325]
#define sipNameNr_createThirdPartyMessage 8349
#define sipName_createThirdPartyMessage &sipStrings_QtGui[8349]
#define sipNameNr_decideFormatFromContent 8373
#define sipName_decideFormatFromContent &sipStrings_QtGui[8373]
#define sipNameNr_hasOpenGLShaderPrograms 8397
#define sipName_hasOpenGLShaderPrograms &sipStrings_QtGui[8397]
#define sipNameNr_imageFormatsForMimeType 8421
#define sipName_imageFormatsForMimeType &sipStrings_QtGui[8421]
#define sipNameNr_setCurrentBlockUserData 8445
#define sipName_setCurrentBlockUserData &sipStrings_QtGui[8445]
#define sipNameNr_setDesktopSettingsAware 8469
#define sipName_setDesktopSettingsAware &sipStrings_QtGui[8469]
#define sipNameNr_setFixedSamplePositions 8493
#define sipName_setFixedSamplePositions &sipStrings_QtGui[8493]
#define sipNameNr_setHorizontalHeaderItem 8517
#define sipName_setHorizontalHeaderItem &sipStrings_QtGui[8517]
#define sipNameNr_setKeepPositionOnInsert 8541
#define sipName_setKeepPositionOnInsert &sipStrings_QtGui[8541]
#define sipNameNr_setMaximumLevelOfDetail 8565
#define sipName_setMaximumLevelOfDetail &sipStrings_QtGui[8565]
#define sipNameNr_setMinimumLevelOfDetail 8589
#define sipName_setMinimumLevelOfDetail &sipStrings_QtGui[8589]
#define sipNameNr_setProgressiveScanWrite 8613
#define sipName_setProgressiveScanWrite &sipStrings_QtGui[8613]
#define sipNameNr_setVerticalHeaderLabels 8637
#define sipName_setVerticalHeaderLabels &sipStrings_QtGui[8637]
#define sipNameNr_setViewTransformEnabled 8661
#define sipName_setViewTransformEnabled &sipStrings_QtGui[8661]
#define sipNameNr_supportedWritingSystems 8685
#define sipName_supportedWritingSystems &sipStrings_QtGui[8685]
#define sipNameNr_tabFocusBehaviorChanged 8709
#define sipName_tabFocusBehaviorChanged &sipStrings_QtGui[8709]
#define sipNameNr_wheelScrollLinesChanged 8733
#define sipName_wheelScrollLinesChanged &sipStrings_QtGui[8733]
#define sipNameNr_AvailableSizesArgument 449
#define sipName_AvailableSizesArgument &sipStrings_QtGui[449]
#define sipNameNr_BindingTargetRectangle 8757
#define sipName_BindingTargetRectangle &sipStrings_QtGui[8757]
#define sipNameNr_BlockNonBreakableLines 8780
#define sipName_BlockNonBreakableLines &sipStrings_QtGui[8780]
#define sipNameNr_BorderStyle_DotDotDash 8803
#define sipName_BorderStyle_DotDotDash &sipStrings_QtGui[8803]
#define sipNameNr_CompositionMode_Darken 8826
#define sipName_CompositionMode_Darken &sipStrings_QtGui[8826]
#define sipNameNr_CompositionMode_Screen 8849
#define sipName_CompositionMode_Screen &sipStrings_QtGui[8849]
#define sipNameNr_CompositionMode_Source 8872
#define sipName_CompositionMode_Source &sipStrings_QtGui[8872]
#define sipNameNr_DeprecatedBehaviorType 8895
#define sipName_DeprecatedBehaviorType &sipStrings_QtGui[8895]
#define sipNameNr_LosslessImageRendering 8918
#define sipName_LosslessImageRendering &sipStrings_QtGui[8918]
#define sipNameNr_PageBreak_AlwaysBefore 8941
#define sipName_PageBreak_AlwaysBefore &sipStrings_QtGui[8941]
#define sipNameNr_PaintOutsidePaintEvent 8964
#define sipName_PaintOutsidePaintEvent &sipStrings_QtGui[8964]
#define sipNameNr_QColorSpace__Primaries 8987
#define sipName_QColorSpace__Primaries &sipStrings_QtGui[8987]
#define sipNameNr_QInputMethodQueryEvent 9010
#define sipName_QInputMethodQueryEvent &sipStrings_QtGui[9010]
#define sipNameNr_9033 9033
#define sipName_9033 &sipStrings_QtGui[9033]
#define sipNameNr_QOpenGLTexture__Filter 9056
#define sipName_QOpenGLTexture__Filter &sipStrings_QtGui[9056]
#define sipNameNr_QOpenGLTexture__Target 9079
#define sipName_QOpenGLTexture__Target &sipStrings_QtGui[9079]
#define sipNameNr_QSurface__SurfaceClass 9102
#define sipName_QSurface__SurfaceClass &sipStrings_QtGui[9102]
#define sipNameNr_QTextItem__RenderFlags 9125
#define sipName_QTextItem__RenderFlags &sipStrings_QtGui[9125]
#define sipNameNr_QTextListFormat__Style 9148
#define sipName_QTextListFormat__Style &sipStrings_QtGui[9148]
#define sipNameNr_QWhatsThisClickedEvent 9171
#define sipName_QWhatsThisClickedEvent &sipStrings_QtGui[9171]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x5 9194
#define sipName_SRGB8_Alpha8_ASTC_10x5 &sipStrings_QtGui[9194]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x6 9217
#define sipName_SRGB8_Alpha8_ASTC_10x6 &sipStrings_QtGui[9217]
#define sipNameNr_SRGB8_Alpha8_ASTC_10x8 9240
#define sipName_SRGB8_Alpha8_ASTC_10x8 &sipStrings_QtGui[9240]
#define sipNameNr_ShowDocumentTerminator 9263
#define sipName_ShowDocumentTerminator &sipStrings_QtGui[9263]
#define sipNameNr_TableCellBottomPadding 9286
#define sipName_TableCellBottomPadding &sipStrings_QtGui[9286]
#define sipNameNr_TessellationEvaluation 9309
#define sipName_TessellationEvaluation &sipStrings_QtGui[9309]
#define sipNameNr_TransformationRotate90 9332
#define sipName_TransformationRotate90 &sipStrings_QtGui[9332]
#define sipNameNr_UnsupportedFormatError 9355
#define sipName_UnsupportedFormatError &sipStrings_QtGui[9355]
#define sipNameNr_allowsErrorInteraction 9378
#define sipName_allowsErrorInteraction &sipStrings_QtGui[9378]
#define sipNameNr_anchorRectangleChanged 9401
#define sipName_anchorRectangleChanged &sipStrings_QtGui[9401]
#define sipNameNr_applicationDisplayName 9424
#define sipName_applicationDisplayName &sipStrings_QtGui[9424]
#define sipNameNr_clearAdditionalFormats 9447
#define sipName_clearAdditionalFormats &sipStrings_QtGui[9447]
#define sipNameNr_columnWidthConstraints 9470
#define sipName_columnWidthConstraints &sipStrings_QtGui[9470]
#define sipNameNr_cursorFlashTimeChanged 9493
#define sipName_cursorFlashTimeChanged &sipStrings_QtGui[9493]
#define sipNameNr_cursorRectangleChanged 9516
#define sipName_cursorRectangleChanged &sipStrings_QtGui[9516]
#define sipNameNr_defaultCursorMoveStyle 9539
#define sipName_defaultCursorMoveStyle &sipStrings_QtGui[9539]
#define sipNameNr_devicePixelRatioFScale 9562
#define sipName_devicePixelRatioFScale &sipStrings_QtGui[9562]
#define sipNameNr_inputItemClipRectangle 9585
#define sipName_inputItemClipRectangle &sipStrings_QtGui[9585]
#define sipNameNr_isFixedSamplePositions 9608
#define sipName_isFixedSamplePositions &sipStrings_QtGui[9608]
#define sipNameNr_keyboardAutoRepeatRate 9631
#define sipName_keyboardAutoRepeatRate &sipStrings_QtGui[9631]
#define sipNameNr_layoutDirectionChanged 9654
#define sipName_layoutDirectionChanged &sipStrings_QtGui[9654]
#define sipNameNr_previousCursorPosition 9677
#define sipName_previousCursorPosition &sipStrings_QtGui[9677]
#define sipNameNr_queryKeyboardModifiers 9700
#define sipName_queryKeyboardModifiers &sipStrings_QtGui[9700]
#define sipNameNr_quitOnLastWindowClosed 9723
#define sipName_quitOnLastWindowClosed &sipStrings_QtGui[9723]
#define sipNameNr_setDocumentXmpMetadata 9746
#define sipName_setDocumentXmpMetadata &sipStrings_QtGui[9746]
#define sipNameNr_setFallbackSearchPaths 9769
#define sipName_setFallbackSearchPaths &sipStrings_QtGui[9769]
#define sipNameNr_setFocusOnTouchRelease 9792
#define sipName_setFocusOnTouchRelease &sipStrings_QtGui[9792]
#define sipNameNr_setKeyboardGrabEnabled 9815
#define sipName_setKeyboardGrabEnabled &sipStrings_QtGui[9815]
#define sipNameNr_setMagnificationFilter 9838
#define sipName_setMagnificationFilter &sipStrings_QtGui[9838]
#define sipNameNr_setTableCellColumnSpan 9861
#define sipName_setTableCellColumnSpan &sipStrings_QtGui[9861]
#define sipNameNr_supportsThreadedOpenGL 9884
#define sipName_supportsThreadedOpenGL &sipStrings_QtGui[9884]
#define sipNameNr_takeVerticalHeaderItem 9907
#define sipName_takeVerticalHeaderItem &sipStrings_QtGui[9907]
#define sipNameNr_touchDoubleTapDistance 9930
#define sipName_touchDoubleTapDistance &sipStrings_QtGui[9930]
#define sipNameNr_useHoverEffectsChanged 9953
#define sipName_useHoverEffectsChanged &sipStrings_QtGui[9953]
#define sipNameNr_virtualGeometryChanged 9976
#define sipName_virtualGeometryChanged &sipStrings_QtGui[9976]
#define sipNameNr_CompositionMode_Clear 9999
#define sipName_CompositionMode_Clear &sipStrings_QtGui[9999]
#define sipNameNr_DefaultRenderableType 10021
#define sipName_DefaultRenderableType &sipStrings_QtGui[10021]
#define sipNameNr_FontHintingPreference 7433
#define sipName_FontHintingPreference &sipStrings_QtGui[7433]
#define sipNameNr_FontLetterSpacingType 7458
#define sipName_FontLetterSpacingType &sipStrings_QtGui[7458]
#define sipNameNr_FuzzyOrientationMatch 10043
#define sipName_FuzzyOrientationMatch &sipStrings_QtGui[10043]
#define sipNameNr_IncludeTrailingSpaces 10065
#define sipName_IncludeTrailingSpaces &sipStrings_QtGui[10065]
#define sipNameNr_MarkdownDialectGitHub 10087
#define sipName_MarkdownDialectGitHub &sipStrings_QtGui[10087]
#define sipNameNr_MoveToStartOfDocument 10109
#define sipName_MoveToStartOfDocument &sipStrings_QtGui[10109]
#define sipNameNr_NonCosmeticDefaultPen 10131
#define sipName_NonCosmeticDefaultPen &sipStrings_QtGui[10131]
#define sipNameNr_PageBreak_AlwaysAfter 10153
#define sipName_PageBreak_AlwaysAfter &sipStrings_QtGui[10153]
#define sipNameNr_PreferVerticalHinting 10175
#define sipName_PreferVerticalHinting &sipStrings_QtGui[10175]
#define sipNameNr_QFont__Capitalization 10197
#define sipName_QFont__Capitalization &sipStrings_QtGui[10197]
#define sipNameNr_10219 10219
#define sipName_10219 &sipStrings_QtGui[10219]
#define sipNameNr_10241 10241
#define sipName_10241 &sipStrings_QtGui[10241]
#define sipNameNr_QOpenGLBuffer__Access 10263
#define sipName_QOpenGLBuffer__Access &sipStrings_QtGui[10263]
#define sipNameNr_QOpenGLTextureBlitter 10285
#define sipName_QOpenGLTextureBlitter &sipStrings_QtGui[10285]
#define sipNameNr_QOpenGLVersionProfile 10307
#define sipName_QOpenGLVersionProfile &sipStrings_QtGui[10307]
#define sipNameNr_QPageSize__PageSizeId 10329
#define sipName_QPageSize__PageSizeId &sipStrings_QtGui[10329]
#define sipNameNr_QPainter__RenderHints 10351
#define sipName_QPainter__RenderHints &sipStrings_QtGui[10351]
#define sipNameNr_QPainterPath__Element 10373
#define sipName_QPainterPath__Element &sipStrings_QtGui[10373]
#define sipNameNr_QPlatformSurfaceEvent 10395
#define sipName_QPlatformSurfaceEvent &sipStrings_QtGui[10395]
#define sipNameNr_QRawFont__LayoutFlags 10417
#define sipName_QRawFont__LayoutFlags &sipStrings_QtGui[10417]
#define sipNameNr_QSurface__SurfaceType 10439
#define sipName_QSurface__SurfaceType &sipStrings_QtGui[10439]
#define sipNameNr_QTextCursor__MoveMode 10461
#define sipName_QTextCursor__MoveMode &sipStrings_QtGui[10461]
#define sipNameNr_QTextDocument__Stacks 10483
#define sipName_QTextDocument__Stacks &sipStrings_QtGui[10483]
#define sipNameNr_QTextDocumentFragment 10505
#define sipName_QTextDocumentFragment &sipStrings_QtGui[10505]
#define sipNameNr_QTextFormat__Property 10527
#define sipName_QTextFormat__Property &sipStrings_QtGui[10527]
#define sipNameNr_QTextItem__RenderFlag 10549
#define sipName_QTextItem__RenderFlag &sipStrings_QtGui[10549]
#define sipNameNr_QTextOption__WrapMode 10571
#define sipName_QTextOption__WrapMode &sipStrings_QtGui[10571]
#define sipNameNr_QWindow__AncestorMode 10593
#define sipName_QWindow__AncestorMode &sipStrings_QtGui[10593]
#define sipNameNr_Qt4CompatiblePainting 10615
#define sipName_Qt4CompatiblePainting &sipStrings_QtGui[10615]
#define sipNameNr_RGB_BP_UNSIGNED_FLOAT 10637
#define sipName_RGB_BP_UNSIGNED_FLOAT &sipStrings_QtGui[10637]
#define sipNameNr_RangeInvalidateBuffer 10659
#define sipName_RangeInvalidateBuffer &sipStrings_QtGui[10659]
#define sipNameNr_SRGB8_Alpha8_ASTC_4x4 10681
#define sipName_SRGB8_Alpha8_ASTC_4x4 &sipStrings_QtGui[10681]
#define sipNameNr_SRGB8_Alpha8_ASTC_5x4 10703
#define sipName_SRGB8_Alpha8_ASTC_5x4 &sipStrings_QtGui[10703]
#define sipNameNr_SRGB8_Alpha8_ASTC_5x5 10725
#define sipName_SRGB8_Alpha8_ASTC_5x5 &sipStrings_QtGui[10725]
#define sipNameNr_SRGB8_Alpha8_ASTC_6x5 10747
#define sipName_SRGB8_Alpha8_ASTC_6x5 &sipStrings_QtGui[10747]
#define sipNameNr_SRGB8_Alpha8_ASTC_6x6 10769
#define sipName_SRGB8_Alpha8_ASTC_6x6 &sipStrings_QtGui[10769]
#define sipNameNr_SRGB8_Alpha8_ASTC_8x5 10791
#define sipName_SRGB8_Alpha8_ASTC_8x5 &sipStrings_QtGui[10791]
#define sipNameNr_SRGB8_Alpha8_ASTC_8x6 10813
#define sipName_SRGB8_Alpha8_ASTC_8x6 &sipStrings_QtGui[10813]
#define sipNameNr_SRGB8_Alpha8_ASTC_8x8 10835
#define sipName_SRGB8_Alpha8_ASTC_8x8 &sipStrings_QtGui[10835]
#define sipNameNr_SRGB8_Alpha8_ETC2_EAC 10857
#define sipName_SRGB8_Alpha8_ETC2_EAC &sipStrings_QtGui[10857]
#define sipNameNr_SelectStartOfDocument 10879
#define sipName_SelectStartOfDocument &sipStrings_QtGui[10879]
#define sipNameNr_SmoothPixmapTransform 10901
#define sipName_SmoothPixmapTransform &sipStrings_QtGui[10901]
#define sipNameNr_TableCellBottomBorder 10923
#define sipName_TableCellBottomBorder &sipStrings_QtGui[10923]
#define sipNameNr_TableCellRightPadding 10945
#define sipName_TableCellRightPadding &sipStrings_QtGui[10945]
#define sipNameNr_TextVerticalAlignment 10967
#define sipName_TextVerticalAlignment &sipStrings_QtGui[10967]
#define sipNameNr_UndefinedBehaviorType 10989
#define sipName_UndefinedBehaviorType &sipStrings_QtGui[10989]
#define sipNameNr_accessibleDescription 11011
#define sipName_accessibleDescription &sipStrings_QtGui[11011]
#define sipNameNr_autoDetectImageFormat 11033
#define sipName_autoDetectImageFormat &sipStrings_QtGui[11033]
#define sipNameNr_bindAttributeLocation 11055
#define sipName_bindAttributeLocation &sipStrings_QtGui[11055]
#define sipNameNr_convertedToColorSpace 11077
#define sipName_convertedToColorSpace &sipStrings_QtGui[11077]
#define sipNameNr_cursorPositionChanged 11099
#define sipName_cursorPositionChanged &sipStrings_QtGui[11099]
#define sipNameNr_disableAttributeArray 11121
#define sipName_disableAttributeArray &sipStrings_QtGui[11121]
#define sipNameNr_documentLayoutChanged 11143
#define sipName_documentLayoutChanged &sipStrings_QtGui[11143]
#define sipNameNr_findBlockByLineNumber 11165
#define sipName_findBlockByLineNumber &sipStrings_QtGui[11165]
#define sipNameNr_fontHintingPreference 11187
#define sipName_fontHintingPreference &sipStrings_QtGui[11187]
#define sipNameNr_fontLetterSpacingType 11209
#define sipName_fontLetterSpacingType &sipStrings_QtGui[11209]
#define sipNameNr_glyphIndexesForString 11231
#define sipName_glyphIndexesForString &sipStrings_QtGui[11231]
#define sipNameNr_inputDirectionChanged 11253
#define sipName_inputDirectionChanged &sipStrings_QtGui[11253]
#define sipNameNr_internalTextureFormat 11275
#define sipName_internalTextureFormat &sipStrings_QtGui[11275]
#define sipNameNr_isValidCursorPosition 11297
#define sipName_isValidCursorPosition &sipStrings_QtGui[11297]
#define sipNameNr_joinPreviousEditBlock 11319
#define sipName_joinPreviousEditBlock &sipStrings_QtGui[11319]
#define sipNameNr_keyboardInputInterval 11341
#define sipName_keyboardInputInterval &sipStrings_QtGui[11341]
#define sipNameNr_mouseDoubleClickEvent 11363
#define sipName_mouseDoubleClickEvent &sipStrings_QtGui[11363]
#define sipNameNr_orientationUpdateMask 11385
#define sipName_orientationUpdateMask &sipStrings_QtGui[11385]
#define sipNameNr_passwordMaskCharacter 11407
#define sipName_passwordMaskCharacter &sipStrings_QtGui[11407]
#define sipNameNr_qPixelFormatGrayscale 11429
#define sipName_qPixelFormatGrayscale &sipStrings_QtGui[11429]
#define sipNameNr_removeApplicationFont 11451
#define sipName_removeApplicationFont &sipStrings_QtGui[11451]
#define sipNameNr_restoreOverrideCursor 11473
#define sipName_restoreOverrideCursor &sipStrings_QtGui[11473]
#define sipNameNr_setComparisonFunction 11495
#define sipName_setComparisonFunction &sipStrings_QtGui[11495]
#define sipNameNr_setFontCapitalization 11517
#define sipName_setFontCapitalization &sipStrings_QtGui[11517]
#define sipNameNr_setInputItemRectangle 11539
#define sipName_setInputItemRectangle &sipStrings_QtGui[11539]
#define sipNameNr_setInputItemTransform 11561
#define sipName_setInputItemTransform &sipStrings_QtGui[11561]
#define sipNameNr_setLevelOfDetailRange 11583
#define sipName_setLevelOfDetailRange &sipStrings_QtGui[11583]
#define sipNameNr_setMaximumTouchPoints 11605
#define sipName_setMaximumTouchPoints &sipStrings_QtGui[11605]
#define sipNameNr_setMinificationFilter 11627
#define sipName_setMinificationFilter &sipStrings_QtGui[11627]
#define sipNameNr_setVerticalHeaderItem 11649
#define sipName_setVerticalHeaderItem &sipStrings_QtGui[11649]
#define sipNameNr_setWorldMatrixEnabled 11671
#define sipName_setWorldMatrixEnabled &sipStrings_QtGui[11671]
#define sipNameNr_singleClickActivation 11693
#define sipName_singleClickActivation &sipStrings_QtGui[11693]
#define sipNameNr_supportedImageFormats 11715
#define sipName_supportedImageFormats &sipStrings_QtGui[11715]
#define sipNameNr_AnisotropicFiltering 11737
#define sipName_AnisotropicFiltering &sipStrings_QtGui[11737]
#define sipNameNr_BindingTarget1DArray 11758
#define sipName_BindingTarget1DArray &sipStrings_QtGui[11758]
#define sipNameNr_BindingTarget2DArray 11779
#define sipName_BindingTarget2DArray &sipStrings_QtGui[11779]
#define sipNameNr_BindingTargetCubeMap 11800
#define sipName_BindingTargetCubeMap &sipStrings_QtGui[11800]
#define sipNameNr_CombinedDepthStencil 11821
#define sipName_CombinedDepthStencil &sipStrings_QtGui[11821]
#define sipNameNr_CompatibilityProfile 11842
#define sipName_CompatibilityProfile &sipStrings_QtGui[11842]
#define sipNameNr_CompositionMode_Plus 11863
#define sipName_CompositionMode_Plus &sipStrings_QtGui[11863]
#define sipNameNr_DirtyCompositionMode 11884
#define sipName_DirtyCompositionMode &sipStrings_QtGui[11884]
#define sipNameNr_DontResetTextureUnit 11905
#define sipName_DontResetTextureUnit &sipStrings_QtGui[11905]
#define sipNameNr_LuminanceAlphaFormat 11926
#define sipName_LuminanceAlphaFormat &sipStrings_QtGui[11926]
#define sipNameNr_NearestMipMapNearest 11947
#define sipName_NearestMipMapNearest &sipStrings_QtGui[11947]
#define sipNameNr_NotificationSeverity 11968
#define sipName_NotificationSeverity &sipStrings_QtGui[11968]
#define sipNameNr_OpenGLContextProfile 415
#define sipName_OpenGLContextProfile &sipStrings_QtGui[415]
#define sipNameNr_PerspectiveTransform 11989
#define sipName_PerspectiveTransform &sipStrings_QtGui[11989]
#define sipNameNr_PreferDefaultHinting 12010
#define sipName_PreferDefaultHinting &sipStrings_QtGui[12010]
#define sipNameNr_ProgressiveScanWrite 8616
#define sipName_ProgressiveScanWrite &sipStrings_QtGui[8616]
#define sipNameNr_QColorConstants__Svg 12031
#define sipName_QColorConstants__Svg &sipStrings_QtGui[12031]
#define sipNameNr_QFont__StyleStrategy 12052
#define sipName_QFont__StyleStrategy &sipStrings_QtGui[12052]
#define sipNameNr_QInputMethod__Action 12073
#define sipName_QInputMethod__Action &sipStrings_QtGui[12073]
#define sipNameNr_12094 12094
#define sipName_12094 &sipStrings_QtGui[12094]
#define sipNameNr_QOpenGLShaderProgram 12115
#define sipName_QOpenGLShaderProgram &sipStrings_QtGui[12115]
#define sipNameNr_QPainter__RenderHint 12136
#define sipName_QPainter__RenderHint &sipStrings_QtGui[12136]
#define sipNameNr_QPalette__ColorGroup 12157
#define sipName_QPalette__ColorGroup &sipStrings_QtGui[12157]
#define sipNameNr_QRawFont__LayoutFlag 12178
#define sipName_QRawFont__LayoutFlag &sipStrings_QtGui[12178]
#define sipNameNr_QTextBlock__iterator 12199
#define sipName_QTextBlock__iterator &sipStrings_QtGui[12199]
#define sipNameNr_QTextFrame__iterator 12220
#define sipName_QTextFrame__iterator &sipStrings_QtGui[12220]
#define sipNameNr_QTextObjectInterface 12241
#define sipName_QTextObjectInterface &sipStrings_QtGui[12241]
#define sipNameNr_QTextOption__TabType 12262
#define sipName_QTextOption__TabType &sipStrings_QtGui[12262]
#define sipNameNr_QTextTableCellFormat 12283
#define sipName_QTextTableCellFormat &sipStrings_QtGui[12283]
#define sipNameNr_12304 12304
#define sipName_12304 &sipStrings_QtGui[12304]
#define sipNameNr_12325 12325
#define sipName_12325 &sipStrings_QtGui[12325]
#define sipNameNr_ScaledPixmapArgument 1016
#define sipName_ScaledPixmapArgument &sipStrings_QtGui[1016]
#define sipNameNr_ShaderCompilerSource 12346
#define sipName_ShaderCompilerSource &sipStrings_QtGui[12346]
#define sipNameNr_SmallestReadableFont 12367
#define sipName_SmallestReadableFont &sipStrings_QtGui[12367]
#define sipNameNr_SubPixelAntialiasing 12388
#define sipName_SubPixelAntialiasing &sipStrings_QtGui[12388]
#define sipNameNr_TableCellLeftPadding 12409
#define sipName_TableCellLeftPadding &sipStrings_QtGui[12409]
#define sipNameNr_TableCellRightBorder 12430
#define sipName_TableCellRightBorder &sipStrings_QtGui[12430]
#define sipNameNr_TextureCubeMapArrays 12451
#define sipName_TextureCubeMapArrays &sipStrings_QtGui[12451]
#define sipNameNr_TransformationMirror 12472
#define sipName_TransformationMirror &sipStrings_QtGui[12472]
#define sipNameNr_TransformedByDefault 12493
#define sipName_TransformedByDefault &sipStrings_QtGui[12493]
#define sipNameNr_acceptProposedAction 12514
#define sipName_acceptProposedAction &sipStrings_QtGui[12514]
#define sipNameNr_availableVirtualSize 12535
#define sipName_availableVirtualSize &sipStrings_QtGui[12535]
#define sipNameNr_changeOverrideCursor 12556
#define sipName_changeOverrideCursor &sipStrings_QtGui[12556]
#define sipNameNr_convertFromPlainText 12577
#define sipName_convertFromPlainText &sipStrings_QtGui[12577]
#define sipNameNr_currentBlockUserData 12598
#define sipName_currentBlockUserData &sipStrings_QtGui[12598]
#define sipNameNr_desktopSettingsAware 12619
#define sipName_desktopSettingsAware &sipStrings_QtGui[12619]
#define sipNameNr_enableAttributeArray 12640
#define sipName_enableAttributeArray &sipStrings_QtGui[12640]
#define sipNameNr_horizontalHeaderItem 12661
#define sipName_horizontalHeaderItem &sipStrings_QtGui[12661]
#define sipNameNr_keepPositionOnInsert 12682
#define sipName_keepPositionOnInsert &sipStrings_QtGui[12682]
#define sipNameNr_lengthVectorProperty 12703
#define sipName_lengthVectorProperty &sipStrings_QtGui[12703]
#define sipNameNr_lightgoldenrodyellow 12724
#define sipName_lightgoldenrodyellow &sipStrings_QtGui[12724]
#define sipNameNr_maximumHeightChanged 12745
#define sipName_maximumHeightChanged &sipStrings_QtGui[12745]
#define sipNameNr_maximumLevelOfDetail 12766
#define sipName_maximumLevelOfDetail &sipStrings_QtGui[12766]
#define sipNameNr_maximumMessageLength 12787
#define sipName_maximumMessageLength &sipStrings_QtGui[12787]
#define sipNameNr_mergeBlockCharFormat 12808
#define sipName_mergeBlockCharFormat &sipStrings_QtGui[12808]
#define sipNameNr_minimumHeightChanged 12829
#define sipName_minimumHeightChanged &sipStrings_QtGui[12829]
#define sipNameNr_minimumLevelOfDetail 12850
#define sipName_minimumLevelOfDetail &sipStrings_QtGui[12850]
#define sipNameNr_physicalDotsPerInchX 12871
#define sipName_physicalDotsPerInchX &sipStrings_QtGui[12871]
#define sipNameNr_physicalDotsPerInchY 12892
#define sipName_physicalDotsPerInchY &sipStrings_QtGui[12892]
#define sipNameNr_positionInlineObject 12913
#define sipName_positionInlineObject &sipStrings_QtGui[12913]
#define sipNameNr_primaryScreenChanged 12934
#define sipName_primaryScreenChanged &sipStrings_QtGui[12934]
#define sipNameNr_progressiveScanWrite 12955
#define sipName_progressiveScanWrite &sipStrings_QtGui[12955]
#define sipNameNr_setAdditionalFormats 12976
#define sipName_setAdditionalFormats &sipStrings_QtGui[12976]
#define sipNameNr_setBottomBorderBrush 12997
#define sipName_setBottomBorderBrush &sipStrings_QtGui[12997]
#define sipNameNr_setBottomBorderStyle 13018
#define sipName_setBottomBorderStyle &sipStrings_QtGui[13018]
#define sipNameNr_setCurrentBlockState 13039
#define sipName_setCurrentBlockState &sipStrings_QtGui[13039]
#define sipNameNr_setCurrentColorGroup 13060
#define sipName_setCurrentColorGroup &sipStrings_QtGui[13060]
#define sipNameNr_setDefaultStyleSheet 13081
#define sipName_setDefaultStyleSheet &sipStrings_QtGui[13081]
#define sipNameNr_setDefaultTextOption 13102
#define sipName_setDefaultTextOption &sipStrings_QtGui[13102]
#define sipNameNr_setElementPositionAt 13123
#define sipName_setElementPositionAt &sipStrings_QtGui[13123]
#define sipNameNr_setFallbackThemeName 13144
#define sipName_setFallbackThemeName &sipStrings_QtGui[13144]
#define sipNameNr_setFontLetterSpacing 13165
#define sipName_setFontLetterSpacing &sipStrings_QtGui[13165]
#define sipNameNr_setFontStyleStrategy 13186
#define sipName_setFontStyleStrategy &sipStrings_QtGui[13186]
#define sipNameNr_setHintingPreference 13207
#define sipName_setHintingPreference &sipStrings_QtGui[13207]
#define sipNameNr_setLevelofDetailBias 13228
#define sipName_setLevelofDetailBias &sipStrings_QtGui[13228]
#define sipNameNr_setMaximumAnisotropy 13249
#define sipName_setMaximumAnisotropy &sipStrings_QtGui[13249]
#define sipNameNr_setMaximumBlockCount 13270
#define sipName_setMaximumBlockCount &sipStrings_QtGui[13270]
#define sipNameNr_setNonBreakableLines 13291
#define sipName_setNonBreakableLines &sipStrings_QtGui[13291]
#define sipNameNr_setRegularExpression 13312
#define sipName_setRegularExpression &sipStrings_QtGui[13312]
#define sipNameNr_setStencilBufferSize 13333
#define sipName_setStencilBufferSize &sipStrings_QtGui[13333]
#define sipNameNr_setUniformValueArray 13354
#define sipName_setUniformValueArray &sipStrings_QtGui[13354]
#define sipNameNr_setVerticalAlignment 13375
#define sipName_setVerticalAlignment &sipStrings_QtGui[13375]
#define sipNameNr_setVerticalMovementX 13396
#define sipName_setVerticalMovementX &sipStrings_QtGui[13396]
#define sipNameNr_startDragTimeChanged 13417
#define sipName_startDragTimeChanged &sipStrings_QtGui[13417]
#define sipNameNr_supportedDragActions 13438
#define sipName_supportedDragActions &sipStrings_QtGui[13438]
#define sipNameNr_supportedDropActions 13459
#define sipName_supportedDropActions &sipStrings_QtGui[13459]
#define sipNameNr_tableCellFormatIndex 13480
#define sipName_tableCellFormatIndex &sipStrings_QtGui[13480]
#define sipNameNr_viewTransformEnabled 13501
#define sipName_viewTransformEnabled &sipStrings_QtGui[13501]
#define sipNameNr_withTransferFunction 13522
#define sipName_withTransferFunction &sipStrings_QtGui[13522]
#define sipNameNr_AsynchronousLogging 13543
#define sipName_AsynchronousLogging &sipStrings_QtGui[13543]
#define sipNameNr_AutomaticVisibility 13563
#define sipName_AutomaticVisibility &sipStrings_QtGui[13563]
#define sipNameNr_BindingTargetBuffer 13583
#define sipName_BindingTargetBuffer &sipStrings_QtGui[13583]
#define sipNameNr_BorderStyle_DotDash 13603
#define sipName_BorderStyle_DotDash &sipStrings_QtGui[13603]
#define sipNameNr_CompareGreaterEqual 13623
#define sipName_CompareGreaterEqual &sipStrings_QtGui[13623]
#define sipNameNr_CompareRefToTexture 13643
#define sipName_CompareRefToTexture &sipStrings_QtGui[13643]
#define sipNameNr_CompositionMode_Xor 13663
#define sipName_CompositionMode_Xor &sipStrings_QtGui[13663]
#define sipNameNr_ConicalGradientFill 13683
#define sipName_ConicalGradientFill &sipStrings_QtGui[13683]
#define sipNameNr_CoordinateDirection 560
#define sipName_CoordinateDirection &sipStrings_QtGui[560]
#define sipNameNr_CurrentSystemEndian 13703
#define sipName_CurrentSystemEndian &sipStrings_QtGui[13703]
#define sipNameNr_DefaultSwapBehavior 13723
#define sipName_DefaultSwapBehavior &sipStrings_QtGui[13723]
#define sipNameNr_DeprecatedFunctions 13743
#define sipName_DeprecatedFunctions &sipStrings_QtGui[13743]
#define sipNameNr_DirtyBackgroundMode 13763
#define sipName_DirtyBackgroundMode &sipStrings_QtGui[13763]
#define sipNameNr_DontGenerateMipMaps 13783
#define sipName_DontGenerateMipMaps &sipStrings_QtGui[13783]
#define sipNameNr_FindCaseSensitively 13803
#define sipName_FindCaseSensitively &sipStrings_QtGui[13803]
#define sipNameNr_ForceIntegerMetrics 13823
#define sipName_ForceIntegerMetrics &sipStrings_QtGui[13823]
#define sipNameNr_ImageTransformation 13843
#define sipName_ImageTransformation &sipStrings_QtGui[13843]
#define sipNameNr_InsertLineSeparator 13863
#define sipName_InsertLineSeparator &sipStrings_QtGui[13863]
#define sipNameNr_LinearMipMapNearest 13883
#define sipName_LinearMipMapNearest &sipStrings_QtGui[13883]
#define sipNameNr_MoveToEndOfDocument 13903
#define sipName_MoveToEndOfDocument &sipStrings_QtGui[13903]
#define sipNameNr_NearestMipMapLinear 13923
#define sipName_NearestMipMapLinear &sipStrings_QtGui[13923]
#define sipNameNr_NoSubpixelAntialias 13943
#define sipName_NoSubpixelAntialias &sipStrings_QtGui[13943]
#define sipNameNr_PaintEngineFeatures 1051
#define sipName_PaintEngineFeatures &sipStrings_QtGui[1051]
#define sipNameNr_PdmDevicePixelRatio 13963
#define sipName_PdmDevicePixelRatio &sipStrings_QtGui[13963]
#define sipNameNr_PixmapFragmentHints 3333
#define sipName_PixmapFragmentHints &sipStrings_QtGui[3333]
#define sipNameNr_13983 13983
#define sipName_13983 &sipStrings_QtGui[13983]
#define sipNameNr_QNativeGestureEvent 14003
#define sipName_QNativeGestureEvent &sipStrings_QtGui[14003]
#define sipNameNr_QOpenGLBuffer__Type 14023
#define sipName_QOpenGLBuffer__Type &sipStrings_QtGui[14023]
#define sipNameNr_QOpenGLContextGroup 14043
#define sipName_QOpenGLContextGroup &sipStrings_QtGui[14043]
#define sipNameNr_QOpenGLDebugMessage 14063
#define sipName_QOpenGLDebugMessage &sipStrings_QtGui[14063]
#define sipNameNr_QPainterPathStroker 14083
#define sipName_QPainterPathStroker &sipStrings_QtGui[14083]
#define sipNameNr_QPalette__ColorRole 14103
#define sipName_QPalette__ColorRole &sipStrings_QtGui[14103]
#define sipNameNr_QRegion__RegionType 14123
#define sipName_QRegion__RegionType &sipStrings_QtGui[14123]
#define sipNameNr_QScrollPrepareEvent 14143
#define sipName_QScrollPrepareEvent &sipStrings_QtGui[14143]
#define sipNameNr_QTextDocumentWriter 14163
#define sipName_QTextDocumentWriter &sipStrings_QtGui[14163]
#define sipNameNr_QWindow__Visibility 14183
#define sipName_QWindow__Visibility &sipStrings_QtGui[14183]
#define sipNameNr_RGB_BP_SIGNED_FLOAT 14203
#define sipName_RGB_BP_SIGNED_FLOAT &sipStrings_QtGui[14203]
#define sipNameNr_RangeUnsynchronized 14223
#define sipName_RangeUnsynchronized &sipStrings_QtGui[14223]
#define sipNameNr_SelectEndOfDocument 14243
#define sipName_SelectEndOfDocument &sipStrings_QtGui[14243]
#define sipNameNr_SpellCheckUnderline 14263
#define sipName_SpellCheckUnderline &sipStrings_QtGui[14263]
#define sipNameNr_StretchToDeviceMode 14283
#define sipName_StretchToDeviceMode &sipStrings_QtGui[14283]
#define sipNameNr_TableBorderCollapse 14303
#define sipName_TableBorderCollapse &sipStrings_QtGui[14303]
#define sipNameNr_TableCellColumnSpan 9864
#define sipName_TableCellColumnSpan &sipStrings_QtGui[9864]
#define sipNameNr_TableCellLeftBorder 14323
#define sipName_TableCellLeftBorder &sipStrings_QtGui[14323]
#define sipNameNr_TableCellTopPadding 14343
#define sipName_TableCellTopPadding &sipStrings_QtGui[14343]
#define sipNameNr_TableHeaderRowCount 14363
#define sipName_TableHeaderRowCount &sipStrings_QtGui[14363]
#define sipNameNr_Target2DMultisample 4972
#define sipName_Target2DMultisample &sipStrings_QtGui[4972]
#define sipNameNr_TessellationControl 14383
#define sipName_TessellationControl &sipStrings_QtGui[14383]
#define sipNameNr_applyColorTransform 14403
#define sipName_applyColorTransform &sipStrings_QtGui[14403]
#define sipNameNr_beginNativePainting 14423
#define sipName_beginNativePainting &sipStrings_QtGui[14423]
#define sipNameNr_brushNeedsResolving 14443
#define sipName_brushNeedsResolving &sipStrings_QtGui[14443]
#define sipNameNr_clearUndoRedoStacks 14463
#define sipName_clearUndoRedoStacks &sipStrings_QtGui[14463]
#define sipNameNr_convertToColorSpace 14483
#define sipName_convertToColorSpace &sipStrings_QtGui[14483]
#define sipNameNr_createHeuristicMask 14503
#define sipName_createHeuristicMask &sipStrings_QtGui[14503]
#define sipNameNr_createMaskFromColor 14523
#define sipName_createMaskFromColor &sipStrings_QtGui[14523]
#define sipNameNr_currentContextGroup 14543
#define sipName_currentContextGroup &sipStrings_QtGui[14543]
#define sipNameNr_documentSizeChanged 14563
#define sipName_documentSizeChanged &sipStrings_QtGui[14563]
#define sipNameNr_documentXmpMetadata 14583
#define sipName_documentXmpMetadata &sipStrings_QtGui[14583]
#define sipNameNr_drawPixmapFragments 14603
#define sipName_drawPixmapFragments &sipStrings_QtGui[14603]
#define sipNameNr_fallbackSearchPaths 14623
#define sipName_fallbackSearchPaths &sipStrings_QtGui[14623]
#define sipNameNr_firstCursorPosition 14643
#define sipName_firstCursorPosition &sipStrings_QtGui[14643]
#define sipNameNr_fontDatabaseChanged 14663
#define sipName_fontDatabaseChanged &sipStrings_QtGui[14663]
#define sipNameNr_hasComplexSelection 14683
#define sipName_hasComplexSelection &sipStrings_QtGui[14683]
#define sipNameNr_insertSubstitutions 14703
#define sipName_insertSubstitutions &sipStrings_QtGui[14703]
#define sipNameNr_lineForTextPosition 14723
#define sipName_lineForTextPosition &sipStrings_QtGui[14723]
#define sipNameNr_logicalDotsPerInchX 14743
#define sipName_logicalDotsPerInchX &sipStrings_QtGui[14743]
#define sipNameNr_logicalDotsPerInchY 14763
#define sipName_logicalDotsPerInchY &sipStrings_QtGui[14763]
#define sipNameNr_magnificationFilter 14783
#define sipName_magnificationFilter &sipStrings_QtGui[14783]
#define sipNameNr_maximumWidthChanged 14803
#define sipName_maximumWidthChanged &sipStrings_QtGui[14803]
#define sipNameNr_minimumWidthChanged 14823
#define sipName_minimumWidthChanged &sipStrings_QtGui[14823]
#define sipNameNr_modificationChanged 14843
#define sipName_modificationChanged &sipStrings_QtGui[14843]
#define sipNameNr_physicalDotsPerInch 14863
#define sipName_physicalDotsPerInch &sipStrings_QtGui[14863]
#define sipNameNr_physicalSizeChanged 14883
#define sipName_physicalSizeChanged &sipStrings_QtGui[14883]
#define sipNameNr_preeditAreaPosition 14903
#define sipName_preeditAreaPosition &sipStrings_QtGui[14903]
#define sipNameNr_reinterpretAsFormat 14923
#define sipName_reinterpretAsFormat &sipStrings_QtGui[14923]
#define sipNameNr_removeSubstitutions 14943
#define sipName_removeSubstitutions &sipStrings_QtGui[14943]
#define sipNameNr_rightCursorPosition 14963
#define sipName_rightCursorPosition &sipStrings_QtGui[14963]
#define sipNameNr_setDepthStencilMode 14983
#define sipName_setDepthStencilMode &sipStrings_QtGui[14983]
#define sipNameNr_setDevicePixelRatio 15003
#define sipName_setDevicePixelRatio &sipStrings_QtGui[15003]
#define sipNameNr_setMouseGrabEnabled 15023
#define sipName_setMouseGrabEnabled &sipStrings_QtGui[15023]
#define sipNameNr_setPatchVertexCount 15043
#define sipName_setPatchVertexCount &sipStrings_QtGui[15043]
#define sipNameNr_setRightBorderBrush 15063
#define sipName_setRightBorderBrush &sipStrings_QtGui[15063]
#define sipNameNr_setRightBorderStyle 15083
#define sipName_setRightBorderStyle &sipStrings_QtGui[15083]
#define sipNameNr_setSwapBytesEnabled 15103
#define sipName_setSwapBytesEnabled &sipStrings_QtGui[15103]
#define sipNameNr_setTableCellRowSpan 15123
#define sipName_setTableCellRowSpan &sipStrings_QtGui[15123]
#define sipNameNr_setThemeSearchPaths 15143
#define sipName_setThemeSearchPaths &sipStrings_QtGui[15143]
#define sipNameNr_setTransferFunction 15163
#define sipName_setTransferFunction &sipStrings_QtGui[15163]
#define sipNameNr_setUseDesignMetrics 15183
#define sipName_setUseDesignMetrics &sipStrings_QtGui[15183]
#define sipNameNr_setVisualNavigation 15203
#define sipName_setVisualNavigation &sipStrings_QtGui[15203]
#define sipNameNr_tableCellColumnSpan 15223
#define sipName_tableCellColumnSpan &sipStrings_QtGui[15223]
#define sipNameNr_writingSystemSample 15243
#define sipName_writingSystemSample &sipStrings_QtGui[15243]
#define sipNameNr_AlphaPremultiplied 1552
#define sipName_AlphaPremultiplied &sipStrings_QtGui[1552]
#define sipNameNr_AvailableSizesHook 15263
#define sipName_AvailableSizesHook &sipStrings_QtGui[15263]
#define sipNameNr_BackgroundImageUrl 15282
#define sipName_BackgroundImageUrl &sipStrings_QtGui[15282]
#define sipNameNr_BorderStyle_Dashed 15301
#define sipName_BorderStyle_Dashed &sipStrings_QtGui[15301]
#define sipNameNr_BorderStyle_Dotted 15320
#define sipName_BorderStyle_Dotted &sipStrings_QtGui[15320]
#define sipNameNr_BorderStyle_Double 15339
#define sipName_BorderStyle_Double &sipStrings_QtGui[15339]
#define sipNameNr_BorderStyle_Groove 15358
#define sipName_BorderStyle_Groove &sipStrings_QtGui[15358]
#define sipNameNr_BorderStyle_Outset 15377
#define sipName_BorderStyle_Outset &sipStrings_QtGui[15377]
#define sipNameNr_ComparisonFunction 740
#define sipName_ComparisonFunction &sipStrings_QtGui[740]
#define sipNameNr_CurveToDataElement 15396
#define sipName_CurveToDataElement &sipStrings_QtGui[15396]
#define sipNameNr_DeleteCompleteLine 15415
#define sipName_DeleteCompleteLine &sipStrings_QtGui[15415]
#define sipNameNr_FanFoldGermanLegal 15434
#define sipName_FanFoldGermanLegal &sipStrings_QtGui[15434]
#define sipNameNr_FontCapitalization 11520
#define sipName_FontCapitalization &sipStrings_QtGui[11520]
#define sipNameNr_FontSizeAdjustment 15453
#define sipName_FontSizeAdjustment &sipStrings_QtGui[15453]
#define sipNameNr_Format_Grayscale16 15472
#define sipName_Format_Grayscale16 &sipStrings_QtGui[15472]
#define sipNameNr_FullWidthSelection 15491
#define sipName_FullWidthSelection &sipStrings_QtGui[15491]
#define sipNameNr_IncrementalReading 15510
#define sipName_IncrementalReading &sipStrings_QtGui[15510]
#define sipNameNr_LineDistanceHeight 15529
#define sipName_LineDistanceHeight &sipStrings_QtGui[15529]
#define sipNameNr_LinearGradientFill 15548
#define sipName_LinearGradientFill &sipStrings_QtGui[15548]
#define sipNameNr_LinearMipMapLinear 15567
#define sipName_LinearMipMapLinear &sipStrings_QtGui[15567]
#define sipNameNr_MoveToPreviousChar 15586
#define sipName_MoveToPreviousChar &sipStrings_QtGui[15586]
#define sipNameNr_MoveToPreviousLine 15605
#define sipName_MoveToPreviousLine &sipStrings_QtGui[15605]
#define sipNameNr_MoveToPreviousPage 15624
#define sipName_MoveToPreviousPage &sipStrings_QtGui[15624]
#define sipNameNr_MoveToPreviousWord 15643
#define sipName_MoveToPreviousWord &sipStrings_QtGui[15643]
#define sipNameNr_MoveToStartOfBlock 15662
#define sipName_MoveToStartOfBlock &sipStrings_QtGui[15662]
#define sipNameNr_NormalizedPosition 15681
#define sipName_NormalizedPosition &sipStrings_QtGui[15681]
#define sipNameNr_ObjectBoundingMode 15700
#define sipName_ObjectBoundingMode &sipStrings_QtGui[15700]
#define sipNameNr_PaintEngineFeature 1519
#define sipName_PaintEngineFeature &sipStrings_QtGui[1519]
#define sipNameNr_PartialUpdateBlend 15719
#define sipName_PartialUpdateBlend &sipStrings_QtGui[15719]
#define sipNameNr_PixmapFragmentHint 3983
#define sipName_PixmapFragmentHint &sipStrings_QtGui[3983]
#define sipNameNr_PrimitiveTransform 15738
#define sipName_PrimitiveTransform &sipStrings_QtGui[15738]
#define sipNameNr_ProportionalHeight 15757
#define sipName_ProportionalHeight &sipStrings_QtGui[15757]
#define sipNameNr_QColor__NameFormat 15776
#define sipName_QColor__NameFormat &sipStrings_QtGui[15776]
#define sipNameNr_QFont__SpacingType 15795
#define sipName_QFont__SpacingType &sipStrings_QtGui[15795]
#define sipNameNr_QImage__InvertMode 15814
#define sipName_QImage__InvertMode &sipStrings_QtGui[15814]
#define sipNameNr_15833 15833
#define sipName_15833 &sipStrings_QtGui[15833]
#define sipNameNr_QMovie__MovieState 15852
#define sipName_QMovie__MovieState &sipStrings_QtGui[15852]
#define sipNameNr_QOpenGLDebugLogger 15871
#define sipName_QOpenGLDebugLogger &sipStrings_QtGui[15871]
#define sipNameNr_QOpenGLPaintDevice 15890
#define sipName_QOpenGLPaintDevice &sipStrings_QtGui[15890]
#define sipNameNr_QOpenGLTimeMonitor 15909
#define sipName_QOpenGLTimeMonitor &sipStrings_QtGui[15909]
#define sipNameNr_QPaintDeviceWindow 15928
#define sipName_QPaintDeviceWindow &sipStrings_QtGui[15928]
#define sipNameNr_QPaintEngine__Type 15947
#define sipName_QPaintEngine__Type &sipStrings_QtGui[15947]
#define sipNameNr_15966 15966
#define sipName_15966 &sipStrings_QtGui[15966]
#define sipNameNr_QStandardItemModel 15985
#define sipName_QStandardItemModel &sipStrings_QtGui[15985]
#define sipNameNr_QSyntaxHighlighter 16004
#define sipName_QSyntaxHighlighter &sipStrings_QtGui[16004]
#define sipNameNr_QTextBlockUserData 16023
#define sipName_QTextBlockUserData &sipStrings_QtGui[16023]
#define sipNameNr_QTextOption__Flags 16042
#define sipName_QTextOption__Flags &sipStrings_QtGui[16042]
#define sipNameNr_RadialGradientFill 16061
#define sipName_RadialGradientFill &sipStrings_QtGui[16061]
#define sipNameNr_RangeFlushExplicit 16080
#define sipName_RangeFlushExplicit &sipStrings_QtGui[16080]
#define sipNameNr_RasterOp_NotSource 16099
#define sipName_RasterOp_NotSource &sipStrings_QtGui[16099]
#define sipNameNr_RestartImmediately 16118
#define sipName_RestartImmediately &sipStrings_QtGui[16118]
#define sipNameNr_ScientificNotation 16137
#define sipName_ScientificNotation &sipStrings_QtGui[16137]
#define sipNameNr_SelectPreviousChar 16156
#define sipName_SelectPreviousChar &sipStrings_QtGui[16156]
#define sipNameNr_SelectPreviousLine 16175
#define sipName_SelectPreviousLine &sipStrings_QtGui[16175]
#define sipNameNr_SelectPreviousPage 16194
#define sipName_SelectPreviousPage &sipStrings_QtGui[16194]
#define sipNameNr_SelectPreviousWord 16213
#define sipName_SelectPreviousWord &sipStrings_QtGui[16213]
#define sipNameNr_SelectStartOfBlock 16232
#define sipName_SelectStartOfBlock &sipStrings_QtGui[16232]
#define sipNameNr_StyleSheetResource 16251
#define sipName_StyleSheetResource &sipStrings_QtGui[16251]
#define sipNameNr_SynchronousLogging 16270
#define sipName_SynchronousLogging &sipStrings_QtGui[16270]
#define sipNameNr_TableCellTopBorder 16289
#define sipName_TableCellTopBorder &sipStrings_QtGui[16289]
#define sipNameNr_TargetCubeMapArray 5674
#define sipName_TargetCubeMapArray &sipStrings_QtGui[5674]
#define sipNameNr_TextUnderlineColor 16308
#define sipName_TextUnderlineColor &sipStrings_QtGui[16308]
#define sipNameNr_TextUnderlineStyle 16327
#define sipName_TextUnderlineStyle &sipStrings_QtGui[16327]
#define sipNameNr_TextureMipMapLevel 16346
#define sipName_TextureMipMapLevel &sipStrings_QtGui[16346]
#define sipNameNr_TextureMultisample 16365
#define sipName_TextureMultisample &sipStrings_QtGui[16365]
#define sipNameNr_TraditionalChinese 16384
#define sipName_TraditionalChinese &sipStrings_QtGui[16384]
#define sipNameNr_TransformationFlip 16403
#define sipName_TransformationFlip &sipStrings_QtGui[16403]
#define sipNameNr_TransformationNone 16422
#define sipName_TransformationNone &sipStrings_QtGui[16422]
#define sipNameNr_TransformationType 2637
#define sipName_TransformationType &sipStrings_QtGui[2637]
#define sipNameNr_TypeInterpretation 1585
#define sipName_TypeInterpretation &sipStrings_QtGui[1585]
#define sipNameNr_UInt32_RGB10A2_Rev 16441
#define sipName_UInt32_RGB10A2_Rev &sipStrings_QtGui[16441]
#define sipNameNr_WindowSystemSource 16460
#define sipName_WindowSystemSource &sipStrings_QtGui[16460]
#define sipNameNr_aboutToBeDestroyed 16479
#define sipName_aboutToBeDestroyed &sipStrings_QtGui[16479]
#define sipNameNr_addApplicationFont 16498
#define sipName_addApplicationFont &sipStrings_QtGui[16498]
#define sipNameNr_addColorAttachment 16517
#define sipName_addColorAttachment &sipStrings_QtGui[16517]
#define sipNameNr_availableRedoSteps 16536
#define sipName_availableRedoSteps &sipStrings_QtGui[16536]
#define sipNameNr_availableUndoSteps 16555
#define sipName_availableUndoSteps &sipStrings_QtGui[16555]
#define sipNameNr_blockFormatChanged 16574
#define sipName_blockFormatChanged &sipStrings_QtGui[16574]
#define sipNameNr_comparisonFunction 16593
#define sipName_comparisonFunction &sipStrings_QtGui[16593]
#define sipNameNr_contentOrientation 16612
#define sipName_contentOrientation &sipStrings_QtGui[16612]
#define sipNameNr_currentFrameNumber 16631
#define sipName_currentFrameNumber &sipStrings_QtGui[16631]
#define sipNameNr_currentImageNumber 16650
#define sipName_currentImageNumber &sipStrings_QtGui[16650]
#define sipNameNr_deletePreviousChar 16669
#define sipName_deletePreviousChar &sipStrings_QtGui[16669]
#define sipNameNr_ensureActiveTarget 16688
#define sipName_ensureActiveTarget &sipStrings_QtGui[16688]
#define sipNameNr_focusObjectChanged 16707
#define sipName_focusObjectChanged &sipStrings_QtGui[16707]
#define sipNameNr_focusWindowChanged 16726
#define sipName_focusWindowChanged &sipStrings_QtGui[16726]
#define sipNameNr_fontCapitalization 16745
#define sipName_fontCapitalization &sipStrings_QtGui[16745]
#define sipNameNr_fontSmoothingGamma 16764
#define sipName_fontSmoothingGamma &sipStrings_QtGui[16764]
#define sipNameNr_fromRotationMatrix 16783
#define sipName_fromRotationMatrix &sipStrings_QtGui[16783]
#define sipNameNr_globalShareContext 16802
#define sipName_globalShareContext &sipStrings_QtGui[16802]
#define sipNameNr_inputItemRectangle 16821
#define sipName_inputItemRectangle &sipStrings_QtGui[16821]
#define sipNameNr_inputItemTransform 16840
#define sipName_inputItemTransform &sipStrings_QtGui[16840]
#define sipNameNr_insertSubstitution 16859
#define sipName_insertSubstitution &sipStrings_QtGui[16859]
#define sipNameNr_isSmoothlyScalable 16878
#define sipName_isSmoothlyScalable &sipStrings_QtGui[16878]
#define sipNameNr_isStorageAllocated 16897
#define sipName_isStorageAllocated &sipStrings_QtGui[16897]
#define sipNameNr_isSwapBytesEnabled 16916
#define sipName_isSwapBytesEnabled &sipStrings_QtGui[16916]
#define sipNameNr_lastCursorPosition 16935
#define sipName_lastCursorPosition &sipStrings_QtGui[16935]
#define sipNameNr_leftCursorPosition 16954
#define sipName_leftCursorPosition &sipStrings_QtGui[16954]
#define sipNameNr_levelOfDetailRange 16973
#define sipName_levelOfDetailRange &sipStrings_QtGui[16973]
#define sipNameNr_logicalDotsPerInch 16992
#define sipName_logicalDotsPerInch &sipStrings_QtGui[16992]
#define sipNameNr_maximumTouchPoints 17011
#define sipName_maximumTouchPoints &sipStrings_QtGui[17011]
#define sipNameNr_minificationFilter 17030
#define sipName_minificationFilter &sipStrings_QtGui[17030]
#define sipNameNr_nextCursorPosition 17049
#define sipName_nextCursorPosition &sipStrings_QtGui[17049]
#define sipNameNr_openGLModuleHandle 17068
#define sipName_openGLModuleHandle &sipStrings_QtGui[17068]
#define sipNameNr_orientationChanged 17087
#define sipName_orientationChanged &sipStrings_QtGui[17087]
#define sipNameNr_previousBlockState 17106
#define sipName_previousBlockState &sipStrings_QtGui[17106]
#define sipNameNr_primaryOrientation 17125
#define sipName_primaryOrientation &sipStrings_QtGui[17125]
#define sipNameNr_rawScreenPositions 17144
#define sipName_rawScreenPositions &sipStrings_QtGui[17144]
#define sipNameNr_refreshRateChanged 17163
#define sipName_refreshRateChanged &sipStrings_QtGui[17163]
#define sipNameNr_removeSelectedText 17182
#define sipName_removeSelectedText &sipStrings_QtGui[17182]
#define sipNameNr_resizeInlineObject 17201
#define sipName_resizeInlineObject &sipStrings_QtGui[17201]
#define sipNameNr_selectedTableCells 17220
#define sipName_selectedTableCells &sipStrings_QtGui[17220]
#define sipNameNr_setAlphaBufferSize 17239
#define sipName_setAlphaBufferSize &sipStrings_QtGui[17239]
#define sipNameNr_setAttributeBuffer 17258
#define sipName_setAttributeBuffer &sipStrings_QtGui[17258]
#define sipNameNr_setBackgroundColor 17277
#define sipName_setBackgroundColor &sipStrings_QtGui[17277]
#define sipNameNr_setBlockCharFormat 17296
#define sipName_setBlockCharFormat &sipStrings_QtGui[17296]
#define sipNameNr_setCompositionMode 17315
#define sipName_setCompositionMode &sipStrings_QtGui[17315]
#define sipNameNr_setContentPosRange 17334
#define sipName_setContentPosRange &sipStrings_QtGui[17334]
#define sipNameNr_setCursorMoveStyle 17353
#define sipName_setCursorMoveStyle &sipStrings_QtGui[17353]
#define sipNameNr_setDepthBufferSize 17372
#define sipName_setDepthBufferSize &sipStrings_QtGui[17372]
#define sipNameNr_setDesktopFileName 17391
#define sipName_setDesktopFileName &sipStrings_QtGui[17391]
#define sipNameNr_setFontWordSpacing 17410
#define sipName_setFontWordSpacing &sipStrings_QtGui[17410]
#define sipNameNr_setGreenBufferSize 17429
#define sipName_setGreenBufferSize &sipStrings_QtGui[17429]
#define sipNameNr_setLayoutDirection 17448
#define sipName_setLayoutDirection &sipStrings_QtGui[17448]
#define sipNameNr_setLeadingIncluded 17467
#define sipName_setLeadingIncluded &sipStrings_QtGui[17467]
#define sipNameNr_setLeftBorderBrush 17486
#define sipName_setLeftBorderBrush &sipStrings_QtGui[17486]
#define sipNameNr_setLeftBorderStyle 17505
#define sipName_setLeftBorderStyle &sipStrings_QtGui[17505]
#define sipNameNr_setManagerProperty 17524
#define sipName_setManagerProperty &sipStrings_QtGui[17524]
#define sipNameNr_setMetaInformation 17543
#define sipName_setMetaInformation &sipStrings_QtGui[17543]
#define sipNameNr_setPageBreakPolicy 17562
#define sipName_setPageBreakPolicy &sipStrings_QtGui[17562]
#define sipNameNr_setPageOrientation 17581
#define sipName_setPageOrientation &sipStrings_QtGui[17581]
#define sipNameNr_setPerformanceHint 17600
#define sipName_setPerformanceHint &sipStrings_QtGui[17600]
#define sipNameNr_setTabStopDistance 17619
#define sipName_setTabStopDistance &sipStrings_QtGui[17619]
#define sipNameNr_setTransientParent 17638
#define sipName_setTransientParent &sipStrings_QtGui[17638]
#define sipNameNr_setUndoRedoEnabled 17657
#define sipName_setUndoRedoEnabled &sipStrings_QtGui[17657]
#define sipNameNr_setUseHoverEffects 17676
#define sipName_setUseHoverEffects &sipStrings_QtGui[17676]
#define sipNameNr_startNormalizedPos 17695
#define sipName_startNormalizedPos &sipStrings_QtGui[17695]
#define sipNameNr_supportedMimeTypes 17714
#define sipName_supportedMimeTypes &sipStrings_QtGui[17714]
#define sipNameNr_supportsFindBuffer 17733
#define sipName_supportsFindBuffer &sipStrings_QtGui[17733]
#define sipNameNr_tangentialPressure 17752
#define sipName_tangentialPressure &sipStrings_QtGui[17752]
#define sipNameNr_typeInterpretation 17771
#define sipName_typeInterpretation &sipStrings_QtGui[17771]
#define sipNameNr_verticalHeaderItem 17790
#define sipName_verticalHeaderItem &sipStrings_QtGui[17790]
#define sipNameNr_windowStateChanged 17809
#define sipName_windowStateChanged &sipStrings_QtGui[17809]
#define sipNameNr_windowTitleChanged 17828
#define sipName_windowTitleChanged &sipStrings_QtGui[17828]
#define sipNameNr_worldMatrixEnabled 17847
#define sipName_worldMatrixEnabled &sipStrings_QtGui[17847]
#define sipNameNr_AggressiveCaching 17866
#define sipName_AggressiveCaching &sipStrings_QtGui[17866]
#define sipNameNr_ApplicationSource 17884
#define sipName_ApplicationSource &sipStrings_QtGui[17884]
#define sipNameNr_BlockBottomMargin 17902
#define sipName_BlockBottomMargin &sipStrings_QtGui[17902]
#define sipNameNr_BlockCodeLanguage 17920
#define sipName_BlockCodeLanguage &sipStrings_QtGui[17920]
#define sipNameNr_BorderStyle_Inset 17938
#define sipName_BorderStyle_Inset &sipStrings_QtGui[17938]
#define sipNameNr_BorderStyle_Ridge 17956
#define sipName_BorderStyle_Ridge &sipStrings_QtGui[17956]
#define sipNameNr_BorderStyle_Solid 17974
#define sipName_BorderStyle_Solid &sipStrings_QtGui[17974]
#define sipNameNr_CursorOnCharacter 17992
#define sipName_CursorOnCharacter &sipStrings_QtGui[17992]
#define sipNameNr_DefaultColorSpace 18010
#define sipName_DefaultColorSpace &sipStrings_QtGui[18010]
#define sipNameNr_DeleteStartOfWord 18028
#define sipName_DeleteStartOfWord &sipStrings_QtGui[18028]
#define sipNameNr_ExcludeTransients 18046
#define sipName_ExcludeTransients &sipStrings_QtGui[18046]
#define sipNameNr_ExecutiveStandard 18064
#define sipName_ExecutiveStandard &sipStrings_QtGui[18064]
#define sipNameNr_FileNotFoundError 18082
#define sipName_FileNotFoundError &sipStrings_QtGui[18082]
#define sipNameNr_FirstFontProperty 18100
#define sipName_FirstFontProperty &sipStrings_QtGui[18100]
#define sipNameNr_FontLetterSpacing 13168
#define sipName_FontLetterSpacing &sipStrings_QtGui[13168]
#define sipNameNr_FontPropertiesAll 18118
#define sipName_FontPropertiesAll &sipStrings_QtGui[18118]
#define sipNameNr_FontSizeIncrement 18136
#define sipName_FontSizeIncrement &sipStrings_QtGui[18136]
#define sipNameNr_FontStyleStrategy 13189
#define sipName_FontStyleStrategy &sipStrings_QtGui[13189]
#define sipNameNr_Format_Grayscale8 18154
#define sipName_Format_Grayscale8 &sipStrings_QtGui[18154]
#define sipNameNr_FrameBottomMargin 18172
#define sipName_FrameBottomMargin &sipStrings_QtGui[18172]
#define sipNameNr_HintingPreference 6762
#define sipName_HintingPreference &sipStrings_QtGui[6762]
#define sipNameNr_IncludeTransients 18190
#define sipName_IncludeTransients &sipStrings_QtGui[18190]
#define sipNameNr_InvalidImageError 18208
#define sipName_InvalidImageError &sipStrings_QtGui[18208]
#define sipNameNr_MoveToStartOfLine 18226
#define sipName_MoveToStartOfLine &sipStrings_QtGui[18226]
#define sipNameNr_NPOTTextureRepeat 18244
#define sipName_NPOTTextureRepeat &sipStrings_QtGui[18244]
#define sipNameNr_PaintDeviceMetric 2105
#define sipName_PaintDeviceMetric &sipStrings_QtGui[2105]
#define sipNameNr_PartialUpdateBlit 18262
#define sipName_PartialUpdateBlit &sipStrings_QtGui[18262]
#define sipNameNr_PercentageSpacing 18280
#define sipName_PercentageSpacing &sipStrings_QtGui[18280]
#define sipNameNr_PixelAntialiasing 12391
#define sipName_PixelAntialiasing &sipStrings_QtGui[12391]
#define sipNameNr_PixelUnpackBuffer 18298
#define sipName_PixelUnpackBuffer &sipStrings_QtGui[18298]
#define sipNameNr_PreferFullHinting 18316
#define sipName_PreferFullHinting &sipStrings_QtGui[18316]
#define sipNameNr_PreviousCharacter 18334
#define sipName_PreviousCharacter &sipStrings_QtGui[18334]
#define sipNameNr_QContextMenuEvent 18352
#define sipName_QContextMenuEvent &sipStrings_QtGui[18352]
#define sipNameNr_QGradient__Preset 18370
#define sipName_QGradient__Preset &sipStrings_QtGui[18370]
#define sipNameNr_QGradient__Spread 18388
#define sipName_QGradient__Spread &sipStrings_QtGui[18388]
#define sipNameNr_QInputMethodEvent 18406
#define sipName_QInputMethodEvent &sipStrings_QtGui[18406]
#define sipNameNr_18424 18424
#define sipName_18424 &sipStrings_QtGui[18424]
#define sipNameNr_QMovie__CacheMode 18442
#define sipName_QMovie__CacheMode &sipStrings_QtGui[18442]
#define sipNameNr_QOffscreenSurface 18460
#define sipName_QOffscreenSurface &sipStrings_QtGui[18460]
#define sipNameNr_QOpenGLTimerQuery 18478
#define sipName_QOpenGLTimerQuery &sipStrings_QtGui[18478]
#define sipNameNr_QPageLayout__Mode 18496
#define sipName_QPageLayout__Mode &sipStrings_QtGui[18496]
#define sipNameNr_QPageLayout__Unit 18514
#define sipName_QPageLayout__Unit &sipStrings_QtGui[18514]
#define sipNameNr_QPagedPaintDevice 18532
#define sipName_QPagedPaintDevice &sipStrings_QtGui[18532]
#define sipNameNr_QPaintEngineState 18550
#define sipName_QPaintEngineState &sipStrings_QtGui[18550]
#define sipNameNr_QPixmapCache__Key 18568
#define sipName_QPixmapCache__Key &sipStrings_QtGui[18568]
#define sipNameNr_QTextInlineObject 18586
#define sipName_QTextInlineObject &sipStrings_QtGui[18586]
#define sipNameNr_QTextLength__Type 18604
#define sipName_QTextLength__Type &sipStrings_QtGui[18604]
#define sipNameNr_QTextOption__Flag 18622
#define sipName_QTextOption__Flag &sipStrings_QtGui[18622]
#define sipNameNr_QValidator__State 18640
#define sipName_QValidator__State &sipStrings_QtGui[18640]
#define sipNameNr_18658 18658
#define sipName_18658 &sipStrings_QtGui[18658]
#define sipNameNr_ResetNotification 18676
#define sipName_ResetNotification &sipStrings_QtGui[18676]
#define sipNameNr_SelectStartOfLine 18694
#define sipName_SelectStartOfLine &sipStrings_QtGui[18694]
#define sipNameNr_ShowTabsAndSpaces 18712
#define sipName_ShowTabsAndSpaces &sipStrings_QtGui[18712]
#define sipNameNr_SimplifiedChinese 18730
#define sipName_SimplifiedChinese &sipStrings_QtGui[18730]
#define sipNameNr_SupportedSubTypes 18748
#define sipName_SupportedSubTypes &sipStrings_QtGui[18748]
#define sipNameNr_UInt16_R5G6B5_Rev 18766
#define sipName_UInt16_R5G6B5_Rev &sipStrings_QtGui[18766]
#define sipNameNr_UInt16_RGB5A1_Rev 18784
#define sipName_UInt16_RGB5A1_Rev &sipStrings_QtGui[18784]
#define sipNameNr_UndoAndRedoStacks 18802
#define sipName_UndoAndRedoStacks &sipStrings_QtGui[18802]
#define sipNameNr_VerticalAlignment 776
#define sipName_VerticalAlignment &sipStrings_QtGui[776]
#define sipNameNr_addFileAttachment 18820
#define sipName_addFileAttachment &sipStrings_QtGui[18820]
#define sipNameNr_additionalFormats 18838
#define sipName_additionalFormats &sipStrings_QtGui[18838]
#define sipNameNr_allowsInteraction 18856
#define sipName_allowsInteraction &sipStrings_QtGui[18856]
#define sipNameNr_attributeLocation 18874
#define sipName_attributeLocation &sipStrings_QtGui[18874]
#define sipNameNr_availableGeometry 18892
#define sipName_availableGeometry &sipStrings_QtGui[18892]
#define sipNameNr_blockBoundingRect 18910
#define sipName_blockBoundingRect &sipStrings_QtGui[18910]
#define sipNameNr_blockCountChanged 18928
#define sipName_blockCountChanged &sipStrings_QtGui[18928]
#define sipNameNr_blockWithMarkerAt 18946
#define sipName_blockWithMarkerAt &sipStrings_QtGui[18946]
#define sipNameNr_bottomBorderBrush 18964
#define sipName_bottomBorderBrush &sipStrings_QtGui[18964]
#define sipNameNr_bottomBorderStyle 18982
#define sipName_bottomBorderStyle &sipStrings_QtGui[18982]
#define sipNameNr_combinedTransform 19000
#define sipName_combinedTransform &sipStrings_QtGui[19000]
#define sipNameNr_commitDataRequest 19018
#define sipName_commitDataRequest &sipStrings_QtGui[19018]
#define sipNameNr_compileSourceCode 19036
#define sipName_compileSourceCode &sipStrings_QtGui[19036]
#define sipNameNr_compileSourceFile 19054
#define sipName_compileSourceFile &sipStrings_QtGui[19054]
#define sipNameNr_createTextureView 19072
#define sipName_createTextureView &sipStrings_QtGui[19072]
#define sipNameNr_currentBlockState 19090
#define sipName_currentBlockState &sipStrings_QtGui[19090]
#define sipNameNr_currentColorGroup 19108
#define sipName_currentColorGroup &sipStrings_QtGui[19108]
#define sipNameNr_defaultStyleSheet 19126
#define sipName_defaultStyleSheet &sipStrings_QtGui[19126]
#define sipNameNr_defaultTextOption 19144
#define sipName_defaultTextOption &sipStrings_QtGui[19144]
#define sipNameNr_devicePixelRatioF 19162
#define sipName_devicePixelRatioF &sipStrings_QtGui[19162]
#define sipNameNr_drawConvexPolygon 19180
#define sipName_drawConvexPolygon &sipStrings_QtGui[19180]
#define sipNameNr_endNativePainting 19198
#define sipName_endNativePainting &sipStrings_QtGui[19198]
#define sipNameNr_fallbackThemeName 19216
#define sipName_fallbackThemeName &sipStrings_QtGui[19216]
#define sipNameNr_findBlockByNumber 19234
#define sipName_findBlockByNumber &sipStrings_QtGui[19234]
#define sipNameNr_findBufferChanged 19252
#define sipName_findBufferChanged &sipStrings_QtGui[19252]
#define sipNameNr_fontLetterSpacing 19270
#define sipName_fontLetterSpacing &sipStrings_QtGui[19270]
#define sipNameNr_fontStyleStrategy 19288
#define sipName_fontStyleStrategy &sipStrings_QtGui[19288]
#define sipNameNr_frameBoundingRect 19306
#define sipName_frameBoundingRect &sipStrings_QtGui[19306]
#define sipNameNr_hasStaticContents 19324
#define sipName_hasStaticContents &sipStrings_QtGui[19324]
#define sipNameNr_hintingPreference 19342
#define sipName_hintingPreference &sipStrings_QtGui[19342]
#define sipNameNr_horizontalAdvance 19360
#define sipName_horizontalAdvance &sipStrings_QtGui[19360]
#define sipNameNr_invisibleRootItem 19378
#define sipName_invisibleRootItem &sipStrings_QtGui[19378]
#define sipNameNr_isResultAvailable 19396
#define sipName_isResultAvailable &sipStrings_QtGui[19396]
#define sipNameNr_isSessionRestored 19414
#define sipName_isSessionRestored &sipStrings_QtGui[19414]
#define sipNameNr_isTableCellFormat 19432
#define sipName_isTableCellFormat &sipStrings_QtGui[19432]
#define sipNameNr_isUndoRedoEnabled 19450
#define sipName_isUndoRedoEnabled &sipStrings_QtGui[19450]
#define sipNameNr_keyboardModifiers 19468
#define sipName_keyboardModifiers &sipStrings_QtGui[19468]
#define sipNameNr_keyboardRectangle 19486
#define sipName_keyboardRectangle &sipStrings_QtGui[19486]
#define sipNameNr_lastNormalizedPos 19504
#define sipName_lastNormalizedPos &sipStrings_QtGui[19504]
#define sipNameNr_letterSpacingType 19522
#define sipName_letterSpacingType &sipStrings_QtGui[19522]
#define sipNameNr_levelofDetailBias 19540
#define sipName_levelofDetailBias &sipStrings_QtGui[19540]
#define sipNameNr_markContentsDirty 19558
#define sipName_markContentsDirty &sipStrings_QtGui[19558]
#define sipNameNr_maximumAnisotropy 19576
#define sipName_maximumAnisotropy &sipStrings_QtGui[19576]
#define sipNameNr_maximumBlockCount 19594
#define sipName_maximumBlockCount &sipStrings_QtGui[19594]
#define sipNameNr_mediumspringgreen 19612
#define sipName_mediumspringgreen &sipStrings_QtGui[19612]
#define sipNameNr_mouseReleaseEvent 19630
#define sipName_mouseReleaseEvent &sipStrings_QtGui[19630]
#define sipNameNr_nativeOrientation 19648
#define sipName_nativeOrientation &sipStrings_QtGui[19648]
#define sipNameNr_nonBreakableLines 19666
#define sipName_nonBreakableLines &sipStrings_QtGui[19666]
#define sipNameNr_overshootDistance 19684
#define sipName_overshootDistance &sipStrings_QtGui[19684]
#define sipNameNr_passwordMaskDelay 19702
#define sipName_passwordMaskDelay &sipStrings_QtGui[19702]
#define sipNameNr_penNeedsResolving 19720
#define sipName_penNeedsResolving &sipStrings_QtGui[19720]
#define sipNameNr_qPixelFormatAlpha 19738
#define sipName_qPixelFormatAlpha &sipStrings_QtGui[19738]
#define sipNameNr_regularExpression 19756
#define sipName_regularExpression &sipStrings_QtGui[19756]
#define sipNameNr_replacementLength 19774
#define sipName_replacementLength &sipStrings_QtGui[19774]
#define sipNameNr_setAccessibleText 19792
#define sipName_setAccessibleText &sipStrings_QtGui[19792]
#define sipNameNr_setAttributeArray 19810
#define sipName_setAttributeArray &sipStrings_QtGui[19810]
#define sipNameNr_setAttributeValue 19828
#define sipName_setAttributeValue &sipStrings_QtGui[19828]
#define sipNameNr_setBackgroundMode 19846
#define sipName_setBackgroundMode &sipStrings_QtGui[19846]
#define sipNameNr_setBlueBufferSize 19864
#define sipName_setBlueBufferSize &sipStrings_QtGui[19864]
#define sipNameNr_setBorderCollapse 19882
#define sipName_setBorderCollapse &sipStrings_QtGui[19882]
#define sipNameNr_setCapitalization 19900
#define sipName_setCapitalization &sipStrings_QtGui[19900]
#define sipNameNr_setComparisonMode 19918
#define sipName_setComparisonMode &sipStrings_QtGui[19918]
#define sipNameNr_setCompressedData 19936
#define sipName_setCompressedData &sipStrings_QtGui[19936]
#define sipNameNr_setCoordinateMode 19954
#define sipName_setCoordinateMode &sipStrings_QtGui[19954]
#define sipNameNr_setCurveThreshold 19972
#define sipName_setCurveThreshold &sipStrings_QtGui[19972]
#define sipNameNr_setDiscardCommand 19990
#define sipName_setDiscardCommand &sipStrings_QtGui[19990]
#define sipNameNr_setDocumentLayout 20008
#define sipName_setDocumentLayout &sipStrings_QtGui[20008]
#define sipNameNr_setDocumentMargin 20026
#define sipName_setDocumentMargin &sipStrings_QtGui[20026]
#define sipNameNr_setFontFixedPitch 20044
#define sipName_setFontFixedPitch &sipStrings_QtGui[20044]
#define sipNameNr_setHeaderRowCount 20062
#define sipName_setHeaderRowCount &sipStrings_QtGui[20062]
#define sipNameNr_setMinimumMargins 20080
#define sipName_setMinimumMargins &sipStrings_QtGui[20080]
#define sipNameNr_setOptimizedWrite 20098
#define sipName_setOptimizedWrite &sipStrings_QtGui[20098]
#define sipNameNr_setOverrideCursor 20116
#define sipName_setOverrideCursor &sipStrings_QtGui[20116]
#define sipNameNr_setRedBlueSwizzle 20134
#define sipName_setRedBlueSwizzle &sipStrings_QtGui[20134]
#define sipNameNr_setRenderableType 20152
#define sipName_setRenderableType &sipStrings_QtGui[20152]
#define sipNameNr_setRestartCommand 20170
#define sipName_setRestartCommand &sipStrings_QtGui[20170]
#define sipNameNr_setScaledClipRect 20188
#define sipName_setScaledClipRect &sipStrings_QtGui[20188]
#define sipNameNr_setStaticContents 20206
#define sipName_setStaticContents &sipStrings_QtGui[20206]
#define sipNameNr_setTopBorderBrush 20224
#define sipName_setTopBorderBrush &sipStrings_QtGui[20224]
#define sipNameNr_setTopBorderStyle 20242
#define sipName_setTopBorderStyle &sipStrings_QtGui[20242]
#define sipNameNr_setTransformation 20260
#define sipName_setTransformation &sipStrings_QtGui[20260]
#define sipNameNr_setUnderlineColor 20278
#define sipName_setUnderlineColor &sipStrings_QtGui[20278]
#define sipNameNr_setUnderlineStyle 20296
#define sipName_setUnderlineStyle &sipStrings_QtGui[20296]
#define sipNameNr_setWorldTransform 20314
#define sipName_setWorldTransform &sipStrings_QtGui[20314]
#define sipNameNr_sip_simplewrapper 20332
#define sipName_sip_simplewrapper &sipStrings_QtGui[20332]
#define sipNameNr_startDragDistance 20350
#define sipName_startDragDistance &sipStrings_QtGui[20350]
#define sipNameNr_startDragVelocity 20368
#define sipName_startDragVelocity &sipStrings_QtGui[20368]
#define sipNameNr_startSystemResize 20386
#define sipName_startSystemResize &sipStrings_QtGui[20386]
#define sipNameNr_stencilBufferSize 20404
#define sipName_stencilBufferSize &sipStrings_QtGui[20404]
#define sipNameNr_supportedSubTypes 20422
#define sipName_supportedSubTypes &sipStrings_QtGui[20422]
#define sipNameNr_supportsAnimation 20440
#define sipName_supportsAnimation &sipStrings_QtGui[20440]
#define sipNameNr_supportsCharacter 20458
#define sipName_supportsCharacter &sipStrings_QtGui[20458]
#define sipNameNr_supportsSelection 20476
#define sipName_supportsSelection &sipStrings_QtGui[20476]
#define sipNameNr_tightBoundingRect 20494
#define sipName_tightBoundingRect &sipStrings_QtGui[20494]
#define sipNameNr_toSubpathPolygons 20512
#define sipName_toSubpathPolygons &sipStrings_QtGui[20512]
#define sipNameNr_toTableCellFormat 20530
#define sipName_toTableCellFormat &sipStrings_QtGui[20530]
#define sipNameNr_underlinePosition 20548
#define sipName_underlinePosition &sipStrings_QtGui[20548]
#define sipNameNr_unregisterHandler 20566
#define sipName_unregisterHandler &sipStrings_QtGui[20566]
#define sipNameNr_verticalAlignment 20584
#define sipName_verticalAlignment &sipStrings_QtGui[20584]
#define sipNameNr_verticalMovementX 20602
#define sipName_verticalMovementX &sipStrings_QtGui[20602]
#define sipNameNr_visibilityChanged 20620
#define sipName_visibilityChanged &sipStrings_QtGui[20620]
#define sipNameNr_writingSystemName 20638
#define sipName_writingSystemName &sipStrings_QtGui[20638]
#define sipNameNr_AlignSuperScript 20656
#define sipName_AlignSuperScript &sipStrings_QtGui[20656]
#define sipNameNr_AntialiasingType 5245
#define sipName_AntialiasingType &sipStrings_QtGui[5245]
#define sipNameNr_BlockRightMargin 20673
#define sipName_BlockRightMargin &sipStrings_QtGui[20673]
#define sipNameNr_BlockUnderCursor 20690
#define sipName_BlockUnderCursor &sipStrings_QtGui[20690]
#define sipNameNr_BorderStyle_None 20707
#define sipName_BorderStyle_None &sipStrings_QtGui[20707]
#define sipNameNr_CommpareNotEqual 20724
#define sipName_CommpareNotEqual &sipStrings_QtGui[20724]
#define sipNameNr_CompareLessEqual 20741
#define sipName_CompareLessEqual &sipStrings_QtGui[20741]
#define sipNameNr_CompressionRatio 20758
#define sipName_CompressionRatio &sipStrings_QtGui[20758]
#define sipNameNr_CubeMapNegativeX 20775
#define sipName_CubeMapNegativeX &sipStrings_QtGui[20775]
#define sipNameNr_CubeMapNegativeY 20792
#define sipName_CubeMapNegativeY &sipStrings_QtGui[20792]
#define sipNameNr_CubeMapNegativeZ 20809
#define sipName_CubeMapNegativeZ &sipStrings_QtGui[20809]
#define sipNameNr_CubeMapPositiveX 20826
#define sipName_CubeMapPositiveX &sipStrings_QtGui[20826]
#define sipNameNr_CubeMapPositiveY 20843
#define sipName_CubeMapPositiveY &sipStrings_QtGui[20843]
#define sipNameNr_CubeMapPositiveZ 20860
#define sipName_CubeMapPositiveZ &sipStrings_QtGui[20860]
#define sipNameNr_DepthStencilMode 1356
#define sipName_DepthStencilMode &sipStrings_QtGui[1356]
#define sipNameNr_DirtyBrushOrigin 20877
#define sipName_DirtyBrushOrigin &sipStrings_QtGui[20877]
#define sipNameNr_DirtyClipEnabled 20894
#define sipName_DirtyClipEnabled &sipStrings_QtGui[20894]
#define sipNameNr_EnvelopePersonal 20911
#define sipName_EnvelopePersonal &sipStrings_QtGui[20911]
#define sipNameNr_EternalConstance 20928
#define sipName_EternalConstance &sipStrings_QtGui[20928]
#define sipNameNr_FrameBorderBrush 20945
#define sipName_FrameBorderBrush &sipStrings_QtGui[20945]
#define sipNameNr_FrameBorderStyle 20962
#define sipName_FrameBorderStyle &sipStrings_QtGui[20962]
#define sipNameNr_FrameRightMargin 20979
#define sipName_FrameRightMargin &sipStrings_QtGui[20979]
#define sipNameNr_ImageReaderError 2360
#define sipName_ImageReaderError &sipStrings_QtGui[2360]
#define sipNameNr_ImageWriterError 2391
#define sipName_ImageWriterError &sipStrings_QtGui[2391]
#define sipNameNr_ImmutableStorage 20996
#define sipName_ImmutableStorage &sipStrings_QtGui[20996]
#define sipNameNr_InvalidDataError 21013
#define sipName_InvalidDataError &sipStrings_QtGui[21013]
#define sipNameNr_LastFontProperty 21030
#define sipName_LastFontProperty &sipStrings_QtGui[21030]
#define sipNameNr_ListNumberPrefix 21047
#define sipName_ListNumberPrefix &sipStrings_QtGui[21047]
#define sipNameNr_ListNumberSuffix 21064
#define sipName_ListNumberSuffix &sipStrings_QtGui[21064]
#define sipNameNr_MarkdownFeatures 2170
#define sipName_MarkdownFeatures &sipStrings_QtGui[2170]
#define sipNameNr_MarkdownResource 21081
#define sipName_MarkdownResource &sipStrings_QtGui[21081]
#define sipNameNr_MipMapGeneration 1389
#define sipName_MipMapGeneration &sipStrings_QtGui[1389]
#define sipNameNr_MoveToEndOfBlock 21098
#define sipName_MoveToEndOfBlock &sipStrings_QtGui[21098]
#define sipNameNr_NotPremultiplied 21115
#define sipName_NotPremultiplied &sipStrings_QtGui[21115]
#define sipNameNr_OpenGLCompatible 21132
#define sipName_OpenGLCompatible &sipStrings_QtGui[21132]
#define sipNameNr_OpenGLModuleType 1323
#define sipName_OpenGLModuleType &sipStrings_QtGui[1323]
#define sipNameNr_OriginBottomLeft 21149
#define sipName_OriginBottomLeft &sipStrings_QtGui[21149]
#define sipNameNr_PatternTransform 21166
#define sipName_PatternTransform &sipStrings_QtGui[21166]
#define sipNameNr_PercentageLength 21183
#define sipName_PercentageLength &sipStrings_QtGui[21183]
#define sipNameNr_QClipboard__Mode 21200
#define sipName_QClipboard__Mode &sipStrings_QtGui[21200]
#define sipNameNr_QConicalGradient 21217
#define sipName_QConicalGradient &sipStrings_QtGui[21217]
#define sipNameNr_QDesktopServices 21234
#define sipName_QDesktopServices &sipStrings_QtGui[21234]
#define sipNameNr_QDoubleValidator 21251
#define sipName_QDoubleValidator &sipStrings_QtGui[21251]
#define sipNameNr_QFont__StyleHint 21268
#define sipName_QFont__StyleHint &sipStrings_QtGui[21268]
#define sipNameNr_21285 21285
#define sipName_21285 &sipStrings_QtGui[21285]
#define sipNameNr_21302 21302
#define sipName_21302 &sipStrings_QtGui[21302]
#define sipNameNr_QRegExpValidator 21319
#define sipName_QRegExpValidator &sipStrings_QtGui[21319]
#define sipNameNr_21336 21336
#define sipName_21336 &sipStrings_QtGui[21336]
#define sipNameNr_QTextBlockFormat 21353
#define sipName_QTextBlockFormat &sipStrings_QtGui[21353]
#define sipNameNr_QTextFrameFormat 21370
#define sipName_QTextFrameFormat &sipStrings_QtGui[21370]
#define sipNameNr_QTextImageFormat 21387
#define sipName_QTextImageFormat &sipStrings_QtGui[21387]
#define sipNameNr_QTextOption__Tab 21404
#define sipName_QTextOption__Tab &sipStrings_QtGui[21404]
#define sipNameNr_QTextTableFormat 21421
#define sipName_QTextTableFormat &sipStrings_QtGui[21421]
#define sipNameNr_RangeAccessFlags 2010
#define sipName_RangeAccessFlags &sipStrings_QtGui[2010]
#define sipNameNr_ResetTextureUnit 11909
#define sipName_ResetTextureUnit &sipStrings_QtGui[11909]
#define sipNameNr_RestartIfRunning 21438
#define sipName_RestartIfRunning &sipStrings_QtGui[21438]
#define sipNameNr_ScaledPixmapHook 21455
#define sipName_ScaledPixmapHook &sipStrings_QtGui[21455]
#define sipNameNr_SelectEndOfBlock 21472
#define sipName_SelectEndOfBlock &sipStrings_QtGui[21472]
#define sipNameNr_SeparateAdvances 21489
#define sipName_SeparateAdvances &sipStrings_QtGui[21489]
#define sipNameNr_StandardNotation 21506
#define sipName_StandardNotation &sipStrings_QtGui[21506]
#define sipNameNr_StencilTexturing 21523
#define sipName_StencilTexturing &sipStrings_QtGui[21523]
#define sipNameNr_SurfaceEventType 268
#define sipName_SurfaceEventType &sipStrings_QtGui[268]
#define sipNameNr_SwizzleComponent 1422
#define sipName_SwizzleComponent &sipStrings_QtGui[1422]
#define sipNameNr_TableCellPadding 21540
#define sipName_TableCellPadding &sipStrings_QtGui[21540]
#define sipNameNr_TableCellRowSpan 15126
#define sipName_TableCellRowSpan &sipStrings_QtGui[15126]
#define sipNameNr_TableCellSpacing 21557
#define sipName_TableCellSpacing &sipStrings_QtGui[21557]
#define sipNameNr_TextAntialiasing 21574
#define sipName_TextAntialiasing &sipStrings_QtGui[21574]
#define sipNameNr_TextureRectangle 21591
#define sipName_TextureRectangle &sipStrings_QtGui[21591]
#define sipNameNr_TextureUnitReset 1455
#define sipName_TextureUnitReset &sipStrings_QtGui[1455]
#define sipNameNr_ThirdPartySource 21608
#define sipName_ThirdPartySource &sipStrings_QtGui[21608]
#define sipNameNr_TransferFunction 3096
#define sipName_TransferFunction &sipStrings_QtGui[3096]
#define sipNameNr_UInt16_RGBA4_Rev 21625
#define sipName_UInt16_RGBA4_Rev &sipStrings_QtGui[21625]
#define sipNameNr_UInt32_RGBA8_Rev 21642
#define sipName_UInt32_RGBA8_Rev &sipStrings_QtGui[21642]
#define sipNameNr_UseDesignMetrics 15186
#define sipName_UseDesignMetrics &sipStrings_QtGui[15186]
#define sipNameNr_alphaMapForGlyph 21659
#define sipName_alphaMapForGlyph &sipStrings_QtGui[21659]
#define sipNameNr_animatingChanged 21676
#define sipName_animatingChanged &sipStrings_QtGui[21676]
#define sipNameNr_antialiasingType 21693
#define sipName_antialiasingType &sipStrings_QtGui[21693]
#define sipNameNr_applicationState 21710
#define sipName_applicationState &sipStrings_QtGui[21710]
#define sipNameNr_averageCharWidth 21727
#define sipName_averageCharWidth &sipStrings_QtGui[21727]
#define sipNameNr_blockFormatIndex 21744
#define sipName_blockFormatIndex &sipStrings_QtGui[21744]
#define sipNameNr_boundingRectChar 21761
#define sipName_boundingRectChar &sipStrings_QtGui[21761]
#define sipNameNr_clipBoundingRect 21778
#define sipName_clipBoundingRect &sipStrings_QtGui[21778]
#define sipNameNr_controlPointRect 21795
#define sipName_controlPointRect &sipStrings_QtGui[21795]
#define sipNameNr_convertFromImage 21812
#define sipName_convertFromImage &sipStrings_QtGui[21812]
#define sipNameNr_currentImageRect 21829
#define sipName_currentImageRect &sipStrings_QtGui[21829]
#define sipNameNr_depthStencilMode 21846
#define sipName_depthStencilMode &sipStrings_QtGui[21846]
#define sipNameNr_devicePixelRatio 21863
#define sipName_devicePixelRatio &sipStrings_QtGui[21863]
#define sipNameNr_disconnectNotify 21880
#define sipName_disconnectNotify &sipStrings_QtGui[21880]
#define sipNameNr_drawInlineObject 21897
#define sipName_drawInlineObject &sipStrings_QtGui[21897]
#define sipNameNr_ellipseDiameters 21914
#define sipName_ellipseDiameters &sipStrings_QtGui[21914]
#define sipNameNr_fromAxisAndAngle 21931
#define sipName_fromAxisAndAngle &sipStrings_QtGui[21931]
#define sipNameNr_handlerForObject 21948
#define sipName_handlerForObject &sipStrings_QtGui[21948]
#define sipNameNr_hasOpenGLShaders 21965
#define sipName_hasOpenGLShaders &sipStrings_QtGui[21965]
#define sipNameNr_isBitmapScalable 21982
#define sipName_isBitmapScalable &sipStrings_QtGui[21982]
#define sipNameNr_lastResortFamily 21999
#define sipName_lastResortFamily &sipStrings_QtGui[21999]
#define sipNameNr_lastWindowClosed 22016
#define sipName_lastWindowClosed &sipStrings_QtGui[22016]
#define sipNameNr_maximumMipLevels 22033
#define sipName_maximumMipLevels &sipStrings_QtGui[22033]
#define sipNameNr_mediumaquamarine 22050
#define sipName_mediumaquamarine &sipStrings_QtGui[22050]
#define sipNameNr_mergeBlockFormat 22067
#define sipName_mergeBlockFormat &sipStrings_QtGui[22067]
#define sipNameNr_nativeVirtualKey 22084
#define sipName_nativeVirtualKey &sipStrings_QtGui[22084]
#define sipNameNr_naturalTextWidth 22101
#define sipName_naturalTextWidth &sipStrings_QtGui[22101]
#define sipNameNr_openGLModuleType 22118
#define sipName_openGLModuleType &sipStrings_QtGui[22118]
#define sipNameNr_pageCountChanged 22135
#define sipName_pageCountChanged &sipStrings_QtGui[22135]
#define sipNameNr_patchVertexCount 22152
#define sipName_patchVertexCount &sipStrings_QtGui[22152]
#define sipNameNr_qPixelFormatCmyk 22169
#define sipName_qPixelFormatCmyk &sipStrings_QtGui[22169]
#define sipNameNr_qPixelFormatRgba 22186
#define sipName_qPixelFormatRgba &sipStrings_QtGui[22186]
#define sipNameNr_queryFocusObject 22203
#define sipName_queryFocusObject &sipStrings_QtGui[22203]
#define sipNameNr_rehighlightBlock 22220
#define sipName_rehighlightBlock &sipStrings_QtGui[22220]
#define sipNameNr_removeAllShaders 22237
#define sipName_removeAllShaders &sipStrings_QtGui[22237]
#define sipNameNr_replacementStart 22254
#define sipName_replacementStart &sipStrings_QtGui[22254]
#define sipNameNr_rightBorderBrush 22271
#define sipName_rightBorderBrush &sipStrings_QtGui[22271]
#define sipNameNr_rightBorderStyle 22288
#define sipName_rightBorderStyle &sipStrings_QtGui[22288]
#define sipNameNr_saveStateRequest 22305
#define sipName_saveStateRequest &sipStrings_QtGui[22305]
#define sipNameNr_selectionChanged 22322
#define sipName_selectionChanged &sipStrings_QtGui[22322]
#define sipNameNr_setAutoTransform 22339
#define sipName_setAutoTransform &sipStrings_QtGui[22339]
#define sipNameNr_setBottomPadding 22356
#define sipName_setBottomPadding &sipStrings_QtGui[22356]
#define sipNameNr_setDefaultFormat 22373
#define sipName_setDefaultFormat &sipStrings_QtGui[22373]
#define sipNameNr_setDotsPerMeterX 22390
#define sipName_setDotsPerMeterX &sipStrings_QtGui[22390]
#define sipNameNr_setDotsPerMeterY 22407
#define sipName_setDotsPerMeterY &sipStrings_QtGui[22407]
#define sipNameNr_setFontPointSize 22424
#define sipName_setFontPointSize &sipStrings_QtGui[22424]
#define sipNameNr_setFontStrikeOut 22441
#define sipName_setFontStrikeOut &sipStrings_QtGui[22441]
#define sipNameNr_setFontStyleHint 22458
#define sipName_setFontStyleHint &sipStrings_QtGui[22458]
#define sipNameNr_setFontStyleName 22475
#define sipName_setFontStyleName &sipStrings_QtGui[22475]
#define sipNameNr_setFontUnderline 22492
#define sipName_setFontUnderline &sipStrings_QtGui[22492]
#define sipNameNr_setFramePosition 22509
#define sipName_setFramePosition &sipStrings_QtGui[22509]
#define sipNameNr_setItemPrototype 22526
#define sipName_setItemPrototype &sipStrings_QtGui[22526]
#define sipNameNr_setItemRoleNames 22543
#define sipName_setItemRoleNames &sipStrings_QtGui[22543]
#define sipNameNr_setLetterSpacing 22560
#define sipName_setLetterSpacing &sipStrings_QtGui[22560]
#define sipNameNr_setMaximumHeight 22577
#define sipName_setMaximumHeight &sipStrings_QtGui[22577]
#define sipNameNr_setMinMagFilters 22594
#define sipName_setMinMagFilters &sipStrings_QtGui[22594]
#define sipNameNr_setMinimumHeight 22611
#define sipName_setMinimumHeight &sipStrings_QtGui[22611]
#define sipNameNr_setMipLevelRange 22628
#define sipName_setMipLevelRange &sipStrings_QtGui[22628]
#define sipNameNr_setRedBufferSize 22645
#define sipName_setRedBufferSize &sipStrings_QtGui[22645]
#define sipNameNr_setSizeIncrement 22662
#define sipName_setSizeIncrement &sipStrings_QtGui[22662]
#define sipNameNr_setStyleStrategy 22679
#define sipName_setStyleStrategy &sipStrings_QtGui[22679]
#define sipNameNr_setTextAlignment 22696
#define sipName_setTextAlignment &sipStrings_QtGui[22696]
#define sipNameNr_setTextDirection 22713
#define sipName_setTextDirection &sipStrings_QtGui[22713]
#define sipNameNr_setTextureTarget 22730
#define sipName_setTextureTarget &sipStrings_QtGui[22730]
#define sipNameNr_showIsFullScreen 22747
#define sipName_showIsFullScreen &sipStrings_QtGui[22747]
#define sipNameNr_supportedActions 22764
#define sipName_supportedActions &sipStrings_QtGui[22764]
#define sipNameNr_supportedFormats 22781
#define sipName_supportedFormats &sipStrings_QtGui[22781]
#define sipNameNr_surfaceEventType 22798
#define sipName_surfaceEventType &sipStrings_QtGui[22798]
#define sipNameNr_tabFocusBehavior 22815
#define sipName_tabFocusBehavior &sipStrings_QtGui[22815]
#define sipNameNr_tableCellRowSpan 22832
#define sipName_tableCellRowSpan &sipStrings_QtGui[22832]
#define sipNameNr_themeSearchPaths 22849
#define sipName_themeSearchPaths &sipStrings_QtGui[22849]
#define sipNameNr_toRotationMatrix 22866
#define sipName_toRotationMatrix &sipStrings_QtGui[22866]
#define sipNameNr_toVector2DAffine 22883
#define sipName_toVector2DAffine &sipStrings_QtGui[22883]
#define sipNameNr_toVector3DAffine 22900
#define sipName_toVector3DAffine &sipStrings_QtGui[22900]
#define sipNameNr_touchPointStates 22917
#define sipName_touchPointStates &sipStrings_QtGui[22917]
#define sipNameNr_transferFunction 22934
#define sipName_transferFunction &sipStrings_QtGui[22934]
#define sipNameNr_transformBetween 22951
#define sipName_transformBetween &sipStrings_QtGui[22951]
#define sipNameNr_undoCommandAdded 22968
#define sipName_undoCommandAdded &sipStrings_QtGui[22968]
#define sipNameNr_useDesignMetrics 22985
#define sipName_useDesignMetrics &sipStrings_QtGui[22985]
#define sipNameNr_useRtlExtensions 23002
#define sipName_useRtlExtensions &sipStrings_QtGui[23002]
#define sipNameNr_versionFunctions 23019
#define sipName_versionFunctions &sipStrings_QtGui[23019]
#define sipNameNr_virtualSiblingAt 23036
#define sipName_virtualSiblingAt &sipStrings_QtGui[23036]
#define sipNameNr_visualNavigation 23053
#define sipName_visualNavigation &sipStrings_QtGui[23053]
#define sipNameNr_waitForIntervals 23070
#define sipName_waitForIntervals &sipStrings_QtGui[23070]
#define sipNameNr_waitForTimestamp 23087
#define sipName_waitForTimestamp &sipStrings_QtGui[23087]
#define sipNameNr_wheelScrollLines 23104
#define sipName_wheelScrollLines &sipStrings_QtGui[23104]
#define sipNameNr_AbsoluteSpacing 23121
#define sipName_AbsoluteSpacing &sipStrings_QtGui[23121]
#define sipNameNr_BackgroundBrush 23137
#define sipName_BackgroundBrush &sipStrings_QtGui[23137]
#define sipNameNr_BackgroundColor 17280
#define sipName_BackgroundColor &sipStrings_QtGui[17280]
#define sipNameNr_BindingTarget1D 23153
#define sipName_BindingTarget1D &sipStrings_QtGui[23153]
#define sipNameNr_BindingTarget2D 23169
#define sipName_BindingTarget2D &sipStrings_QtGui[23169]
#define sipNameNr_BindingTarget3D 23185
#define sipName_BindingTarget3D &sipStrings_QtGui[23185]
#define sipNameNr_BlockLeftMargin 23201
#define sipName_BlockLeftMargin &sipStrings_QtGui[23201]
#define sipNameNr_BlockQuoteLevel 23217
#define sipName_BlockQuoteLevel &sipStrings_QtGui[23217]
#define sipNameNr_CheerfulCaramel 23233
#define sipName_CheerfulCaramel &sipStrings_QtGui[23233]
#define sipNameNr_CloudyKnoxville 23249
#define sipName_CloudyKnoxville &sipStrings_QtGui[23249]
#define sipNameNr_CompositionMode 6093
#define sipName_CompositionMode &sipStrings_QtGui[6093]
#define sipNameNr_ConicalGradient 21218
#define sipName_ConicalGradient &sipStrings_QtGui[21218]
#define sipNameNr_ConstantOpacity 23265
#define sipName_ConstantOpacity &sipStrings_QtGui[23265]
#define sipNameNr_DeleteEndOfLine 23281
#define sipName_DeleteEndOfLine &sipStrings_QtGui[23281]
#define sipNameNr_DeleteEndOfWord 23297
#define sipName_DeleteEndOfWord &sipStrings_QtGui[23297]
#define sipNameNr_DirtyBackground 23313
#define sipName_DirtyBackground &sipStrings_QtGui[23313]
#define sipNameNr_DirtyClipRegion 23329
#define sipName_DirtyClipRegion &sipStrings_QtGui[23329]
#define sipNameNr_EnvelopeItalian 23345
#define sipName_EnvelopeItalian &sipStrings_QtGui[23345]
#define sipNameNr_EnvelopeMonarch 23361
#define sipName_EnvelopeMonarch &sipStrings_QtGui[23361]
#define sipNameNr_FontWordSpacing 17413
#define sipName_FontWordSpacing &sipStrings_QtGui[17413]
#define sipNameNr_ForegroundBrush 23377
#define sipName_ForegroundBrush &sipStrings_QtGui[23377]
#define sipNameNr_Format_Indexed8 23393
#define sipName_Format_Indexed8 &sipStrings_QtGui[23393]
#define sipNameNr_Format_RGBA8888 23409
#define sipName_Format_RGBA8888 &sipStrings_QtGui[23409]
#define sipNameNr_Format_RGBX8888 23425
#define sipName_Format_RGBX8888 &sipStrings_QtGui[23425]
#define sipNameNr_FrameLeftMargin 23441
#define sipName_FrameLeftMargin &sipStrings_QtGui[23441]
#define sipNameNr_GenerateMipMaps 13787
#define sipName_GenerateMipMaps &sipStrings_QtGui[13787]
#define sipNameNr_HighlightedText 23457
#define sipName_HighlightedText &sipStrings_QtGui[23457]
#define sipNameNr_InvalidSeverity 23473
#define sipName_InvalidSeverity &sipStrings_QtGui[23473]
#define sipNameNr_LandingAircraft 23489
#define sipName_LandingAircraft &sipStrings_QtGui[23489]
#define sipNameNr_LayoutDirection 17451
#define sipName_LayoutDirection &sipStrings_QtGui[17451]
#define sipNameNr_LineHeightTypes 1089
#define sipName_LineHeightTypes &sipStrings_QtGui[1089]
#define sipNameNr_LineUnderCursor 23505
#define sipName_LineUnderCursor &sipStrings_QtGui[23505]
#define sipNameNr_LuminanceFormat 23521
#define sipName_LuminanceFormat &sipStrings_QtGui[23521]
#define sipNameNr_MarkdownFeature 2578
#define sipName_MarkdownFeature &sipStrings_QtGui[2578]
#define sipNameNr_MetaInformation 2609
#define sipName_MetaInformation &sipStrings_QtGui[2609]
#define sipNameNr_ModerateCaching 23537
#define sipName_ModerateCaching &sipStrings_QtGui[23537]
#define sipNameNr_MoveToEndOfLine 23553
#define sipName_MoveToEndOfLine &sipStrings_QtGui[23553]
#define sipNameNr_NamedColorSpace 3754
#define sipName_NamedColorSpace &sipStrings_QtGui[3754]
#define sipNameNr_NoPartialUpdate 23569
#define sipName_NoPartialUpdate &sipStrings_QtGui[23569]
#define sipNameNr_PageBreakPolicy 17565
#define sipName_PageBreakPolicy &sipStrings_QtGui[17565]
#define sipNameNr_PdmPhysicalDpiX 23585
#define sipName_PdmPhysicalDpiX &sipStrings_QtGui[23585]
#define sipNameNr_PdmPhysicalDpiY 23601
#define sipName_PdmPhysicalDpiY &sipStrings_QtGui[23601]
#define sipNameNr_PerformanceHint 4044
#define sipName_PerformanceHint &sipStrings_QtGui[4044]
#define sipNameNr_PerformanceType 23617
#define sipName_PerformanceType &sipStrings_QtGui[23617]
#define sipNameNr_PixelPackBuffer 23633
#define sipName_PixelPackBuffer &sipStrings_QtGui[23633]
#define sipNameNr_PixmapTransform 10907
#define sipName_PixmapTransform &sipStrings_QtGui[10907]
#define sipNameNr_PlaceholderText 23649
#define sipName_PlaceholderText &sipStrings_QtGui[23649]
#define sipNameNr_PolygonDrawMode 3307
#define sipName_PolygonDrawMode &sipStrings_QtGui[3307]
#define sipNameNr_PortabilityType 23665
#define sipName_PortabilityType &sipStrings_QtGui[23665]
#define sipNameNr_PreferAntialias 23681
#define sipName_PreferAntialias &sipStrings_QtGui[23681]
#define sipNameNr_PreferNoHinting 23697
#define sipName_PreferNoHinting &sipStrings_QtGui[23697]
#define sipNameNr_PreferNoShaping 23713
#define sipName_PreferNoShaping &sipStrings_QtGui[23713]
#define sipNameNr_QColorConstants 23729
#define sipName_QColorConstants &sipStrings_QtGui[23729]
#define sipNameNr_QColorTransform 23745
#define sipName_QColorTransform &sipStrings_QtGui[23745]
#define sipNameNr_QDragEnterEvent 23761
#define sipName_QDragEnterEvent &sipStrings_QtGui[23761]
#define sipNameNr_QDragLeaveEvent 23777
#define sipName_QDragLeaveEvent &sipStrings_QtGui[23777]
#define sipNameNr_QGradient__Type 23793
#define sipName_QGradient__Type &sipStrings_QtGui[23793]
#define sipNameNr_QGuiApplication 23809
#define sipName_QGuiApplication &sipStrings_QtGui[23809]
#define sipNameNr_QImageIOHandler 23825
#define sipName_QImageIOHandler &sipStrings_QtGui[23825]
#define sipNameNr_QLinearGradient 23841
#define sipName_QLinearGradient &sipStrings_QtGui[23841]
#define sipNameNr_23857 23857
#define sipName_23857 &sipStrings_QtGui[23857]
#define sipNameNr_23873 23873
#define sipName_23873 &sipStrings_QtGui[23873]
#define sipNameNr_QPageSize__Unit 23889
#define sipName_QPageSize__Unit &sipStrings_QtGui[23889]
#define sipNameNr_QRadialGradient 23905
#define sipName_QRadialGradient &sipStrings_QtGui[23905]
#define sipNameNr_QSessionManager 23921
#define sipName_QSessionManager &sipStrings_QtGui[23921]
#define sipNameNr_QStatusTipEvent 23937
#define sipName_QStatusTipEvent &sipStrings_QtGui[23937]
#define sipNameNr_QTextBlockGroup 23953
#define sipName_QTextBlockGroup &sipStrings_QtGui[23953]
#define sipNameNr_QTextCharFormat 23969
#define sipName_QTextCharFormat &sipStrings_QtGui[23969]
#define sipNameNr_QTextLine__Edge 23985
#define sipName_QTextLine__Edge &sipStrings_QtGui[23985]
#define sipNameNr_QTextListFormat 24001
#define sipName_QTextListFormat &sipStrings_QtGui[24001]
#define sipNameNr_24017 24017
#define sipName_24017 &sipStrings_QtGui[24017]
#define sipNameNr_RGBA_ASTC_10x10 24033
#define sipName_RGBA_ASTC_10x10 &sipStrings_QtGui[24033]
#define sipNameNr_RGBA_ASTC_12x10 24049
#define sipName_RGBA_ASTC_12x10 &sipStrings_QtGui[24049]
#define sipNameNr_RGBA_ASTC_12x12 24065
#define sipName_RGBA_ASTC_12x12 &sipStrings_QtGui[24065]
#define sipNameNr_RangeAccessFlag 2454
#define sipName_RangeAccessFlag &sipStrings_QtGui[2454]
#define sipNameNr_RangeInvalidate 24081
#define sipName_RangeInvalidate &sipStrings_QtGui[24081]
#define sipNameNr_RasterGLSurface 24097
#define sipName_RasterGLSurface &sipStrings_QtGui[24097]
#define sipNameNr_SRGB_Alpha_DXT1 24113
#define sipName_SRGB_Alpha_DXT1 &sipStrings_QtGui[24113]
#define sipNameNr_SRGB_Alpha_DXT3 24129
#define sipName_SRGB_Alpha_DXT3 &sipStrings_QtGui[24129]
#define sipNameNr_SRGB_Alpha_DXT5 24145
#define sipName_SRGB_Alpha_DXT5 &sipStrings_QtGui[24145]
#define sipNameNr_SaintPetersburg 24161
#define sipName_SaintPetersburg &sipStrings_QtGui[24161]
#define sipNameNr_SelectEndOfLine 24177
#define sipName_SelectEndOfLine &sipStrings_QtGui[24177]
#define sipNameNr_SingleUnderline 24193
#define sipName_SingleUnderline &sipStrings_QtGui[24193]
#define sipNameNr_SizeMatchPolicy 5192
#define sipName_SizeMatchPolicy &sipStrings_QtGui[5192]
#define sipNameNr_TableCellObject 24209
#define sipName_TableCellObject &sipStrings_QtGui[24209]
#define sipNameNr_TargetRectangle 8764
#define sipName_TargetRectangle &sipStrings_QtGui[8764]
#define sipNameNr_Transformations 1258
#define sipName_Transformations &sipStrings_QtGui[1258]
#define sipNameNr_UInt32_RG11B10F 24225
#define sipName_UInt32_RG11B10F &sipStrings_QtGui[24225]
#define sipNameNr_UInt8_RG3B2_Rev 24241
#define sipName_UInt8_RG3B2_Rev &sipStrings_QtGui[24241]
#define sipNameNr_UnknownResource 24257
#define sipName_UnknownResource &sipStrings_QtGui[24257]
#define sipNameNr_UnsignedInteger 24273
#define sipName_UnsignedInteger &sipStrings_QtGui[24273]
#define sipNameNr_WordUnderCursor 24289
#define sipName_WordUnderCursor &sipStrings_QtGui[24289]
#define sipNameNr_allocateStorage 24305
#define sipName_allocateStorage &sipStrings_QtGui[24305]
#define sipNameNr_alphaBufferSize 24321
#define sipName_alphaBufferSize &sipStrings_QtGui[24321]
#define sipNameNr_anchorRectangle 24337
#define sipName_anchorRectangle &sipStrings_QtGui[24337]
#define sipNameNr_aspectRatioMode 24353
#define sipName_aspectRatioMode &sipStrings_QtGui[24353]
#define sipNameNr_backgroundBrush 24369
#define sipName_backgroundBrush &sipStrings_QtGui[24369]
#define sipNameNr_backgroundColor 24385
#define sipName_backgroundColor &sipStrings_QtGui[24385]
#define sipNameNr_blitFramebuffer 24401
#define sipName_blitFramebuffer &sipStrings_QtGui[24401]
#define sipNameNr_blockCharFormat 24417
#define sipName_blockCharFormat &sipStrings_QtGui[24417]
#define sipNameNr_cacheStatistics 24433
#define sipName_cacheStatistics &sipStrings_QtGui[24433]
#define sipNameNr_canDropMimeData 24449
#define sipName_canDropMimeData &sipStrings_QtGui[24449]
#define sipNameNr_charFormatIndex 24465
#define sipName_charFormatIndex &sipStrings_QtGui[24465]
#define sipNameNr_clearBackground 24481
#define sipName_clearBackground &sipStrings_QtGui[24481]
#define sipNameNr_clearForeground 24497
#define sipName_clearForeground &sipStrings_QtGui[24497]
#define sipNameNr_compositionMode 24513
#define sipName_compositionMode &sipStrings_QtGui[24513]
#define sipNameNr_contentPosRange 24529
#define sipName_contentPosRange &sipStrings_QtGui[24529]
#define sipNameNr_contentsChanged 24545
#define sipName_contentsChanged &sipStrings_QtGui[24545]
#define sipNameNr_convertToFormat 24561
#define sipName_convertToFormat &sipStrings_QtGui[24561]
#define sipNameNr_createAlphaMask 24577
#define sipName_createAlphaMask &sipStrings_QtGui[24577]
#define sipNameNr_currentPosition 24593
#define sipName_currentPosition &sipStrings_QtGui[24593]
#define sipNameNr_cursorFlashTime 24609
#define sipName_cursorFlashTime &sipStrings_QtGui[24609]
#define sipNameNr_cursorMoveStyle 24625
#define sipName_cursorMoveStyle &sipStrings_QtGui[24625]
#define sipNameNr_cursorRectangle 24641
#define sipName_cursorRectangle &sipStrings_QtGui[24641]
#define sipNameNr_defineIOHandler 24657
#define sipName_defineIOHandler &sipStrings_QtGui[24657]
#define sipNameNr_definitionUnits 24673
#define sipName_definitionUnits &sipStrings_QtGui[24673]
#define sipNameNr_depthBufferSize 24689
#define sipName_depthBufferSize &sipStrings_QtGui[24689]
#define sipNameNr_desktopFileName 24705
#define sipName_desktopFileName &sipStrings_QtGui[24705]
#define sipNameNr_deviceTransform 24721
#define sipName_deviceTransform &sipStrings_QtGui[24721]
#define sipNameNr_disableMessages 24737
#define sipName_disableMessages &sipStrings_QtGui[24737]
#define sipNameNr_distanceToPlane 24753
#define sipName_distanceToPlane &sipStrings_QtGui[24753]
#define sipNameNr_distanceToPoint 24769
#define sipName_distanceToPoint &sipStrings_QtGui[24769]
#define sipNameNr_documentChanged 24785
#define sipName_documentChanged &sipStrings_QtGui[24785]
#define sipNameNr_drawRoundedRect 24801
#define sipName_drawRoundedRect &sipStrings_QtGui[24801]
#define sipNameNr_drawTiledPixmap 24817
#define sipName_drawTiledPixmap &sipStrings_QtGui[24817]
#define sipNameNr_emitDataChanged 24833
#define sipName_emitDataChanged &sipStrings_QtGui[24833]
#define sipNameNr_firstLineNumber 24849
#define sipName_firstLineNumber &sipStrings_QtGui[24849]
#define sipNameNr_fontWordSpacing 24865
#define sipName_fontWordSpacing &sipStrings_QtGui[24865]
#define sipNameNr_fromEulerAngles 24881
#define sipName_fromEulerAngles &sipStrings_QtGui[24881]
#define sipNameNr_fromImageReader 24897
#define sipName_fromImageReader &sipStrings_QtGui[24897]
#define sipNameNr_generateMipMaps 24913
#define sipName_generateMipMaps &sipStrings_QtGui[24913]
#define sipNameNr_geometryChanged 24929
#define sipName_geometryChanged &sipStrings_QtGui[24929]
#define sipNameNr_getAxisAndAngle 24945
#define sipName_getAxisAndAngle &sipStrings_QtGui[24945]
#define sipNameNr_grabFramebuffer 24961
#define sipName_grabFramebuffer &sipStrings_QtGui[24961]
#define sipNameNr_greenBufferSize 24977
#define sipName_greenBufferSize &sipStrings_QtGui[24977]
#define sipNameNr_hasAlphaChannel 24993
#define sipName_hasAlphaChannel &sipStrings_QtGui[24993]
#define sipNameNr_highlightedText 25009
#define sipName_highlightedText &sipStrings_QtGui[25009]
#define sipNameNr_internal_format 25025
#define sipName_internal_format &sipStrings_QtGui[25025]
#define sipNameNr_isLegacyVersion 25041
#define sipName_isLegacyVersion &sipStrings_QtGui[25041]
#define sipNameNr_isPrivateFamily 25057
#define sipName_isPrivateFamily &sipStrings_QtGui[25057]
#define sipNameNr_isRedoAvailable 25073
#define sipName_isRedoAvailable &sipStrings_QtGui[25073]
#define sipNameNr_isSavingSession 25089
#define sipName_isSavingSession &sipStrings_QtGui[25089]
#define sipNameNr_isUndoAvailable 25105
#define sipName_isUndoAvailable &sipStrings_QtGui[25105]
#define sipNameNr_jumpToNextFrame 25121
#define sipName_jumpToNextFrame &sipStrings_QtGui[25121]
#define sipNameNr_jumpToNextImage 25137
#define sipName_jumpToNextImage &sipStrings_QtGui[25137]
#define sipNameNr_keyReleaseEvent 25153
#define sipName_keyReleaseEvent &sipStrings_QtGui[25153]
#define sipNameNr_lastErrorString 25169
#define sipName_lastErrorString &sipStrings_QtGui[25169]
#define sipNameNr_layoutDirection 25185
#define sipName_layoutDirection &sipStrings_QtGui[25185]
#define sipNameNr_leadingIncluded 25201
#define sipName_leadingIncluded &sipStrings_QtGui[25201]
#define sipNameNr_leftBorderBrush 25217
#define sipName_leftBorderBrush &sipStrings_QtGui[25217]
#define sipNameNr_leftBorderStyle 25233
#define sipName_leftBorderStyle &sipStrings_QtGui[25233]
#define sipNameNr_mediumslateblue 25249
#define sipName_mediumslateblue &sipStrings_QtGui[25249]
#define sipNameNr_mediumturquoise 25265
#define sipName_mediumturquoise &sipStrings_QtGui[25265]
#define sipNameNr_mediumvioletred 25281
#define sipName_mediumvioletred &sipStrings_QtGui[25281]
#define sipNameNr_mergeCharFormat 25297
#define sipName_mergeCharFormat &sipStrings_QtGui[25297]
#define sipNameNr_metaInformation 25313
#define sipName_metaInformation &sipStrings_QtGui[25313]
#define sipNameNr_mightBeRichText 25329
#define sipName_mightBeRichText &sipStrings_QtGui[25329]
#define sipNameNr_minRightBearing 25345
#define sipName_minRightBearing &sipStrings_QtGui[25345]
#define sipNameNr_modalityChanged 25361
#define sipName_modalityChanged &sipStrings_QtGui[25361]
#define sipNameNr_mousePressEvent 25377
#define sipName_mousePressEvent &sipStrings_QtGui[25377]
#define sipNameNr_nativeModifiers 25393
#define sipName_nativeModifiers &sipStrings_QtGui[25393]
#define sipNameNr_naturalTextRect 25409
#define sipName_naturalTextRect &sipStrings_QtGui[25409]
#define sipNameNr_objectForFormat 25425
#define sipName_objectForFormat &sipStrings_QtGui[25425]
#define sipNameNr_pageBreakPolicy 25441
#define sipName_pageBreakPolicy &sipStrings_QtGui[25441]
#define sipNameNr_paintRectPixels 25457
#define sipName_paintRectPixels &sipStrings_QtGui[25457]
#define sipNameNr_paintRectPoints 25473
#define sipName_paintRectPoints &sipStrings_QtGui[25473]
#define sipNameNr_percentAtLength 25489
#define sipName_percentAtLength &sipStrings_QtGui[25489]
#define sipNameNr_performanceHint 25505
#define sipName_performanceHint &sipStrings_QtGui[25505]
#define sipNameNr_placeholderText 25521
#define sipName_placeholderText &sipStrings_QtGui[25521]
#define sipNameNr_positionInBlock 25537
#define sipName_positionInBlock &sipStrings_QtGui[25537]
#define sipNameNr_possibleActions 25553
#define sipName_possibleActions &sipStrings_QtGui[25553]
#define sipNameNr_preeditAreaText 25569
#define sipName_preeditAreaText &sipStrings_QtGui[25569]
#define sipNameNr_qPixelFormatHsl 25585
#define sipName_qPixelFormatHsl &sipStrings_QtGui[25585]
#define sipNameNr_qPixelFormatHsv 25601
#define sipName_qPixelFormatHsv &sipStrings_QtGui[25601]
#define sipNameNr_qPixelFormatYuv 25617
#define sipName_qPixelFormatYuv &sipStrings_QtGui[25617]
#define sipNameNr_recordTimestamp 25633
#define sipName_recordTimestamp &sipStrings_QtGui[25633]
#define sipNameNr_registerHandler 20568
#define sipName_registerHandler &sipStrings_QtGui[20568]
#define sipNameNr_requestActivate 25649
#define sipName_requestActivate &sipStrings_QtGui[25649]
#define sipNameNr_requestedFormat 25665
#define sipName_requestedFormat &sipStrings_QtGui[25665]
#define sipNameNr_setAlphaChannel 25681
#define sipName_setAlphaChannel &sipStrings_QtGui[25681]
#define sipNameNr_setAutoTristate 25697
#define sipName_setAutoTristate &sipStrings_QtGui[25697]
#define sipNameNr_setBottomBorder 25713
#define sipName_setBottomBorder &sipStrings_QtGui[25713]
#define sipNameNr_setBottomMargin 25729
#define sipName_setBottomMargin &sipStrings_QtGui[25729]
#define sipNameNr_setBoundingRect 25745
#define sipName_setBoundingRect &sipStrings_QtGui[25745]
#define sipNameNr_setCacheEnabled 25761
#define sipName_setCacheEnabled &sipStrings_QtGui[25761]
#define sipNameNr_setCapabilities 25777
#define sipName_setCapabilities &sipStrings_QtGui[25777]
#define sipNameNr_setCenterRadius 25793
#define sipName_setCenterRadius &sipStrings_QtGui[25793]
#define sipNameNr_setCommitString 25809
#define sipName_setCommitString &sipStrings_QtGui[25809]
#define sipNameNr_setFontFamilies 25825
#define sipName_setFontFamilies &sipStrings_QtGui[25825]
#define sipNameNr_setFontOverline 25841
#define sipName_setFontOverline &sipStrings_QtGui[25841]
#define sipNameNr_setGlyphIndexes 25857
#define sipName_setGlyphIndexes &sipStrings_QtGui[25857]
#define sipNameNr_setHeadingLevel 25873
#define sipName_setHeadingLevel &sipStrings_QtGui[25873]
#define sipNameNr_setMajorVersion 25889
#define sipName_setMajorVersion &sipStrings_QtGui[25889]
#define sipNameNr_setMaximumWidth 25905
#define sipName_setMaximumWidth &sipStrings_QtGui[25905]
#define sipNameNr_setMinimumWidth 25921
#define sipName_setMinimumWidth &sipStrings_QtGui[25921]
#define sipNameNr_setMinorVersion 25937
#define sipName_setMinorVersion &sipStrings_QtGui[25937]
#define sipNameNr_setMipBaseLevel 25953
#define sipName_setMipBaseLevel &sipStrings_QtGui[25953]
#define sipNameNr_setNativeHandle 25969
#define sipName_setNativeHandle &sipStrings_QtGui[25969]
#define sipNameNr_setNumberPrefix 25985
#define sipName_setNumberPrefix &sipStrings_QtGui[25985]
#define sipNameNr_setNumberSuffix 26001
#define sipName_setNumberSuffix &sipStrings_QtGui[26001]
#define sipNameNr_setPaintFlipped 26017
#define sipName_setPaintFlipped &sipStrings_QtGui[26017]
#define sipNameNr_setRightPadding 26033
#define sipName_setRightPadding &sipStrings_QtGui[26033]
#define sipNameNr_setShareContext 26049
#define sipName_setShareContext &sipStrings_QtGui[26049]
#define sipNameNr_setSwapBehavior 26065
#define sipName_setSwapBehavior &sipStrings_QtGui[26065]
#define sipNameNr_setSwapInterval 26081
#define sipName_setSwapInterval &sipStrings_QtGui[26081]
#define sipNameNr_setTabPositions 26097
#define sipName_setTabPositions &sipStrings_QtGui[26097]
#define sipNameNr_setTextureImage 26113
#define sipName_setTextureImage &sipStrings_QtGui[26113]
#define sipNameNr_setUniformValue 26129
#define sipName_setUniformValue &sipStrings_QtGui[26129]
#define sipNameNr_setUsagePattern 26145
#define sipName_setUsagePattern &sipStrings_QtGui[26145]
#define sipNameNr_setUserTristate 26161
#define sipName_setUserTristate &sipStrings_QtGui[26161]
#define sipNameNr_setViewportSize 26177
#define sipName_setViewportSize &sipStrings_QtGui[26177]
#define sipNameNr_setWindowStates 26193
#define sipName_setWindowStates &sipStrings_QtGui[26193]
#define sipNameNr_showIsMaximized 26209
#define sipName_showIsMaximized &sipStrings_QtGui[26209]
#define sipNameNr_sourceTransform 26225
#define sipName_sourceTransform &sipStrings_QtGui[26225]
#define sipNameNr_startSystemMove 26241
#define sipName_startSystemMove &sipStrings_QtGui[26241]
#define sipNameNr_tabStopDistance 26257
#define sipName_tabStopDistance &sipStrings_QtGui[26257]
#define sipNameNr_targetTransform 26273
#define sipName_targetTransform &sipStrings_QtGui[26273]
#define sipNameNr_topLevelWindows 26289
#define sipName_topLevelWindows &sipStrings_QtGui[26289]
#define sipNameNr_transientParent 26305
#define sipName_transientParent &sipStrings_QtGui[26305]
#define sipNameNr_uniformLocation 26321
#define sipName_uniformLocation &sipStrings_QtGui[26321]
#define sipNameNr_unpremultiplied 26337
#define sipName_unpremultiplied &sipStrings_QtGui[26337]
#define sipNameNr_unsetUrlHandler 26353
#define sipName_unsetUrlHandler &sipStrings_QtGui[26353]
#define sipNameNr_useHoverEffects 26369
#define sipName_useHoverEffects &sipStrings_QtGui[26369]
#define sipNameNr_virtualGeometry 26385
#define sipName_virtualGeometry &sipStrings_QtGui[26385]
#define sipNameNr_virtualSiblings 26401
#define sipName_virtualSiblings &sipStrings_QtGui[26401]
#define sipNameNr_AlignSubScript 26417
#define sipName_AlignSubScript &sipStrings_QtGui[26417]
#define sipNameNr_BlockAlignment 26432
#define sipName_BlockAlignment &sipStrings_QtGui[26432]
#define sipNameNr_BlockCodeFence 26447
#define sipName_BlockCodeFence &sipStrings_QtGui[26447]
#define sipNameNr_BlockTopMargin 26462
#define sipName_BlockTopMargin &sipStrings_QtGui[26462]
#define sipNameNr_CapabilityFlag 4161
#define sipName_CapabilityFlag &sipStrings_QtGui[4161]
#define sipNameNr_Capitalization 10204
#define sipName_Capitalization &sipStrings_QtGui[10204]
#define sipNameNr_CompareGreater 26477
#define sipName_CompareGreater &sipStrings_QtGui[26477]
#define sipNameNr_ComparisonMode 2517
#define sipName_ComparisonMode &sipStrings_QtGui[2517]
#define sipNameNr_ConfidentCloud 26492
#define sipName_ConfidentCloud &sipStrings_QtGui[26492]
#define sipNameNr_CoordinateMode 5964
#define sipName_CoordinateMode &sipStrings_QtGui[5964]
#define sipNameNr_CursorPosition 6198
#define sipName_CursorPosition &sipStrings_QtGui[6198]
#define sipNameNr_CurveToElement 26507
#define sipName_CurveToElement &sipStrings_QtGui[26507]
#define sipNameNr_DashDotDotLine 26522
#define sipName_DashDotDotLine &sipStrings_QtGui[26522]
#define sipNameNr_DirtyTransform 26537
#define sipName_DirtyTransform &sipStrings_QtGui[26537]
#define sipNameNr_DoublePostcard 26552
#define sipName_DoublePostcard &sipStrings_QtGui[26552]
#define sipNameNr_EnvelopeInvite 26567
#define sipName_EnvelopeInvite &sipStrings_QtGui[26567]
#define sipNameNr_EverlastingSky 26582
#define sipName_EverlastingSky &sipStrings_QtGui[26582]
#define sipNameNr_ExtraCondensed 26597
#define sipName_ExtraCondensed &sipStrings_QtGui[26597]
#define sipNameNr_FindWholeWords 26612
#define sipName_FindWholeWords &sipStrings_QtGui[26612]
#define sipNameNr_FontFixedPitch 20047
#define sipName_FontFixedPitch &sipStrings_QtGui[20047]
#define sipNameNr_Format_Invalid 26627
#define sipName_Format_Invalid &sipStrings_QtGui[26627]
#define sipNameNr_Format_MonoLSB 26642
#define sipName_Format_MonoLSB &sipStrings_QtGui[26642]
#define sipNameNr_FrameTopMargin 26657
#define sipName_FrameTopMargin &sipStrings_QtGui[26657]
#define sipNameNr_IconEngineHook 4530
#define sipName_IconEngineHook &sipStrings_QtGui[4530]
#define sipNameNr_KernedAdvances 26672
#define sipName_KernedAdvances &sipStrings_QtGui[26672]
#define sipNameNr_LineHeightType 26687
#define sipName_LineHeightType &sipStrings_QtGui[26687]
#define sipNameNr_LinearGradient 23842
#define sipName_LinearGradient &sipStrings_QtGui[23842]
#define sipNameNr_ListLowerAlpha 26702
#define sipName_ListLowerAlpha &sipStrings_QtGui[26702]
#define sipNameNr_ListLowerRoman 26717
#define sipName_ListLowerRoman &sipStrings_QtGui[26717]
#define sipNameNr_ListUpperAlpha 26732
#define sipName_ListUpperAlpha &sipStrings_QtGui[26732]
#define sipNameNr_ListUpperRoman 26747
#define sipName_ListUpperRoman &sipStrings_QtGui[26747]
#define sipNameNr_LuminanceAlpha 26762
#define sipName_LuminanceAlpha &sipStrings_QtGui[26762]
#define sipNameNr_MarkdownNoHTML 26777
#define sipName_MarkdownNoHTML &sipStrings_QtGui[26777]
#define sipNameNr_MediumSeverity 26792
#define sipName_MediumSeverity &sipStrings_QtGui[26792]
#define sipNameNr_MillenniumPine 26807
#define sipName_MillenniumPine &sipStrings_QtGui[26807]
#define sipNameNr_MirroredRepeat 26822
#define sipName_MirroredRepeat &sipStrings_QtGui[26822]
#define sipNameNr_MouseEmulation 26837
#define sipName_MouseEmulation &sipStrings_QtGui[26837]
#define sipNameNr_MoveToNextChar 26852
#define sipName_MoveToNextChar &sipStrings_QtGui[26852]
#define sipNameNr_MoveToNextLine 26867
#define sipName_MoveToNextLine &sipStrings_QtGui[26867]
#define sipNameNr_MoveToNextPage 26882
#define sipName_MoveToNextPage &sipStrings_QtGui[26882]
#define sipNameNr_MoveToNextWord 26897
#define sipName_MoveToNextWord &sipStrings_QtGui[26897]
#define sipNameNr_NoSourceFormat 26912
#define sipName_NoSourceFormat &sipStrings_QtGui[26912]
#define sipNameNr_OctoberSilence 26927
#define sipName_OctoberSilence &sipStrings_QtGui[26927]
#define sipNameNr_OptimizedWrite 20101
#define sipName_OptimizedWrite &sipStrings_QtGui[20101]
#define sipNameNr_PageBreakFlags 4838
#define sipName_PageBreakFlags &sipStrings_QtGui[4838]
#define sipNameNr_PageBreak_Auto 26942
#define sipName_PageBreak_Auto &sipStrings_QtGui[26942]
#define sipNameNr_PdfVersion_1_4 26957
#define sipName_PdfVersion_1_4 &sipStrings_QtGui[26957]
#define sipNameNr_PdfVersion_1_6 26972
#define sipName_PdfVersion_1_6 &sipStrings_QtGui[26972]
#define sipNameNr_PdfVersion_A1b 26987
#define sipName_PdfVersion_A1b &sipStrings_QtGui[26987]
#define sipNameNr_PixmapFragment 6965
#define sipName_PixmapFragment &sipStrings_QtGui[6965]
#define sipNameNr_PurpleDivision 27002
#define sipName_PurpleDivision &sipStrings_QtGui[27002]
#define sipNameNr_QDragMoveEvent 27017
#define sipName_QDragMoveEvent &sipStrings_QtGui[27017]
#define sipNameNr_QFileOpenEvent 27032
#define sipName_QFileOpenEvent &sipStrings_QtGui[27032]
#define sipNameNr_QFont__Stretch 27047
#define sipName_QFont__Stretch &sipStrings_QtGui[27047]
#define sipNameNr_QIconDragEvent 27062
#define sipName_QIconDragEvent &sipStrings_QtGui[27062]
#define sipNameNr_QImage__Format 27077
#define sipName_QImage__Format &sipStrings_QtGui[27077]
#define sipNameNr_QOpenGLContext 27092
#define sipName_QOpenGLContext &sipStrings_QtGui[27092]
#define sipNameNr_QOpenGLTexture 27107
#define sipName_QOpenGLTexture &sipStrings_QtGui[27107]
#define sipNameNr_QShortcutEvent 27122
#define sipName_QShortcutEvent &sipStrings_QtGui[27122]
#define sipNameNr_QSurfaceFormat 27137
#define sipName_QSurfaceFormat &sipStrings_QtGui[27137]
#define sipNameNr_QTextTableCell 27152
#define sipName_QTextTableCell &sipStrings_QtGui[27152]
#define sipNameNr_27167 27167
#define sipName_27167 &sipStrings_QtGui[27167]
#define sipNameNr_27182 27182
#define sipName_27182 &sipStrings_QtGui[27182]
#define sipNameNr_27197 27197
#define sipName_27197 &sipStrings_QtGui[27197]
#define sipNameNr_27212 27212
#define sipName_27212 &sipStrings_QtGui[27212]
#define sipNameNr_RG11_EAC_SNorm 27227
#define sipName_RG11_EAC_SNorm &sipStrings_QtGui[27227]
#define sipNameNr_RG11_EAC_UNorm 27242
#define sipName_RG11_EAC_UNorm &sipStrings_QtGui[27242]
#define sipNameNr_RGBA8_ETC2_EAC 27257
#define sipName_RGBA8_ETC2_EAC &sipStrings_QtGui[27257]
#define sipNameNr_RGBA_ASTC_10x5 27272
#define sipName_RGBA_ASTC_10x5 &sipStrings_QtGui[27272]
#define sipNameNr_RGBA_ASTC_10x6 27287
#define sipName_RGBA_ASTC_10x6 &sipStrings_QtGui[27287]
#define sipNameNr_RGBA_ASTC_10x8 27302
#define sipName_RGBA_ASTC_10x8 &sipStrings_QtGui[27302]
#define sipNameNr_RG_ATI2N_SNorm 27317
#define sipName_RG_ATI2N_SNorm &sipStrings_QtGui[27317]
#define sipNameNr_RG_ATI2N_UNorm 27332
#define sipName_RG_ATI2N_UNorm &sipStrings_QtGui[27332]
#define sipNameNr_RadialGradient 23906
#define sipName_RadialGradient &sipStrings_QtGui[23906]
#define sipNameNr_RenderableType 2548
#define sipName_RenderableType &sipStrings_QtGui[2548]
#define sipNameNr_RotationStylus 27347
#define sipName_RotationStylus &sipStrings_QtGui[27347]
#define sipNameNr_ScaledClipRect 20191
#define sipName_ScaledClipRect &sipStrings_QtGui[20191]
#define sipNameNr_ScrollFinished 27362
#define sipName_ScrollFinished &sipStrings_QtGui[27362]
#define sipNameNr_SelectNextChar 27377
#define sipName_SelectNextChar &sipStrings_QtGui[27377]
#define sipNameNr_SelectNextLine 27392
#define sipName_SelectNextLine &sipStrings_QtGui[27392]
#define sipNameNr_SelectNextPage 27407
#define sipName_SelectNextPage &sipStrings_QtGui[27407]
#define sipNameNr_SelectNextWord 27422
#define sipName_SelectNextWord &sipStrings_QtGui[27422]
#define sipNameNr_SequenceFormat 3871
#define sipName_SequenceFormat &sipStrings_QtGui[3871]
#define sipNameNr_SkipCharacters 27437
#define sipName_SkipCharacters &sipStrings_QtGui[27437]
#define sipNameNr_SleeplessNight 27452
#define sipName_SleeplessNight &sipStrings_QtGui[27452]
#define sipNameNr_StrictNovember 27467
#define sipName_StrictNovember &sipStrings_QtGui[27467]
#define sipNameNr_SuppressColors 27482
#define sipName_SuppressColors &sipStrings_QtGui[27482]
#define sipNameNr_SurfaceCreated 27497
#define sipName_SurfaceCreated &sipStrings_QtGui[27497]
#define sipNameNr_Transformation 1948
#define sipName_Transformation &sipStrings_QtGui[1948]
#define sipNameNr_UInt32_RGB10A2 27512
#define sipName_UInt32_RGB10A2 &sipStrings_QtGui[27512]
#define sipNameNr_UInt32_RGB9_E5 27527
#define sipName_UInt32_RGB9_E5 &sipStrings_QtGui[27527]
#define sipNameNr_UltraCondensed 27542
#define sipName_UltraCondensed &sipStrings_QtGui[27542]
#define sipNameNr_UnderlineStyle 2140
#define sipName_UnderlineStyle &sipStrings_QtGui[2140]
#define sipNameNr_UnknownPointer 27557
#define sipName_UnknownPointer &sipStrings_QtGui[27557]
#define sipNameNr_UpdateBehavior 3248
#define sipName_UpdateBehavior &sipStrings_QtGui[3248]
#define sipNameNr_VariableLength 27572
#define sipName_VariableLength &sipStrings_QtGui[27572]
#define sipNameNr_accessibleText 27587
#define sipName_accessibleText &sipStrings_QtGui[27587]
#define sipNameNr_addRoundedRect 27602
#define sipName_addRoundedRect &sipStrings_QtGui[27602]
#define sipNameNr_angleAtPercent 27617
#define sipName_angleAtPercent &sipStrings_QtGui[27617]
#define sipNameNr_availableSizes 27632
#define sipName_availableSizes &sipStrings_QtGui[27632]
#define sipNameNr_backgroundMode 27647
#define sipName_backgroundMode &sipStrings_QtGui[27647]
#define sipNameNr_baseUrlChanged 27662
#define sipName_baseUrlChanged &sipStrings_QtGui[27662]
#define sipNameNr_beginEditBlock 27677
#define sipName_beginEditBlock &sipStrings_QtGui[27677]
#define sipNameNr_blanchedalmond 27692
#define sipName_blanchedalmond &sipStrings_QtGui[27692]
#define sipNameNr_blueBufferSize 27707
#define sipName_blueBufferSize &sipStrings_QtGui[27707]
#define sipNameNr_borderCollapse 27722
#define sipName_borderCollapse &sipStrings_QtGui[27722]
#define sipNameNr_boundTextureId 27737
#define sipName_boundTextureId &sipStrings_QtGui[27737]
#define sipNameNr_brightnessSize 27752
#define sipName_brightnessSize &sipStrings_QtGui[27752]
#define sipNameNr_capitalization 27767
#define sipName_capitalization &sipStrings_QtGui[27767]
#define sipNameNr_characterCount 27782
#define sipName_characterCount &sipStrings_QtGui[27782]
#define sipNameNr_clearSelection 27797
#define sipName_clearSelection &sipStrings_QtGui[27797]
#define sipNameNr_comparisonMode 27812
#define sipName_comparisonMode &sipStrings_QtGui[27812]
#define sipNameNr_contentsChange 27827
#define sipName_contentsChange &sipStrings_QtGui[27827]
#define sipNameNr_coordinateMode 27842
#define sipName_coordinateMode &sipStrings_QtGui[27842]
#define sipNameNr_cornflowerblue 27857
#define sipName_cornflowerblue &sipStrings_QtGui[27857]
#define sipNameNr_currentContext 27872
#define sipName_currentContext &sipStrings_QtGui[27872]
#define sipNameNr_cursorPosition 27887
#define sipName_cursorPosition &sipStrings_QtGui[27887]
#define sipNameNr_curveThreshold 27902
#define sipName_curveThreshold &sipStrings_QtGui[27902]
#define sipNameNr_darkolivegreen 27917
#define sipName_darkolivegreen &sipStrings_QtGui[27917]
#define sipNameNr_definitionSize 27932
#define sipName_definitionSize &sipStrings_QtGui[27932]
#define sipNameNr_discardCommand 27947
#define sipName_discardCommand &sipStrings_QtGui[27947]
#define sipNameNr_distanceToLine 27962
#define sipName_distanceToLine &sipStrings_QtGui[27962]
#define sipNameNr_documentLayout 27977
#define sipName_documentLayout &sipStrings_QtGui[27977]
#define sipNameNr_documentMargin 27992
#define sipName_documentMargin &sipStrings_QtGui[27992]
#define sipNameNr_doubleProperty 28007
#define sipName_doubleProperty &sipStrings_QtGui[28007]
#define sipNameNr_drawStaticText 28022
#define sipName_drawStaticText &sipStrings_QtGui[28022]
#define sipNameNr_enableMessages 28037
#define sipName_enableMessages &sipStrings_QtGui[28037]
#define sipNameNr_fontFixedPitch 28052
#define sipName_fontFixedPitch &sipStrings_QtGui[28052]
#define sipNameNr_fromIccProfile 28067
#define sipName_fromIccProfile &sipStrings_QtGui[28067]
#define sipNameNr_fullRectPixels 28082
#define sipName_fullRectPixels &sipStrings_QtGui[28082]
#define sipNameNr_fullRectPoints 28097
#define sipName_fullRectPoints &sipStrings_QtGui[28097]
#define sipNameNr_getEulerAngles 28112
#define sipName_getEulerAngles &sipStrings_QtGui[28112]
#define sipNameNr_getProcAddress 28127
#define sipName_getProcAddress &sipStrings_QtGui[28127]
#define sipNameNr_globalPosition 28142
#define sipName_globalPosition &sipStrings_QtGui[28142]
#define sipNameNr_headerRowCount 28157
#define sipName_headerRowCount &sipStrings_QtGui[28157]
#define sipNameNr_highlightBlock 22222
#define sipName_highlightBlock &sipStrings_QtGui[22222]
#define sipNameNr_hslSaturationF 28172
#define sipName_hslSaturationF &sipStrings_QtGui[28172]
#define sipNameNr_hsvSaturationF 28187
#define sipName_hsvSaturationF &sipStrings_QtGui[28187]
#define sipNameNr_inputDirection 28202
#define sipName_inputDirection &sipStrings_QtGui[28202]
#define sipNameNr_insertFragment 28217
#define sipName_insertFragment &sipStrings_QtGui[28217]
#define sipNameNr_isAutoTristate 28232
#define sipName_isAutoTristate &sipStrings_QtGui[28232]
#define sipNameNr_isEquivalentTo 28247
#define sipName_isEquivalentTo &sipStrings_QtGui[28247]
#define sipNameNr_isUserTristate 28262
#define sipName_isUserTristate &sipStrings_QtGui[28262]
#define sipNameNr_lastResortFont 28277
#define sipName_lastResortFont &sipStrings_QtGui[28277]
#define sipNameNr_lengthProperty 28292
#define sipName_lengthProperty &sipStrings_QtGui[28292]
#define sipNameNr_lightslategray 28307
#define sipName_lightslategray &sipStrings_QtGui[28307]
#define sipNameNr_lightslategrey 28322
#define sipName_lightslategrey &sipStrings_QtGui[28322]
#define sipNameNr_lightsteelblue 28337
#define sipName_lightsteelblue &sipStrings_QtGui[28337]
#define sipNameNr_lineHeightType 28352
#define sipName_lineHeightType &sipStrings_QtGui[28352]
#define sipNameNr_listFromString 28367
#define sipName_listFromString &sipStrings_QtGui[28367]
#define sipNameNr_loggedMessages 28382
#define sipName_loggedMessages &sipStrings_QtGui[28382]
#define sipNameNr_maximumMargins 28397
#define sipName_maximumMargins &sipStrings_QtGui[28397]
#define sipNameNr_mediumseagreen 28412
#define sipName_mediumseagreen &sipStrings_QtGui[28412]
#define sipNameNr_minLeftBearing 28427
#define sipName_minLeftBearing &sipStrings_QtGui[28427]
#define sipNameNr_minimumMargins 28442
#define sipName_minimumMargins &sipStrings_QtGui[28442]
#define sipNameNr_mouseMoveEvent 28457
#define sipName_mouseMoveEvent &sipStrings_QtGui[28457]
#define sipNameNr_nativeScanCode 28472
#define sipName_nativeScanCode &sipStrings_QtGui[28472]
#define sipNameNr_nextFrameDelay 28487
#define sipName_nextFrameDelay &sipStrings_QtGui[28487]
#define sipNameNr_nextImageDelay 28502
#define sipName_nextImageDelay &sipStrings_QtGui[28502]
#define sipNameNr_opacityChanged 28517
#define sipName_opacityChanged &sipStrings_QtGui[28517]
#define sipNameNr_optimizedWrite 28532
#define sipName_optimizedWrite &sipStrings_QtGui[28532]
#define sipNameNr_overrideCursor 28547
#define sipName_overrideCursor &sipStrings_QtGui[28547]
#define sipNameNr_ownsFindBuffer 28562
#define sipName_ownsFindBuffer &sipStrings_QtGui[28562]
#define sipNameNr_paintingActive 28577
#define sipName_paintingActive &sipStrings_QtGui[28577]
#define sipNameNr_paletteChanged 28592
#define sipName_paletteChanged &sipStrings_QtGui[28592]
#define sipNameNr_pointAtPercent 28607
#define sipName_pointAtPercent &sipStrings_QtGui[28607]
#define sipNameNr_proposedAction 28622
#define sipName_proposedAction &sipStrings_QtGui[28622]
#define sipNameNr_qUnpremultiply 28637
#define sipName_qUnpremultiply &sipStrings_QtGui[28637]
#define sipNameNr_renderableType 28652
#define sipName_renderableType &sipStrings_QtGui[28652]
#define sipNameNr_resetBaseLevel 28667
#define sipName_resetBaseLevel &sipStrings_QtGui[28667]
#define sipNameNr_resetTransform 28682
#define sipName_resetTransform &sipStrings_QtGui[28682]
#define sipNameNr_restartCommand 28697
#define sipName_restartCommand &sipStrings_QtGui[28697]
#define sipNameNr_sRGBColorSpace 28712
#define sipName_sRGBColorSpace &sipStrings_QtGui[28712]
#define sipNameNr_saturationSize 28727
#define sipName_saturationSize &sipStrings_QtGui[28727]
#define sipNameNr_scaledClipRect 28742
#define sipName_scaledClipRect &sipStrings_QtGui[28742]
#define sipNameNr_scaledToHeight 28757
#define sipName_scaledToHeight &sipStrings_QtGui[28757]
#define sipNameNr_selectionStart 28772
#define sipName_selectionStart &sipStrings_QtGui[28772]
#define sipNameNr_setAnchorNames 28787
#define sipName_setAnchorNames &sipStrings_QtGui[28787]
#define sipNameNr_setBlockFormat 28802
#define sipName_setBlockFormat &sipStrings_QtGui[28802]
#define sipNameNr_setBorderBrush 28817
#define sipName_setBorderBrush &sipStrings_QtGui[28817]
#define sipNameNr_setBorderColor 28832
#define sipName_setBorderColor &sipStrings_QtGui[28832]
#define sipNameNr_setBorderStyle 28847
#define sipName_setBorderStyle &sipStrings_QtGui[28847]
#define sipNameNr_setBrushOrigin 28862
#define sipName_setBrushOrigin &sipStrings_QtGui[28862]
#define sipNameNr_setCellPadding 28877
#define sipName_setCellPadding &sipStrings_QtGui[28877]
#define sipNameNr_setCellSpacing 28892
#define sipName_setCellSpacing &sipStrings_QtGui[28892]
#define sipNameNr_setColumnCount 28907
#define sipName_setColumnCount &sipStrings_QtGui[28907]
#define sipNameNr_setCompression 28922
#define sipName_setCompression &sipStrings_QtGui[28922]
#define sipNameNr_setDashPattern 28937
#define sipName_setDashPattern &sipStrings_QtGui[28937]
#define sipNameNr_setDefaultFont 28952
#define sipName_setDefaultFont &sipStrings_QtGui[28952]
#define sipNameNr_setDescription 28967
#define sipName_setDescription &sipStrings_QtGui[28967]
#define sipNameNr_setDragEnabled 28982
#define sipName_setDragEnabled &sipStrings_QtGui[28982]
#define sipNameNr_setDropEnabled 28997
#define sipName_setDropEnabled &sipStrings_QtGui[28997]
#define sipNameNr_setFocalRadius 29012
#define sipName_setFocalRadius &sipStrings_QtGui[29012]
#define sipNameNr_setFontKerning 29027
#define sipName_setFontKerning &sipStrings_QtGui[29027]
#define sipNameNr_setFontStretch 29042
#define sipName_setFontStretch &sipStrings_QtGui[29042]
#define sipNameNr_setFrameFormat 29057
#define sipName_setFrameFormat &sipStrings_QtGui[29057]
#define sipNameNr_setImageHeight 29072
#define sipName_setImageHeight &sipStrings_QtGui[29072]
#define sipNameNr_setIndentWidth 29087
#define sipName_setIndentWidth &sipStrings_QtGui[29087]
#define sipNameNr_setLeftPadding 29102
#define sipName_setLeftPadding &sipStrings_QtGui[29102]
#define sipNameNr_setMaximumSize 29117
#define sipName_setMaximumSize &sipStrings_QtGui[29117]
#define sipNameNr_setMinimumSize 29132
#define sipName_setMinimumSize &sipStrings_QtGui[29132]
#define sipNameNr_setMipMaxLevel 29147
#define sipName_setMipMaxLevel &sipStrings_QtGui[29147]
#define sipNameNr_setObjectIndex 29162
#define sipName_setObjectIndex &sipStrings_QtGui[29162]
#define sipNameNr_setOrientation 29177
#define sipName_setOrientation &sipStrings_QtGui[29177]
#define sipNameNr_setPageMargins 29192
#define sipName_setPageMargins &sipStrings_QtGui[29192]
#define sipNameNr_setPaintDevice 29207
#define sipName_setPaintDevice &sipStrings_QtGui[29207]
#define sipNameNr_setPreeditArea 29222
#define sipName_setPreeditArea &sipStrings_QtGui[29222]
#define sipNameNr_setRenderHints 29237
#define sipName_setRenderHints &sipStrings_QtGui[29237]
#define sipNameNr_setRestartHint 29252
#define sipName_setRestartHint &sipStrings_QtGui[29252]
#define sipNameNr_setRightBorder 29267
#define sipName_setRightBorder &sipStrings_QtGui[29267]
#define sipNameNr_setRightMargin 29282
#define sipName_setRightMargin &sipStrings_QtGui[29282]
#define sipNameNr_setRightToLeft 29297
#define sipName_setRightToLeft &sipStrings_QtGui[29297]
#define sipNameNr_setSampleCount 29312
#define sipName_setSampleCount &sipStrings_QtGui[29312]
#define sipNameNr_setSurfaceType 29327
#define sipName_setSurfaceType &sipStrings_QtGui[29327]
#define sipNameNr_setSwizzleMask 29342
#define sipName_setSwizzleMask &sipStrings_QtGui[29342]
#define sipNameNr_setTextOutline 29357
#define sipName_setTextOutline &sipStrings_QtGui[29357]
#define sipNameNr_setWindowState 29372
#define sipName_setWindowState &sipStrings_QtGui[29372]
#define sipNameNr_setWordSpacing 29387
#define sipName_setWordSpacing &sipStrings_QtGui[29387]
#define sipNameNr_showFullScreen 29402
#define sipName_showFullScreen &sipStrings_QtGui[29402]
#define sipNameNr_slopeAtPercent 29417
#define sipName_slopeAtPercent &sipStrings_QtGui[29417]
#define sipNameNr_startScreenPos 29432
#define sipName_startScreenPos &sipStrings_QtGui[29432]
#define sipNameNr_staticContents 29447
#define sipName_staticContents &sipStrings_QtGui[29447]
#define sipNameNr_stringProperty 29462
#define sipName_stringProperty &sipStrings_QtGui[29462]
#define sipNameNr_supportsOpenGL 29477
#define sipName_supportsOpenGL &sipStrings_QtGui[29477]
#define sipNameNr_supportsOption 29492
#define sipName_supportsOption &sipStrings_QtGui[29492]
#define sipNameNr_testRenderHint 29507
#define sipName_testRenderHint &sipStrings_QtGui[29507]
#define sipNameNr_toFillPolygons 29522
#define sipName_toFillPolygons &sipStrings_QtGui[29522]
#define sipNameNr_topBorderBrush 29537
#define sipName_topBorderBrush &sipStrings_QtGui[29537]
#define sipNameNr_topBorderStyle 29552
#define sipName_topBorderStyle &sipStrings_QtGui[29552]
#define sipNameNr_transformation 29567
#define sipName_transformation &sipStrings_QtGui[29567]
#define sipNameNr_underlineColor 29582
#define sipName_underlineColor &sipStrings_QtGui[29582]
#define sipNameNr_underlineStyle 29597
#define sipName_underlineStyle &sipStrings_QtGui[29597]
#define sipNameNr_updateBehavior 29612
#define sipName_updateBehavior &sipStrings_QtGui[29612]
#define sipNameNr_versionProfile 29627
#define sipName_versionProfile &sipStrings_QtGui[29627]
#define sipNameNr_visibleChanged 29642
#define sipName_visibleChanged &sipStrings_QtGui[29642]
#define sipNameNr_waitForSamples 29657
#define sipName_waitForSamples &sipStrings_QtGui[29657]
#define sipNameNr_worldTransform 29672
#define sipName_worldTransform &sipStrings_QtGui[29672]
#define sipNameNr_writingSystems 29687
#define sipName_writingSystems &sipStrings_QtGui[29687]
#define sipNameNr_AlignBaseline 29702
#define sipName_AlignBaseline &sipStrings_QtGui[29702]
#define sipNameNr_AlphaPosition 4755
#define sipName_AlphaPosition &sipStrings_QtGui[4755]
#define sipNameNr_AlternateBase 29716
#define sipName_AlternateBase &sipStrings_QtGui[29716]
#define sipNameNr_AttributeType 1293
#define sipName_AttributeType &sipStrings_QtGui[1293]
#define sipNameNr_BindingTarget 3159
#define sipName_BindingTarget &sipStrings_QtGui[3159]
#define sipNameNr_BurningSpring 29730
#define sipName_BurningSpring &sipStrings_QtGui[29730]
#define sipNameNr_ClampToBorder 29744
#define sipName_ClampToBorder &sipStrings_QtGui[29744]
#define sipNameNr_ColorfulPeach 29758
#define sipName_ColorfulPeach &sipStrings_QtGui[29758]
#define sipNameNr_CompareAlways 29772
#define sipName_CompareAlways &sipStrings_QtGui[29772]
#define sipNameNr_DashUnderline 29786
#define sipName_DashUnderline &sipStrings_QtGui[29786]
#define sipNameNr_DirtyClipPath 29800
#define sipName_DirtyClipPath &sipStrings_QtGui[29800]
#define sipNameNr_DocumentTitle 29814
#define sipName_DocumentTitle &sipStrings_QtGui[29814]
#define sipNameNr_EnvelopeChou3 29828
#define sipName_EnvelopeChou3 &sipStrings_QtGui[29828]
#define sipNameNr_EnvelopeChou4 29842
#define sipName_EnvelopeChou4 &sipStrings_QtGui[29842]
#define sipNameNr_EnvelopeKaku2 29856
#define sipName_EnvelopeKaku2 &sipStrings_QtGui[29856]
#define sipNameNr_EnvelopeKaku3 29870
#define sipName_EnvelopeKaku3 &sipStrings_QtGui[29870]
#define sipNameNr_EnvelopePrc10 29884
#define sipName_EnvelopePrc10 &sipStrings_QtGui[29884]
#define sipNameNr_ExtraExpanded 29898
#define sipName_ExtraExpanded &sipStrings_QtGui[29898]
#define sipNameNr_FanFoldGerman 29912
#define sipName_FanFoldGerman &sipStrings_QtGui[29912]
#define sipNameNr_FloatingPoint 29926
#define sipName_FloatingPoint &sipStrings_QtGui[29926]
#define sipNameNr_FontPixelSize 29940
#define sipName_FontPixelSize &sipStrings_QtGui[29940]
#define sipNameNr_FontPointSize 22427
#define sipName_FontPointSize &sipStrings_QtGui[22427]
#define sipNameNr_FontStrikeOut 22444
#define sipName_FontStrikeOut &sipStrings_QtGui[22444]
#define sipNameNr_FontStyleHint 22461
#define sipName_FontStyleHint &sipStrings_QtGui[22461]
#define sipNameNr_FontStyleName 22478
#define sipName_FontStyleName &sipStrings_QtGui[22478]
#define sipNameNr_FontUnderline 22495
#define sipName_FontUnderline &sipStrings_QtGui[22495]
#define sipNameNr_FormatOptions 3369
#define sipName_FormatOptions &sipStrings_QtGui[3369]
#define sipNameNr_Format_ARGB32 29954
#define sipName_Format_ARGB32 &sipStrings_QtGui[29954]
#define sipNameNr_Format_Alpha8 29968
#define sipName_Format_Alpha8 &sipStrings_QtGui[29968]
#define sipNameNr_Format_BGR888 29982
#define sipName_Format_BGR888 &sipStrings_QtGui[29982]
#define sipNameNr_Format_RGB444 29996
#define sipName_Format_RGB444 &sipStrings_QtGui[29996]
#define sipNameNr_Format_RGB555 30010
#define sipName_Format_RGB555 &sipStrings_QtGui[30010]
#define sipNameNr_Format_RGB666 30024
#define sipName_Format_RGB666 &sipStrings_QtGui[30024]
#define sipNameNr_Format_RGB888 30038
#define sipName_Format_RGB888 &sipStrings_QtGui[30038]
#define sipNameNr_Format_RGBA64 30052
#define sipName_Format_RGBA64 &sipStrings_QtGui[30052]
#define sipNameNr_Format_RGBX64 30066
#define sipName_Format_RGBX64 &sipStrings_QtGui[30066]
#define sipNameNr_GlyphRunFlags 6791
#define sipName_GlyphRunFlags &sipStrings_QtGui[6791]
#define sipNameNr_GroupPushType 30080
#define sipName_GroupPushType &sipStrings_QtGui[30080]
#define sipNameNr_HappyMemories 30094
#define sipName_HappyMemories &sipStrings_QtGui[30094]
#define sipNameNr_ImageResource 30108
#define sipName_ImageResource &sipStrings_QtGui[30108]
#define sipNameNr_Imperial10x11 30122
#define sipName_Imperial10x11 &sipStrings_QtGui[30122]
#define sipNameNr_Imperial10x13 30136
#define sipName_Imperial10x13 &sipStrings_QtGui[30136]
#define sipNameNr_Imperial10x14 30150
#define sipName_Imperial10x14 &sipStrings_QtGui[30150]
#define sipNameNr_Imperial12x11 30164
#define sipName_Imperial12x11 &sipStrings_QtGui[30164]
#define sipNameNr_Imperial15x11 30178
#define sipName_Imperial15x11 &sipStrings_QtGui[30178]
#define sipNameNr_InvalidFormat 30192
#define sipName_InvalidFormat &sipStrings_QtGui[30192]
#define sipNameNr_InvalidSource 30206
#define sipName_InvalidSource &sipStrings_QtGui[30206]
#define sipNameNr_ItmeoBranding 30220
#define sipName_ItmeoBranding &sipStrings_QtGui[30220]
#define sipNameNr_LineToElement 30234
#define sipName_LineToElement &sipStrings_QtGui[30234]
#define sipNameNr_MidnightBloom 30248
#define sipName_MidnightBloom &sipStrings_QtGui[30248]
#define sipNameNr_MinimumHeight 22614
#define sipName_MinimumHeight &sipStrings_QtGui[22614]
#define sipNameNr_MoveOperation 5329
#define sipName_MoveOperation &sipStrings_QtGui[5329]
#define sipNameNr_MoveToElement 30262
#define sipName_MoveToElement &sipStrings_QtGui[30262]
#define sipNameNr_NextCharacter 30276
#define sipName_NextCharacter &sipStrings_QtGui[30276]
#define sipNameNr_NoFontMerging 30290
#define sipName_NoFontMerging &sipStrings_QtGui[30290]
#define sipNameNr_OpenGLSurface 30304
#define sipName_OpenGLSurface &sipStrings_QtGui[30304]
#define sipNameNr_OpenVGSurface 30318
#define sipName_OpenVGSurface &sipStrings_QtGui[30318]
#define sipNameNr_OriginTopLeft 30332
#define sipName_OriginTopLeft &sipStrings_QtGui[30332]
#define sipNameNr_PageBreakFlag 5383
#define sipName_PageBreakFlag &sipStrings_QtGui[5383]
#define sipNameNr_PassionateBed 30346
#define sipName_PassionateBed &sipStrings_QtGui[30346]
#define sipNameNr_PreferDefault 30360
#define sipName_PreferDefault &sipStrings_QtGui[30360]
#define sipNameNr_PreferOutline 30374
#define sipName_PreferOutline &sipStrings_QtGui[30374]
#define sipNameNr_PreferQuality 30388
#define sipName_PreferQuality &sipStrings_QtGui[30388]
#define sipNameNr_Premultiplied 1557
#define sipName_Premultiplied &sipStrings_QtGui[1557]
#define sipNameNr_PreviousBlock 30402
#define sipName_PreviousBlock &sipStrings_QtGui[30402]
#define sipNameNr_PreviousChild 30416
#define sipName_PreviousChild &sipStrings_QtGui[30416]
#define sipNameNr_QBackingStore 30430
#define sipName_QBackingStore &sipStrings_QtGui[30430]
#define sipNameNr_QFont__Weight 30444
#define sipName_QFont__Weight &sipStrings_QtGui[30444]
#define sipNameNr_QFontDatabase 30458
#define sipName_QFontDatabase &sipStrings_QtGui[30458]
#define sipNameNr_QFontMetricsF 30472
#define sipName_QFontMetricsF &sipStrings_QtGui[30472]
#define sipNameNr_QIntValidator 30486
#define sipName_QIntValidator &sipStrings_QtGui[30486]
#define sipNameNr_QOpenGLBuffer 30500
#define sipName_QOpenGLBuffer &sipStrings_QtGui[30500]
#define sipNameNr_QOpenGLShader 30514
#define sipName_QOpenGLShader &sipStrings_QtGui[30514]
#define sipNameNr_QOpenGLWindow 30528
#define sipName_QOpenGLWindow &sipStrings_QtGui[30528]
#define sipNameNr_QRasterWindow 30542
#define sipName_QRasterWindow &sipStrings_QtGui[30542]
#define sipNameNr_QStandardItem 30556
#define sipName_QStandardItem &sipStrings_QtGui[30556]
#define sipNameNr_QTextDocument 30570
#define sipName_QTextDocument &sipStrings_QtGui[30570]
#define sipNameNr_QTextFragment 30584
#define sipName_QTextFragment &sipStrings_QtGui[30584]
#define sipNameNr_30598 30598
#define sipName_30598 &sipStrings_QtGui[30598]
#define sipNameNr_QWindowSystem 30612
#define sipName_QWindowSystem &sipStrings_QtGui[30612]
#define sipNameNr_R11_EAC_SNorm 30626
#define sipName_R11_EAC_SNorm &sipStrings_QtGui[30626]
#define sipNameNr_R11_EAC_UNorm 30640
#define sipName_R11_EAC_UNorm &sipStrings_QtGui[30640]
#define sipNameNr_RGBA_ASTC_4x4 30654
#define sipName_RGBA_ASTC_4x4 &sipStrings_QtGui[30654]
#define sipNameNr_RGBA_ASTC_5x4 30668
#define sipName_RGBA_ASTC_5x4 &sipStrings_QtGui[30668]
#define sipNameNr_RGBA_ASTC_5x5 30682
#define sipName_RGBA_ASTC_5x5 &sipStrings_QtGui[30682]
#define sipNameNr_RGBA_ASTC_6x5 30696
#define sipName_RGBA_ASTC_6x5 &sipStrings_QtGui[30696]
#define sipNameNr_RGBA_ASTC_6x6 30710
#define sipName_RGBA_ASTC_6x6 &sipStrings_QtGui[30710]
#define sipNameNr_RGBA_ASTC_8x5 30724
#define sipName_RGBA_ASTC_8x5 &sipStrings_QtGui[30724]
#define sipNameNr_RGBA_ASTC_8x6 30738
#define sipName_RGBA_ASTC_8x6 &sipStrings_QtGui[30738]
#define sipNameNr_RGBA_ASTC_8x8 30752
#define sipName_RGBA_ASTC_8x8 &sipStrings_QtGui[30752]
#define sipNameNr_R_ATI1N_SNorm 30766
#define sipName_R_ATI1N_SNorm &sipStrings_QtGui[30766]
#define sipNameNr_R_ATI1N_UNorm 30780
#define sipName_R_ATI1N_UNorm &sipStrings_QtGui[30780]
#define sipNameNr_RainyAshville 30794
#define sipName_RainyAshville &sipStrings_QtGui[30794]
#define sipNameNr_RasterOpModes 30808
#define sipName_RasterOpModes &sipStrings_QtGui[30808]
#define sipNameNr_RasterSurface 30822
#define sipName_RasterSurface &sipStrings_QtGui[30822]
#define sipNameNr_ReflectSpread 30836
#define sipName_ReflectSpread &sipStrings_QtGui[30836]
#define sipNameNr_RestartAnyway 30850
#define sipName_RestartAnyway &sipStrings_QtGui[30850]
#define sipNameNr_RiskyConcrete 30864
#define sipName_RiskyConcrete &sipStrings_QtGui[30864]
#define sipNameNr_SRGB_BP_UNorm 30878
#define sipName_SRGB_BP_UNorm &sipStrings_QtGui[30878]
#define sipNameNr_ScrollStarted 30892
#define sipName_ScrollStarted &sipStrings_QtGui[30892]
#define sipNameNr_ScrollUpdated 30906
#define sipName_ScrollUpdated &sipStrings_QtGui[30906]
#define sipNameNr_SelectionType 5356
#define sipName_SelectionType &sipStrings_QtGui[5356]
#define sipNameNr_SemiCondensed 30920
#define sipName_SemiCondensed &sipStrings_QtGui[30920]
#define sipNameNr_SequenceMatch 4559
#define sipName_SequenceMatch &sipStrings_QtGui[4559]
#define sipNameNr_ShaderTypeBit 3930
#define sipName_ShaderTypeBit &sipStrings_QtGui[3930]
#define sipNameNr_SharpeyeEagle 30934
#define sipName_SharpeyeEagle &sipStrings_QtGui[30934]
#define sipNameNr_SplitLigature 30948
#define sipName_SplitLigature &sipStrings_QtGui[30948]
#define sipNameNr_StereoBuffers 30962
#define sipName_StereoBuffers &sipStrings_QtGui[30962]
#define sipNameNr_StyleStrategy 12059
#define sipName_StyleStrategy &sipStrings_QtGui[12059]
#define sipNameNr_SugarLollipop 30976
#define sipName_SugarLollipop &sipStrings_QtGui[30976]
#define sipNameNr_Target1DArray 11765
#define sipName_Target1DArray &sipStrings_QtGui[11765]
#define sipNameNr_Target2DArray 11786
#define sipName_Target2DArray &sipStrings_QtGui[11786]
#define sipNameNr_TargetCubeMap 11807
#define sipName_TargetCubeMap &sipStrings_QtGui[11807]
#define sipNameNr_TemptingAzure 30990
#define sipName_TemptingAzure &sipStrings_QtGui[30990]
#define sipNameNr_TextureArrays 31004
#define sipName_TextureArrays &sipStrings_QtGui[31004]
#define sipNameNr_TextureBuffer 31018
#define sipName_TextureBuffer &sipStrings_QtGui[31018]
#define sipNameNr_TextureFormat 3189
#define sipName_TextureFormat &sipStrings_QtGui[3189]
#define sipNameNr_UInt16_R5G6B5 31032
#define sipName_UInt16_R5G6B5 &sipStrings_QtGui[31032]
#define sipNameNr_UInt16_RGB5A1 31046
#define sipName_UInt16_RGB5A1 &sipStrings_QtGui[31046]
#define sipNameNr_UltraExpanded 31060
#define sipName_UltraExpanded &sipStrings_QtGui[31060]
#define sipNameNr_UnsignedShort 31074
#define sipName_UnsignedShort &sipStrings_QtGui[31074]
#define sipNameNr_ViciousStance 31088
#define sipName_ViciousStance &sipStrings_QtGui[31088]
#define sipNameNr_VulkanSurface 31102
#define sipName_VulkanSurface &sipStrings_QtGui[31102]
#define sipNameNr_WaveUnderline 31116
#define sipName_WaveUnderline &sipStrings_QtGui[31116]
#define sipNameNr_WritingSystem 3785
#define sipName_WritingSystem &sipStrings_QtGui[3785]
#define sipNameNr_actionChanged 31130
#define sipName_actionChanged &sipStrings_QtGui[31130]
#define sipNameNr_activeChanged 31144
#define sipName_activeChanged &sipStrings_QtGui[31144]
#define sipNameNr_alphaPosition 31158
#define sipName_alphaPosition &sipStrings_QtGui[31158]
#define sipNameNr_alternateBase 31172
#define sipName_alternateBase &sipStrings_QtGui[31172]
#define sipNameNr_appendColumns 31186
#define sipName_appendColumns &sipStrings_QtGui[31186]
#define sipNameNr_autoTransform 31200
#define sipName_autoTransform &sipStrings_QtGui[31200]
#define sipNameNr_availableSize 31214
#define sipName_availableSize &sipStrings_QtGui[31214]
#define sipNameNr_bitPlaneCount 31228
#define sipName_bitPlaneCount &sipStrings_QtGui[31228]
#define sipNameNr_blockInserted 31242
#define sipName_blockInserted &sipStrings_QtGui[31242]
#define sipNameNr_bottomPadding 31256
#define sipName_bottomPadding &sipStrings_QtGui[31256]
#define sipNameNr_brushProperty 31270
#define sipName_brushProperty &sipStrings_QtGui[31270]
#define sipNameNr_clearItemData 31284
#define sipName_clearItemData &sipStrings_QtGui[31284]
#define sipNameNr_clearProperty 31298
#define sipName_clearProperty &sipStrings_QtGui[31298]
#define sipNameNr_clipOperation 31312
#define sipName_clipOperation &sipStrings_QtGui[31312]
#define sipNameNr_colorProperty 31326
#define sipName_colorProperty &sipStrings_QtGui[31326]
#define sipNameNr_connectNotify 21883
#define sipName_connectNotify &sipStrings_QtGui[21883]
#define sipNameNr_constScanLine 31340
#define sipName_constScanLine &sipStrings_QtGui[31340]
#define sipNameNr_containsPoint 31354
#define sipName_containsPoint &sipStrings_QtGui[31354]
#define sipNameNr_currentPixmap 31368
#define sipName_currentPixmap &sipStrings_QtGui[31368]
#define sipNameNr_darkgoldenrod 31382
#define sipName_darkgoldenrod &sipStrings_QtGui[31382]
#define sipNameNr_darkslateblue 31396
#define sipName_darkslateblue &sipStrings_QtGui[31396]
#define sipNameNr_darkslategray 31410
#define sipName_darkslategray &sipStrings_QtGui[31410]
#define sipNameNr_darkslategrey 31424
#define sipName_darkslategrey &sipStrings_QtGui[31424]
#define sipNameNr_darkturquoise 31438
#define sipName_darkturquoise &sipStrings_QtGui[31438]
#define sipNameNr_defaultAction 31452
#define sipName_defaultAction &sipStrings_QtGui[31452]
#define sipNameNr_defaultFamily 31466
#define sipName_defaultFamily &sipStrings_QtGui[31466]
#define sipNameNr_defaultFormat 31480
#define sipName_defaultFormat &sipStrings_QtGui[31480]
#define sipNameNr_dotsPerMeterX 31494
#define sipName_dotsPerMeterX &sipStrings_QtGui[31494]
#define sipNameNr_dotsPerMeterY 31508
#define sipName_dotsPerMeterY &sipStrings_QtGui[31508]
#define sipNameNr_firstPosition 31522
#define sipName_firstPosition &sipStrings_QtGui[31522]
#define sipNameNr_focusOutEvent 31536
#define sipName_focusOutEvent &sipStrings_QtGui[31536]
#define sipNameNr_fontPointSize 31550
#define sipName_fontPointSize &sipStrings_QtGui[31550]
#define sipNameNr_fontStrikeOut 31564
#define sipName_fontStrikeOut &sipStrings_QtGui[31564]
#define sipNameNr_fontStyleHint 31578
#define sipName_fontStyleHint &sipStrings_QtGui[31578]
#define sipNameNr_fontStyleName 31592
#define sipName_fontStyleName &sipStrings_QtGui[31592]
#define sipNameNr_fontUnderline 31606
#define sipName_fontUnderline &sipStrings_QtGui[31606]
#define sipNameNr_formatVersion 31620
#define sipName_formatVersion &sipStrings_QtGui[31620]
#define sipNameNr_frameGeometry 31634
#define sipName_frameGeometry &sipStrings_QtGui[31634]
#define sipNameNr_framePosition 31648
#define sipName_framePosition &sipStrings_QtGui[31648]
#define sipNameNr_fromDirection 31662
#define sipName_fromDirection &sipStrings_QtGui[31662]
#define sipNameNr_fromNumericId 31676
#define sipName_fromNumericId &sipStrings_QtGui[31676]
#define sipNameNr_fromPlainText 31690
#define sipName_fromPlainText &sipStrings_QtGui[31690]
#define sipNameNr_fromTranslate 31704
#define sipName_fromTranslate &sipStrings_QtGui[31704]
#define sipNameNr_heightChanged 31718
#define sipName_heightChanged &sipStrings_QtGui[31718]
#define sipNameNr_hslSaturation 31732
#define sipName_hslSaturation &sipStrings_QtGui[31732]
#define sipNameNr_hsvSaturation 31746
#define sipName_hsvSaturation &sipStrings_QtGui[31746]
#define sipNameNr_indexFromItem 31760
#define sipName_indexFromItem &sipStrings_QtGui[31760]
#define sipNameNr_insertColumns 31774
#define sipName_insertColumns &sipStrings_QtGui[31774]
#define sipNameNr_intrinsicSize 31788
#define sipName_intrinsicSize &sipStrings_QtGui[31788]
#define sipNameNr_isBlockFormat 31802
#define sipName_isBlockFormat &sipStrings_QtGui[31802]
#define sipNameNr_isClipEnabled 31816
#define sipName_isClipEnabled &sipStrings_QtGui[31816]
#define sipNameNr_isDragEnabled 31830
#define sipName_isDragEnabled &sipStrings_QtGui[31830]
#define sipNameNr_isDropEnabled 31844
#define sipName_isDropEnabled &sipStrings_QtGui[31844]
#define sipNameNr_isFrameFormat 31858
#define sipName_isFrameFormat &sipStrings_QtGui[31858]
#define sipNameNr_isImageFormat 31872
#define sipName_isImageFormat &sipStrings_QtGui[31872]
#define sipNameNr_isLeftToRight 31886
#define sipName_isLeftToRight &sipStrings_QtGui[31886]
#define sipNameNr_isRightToLeft 31900
#define sipName_isRightToLeft &sipStrings_QtGui[31900]
#define sipNameNr_isTableFormat 31914
#define sipName_isTableFormat &sipStrings_QtGui[31914]
#define sipNameNr_isTextureView 31928
#define sipName_isTextureView &sipStrings_QtGui[31928]
#define sipNameNr_isTranslating 31942
#define sipName_isTranslating &sipStrings_QtGui[31942]
#define sipNameNr_isTransparent 31956
#define sipName_isTransparent &sipStrings_QtGui[31956]
#define sipNameNr_itemFromIndex 31970
#define sipName_itemFromIndex &sipStrings_QtGui[31970]
#define sipNameNr_itemPrototype 31984
#define sipName_itemPrototype &sipStrings_QtGui[31984]
#define sipNameNr_keyPressEvent 31998
#define sipName_keyPressEvent &sipStrings_QtGui[31998]
#define sipNameNr_lastScreenPos 32012
#define sipName_lastScreenPos &sipStrings_QtGui[32012]
#define sipNameNr_lavenderblush 32026
#define sipName_lavenderblush &sipStrings_QtGui[32026]
#define sipNameNr_lengthSquared 32040
#define sipName_lengthSquared &sipStrings_QtGui[32040]
#define sipNameNr_letterSpacing 32054
#define sipName_letterSpacing &sipStrings_QtGui[32054]
#define sipNameNr_lightnessSize 32068
#define sipName_lightnessSize &sipStrings_QtGui[32068]
#define sipNameNr_lightseagreen 32082
#define sipName_lightseagreen &sipStrings_QtGui[32082]
#define sipNameNr_lineThickness 32096
#define sipName_lineThickness &sipStrings_QtGui[32096]
#define sipNameNr_localeChanged 32110
#define sipName_localeChanged &sipStrings_QtGui[32110]
#define sipNameNr_mapFromGlobal 32124
#define sipName_mapFromGlobal &sipStrings_QtGui[32124]
#define sipNameNr_marginsPixels 32138
#define sipName_marginsPixels &sipStrings_QtGui[32138]
#define sipNameNr_marginsPoints 32152
#define sipName_marginsPoints &sipStrings_QtGui[32152]
#define sipNameNr_maximumHeight 32166
#define sipName_maximumHeight &sipStrings_QtGui[32166]
#define sipNameNr_messageLogged 32180
#define sipName_messageLogged &sipStrings_QtGui[32180]
#define sipNameNr_minMagFilters 32194
#define sipName_minMagFilters &sipStrings_QtGui[32194]
#define sipNameNr_minimumHeight 32208
#define sipName_minimumHeight &sipStrings_QtGui[32208]
#define sipNameNr_mipLevelRange 32222
#define sipName_mipLevelRange &sipStrings_QtGui[32222]
#define sipNameNr_normalizedPos 32236
#define sipName_normalizedPos &sipStrings_QtGui[32236]
#define sipNameNr_outputFormats 32250
#define sipName_outputFormats &sipStrings_QtGui[32250]
#define sipNameNr_ownsClipboard 32264
#define sipName_ownsClipboard &sipStrings_QtGui[32264]
#define sipNameNr_ownsSelection 32278
#define sipName_ownsSelection &sipStrings_QtGui[32278]
#define sipNameNr_palegoldenrod 32292
#define sipName_palegoldenrod &sipStrings_QtGui[32292]
#define sipNameNr_paleturquoise 32306
#define sipName_paleturquoise &sipStrings_QtGui[32306]
#define sipNameNr_palevioletred 32320
#define sipName_palevioletred &sipStrings_QtGui[32320]
#define sipNameNr_pictureFormat 32334
#define sipName_pictureFormat &sipStrings_QtGui[32334]
#define sipNameNr_preeditString 32348
#define sipName_preeditString &sipStrings_QtGui[32348]
#define sipNameNr_premultiplied 26339
#define sipName_premultiplied &sipStrings_QtGui[26339]
#define sipNameNr_primaryScreen 32362
#define sipName_primaryScreen &sipStrings_QtGui[32362]
#define sipNameNr_propertyCount 32376
#define sipName_propertyCount &sipStrings_QtGui[32376]
#define sipNameNr_qFuzzyCompare 32390
#define sipName_qFuzzyCompare &sipStrings_QtGui[32390]
#define sipNameNr_redBufferSize 32404
#define sipName_redBufferSize &sipStrings_QtGui[32404]
#define sipNameNr_redoAvailable 32418
#define sipName_redoAvailable &sipStrings_QtGui[32418]
#define sipNameNr_removeColumns 32432
#define sipName_removeColumns &sipStrings_QtGui[32432]
#define sipNameNr_requestPhase2 32446
#define sipName_requestPhase2 &sipStrings_QtGui[32446]
#define sipNameNr_requestUpdate 32460
#define sipName_requestUpdate &sipStrings_QtGui[32460]
#define sipNameNr_rotateRadians 32474
#define sipName_rotateRadians &sipStrings_QtGui[32474]
#define sipNameNr_rotatedVector 32488
#define sipName_rotatedVector &sipStrings_QtGui[32488]
#define sipNameNr_scaledToWidth 32502
#define sipName_scaledToWidth &sipStrings_QtGui[32502]
#define sipNameNr_screenChanged 32516
#define sipName_screenChanged &sipStrings_QtGui[32516]
#define sipNameNr_screenRemoved 32530
#define sipName_screenRemoved &sipStrings_QtGui[32530]
#define sipNameNr_setAnchorHref 32544
#define sipName_setAnchorHref &sipStrings_QtGui[32544]
#define sipNameNr_setAttachment 32558
#define sipName_setAttachment &sipStrings_QtGui[32558]
#define sipNameNr_setBackground 32572
#define sipName_setBackground &sipStrings_QtGui[32572]
#define sipNameNr_setCacheLimit 32586
#define sipName_setCacheLimit &sipStrings_QtGui[32586]
#define sipNameNr_setCharFormat 32600
#define sipName_setCharFormat &sipStrings_QtGui[32600]
#define sipNameNr_setCheckState 32614
#define sipName_setCheckState &sipStrings_QtGui[32614]
#define sipNameNr_setClipRegion 32628
#define sipName_setClipRegion &sipStrings_QtGui[32628]
#define sipNameNr_setColorCount 32642
#define sipName_setColorCount &sipStrings_QtGui[32642]
#define sipNameNr_setColorGroup 32656
#define sipName_setColorGroup &sipStrings_QtGui[32656]
#define sipNameNr_setColorSpace 32670
#define sipName_setColorSpace &sipStrings_QtGui[32670]
#define sipNameNr_setColorTable 32684
#define sipName_setColorTable &sipStrings_QtGui[32684]
#define sipNameNr_setContentPos 32698
#define sipName_setContentPos &sipStrings_QtGui[32698]
#define sipNameNr_setDashOffset 32712
#define sipName_setDashOffset &sipStrings_QtGui[32712]
#define sipNameNr_setDragCursor 32726
#define sipName_setDragCursor &sipStrings_QtGui[32726]
#define sipNameNr_setDropAction 32740
#define sipName_setDropAction &sipStrings_QtGui[32740]
#define sipNameNr_setFixedPitch 32754
#define sipName_setFixedPitch &sipStrings_QtGui[32754]
#define sipNameNr_setFocalPoint 32768
#define sipName_setFocalPoint &sipStrings_QtGui[32768]
#define sipNameNr_setFontFamily 32782
#define sipName_setFontFamily &sipStrings_QtGui[32782]
#define sipNameNr_setFontItalic 32796
#define sipName_setFontItalic &sipStrings_QtGui[32796]
#define sipNameNr_setFontWeight 32810
#define sipName_setFontWeight &sipStrings_QtGui[32810]
#define sipNameNr_setForeground 32824
#define sipName_setForeground &sipStrings_QtGui[32824]
#define sipNameNr_setHeaderData 32838
#define sipName_setHeaderData &sipStrings_QtGui[32838]
#define sipNameNr_setLeftBorder 32852
#define sipName_setLeftBorder &sipStrings_QtGui[32852]
#define sipNameNr_setLeftMargin 32866
#define sipName_setLeftMargin &sipStrings_QtGui[32866]
#define sipNameNr_setLineHeight 32880
#define sipName_setLineHeight &sipStrings_QtGui[32880]
#define sipNameNr_setMiterLimit 32894
#define sipName_setMiterLimit &sipStrings_QtGui[32894]
#define sipNameNr_setNamedColor 32908
#define sipName_setNamedColor &sipStrings_QtGui[32908]
#define sipNameNr_setNumColumns 32922
#define sipName_setNumColumns &sipStrings_QtGui[32922]
#define sipNameNr_setObjectType 32936
#define sipName_setObjectType &sipStrings_QtGui[32936]
#define sipNameNr_setPageLayout 32950
#define sipName_setPageLayout &sipStrings_QtGui[32950]
#define sipNameNr_setPageSizeMM 32964
#define sipName_setPageSizeMM &sipStrings_QtGui[32964]
#define sipNameNr_setParameters 32978
#define sipName_setParameters &sipStrings_QtGui[32978]
#define sipNameNr_setPdfVersion 32992
#define sipName_setPdfVersion &sipStrings_QtGui[32992]
#define sipNameNr_setPixelColor 33006
#define sipName_setPixelColor &sipStrings_QtGui[33006]
#define sipNameNr_setPointSizeF 33020
#define sipName_setPointSizeF &sipStrings_QtGui[33020]
#define sipNameNr_setRenderHint 33034
#define sipName_setRenderHint &sipStrings_QtGui[33034]
#define sipNameNr_setResolution 33048
#define sipName_setResolution &sipStrings_QtGui[33048]
#define sipNameNr_setScaledSize 33062
#define sipName_setScaledSize &sipStrings_QtGui[33062]
#define sipNameNr_setSelectable 33076
#define sipName_setSelectable &sipStrings_QtGui[33076]
#define sipNameNr_setSkipImages 33090
#define sipName_setSkipImages &sipStrings_QtGui[33090]
#define sipNameNr_setSkipPixels 33104
#define sipName_setSkipPixels &sipStrings_QtGui[33104]
#define sipNameNr_setTextFormat 33118
#define sipName_setTextFormat &sipStrings_QtGui[33118]
#define sipNameNr_setTextIndent 33132
#define sipName_setTextIndent &sipStrings_QtGui[33132]
#define sipNameNr_setTextOption 33146
#define sipName_setTextOption &sipStrings_QtGui[33146]
#define sipNameNr_setToIdentity 33160
#define sipName_setToIdentity &sipStrings_QtGui[33160]
#define sipNameNr_setTopPadding 33174
#define sipName_setTopPadding &sipStrings_QtGui[33174]
#define sipNameNr_setUrlHandler 26355
#define sipName_setUrlHandler &sipStrings_QtGui[26355]
#define sipNameNr_setVisibility 33188
#define sipName_setVisibility &sipStrings_QtGui[33188]
#define sipNameNr_setWindowIcon 33202
#define sipName_setWindowIcon &sipStrings_QtGui[33202]
#define sipNameNr_showMaximized 33216
#define sipName_showMaximized &sipStrings_QtGui[33216]
#define sipNameNr_showMinimized 33230
#define sipName_showMinimized &sipStrings_QtGui[33230]
#define sipNameNr_sizeIncrement 33244
#define sipName_sizeIncrement &sipStrings_QtGui[33244]
#define sipNameNr_standardSizes 33258
#define sipName_standardSizes &sipStrings_QtGui[33258]
#define sipNameNr_startDragTime 33272
#define sipName_startDragTime &sipStrings_QtGui[33272]
#define sipNameNr_startScenePos 33286
#define sipName_startScenePos &sipStrings_QtGui[33286]
#define sipNameNr_styleStrategy 33300
#define sipName_styleStrategy &sipStrings_QtGui[33300]
#define sipNameNr_substitutions 33314
#define sipName_substitutions &sipStrings_QtGui[33314]
#define sipNameNr_targetChanged 33328
#define sipName_targetChanged &sipStrings_QtGui[33328]
#define sipNameNr_textAlignment 33342
#define sipName_textAlignment &sipStrings_QtGui[33342]
#define sipNameNr_textDirection 33356
#define sipName_textDirection &sipStrings_QtGui[33356]
#define sipNameNr_textureTarget 33370
#define sipName_textureTarget &sipStrings_QtGui[33370]
#define sipNameNr_toBlockFormat 33384
#define sipName_toBlockFormat &sipStrings_QtGui[33384]
#define sipNameNr_toEulerAngles 33398
#define sipName_toEulerAngles &sipStrings_QtGui[33398]
#define sipNameNr_toExtendedRgb 33412
#define sipName_toExtendedRgb &sipStrings_QtGui[33412]
#define sipNameNr_toFillPolygon 33426
#define sipName_toFillPolygon &sipStrings_QtGui[33426]
#define sipNameNr_toFrameFormat 33440
#define sipName_toFrameFormat &sipStrings_QtGui[33440]
#define sipNameNr_toImageFormat 33454
#define sipName_toImageFormat &sipStrings_QtGui[33454]
#define sipNameNr_toPixelFormat 33468
#define sipName_toPixelFormat &sipStrings_QtGui[33468]
#define sipNameNr_toTableFormat 33482
#define sipName_toTableFormat &sipStrings_QtGui[33482]
#define sipNameNr_transformMode 33496
#define sipName_transformMode &sipStrings_QtGui[33496]
#define sipNameNr_undoAvailable 33510
#define sipName_undoAvailable &sipStrings_QtGui[33510]
#define sipNameNr_waitForResult 33524
#define sipName_waitForResult &sipStrings_QtGui[33524]
#define sipNameNr_writingSystem 33538
#define sipName_writingSystem &sipStrings_QtGui[33538]
#define sipNameNr_AfricanField 33552
#define sipName_AfricanField &sipStrings_QtGui[33552]
#define sipNameNr_AlchemistLab 33565
#define sipName_AlchemistLab &sipStrings_QtGui[33565]
#define sipNameNr_AllLowercase 33578
#define sipName_AllLowercase &sipStrings_QtGui[33578]
#define sipNameNr_AllUppercase 33591
#define sipName_AllUppercase &sipStrings_QtGui[33591]
#define sipNameNr_AncestorMode 10602
#define sipName_AncestorMode &sipStrings_QtGui[10602]
#define sipNameNr_Antialiasing 7688
#define sipName_Antialiasing &sipStrings_QtGui[7688]
#define sipNameNr_AquaGuidance 33604
#define sipName_AquaGuidance &sipStrings_QtGui[33604]
#define sipNameNr_BGRA_Integer 33617
#define sipName_BGRA_Integer &sipStrings_QtGui[33617]
#define sipNameNr_Capabilities 5438
#define sipName_Capabilities &sipStrings_QtGui[5438]
#define sipNameNr_CompareEqual 33630
#define sipName_CompareEqual &sipStrings_QtGui[33630]
#define sipNameNr_CompareNever 33643
#define sipName_CompareNever &sipStrings_QtGui[33643]
#define sipNameNr_CoreGraphics 33656
#define sipName_CoreGraphics &sipStrings_QtGui[33656]
#define sipNameNr_CrystalRiver 33669
#define sipName_CrystalRiver &sipStrings_QtGui[33669]
#define sipNameNr_DebugContext 33682
#define sipName_DebugContext &sipStrings_QtGui[33682]
#define sipNameNr_DelimiterTab 33695
#define sipName_DelimiterTab &sipStrings_QtGui[33695]
#define sipNameNr_DepthStencil 11829
#define sipName_DepthStencil &sipStrings_QtGui[11829]
#define sipNameNr_DirtyOpacity 33708
#define sipName_DirtyOpacity &sipStrings_QtGui[33708]
#define sipNameNr_DoubleBuffer 33721
#define sipName_DoubleBuffer &sipStrings_QtGui[33721]
#define sipNameNr_EnvelopePrc1 33734
#define sipName_EnvelopePrc1 &sipStrings_QtGui[33734]
#define sipNameNr_EnvelopePrc2 33747
#define sipName_EnvelopePrc2 &sipStrings_QtGui[33747]
#define sipNameNr_EnvelopePrc3 33760
#define sipName_EnvelopePrc3 &sipStrings_QtGui[33760]
#define sipNameNr_EnvelopePrc4 33773
#define sipName_EnvelopePrc4 &sipStrings_QtGui[33773]
#define sipNameNr_EnvelopePrc5 33786
#define sipName_EnvelopePrc5 &sipStrings_QtGui[33786]
#define sipNameNr_EnvelopePrc6 33799
#define sipName_EnvelopePrc6 &sipStrings_QtGui[33799]
#define sipNameNr_EnvelopePrc7 33812
#define sipName_EnvelopePrc7 &sipStrings_QtGui[33812]
#define sipNameNr_EnvelopePrc8 33825
#define sipName_EnvelopePrc8 &sipStrings_QtGui[33825]
#define sipNameNr_EnvelopePrc9 33838
#define sipName_EnvelopePrc9 &sipStrings_QtGui[33838]
#define sipNameNr_EnvelopeYou4 33851
#define sipName_EnvelopeYou4 &sipStrings_QtGui[33851]
#define sipNameNr_FabledSunset 33864
#define sipName_FabledSunset &sipStrings_QtGui[33864]
#define sipNameNr_FarawayRiver 33877
#define sipName_FarawayRiver &sipStrings_QtGui[33877]
#define sipNameNr_FindBackward 33890
#define sipName_FindBackward &sipStrings_QtGui[33890]
#define sipNameNr_FindPrevious 33903
#define sipName_FindPrevious &sipStrings_QtGui[33903]
#define sipNameNr_FontFamilies 8312
#define sipName_FontFamilies &sipStrings_QtGui[8312]
#define sipNameNr_FontOverline 25844
#define sipName_FontOverline &sipStrings_QtGui[25844]
#define sipNameNr_ForceOutline 33916
#define sipName_ForceOutline &sipStrings_QtGui[33916]
#define sipNameNr_FormatOption 4076
#define sipName_FormatOption &sipStrings_QtGui[4076]
#define sipNameNr_Format_BGR30 33929
#define sipName_Format_BGR30 &sipStrings_QtGui[33929]
#define sipNameNr_Format_RGB16 33942
#define sipName_Format_RGB16 &sipStrings_QtGui[33942]
#define sipNameNr_Format_RGB30 33955
#define sipName_Format_RGB30 &sipStrings_QtGui[33955]
#define sipNameNr_Format_RGB32 33968
#define sipName_Format_RGB32 &sipStrings_QtGui[33968]
#define sipNameNr_FramePadding 33981
#define sipName_FramePadding &sipStrings_QtGui[33981]
#define sipNameNr_FrozenDreams 33994
#define sipName_FrozenDreams &sipStrings_QtGui[33994]
#define sipNameNr_FullPageMode 34007
#define sipName_FullPageMode &sipStrings_QtGui[34007]
#define sipNameNr_GlyphRunFlag 7712
#define sipName_GlyphRunFlag &sipStrings_QtGui[7712]
#define sipNameNr_GrassShampoo 34020
#define sipName_GrassShampoo &sipStrings_QtGui[34020]
#define sipNameNr_GroupPopType 34033
#define sipName_GroupPopType &sipStrings_QtGui[34033]
#define sipNameNr_HappyUnicorn 34046
#define sipName_HappyUnicorn &sipStrings_QtGui[34046]
#define sipNameNr_HeadingLevel 25876
#define sipName_HeadingLevel &sipStrings_QtGui[25876]
#define sipNameNr_HealthyWater 34059
#define sipName_HealthyWater &sipStrings_QtGui[34059]
#define sipNameNr_HelpContents 34072
#define sipName_HelpContents &sipStrings_QtGui[34072]
#define sipNameNr_HiddenJaguar 34085
#define sipName_HiddenJaguar &sipStrings_QtGui[34085]
#define sipNameNr_HighSeverity 34098
#define sipName_HighSeverity &sipStrings_QtGui[34098]
#define sipNameNr_HtmlResource 34111
#define sipName_HtmlResource &sipStrings_QtGui[34111]
#define sipNameNr_IconNameHook 34124
#define sipName_IconNameHook &sipStrings_QtGui[34124]
#define sipNameNr_IgnoresAlpha 34137
#define sipName_IgnoresAlpha &sipStrings_QtGui[34137]
#define sipNameNr_ImageAltText 34150
#define sipName_ImageAltText &sipStrings_QtGui[34150]
#define sipNameNr_ImageQuality 34163
#define sipName_ImageQuality &sipStrings_QtGui[34163]
#define sipNameNr_Imperial8x10 34176
#define sipName_Imperial8x10 &sipStrings_QtGui[34176]
#define sipNameNr_Imperial9x11 34189
#define sipName_Imperial9x11 &sipStrings_QtGui[34189]
#define sipNameNr_Imperial9x12 34202
#define sipName_Imperial9x12 &sipStrings_QtGui[34202]
#define sipNameNr_Intermediate 34215
#define sipName_Intermediate &sipStrings_QtGui[34215]
#define sipNameNr_LadogaBottom 34228
#define sipName_LadogaBottom &sipStrings_QtGui[34228]
#define sipNameNr_LastPageSize 34241
#define sipName_LastPageSize &sipStrings_QtGui[34241]
#define sipNameNr_LittleEndian 34254
#define sipName_LittleEndian &sipStrings_QtGui[34254]
#define sipNameNr_MetalSurface 34267
#define sipName_MetalSurface &sipStrings_QtGui[34267]
#define sipNameNr_MorningSalad 34280
#define sipName_MorningSalad &sipStrings_QtGui[34280]
#define sipNameNr_MountainRock 34293
#define sipName_MountainRock &sipStrings_QtGui[34293]
#define sipNameNr_NColorGroups 34306
#define sipName_NColorGroups &sipStrings_QtGui[34306]
#define sipNameNr_NPOTTextures 34319
#define sipName_NPOTTextures &sipStrings_QtGui[34319]
#define sipNameNr_NewRetrowave 34332
#define sipName_NewRetrowave &sipStrings_QtGui[34332]
#define sipNameNr_NoAttachment 34345
#define sipName_NoAttachment &sipStrings_QtGui[34345]
#define sipNameNr_NorthMiracle 34358
#define sipName_NorthMiracle &sipStrings_QtGui[34358]
#define sipNameNr_PaintContext 232
#define sipName_PaintContext &sipStrings_QtGui[232]
#define sipNameNr_PainterPaths 34371
#define sipName_PainterPaths &sipStrings_QtGui[34371]
#define sipNameNr_PartialMatch 34384
#define sipName_PartialMatch &sipStrings_QtGui[34384]
#define sipNameNr_PatternBrush 34397
#define sipName_PatternBrush &sipStrings_QtGui[34397]
#define sipNameNr_PdmNumColors 34410
#define sipName_PdmNumColors &sipStrings_QtGui[34410]
#define sipNameNr_PerfectWhite 34423
#define sipName_PerfectWhite &sipStrings_QtGui[34423]
#define sipNameNr_PhoenixStart 34436
#define sipName_PhoenixStart &sipStrings_QtGui[34436]
#define sipNameNr_PoliteRumors 34449
#define sipName_PoliteRumors &sipStrings_QtGui[34449]
#define sipNameNr_PolylineMode 34462
#define sipName_PolylineMode &sipStrings_QtGui[34462]
#define sipNameNr_PortableText 34475
#define sipName_PortableText &sipStrings_QtGui[34475]
#define sipNameNr_PreferBitmap 34488
#define sipName_PreferBitmap &sipStrings_QtGui[34488]
#define sipNameNr_PreferDevice 34501
#define sipName_PreferDevice &sipStrings_QtGui[34501]
#define sipNameNr_PremiumWhite 34514
#define sipName_PremiumWhite &sipStrings_QtGui[34514]
#define sipNameNr_PreviousCell 34527
#define sipName_PreviousCell &sipStrings_QtGui[34527]
#define sipNameNr_PreviousWord 15649
#define sipName_PreviousWord &sipStrings_QtGui[15649]
#define sipNameNr_QActionEvent 34540
#define sipName_QActionEvent &sipStrings_QtGui[34540]
#define sipNameNr_QColor__Spec 34553
#define sipName_QColor__Spec &sipStrings_QtGui[34553]
#define sipNameNr_QExposeEvent 34566
#define sipName_QExposeEvent &sipStrings_QtGui[34566]
#define sipNameNr_QFont__Style 34579
#define sipName_QFont__Style &sipStrings_QtGui[34579]
#define sipNameNr_QFontMetrics 34592
#define sipName_QFontMetrics &sipStrings_QtGui[34592]
#define sipNameNr_QIcon__State 34605
#define sipName_QIcon__State &sipStrings_QtGui[34605]
#define sipNameNr_QImageReader 34618
#define sipName_QImageReader &sipStrings_QtGui[34618]
#define sipNameNr_QImageWriter 34631
#define sipName_QImageWriter &sipStrings_QtGui[34631]
#define sipNameNr_QInputMethod 34644
#define sipName_QInputMethod &sipStrings_QtGui[34644]
#define sipNameNr_QKeySequence 34657
#define sipName_QKeySequence &sipStrings_QtGui[34657]
#define sipNameNr_34670 34670
#define sipName_34670 &sipStrings_QtGui[34670]
#define sipNameNr_QPaintDevice 34683
#define sipName_QPaintDevice &sipStrings_QtGui[34683]
#define sipNameNr_QPaintEngine 34696
#define sipName_QPaintEngine &sipStrings_QtGui[34696]
#define sipNameNr_QPainterPath 34709
#define sipName_QPainterPath &sipStrings_QtGui[34709]
#define sipNameNr_QPixelFormat 34722
#define sipName_QPixelFormat &sipStrings_QtGui[34722]
#define sipNameNr_QPixmapCache 34735
#define sipName_QPixmapCache &sipStrings_QtGui[34735]
#define sipNameNr_QResizeEvent 34748
#define sipName_QResizeEvent &sipStrings_QtGui[34748]
#define sipNameNr_QScrollEvent 34761
#define sipName_QScrollEvent &sipStrings_QtGui[34761]
#define sipNameNr_QTabletEvent 34774
#define sipName_QTabletEvent &sipStrings_QtGui[34774]
#define sipNameNr_QTouchDevice 34787
#define sipName_QTouchDevice &sipStrings_QtGui[34787]
#define sipNameNr_RGBA16_SNorm 34800
#define sipName_RGBA16_SNorm &sipStrings_QtGui[34800]
#define sipNameNr_RGBA16_UNorm 34813
#define sipName_RGBA16_UNorm &sipStrings_QtGui[34813]
#define sipNameNr_RGBA_Integer 34826
#define sipName_RGBA_Integer &sipStrings_QtGui[34826]
#define sipNameNr_RGB_BP_UNorm 30879
#define sipName_RGB_BP_UNorm &sipStrings_QtGui[30879]
#define sipNameNr_RawPositions 34839
#define sipName_RawPositions &sipStrings_QtGui[34839]
#define sipNameNr_RedSalvation 34852
#define sipName_RedSalvation &sipStrings_QtGui[34852]
#define sipNameNr_RepeatSpread 34865
#define sipName_RepeatSpread &sipStrings_QtGui[34865]
#define sipNameNr_ResourceType 4812
#define sipName_ResourceType &sipStrings_QtGui[4812]
#define sipNameNr_RestartNever 34878
#define sipName_RestartNever &sipStrings_QtGui[34878]
#define sipNameNr_SRGB8_Alpha8 34891
#define sipName_SRGB8_Alpha8 &sipStrings_QtGui[34891]
#define sipNameNr_SaltMountain 34904
#define sipName_SaltMountain &sipStrings_QtGui[34904]
#define sipNameNr_SemiExpanded 34917
#define sipName_SemiExpanded &sipStrings_QtGui[34917]
#define sipNameNr_SingleBuffer 34930
#define sipName_SingleBuffer &sipStrings_QtGui[34930]
#define sipNameNr_SingleHeight 34943
#define sipName_SingleHeight &sipStrings_QtGui[34943]
#define sipNameNr_SoftLipstick 34956
#define sipName_SoftLipstick &sipStrings_QtGui[34956]
#define sipNameNr_SpringWarmth 34969
#define sipName_SpringWarmth &sipStrings_QtGui[34969]
#define sipNameNr_StandardMode 34982
#define sipName_StandardMode &sipStrings_QtGui[34982]
#define sipNameNr_StartOfBlock 15668
#define sipName_StartOfBlock &sipStrings_QtGui[15668]
#define sipNameNr_StyleOblique 34995
#define sipName_StyleOblique &sipStrings_QtGui[34995]
#define sipNameNr_SunnyMorning 35008
#define sipName_SunnyMorning &sipStrings_QtGui[35008]
#define sipNameNr_SurfaceClass 9112
#define sipName_SurfaceClass &sipStrings_QtGui[9112]
#define sipNameNr_SwapBehavior 4105
#define sipName_SwapBehavior &sipStrings_QtGui[4105]
#define sipNameNr_SweetDessert 35021
#define sipName_SweetDessert &sipStrings_QtGui[35021]
#define sipNameNr_SwizzleAlpha 35034
#define sipName_SwizzleAlpha &sipStrings_QtGui[35034]
#define sipNameNr_SwizzleGreen 35047
#define sipName_SwizzleGreen &sipStrings_QtGui[35047]
#define sipNameNr_SwizzleValue 3960
#define sipName_SwizzleValue &sipStrings_QtGui[3960]
#define sipNameNr_TabPositions 26100
#define sipName_TabPositions &sipStrings_QtGui[26100]
#define sipNameNr_TableColumns 35060
#define sipName_TableColumns &sipStrings_QtGui[35060]
#define sipNameNr_TabletDevice 5303
#define sipName_TabletDevice &sipStrings_QtGui[5303]
#define sipNameNr_TabloidExtra 35073
#define sipName_TabloidExtra &sipStrings_QtGui[35073]
#define sipNameNr_TargetBuffer 13590
#define sipName_TargetBuffer &sipStrings_QtGui[13590]
#define sipNameNr_TeenNotebook 35086
#define sipName_TeenNotebook &sipStrings_QtGui[35086]
#define sipNameNr_TripleBuffer 35099
#define sipName_TripleBuffer &sipStrings_QtGui[35099]
#define sipNameNr_UInt16_RGBA4 35112
#define sipName_UInt16_RGBA4 &sipStrings_QtGui[35112]
#define sipNameNr_UInt32_D24S8 35125
#define sipName_UInt32_D24S8 &sipStrings_QtGui[35125]
#define sipNameNr_UInt32_RGBA8 35138
#define sipName_UInt32_RGBA8 &sipStrings_QtGui[35138]
#define sipNameNr_UnknownError 35151
#define sipName_UnknownError &sipStrings_QtGui[35151]
#define sipNameNr_UnsignedByte 35164
#define sipName_UnsignedByte &sipStrings_QtGui[35164]
#define sipNameNr_UsagePattern 4588
#define sipName_UsagePattern &sipStrings_QtGui[4588]
#define sipNameNr_UserProperty 35177
#define sipName_UserProperty &sipStrings_QtGui[35177]
#define sipNameNr_UserResource 35190
#define sipName_UserResource &sipStrings_QtGui[35190]
#define sipNameNr_VertexBuffer 35203
#define sipName_VertexBuffer &sipStrings_QtGui[35203]
#define sipNameNr_WrapAnywhere 35216
#define sipName_WrapAnywhere &sipStrings_QtGui[35216]
#define sipNameNr_YoungPassion 35229
#define sipName_YoungPassion &sipStrings_QtGui[35229]
#define sipNameNr___contains__ 35242
#define sipName___contains__ &sipStrings_QtGui[35242]
#define sipNameNr___itruediv__ 35255
#define sipName___itruediv__ &sipStrings_QtGui[35255]
#define sipNameNr_angleBetween 35268
#define sipName_angleBetween &sipStrings_QtGui[35268]
#define sipNameNr_antiquewhite 35281
#define sipName_antiquewhite &sipStrings_QtGui[35281]
#define sipNameNr_appendColumn 35294
#define sipName_appendColumn &sipStrings_QtGui[35294]
#define sipNameNr_atBlockStart 35307
#define sipName_atBlockStart &sipStrings_QtGui[35307]
#define sipNameNr_bitsPerPixel 35320
#define sipName_bitsPerPixel &sipStrings_QtGui[35320]
#define sipNameNr_blockRemoved 35333
#define sipName_blockRemoved &sipStrings_QtGui[35333]
#define sipNameNr_boolProperty 35346
#define sipName_boolProperty &sipStrings_QtGui[35346]
#define sipNameNr_bottomBorder 35359
#define sipName_bottomBorder &sipStrings_QtGui[35359]
#define sipNameNr_bottomMargin 35372
#define sipName_bottomMargin &sipStrings_QtGui[35372]
#define sipNameNr_boundingRect 35385
#define sipName_boundingRect &sipStrings_QtGui[35385]
#define sipNameNr_bytesPerLine 35398
#define sipName_bytesPerLine &sipStrings_QtGui[35398]
#define sipNameNr_cacheEnabled 35411
#define sipName_cacheEnabled &sipStrings_QtGui[35411]
#define sipNameNr_canFetchMore 35424
#define sipName_canFetchMore &sipStrings_QtGui[35424]
#define sipNameNr_capabilities 35437
#define sipName_capabilities &sipStrings_QtGui[35437]
#define sipNameNr_centerRadius 35450
#define sipName_centerRadius &sipStrings_QtGui[35450]
#define sipNameNr_channelCount 35463
#define sipName_channelCount &sipStrings_QtGui[35463]
#define sipNameNr_clearFormats 35476
#define sipName_clearFormats &sipStrings_QtGui[35476]
#define sipNameNr_closeSubpath 35489
#define sipName_closeSubpath &sipStrings_QtGui[35489]
#define sipNameNr_columnNumber 35502
#define sipName_columnNumber &sipStrings_QtGui[35502]
#define sipNameNr_commitString 35515
#define sipName_commitString &sipStrings_QtGui[35515]
#define sipNameNr_createObject 35528
#define sipName_createObject &sipStrings_QtGui[35528]
#define sipNameNr_createStroke 35541
#define sipName_createStroke &sipStrings_QtGui[35541]
#define sipNameNr_crossProduct 35554
#define sipName_crossProduct &sipStrings_QtGui[35554]
#define sipNameNr_currentBlock 35567
#define sipName_currentBlock &sipStrings_QtGui[35567]
#define sipNameNr_currentFrame 35580
#define sipName_currentFrame &sipStrings_QtGui[35580]
#define sipNameNr_currentImage 35593
#define sipName_currentImage &sipStrings_QtGui[35593]
#define sipNameNr_currentTable 35606
#define sipName_currentTable &sipStrings_QtGui[35606]
#define sipNameNr_darkseagreen 35619
#define sipName_darkseagreen &sipStrings_QtGui[35619]
#define sipNameNr_defaultDepth 35632
#define sipName_defaultDepth &sipStrings_QtGui[35632]
#define sipNameNr_documentSize 35645
#define sipName_documentSize &sipStrings_QtGui[35645]
#define sipNameNr_drawContents 35658
#define sipName_drawContents &sipStrings_QtGui[35658]
#define sipNameNr_drawGlyphRun 35671
#define sipName_drawGlyphRun &sipStrings_QtGui[35671]
#define sipNameNr_drawPolyline 35684
#define sipName_drawPolyline &sipStrings_QtGui[35684]
#define sipNameNr_drawTextItem 35697
#define sipName_drawTextItem &sipStrings_QtGui[35697]
#define sipNameNr_dropMimeData 35710
#define sipName_dropMimeData &sipStrings_QtGui[35710]
#define sipNameNr_elementCount 35723
#define sipName_elementCount &sipStrings_QtGui[35723]
#define sipNameNr_endEditBlock 35736
#define sipName_endEditBlock &sipStrings_QtGui[35736]
#define sipNameNr_focusInEvent 35749
#define sipName_focusInEvent &sipStrings_QtGui[35749]
#define sipNameNr_fontFamilies 35762
#define sipName_fontFamilies &sipStrings_QtGui[35762]
#define sipNameNr_fontOverline 35775
#define sipName_fontOverline &sipStrings_QtGui[35775]
#define sipNameNr_frameChanged 35788
#define sipName_frameChanged &sipStrings_QtGui[35788]
#define sipNameNr_frameMargins 35801
#define sipName_frameMargins &sipStrings_QtGui[35801]
#define sipNameNr_frameSwapped 35814
#define sipName_frameSwapped &sipStrings_QtGui[35814]
#define sipNameNr_glyphIndexes 35827
#define sipName_glyphIndexes &sipStrings_QtGui[35827]
#define sipNameNr_hasExtension 35840
#define sipName_hasExtension &sipStrings_QtGui[35840]
#define sipNameNr_hasSelection 35853
#define sipName_hasSelection &sipStrings_QtGui[35853]
#define sipNameNr_hasThemeIcon 35866
#define sipName_hasThemeIcon &sipStrings_QtGui[35866]
#define sipNameNr_headingLevel 35879
#define sipName_headingLevel &sipStrings_QtGui[35879]
#define sipNameNr_hiResGlobalX 35892
#define sipName_hiResGlobalX &sipStrings_QtGui[35892]
#define sipNameNr_hiResGlobalY 35905
#define sipName_hiResGlobalY &sipStrings_QtGui[35905]
#define sipNameNr_initializeGL 35918
#define sipName_initializeGL &sipStrings_QtGui[35918]
#define sipNameNr_inputFormats 35931
#define sipName_inputFormats &sipStrings_QtGui[35931]
#define sipNameNr_insertColumn 35944
#define sipName_insertColumn &sipStrings_QtGui[35944]
#define sipNameNr_invertPixels 35957
#define sipName_invertPixels &sipStrings_QtGui[35957]
#define sipNameNr_invokeAction 35970
#define sipName_invokeAction &sipStrings_QtGui[35970]
#define sipNameNr_isAncestorOf 35983
#define sipName_isAncestorOf &sipStrings_QtGui[35983]
#define sipNameNr_isAutoRepeat 35996
#define sipName_isAutoRepeat &sipStrings_QtGui[35996]
#define sipNameNr_isCharFormat 36009
#define sipName_isCharFormat &sipStrings_QtGui[36009]
#define sipNameNr_isFixedPitch 36022
#define sipName_isFixedPitch &sipStrings_QtGui[36022]
#define sipNameNr_isInvertible 36035
#define sipName_isInvertible &sipStrings_QtGui[36035]
#define sipNameNr_isListFormat 36048
#define sipName_isListFormat &sipStrings_QtGui[36048]
#define sipNameNr_isSelectable 36061
#define sipName_isSelectable &sipStrings_QtGui[36061]
#define sipNameNr_isValidColor 36074
#define sipName_isValidColor &sipStrings_QtGui[36074]
#define sipNameNr_lastPosition 36087
#define sipName_lastPosition &sipStrings_QtGui[36087]
#define sipNameNr_lastScenePos 36100
#define sipName_lastScenePos &sipStrings_QtGui[36100]
#define sipNameNr_lemonchiffon 36113
#define sipName_lemonchiffon &sipStrings_QtGui[36113]
#define sipNameNr_lightskyblue 36126
#define sipName_lightskyblue &sipStrings_QtGui[36126]
#define sipNameNr_listToString 36139
#define sipName_listToString &sipStrings_QtGui[36139]
#define sipNameNr_loadFromData 36152
#define sipName_loadFromData &sipStrings_QtGui[36152]
#define sipNameNr_loadFromFile 36165
#define sipName_loadFromFile &sipStrings_QtGui[36165]
#define sipNameNr_loadResource 36178
#define sipName_loadResource &sipStrings_QtGui[36178]
#define sipNameNr_majorVersion 36191
#define sipName_majorVersion &sipStrings_QtGui[36191]
#define sipNameNr_manufacturer 36204
#define sipName_manufacturer &sipStrings_QtGui[36204]
#define sipNameNr_mapToPolygon 36217
#define sipName_mapToPolygon &sipStrings_QtGui[36217]
#define sipNameNr_maxCharWidth 36230
#define sipName_maxCharWidth &sipStrings_QtGui[36230]
#define sipNameNr_maximumWidth 36243
#define sipName_maximumWidth &sipStrings_QtGui[36243]
#define sipNameNr_mediumorchid 36256
#define sipName_mediumorchid &sipStrings_QtGui[36256]
#define sipNameNr_mediumpurple 36269
#define sipName_mediumpurple &sipStrings_QtGui[36269]
#define sipNameNr_midnightblue 36282
#define sipName_midnightblue &sipStrings_QtGui[36282]
#define sipNameNr_minimumWidth 36295
#define sipName_minimumWidth &sipStrings_QtGui[36295]
#define sipNameNr_minorVersion 36308
#define sipName_minorVersion &sipStrings_QtGui[36308]
#define sipNameNr_mipBaseLevel 36321
#define sipName_mipBaseLevel &sipStrings_QtGui[36321]
#define sipNameNr_mouseButtons 36334
#define sipName_mouseButtons &sipStrings_QtGui[36334]
#define sipNameNr_movePosition 36347
#define sipName_movePosition &sipStrings_QtGui[36347]
#define sipNameNr_nativeHandle 36360
#define sipName_nativeHandle &sipStrings_QtGui[36360]
#define sipNameNr_normalMatrix 36373
#define sipName_normalMatrix &sipStrings_QtGui[36373]
#define sipNameNr_numberPrefix 36386
#define sipName_numberPrefix &sipStrings_QtGui[36386]
#define sipNameNr_numberSuffix 36399
#define sipName_numberSuffix &sipStrings_QtGui[36399]
#define sipNameNr_paintFlipped 36412
#define sipName_paintFlipped &sipStrings_QtGui[36412]
#define sipNameNr_paintUnderGL 36425
#define sipName_paintUnderGL &sipStrings_QtGui[36425]
#define sipNameNr_pathForGlyph 36438
#define sipName_pathForGlyph &sipStrings_QtGui[36438]
#define sipNameNr_physicalDpiX 36451
#define sipName_physicalDpiX &sipStrings_QtGui[36451]
#define sipNameNr_physicalDpiY 36464
#define sipName_physicalDpiY &sipStrings_QtGui[36464]
#define sipNameNr_physicalSize 36477
#define sipName_physicalSize &sipStrings_QtGui[36477]
#define sipNameNr_platformName 36490
#define sipName_platformName &sipStrings_QtGui[36490]
#define sipNameNr_qPremultiply 36503
#define sipName_qPremultiply &sipStrings_QtGui[36503]
#define sipNameNr_quadToSquare 36516
#define sipName_quadToSquare &sipStrings_QtGui[36516]
#define sipNameNr_recordSample 36529
#define sipName_recordSample &sipStrings_QtGui[36529]
#define sipNameNr_removeColumn 36542
#define sipName_removeColumn &sipStrings_QtGui[36542]
#define sipNameNr_removeShader 36555
#define sipName_removeShader &sipStrings_QtGui[36555]
#define sipNameNr_rightBearing 36568
#define sipName_rightBearing &sipStrings_QtGui[36568]
#define sipNameNr_rightPadding 36581
#define sipName_rightPadding &sipStrings_QtGui[36581]
#define sipNameNr_scaledPixmap 36594
#define sipName_scaledPixmap &sipStrings_QtGui[36594]
#define sipNameNr_selectedText 36607
#define sipName_selectedText &sipStrings_QtGui[36607]
#define sipNameNr_selectionEnd 36620
#define sipName_selectionEnd &sipStrings_QtGui[36620]
#define sipNameNr_serialNumber 36633
#define sipName_serialNumber &sipStrings_QtGui[36633]
#define sipNameNr_setAlignment 36646
#define sipName_setAlignment &sipStrings_QtGui[36646]
#define sipNameNr_setCacheMode 36659
#define sipName_setCacheMode &sipStrings_QtGui[36659]
#define sipNameNr_setCheckable 36672
#define sipName_setCheckable &sipStrings_QtGui[36672]
#define sipNameNr_setFinalStop 36685
#define sipName_setFinalStop &sipStrings_QtGui[36685]
#define sipNameNr_setJoinStyle 36698
#define sipName_setJoinStyle &sipStrings_QtGui[36698]
#define sipNameNr_setLineCount 36711
#define sipName_setLineCount &sipStrings_QtGui[36711]
#define sipNameNr_setLineWidth 36724
#define sipName_setLineWidth &sipStrings_QtGui[36724]
#define sipNameNr_setMipLevels 36737
#define sipName_setMipLevels &sipStrings_QtGui[36737]
#define sipNameNr_setPixelSize 36750
#define sipName_setPixelSize &sipStrings_QtGui[36750]
#define sipNameNr_setPlainText 36763
#define sipName_setPlainText &sipStrings_QtGui[36763]
#define sipNameNr_setPointSize 36776
#define sipName_setPointSize &sipStrings_QtGui[36776]
#define sipNameNr_setPositions 36789
#define sipName_setPositions &sipStrings_QtGui[36789]
#define sipNameNr_setPrimaries 36802
#define sipName_setPrimaries &sipStrings_QtGui[36802]
#define sipNameNr_setRowLength 36815
#define sipName_setRowLength &sipStrings_QtGui[36815]
#define sipNameNr_setStatusTip 36828
#define sipName_setStatusTip &sipStrings_QtGui[36828]
#define sipNameNr_setStrikeOut 36841
#define sipName_setStrikeOut &sipStrings_QtGui[36841]
#define sipNameNr_setStyleHint 36854
#define sipName_setStyleHint &sipStrings_QtGui[36854]
#define sipNameNr_setStyleName 36867
#define sipName_setStyleName &sipStrings_QtGui[36867]
#define sipNameNr_setTextWidth 36880
#define sipName_setTextWidth &sipStrings_QtGui[36880]
#define sipNameNr_setThemeName 36893
#define sipName_setThemeName &sipStrings_QtGui[36893]
#define sipNameNr_setTimestamp 36906
#define sipName_setTimestamp &sipStrings_QtGui[36906]
#define sipNameNr_setTopBorder 36919
#define sipName_setTopBorder &sipStrings_QtGui[36919]
#define sipNameNr_setTopMargin 36932
#define sipName_setTopMargin &sipStrings_QtGui[36932]
#define sipNameNr_setTransform 28684
#define sipName_setTransform &sipStrings_QtGui[28684]
#define sipNameNr_setUnderline 36945
#define sipName_setUnderline &sipStrings_QtGui[36945]
#define sipNameNr_setUserState 36958
#define sipName_setUserState &sipStrings_QtGui[36958]
#define sipNameNr_setWhatsThis 36971
#define sipName_setWhatsThis &sipStrings_QtGui[36971]
#define sipNameNr_shareContext 36984
#define sipName_shareContext &sipStrings_QtGui[36984]
#define sipNameNr_smoothScaled 36997
#define sipName_smoothScaled &sipStrings_QtGui[36997]
#define sipNameNr_sortChildren 37010
#define sipName_sortChildren &sipStrings_QtGui[37010]
#define sipNameNr_squareToQuad 37023
#define sipName_squareToQuad &sipStrings_QtGui[37023]
#define sipNameNr_startLogging 37036
#define sipName_startLogging &sipStrings_QtGui[37036]
#define sipNameNr_stateChanged 37049
#define sipName_stateChanged &sipStrings_QtGui[37049]
#define sipNameNr_strikeOutPos 37062
#define sipName_strikeOutPos &sipStrings_QtGui[37062]
#define sipNameNr_surfaceClass 37075
#define sipName_surfaceClass &sipStrings_QtGui[37075]
#define sipNameNr_swapBehavior 37088
#define sipName_swapBehavior &sipStrings_QtGui[37088]
#define sipNameNr_swapInterval 37101
#define sipName_swapInterval &sipStrings_QtGui[37101]
#define sipNameNr_tabPositions 37114
#define sipName_tabPositions &sipStrings_QtGui[37114]
#define sipNameNr_textPosition 37127
#define sipName_textPosition &sipStrings_QtGui[37127]
#define sipNameNr_textureImage 37140
#define sipName_textureImage &sipStrings_QtGui[37140]
#define sipNameNr_toCharFormat 37153
#define sipName_toCharFormat &sipStrings_QtGui[37153]
#define sipNameNr_toListFormat 37166
#define sipName_toListFormat &sipStrings_QtGui[37166]
#define sipNameNr_underlinePos 37179
#define sipName_underlinePos &sipStrings_QtGui[37179]
#define sipNameNr_usagePattern 37192
#define sipName_usagePattern &sipStrings_QtGui[37192]
#define sipNameNr_viewportSize 37205
#define sipName_viewportSize &sipStrings_QtGui[37205]
#define sipNameNr_widthChanged 37218
#define sipName_widthChanged &sipStrings_QtGui[37218]
#define sipNameNr_windowStates 37231
#define sipName_windowStates &sipStrings_QtGui[37231]
#define sipNameNr_AboveTheSky 37244
#define sipName_AboveTheSky &sipStrings_QtGui[37244]
#define sipNameNr_AlignBottom 37256
#define sipName_AlignBottom &sipStrings_QtGui[37256]
#define sipNameNr_AlignMiddle 37268
#define sipName_AlignMiddle &sipStrings_QtGui[37268]
#define sipNameNr_AlignNormal 37280
#define sipName_AlignNormal &sipStrings_QtGui[37280]
#define sipNameNr_AllFeatures 37292
#define sipName_AllFeatures &sipStrings_QtGui[37292]
#define sipNameNr_AlphaFormat 11935
#define sipName_AlphaFormat &sipStrings_QtGui[11935]
#define sipNameNr_AnySeverity 37304
#define sipName_AnySeverity &sipStrings_QtGui[37304]
#define sipNameNr_AtBeginning 37316
#define sipName_AtBeginning &sipStrings_QtGui[37316]
#define sipNameNr_AwesomePine 37328
#define sipName_AwesomePine &sipStrings_QtGui[37328]
#define sipNameNr_BGR_Integer 37340
#define sipName_BGR_Integer &sipStrings_QtGui[37340]
#define sipNameNr_BlockFormat 21358
#define sipName_BlockFormat &sipStrings_QtGui[21358]
#define sipNameNr_BlockIndent 37352
#define sipName_BlockIndent &sipStrings_QtGui[37352]
#define sipNameNr_BlockMarker 37364
#define sipName_BlockMarker &sipStrings_QtGui[37364]
#define sipNameNr_BorderStyle 3401
#define sipName_BorderStyle &sipStrings_QtGui[3401]
#define sipNameNr_BrushStroke 37376
#define sipName_BrushStroke &sipStrings_QtGui[37376]
#define sipNameNr_ClampToEdge 37388
#define sipName_ClampToEdge &sipStrings_QtGui[37388]
#define sipNameNr_CleanMirror 37400
#define sipName_CleanMirror &sipStrings_QtGui[37400]
#define sipNameNr_CloudyApple 37412
#define sipName_CloudyApple &sipStrings_QtGui[37412]
#define sipNameNr_CochitiLake 37424
#define sipName_CochitiLake &sipStrings_QtGui[37424]
#define sipNameNr_ColdEvening 37436
#define sipName_ColdEvening &sipStrings_QtGui[37436]
#define sipNameNr_CompareLess 37448
#define sipName_CompareLess &sipStrings_QtGui[37448]
#define sipNameNr_CompareNone 37460
#define sipName_CompareNone &sipStrings_QtGui[37460]
#define sipNameNr_ContextMenu 37472
#define sipName_ContextMenu &sipStrings_QtGui[37472]
#define sipNameNr_CoreProfile 37484
#define sipName_CoreProfile &sipStrings_QtGui[37484]
#define sipNameNr_Crystalline 37496
#define sipName_Crystalline &sipStrings_QtGui[37496]
#define sipNameNr_CubeMapFace 4673
#define sipName_CubeMapFace &sipStrings_QtGui[4673]
#define sipNameNr_DarkMagenta 37508
#define sipName_DarkMagenta &sipStrings_QtGui[37508]
#define sipNameNr_DashDotLine 37520
#define sipName_DashDotLine &sipStrings_QtGui[37520]
#define sipNameNr_DepthFormat 37532
#define sipName_DepthFormat &sipStrings_QtGui[37532]
#define sipNameNr_Description 7393
#define sipName_Description &sipStrings_QtGui[7393]
#define sipNameNr_DeviceError 37544
#define sipName_DeviceError &sipStrings_QtGui[37544]
#define sipNameNr_DirtyBeauty 37556
#define sipName_DirtyBeauty &sipStrings_QtGui[37556]
#define sipNameNr_DocumentUrl 37568
#define sipName_DocumentUrl &sipStrings_QtGui[37568]
#define sipNameNr_DynamicCopy 37580
#define sipName_DynamicCopy &sipStrings_QtGui[37580]
#define sipNameNr_DynamicDraw 37592
#define sipName_DynamicDraw &sipStrings_QtGui[37592]
#define sipNameNr_DynamicRead 37604
#define sipName_DynamicRead &sipStrings_QtGui[37604]
#define sipNameNr_ElementType 6123
#define sipName_ElementType &sipStrings_QtGui[6123]
#define sipNameNr_EnvelopeC65 37616
#define sipName_EnvelopeC65 &sipStrings_QtGui[37616]
#define sipNameNr_ExtendedRgb 33414
#define sipName_ExtendedRgb &sipStrings_QtGui[33414]
#define sipNameNr_FebruaryInk 37628
#define sipName_FebruaryInk &sipStrings_QtGui[37628]
#define sipNameNr_FixedHeight 37640
#define sipName_FixedHeight &sipStrings_QtGui[37640]
#define sipNameNr_FixedLength 37652
#define sipName_FixedLength &sipStrings_QtGui[37652]
#define sipNameNr_FlyingLemon 37664
#define sipName_FlyingLemon &sipStrings_QtGui[37664]
#define sipNameNr_FontKerning 29030
#define sipName_FontKerning &sipStrings_QtGui[29030]
#define sipNameNr_FontStretch 29045
#define sipName_FontStretch &sipStrings_QtGui[29045]
#define sipNameNr_FormatRange 7093
#define sipName_FormatRange &sipStrings_QtGui[7093]
#define sipNameNr_Format_Mono 37676
#define sipName_Format_Mono &sipStrings_QtGui[37676]
#define sipNameNr_FrameBorder 37688
#define sipName_FrameBorder &sipStrings_QtGui[37688]
#define sipNameNr_FrameFormat 21375
#define sipName_FrameFormat &sipStrings_QtGui[21375]
#define sipNameNr_FrameHeight 37700
#define sipName_FrameHeight &sipStrings_QtGui[37700]
#define sipNameNr_FrameMargin 37712
#define sipName_FrameMargin &sipStrings_QtGui[37712]
#define sipNameNr_FrozenBerry 37724
#define sipName_FrozenBerry &sipStrings_QtGui[37724]
#define sipNameNr_GagarinView 37736
#define sipName_GagarinView &sipStrings_QtGui[37736]
#define sipNameNr_GeneralFont 37748
#define sipName_GeneralFont &sipStrings_QtGui[37748]
#define sipNameNr_HappyFisher 37760
#define sipName_HappyFisher &sipStrings_QtGui[37760]
#define sipNameNr_HeavenPeach 37772
#define sipName_HeavenPeach &sipStrings_QtGui[37772]
#define sipNameNr_ImageHeight 29075
#define sipName_ImageHeight &sipStrings_QtGui[29075]
#define sipNameNr_ImageObject 37784
#define sipName_ImageObject &sipStrings_QtGui[37784]
#define sipNameNr_ImageOption 3816
#define sipName_ImageOption &sipStrings_QtGui[3816]
#define sipNameNr_Imperial7x9 37796
#define sipName_Imperial7x9 &sipStrings_QtGui[37796]
#define sipNameNr_IndexBuffer 37808
#define sipName_IndexBuffer &sipStrings_QtGui[37808]
#define sipNameNr_InvalidType 37820
#define sipName_InvalidType &sipStrings_QtGui[37820]
#define sipNameNr_LayoutFlags 10427
#define sipName_LayoutFlags &sipStrings_QtGui[10427]
#define sipNameNr_LetterExtra 37832
#define sipName_LetterExtra &sipStrings_QtGui[37832]
#define sipNameNr_LetterSmall 37844
#define sipName_LetterSmall &sipStrings_QtGui[37844]
#define sipNameNr_LinkVisited 37856
#define sipName_LinkVisited &sipStrings_QtGui[37856]
#define sipNameNr_ListDecimal 37868
#define sipName_ListDecimal &sipStrings_QtGui[37868]
#define sipNameNr_LoggingMode 2047
#define sipName_LoggingMode &sipStrings_QtGui[2047]
#define sipNameNr_LogicalMode 37880
#define sipName_LogicalMode &sipStrings_QtGui[37880]
#define sipNameNr_LowSeverity 37892
#define sipName_LowSeverity &sipStrings_QtGui[37892]
#define sipNameNr_MalibuBeach 37904
#define sipName_MalibuBeach &sipStrings_QtGui[37904]
#define sipNameNr_MaskedBrush 37916
#define sipName_MaskedBrush &sipStrings_QtGui[37916]
#define sipNameNr_MorpheusDen 37928
#define sipName_MorpheusDen &sipStrings_QtGui[37928]
#define sipNameNr_NColorRoles 37940
#define sipName_NColorRoles &sipStrings_QtGui[37940]
#define sipNameNr_NoAntialias 37952
#define sipName_NoAntialias &sipStrings_QtGui[37952]
#define sipNameNr_NoPixelType 37964
#define sipName_NoPixelType &sipStrings_QtGui[37964]
#define sipNameNr_NoUnderline 37976
#define sipName_NoUnderline &sipStrings_QtGui[37976]
#define sipNameNr_NorseBeauty 37988
#define sipName_NorseBeauty &sipStrings_QtGui[37988]
#define sipNameNr_ObjectIndex 29165
#define sipName_ObjectIndex &sipStrings_QtGui[29165]
#define sipNameNr_ObjectTypes 7068
#define sipName_ObjectTypes &sipStrings_QtGui[7068]
#define sipNameNr_OddEvenMode 38000
#define sipName_OddEvenMode &sipStrings_QtGui[38000]
#define sipNameNr_OrangeJuice 38012
#define sipName_OrangeJuice &sipStrings_QtGui[38012]
#define sipNameNr_Orientation 6918
#define sipName_Orientation &sipStrings_QtGui[6918]
#define sipNameNr_OtherSource 38024
#define sipName_OtherSource &sipStrings_QtGui[38024]
#define sipNameNr_PaintBuffer 38036
#define sipName_PaintBuffer &sipStrings_QtGui[38036]
#define sipNameNr_PdmHeightMM 38048
#define sipName_PdmHeightMM &sipStrings_QtGui[38048]
#define sipNameNr_PerfectBlue 38060
#define sipName_PerfectBlue &sipStrings_QtGui[38060]
#define sipNameNr_PixelFormat 4701
#define sipName_PixelFormat &sipStrings_QtGui[4701]
#define sipNameNr_PointerType 6175
#define sipName_PointerType &sipStrings_QtGui[6175]
#define sipNameNr_PreferMatch 38072
#define sipName_PreferMatch &sipStrings_QtGui[38072]
#define sipNameNr_Preferences 38084
#define sipName_Preferences &sipStrings_QtGui[38084]
#define sipNameNr_PremiumDark 38096
#define sipName_PremiumDark &sipStrings_QtGui[38096]
#define sipNameNr_PreviousRow 38108
#define sipName_PreviousRow &sipStrings_QtGui[38108]
#define sipNameNr_ProPhotoRgb 38120
#define sipName_ProPhotoRgb &sipStrings_QtGui[38120]
#define sipNameNr_PyQt5_QtGui 38132
#define sipName_PyQt5_QtGui &sipStrings_QtGui[38132]
#define sipNameNr_QCloseEvent 38144
#define sipName_QCloseEvent &sipStrings_QtGui[38144]
#define sipNameNr_QColorSpace 38156
#define sipName_QColorSpace &sipStrings_QtGui[38156]
#define sipNameNr_QEnterEvent 38168
#define sipName_QEnterEvent &sipStrings_QtGui[38168]
#define sipNameNr_QFocusEvent 38180
#define sipName_QFocusEvent &sipStrings_QtGui[38180]
#define sipNameNr_QHoverEvent 38192
#define sipName_QHoverEvent &sipStrings_QtGui[38192]
#define sipNameNr_QIcon__Mode 38204
#define sipName_QIcon__Mode &sipStrings_QtGui[38204]
#define sipNameNr_QIconEngine 38216
#define sipName_QIconEngine &sipStrings_QtGui[38216]
#define sipNameNr_QInputEvent 38228
#define sipName_QInputEvent &sipStrings_QtGui[38228]
#define sipNameNr_QMouseEvent 38240
#define sipName_QMouseEvent &sipStrings_QtGui[38240]
#define sipNameNr_QPageLayout 38252
#define sipName_QPageLayout &sipStrings_QtGui[38252]
#define sipNameNr_QPaintEvent 38264
#define sipName_QPaintEvent &sipStrings_QtGui[38264]
#define sipNameNr_QQuaternion 38276
#define sipName_QQuaternion &sipStrings_QtGui[38276]
#define sipNameNr_QStaticText 38288
#define sipName_QStaticText &sipStrings_QtGui[38288]
#define sipNameNr_QStyleHints 38300
#define sipName_QStyleHints &sipStrings_QtGui[38300]
#define sipNameNr_QTextCursor 38312
#define sipName_QTextCursor &sipStrings_QtGui[38312]
#define sipNameNr_QTextFormat 38324
#define sipName_QTextFormat &sipStrings_QtGui[38324]
#define sipNameNr_QTextLayout 38336
#define sipName_QTextLayout &sipStrings_QtGui[38336]
#define sipNameNr_QTextLength 38348
#define sipName_QTextLength &sipStrings_QtGui[38348]
#define sipNameNr_QTextObject 38360
#define sipName_QTextObject &sipStrings_QtGui[38360]
#define sipNameNr_QTextOption 38372
#define sipName_QTextOption &sipStrings_QtGui[38372]
#define sipNameNr_QTouchEvent 38384
#define sipName_QTouchEvent &sipStrings_QtGui[38384]
#define sipNameNr_QWheelEvent 38396
#define sipName_QWheelEvent &sipStrings_QtGui[38396]
#define sipNameNr_RGB16_SNorm 38408
#define sipName_RGB16_SNorm &sipStrings_QtGui[38408]
#define sipNameNr_RGB16_UNorm 38420
#define sipName_RGB16_UNorm &sipStrings_QtGui[38420]
#define sipNameNr_RGBA8_SNorm 38432
#define sipName_RGBA8_SNorm &sipStrings_QtGui[38432]
#define sipNameNr_RGBA8_UNorm 38444
#define sipName_RGBA8_UNorm &sipStrings_QtGui[38444]
#define sipNameNr_RGB_Integer 38456
#define sipName_RGB_Integer &sipStrings_QtGui[38456]
#define sipNameNr_Red_Integer 38468
#define sipName_Red_Integer &sipStrings_QtGui[38468]
#define sipNameNr_RenderFlags 9136
#define sipName_RenderFlags &sipStrings_QtGui[9136]
#define sipNameNr_RenderHints 10361
#define sipName_RenderHints &sipStrings_QtGui[10361]
#define sipNameNr_RestartHint 4019
#define sipName_RestartHint &sipStrings_QtGui[4019]
#define sipNameNr_RightToLeft 29300
#define sipName_RightToLeft &sipStrings_QtGui[29300]
#define sipNameNr_RipeMalinka 38480
#define sipName_RipeMalinka &sipStrings_QtGui[38480]
#define sipNameNr_RoyalGarden 38492
#define sipName_RoyalGarden &sipStrings_QtGui[38492]
#define sipNameNr_ScrollState 6149
#define sipName_ScrollState &sipStrings_QtGui[6149]
#define sipNameNr_SmartIndigo 38504
#define sipName_SmartIndigo &sipStrings_QtGui[38504]
#define sipNameNr_SmilingRain 38516
#define sipName_SmilingRain &sipStrings_QtGui[38516]
#define sipNameNr_SoftCherish 38528
#define sipName_SoftCherish &sipStrings_QtGui[38528]
#define sipNameNr_SpacingType 7468
#define sipName_SpacingType &sipStrings_QtGui[7468]
#define sipNameNr_StandardKey 5993
#define sipName_StandardKey &sipStrings_QtGui[5993]
#define sipNameNr_StartOfLine 18232
#define sipName_StartOfLine &sipStrings_QtGui[18232]
#define sipNameNr_StartOfWord 18034
#define sipName_StartOfWord &sipStrings_QtGui[18034]
#define sipNameNr_StencilMode 1361
#define sipName_StencilMode &sipStrings_QtGui[1361]
#define sipNameNr_StrongBliss 38540
#define sipName_StrongBliss &sipStrings_QtGui[38540]
#define sipNameNr_StrongStick 38552
#define sipName_StrongStick &sipStrings_QtGui[38552]
#define sipNameNr_StyleItalic 38564
#define sipName_StyleItalic &sipStrings_QtGui[38564]
#define sipNameNr_StyleNormal 38576
#define sipName_StyleNormal &sipStrings_QtGui[38576]
#define sipNameNr_SummerGames 38588
#define sipName_SummerGames &sipStrings_QtGui[38588]
#define sipNameNr_SurfaceType 10449
#define sipName_SurfaceType &sipStrings_QtGui[10449]
#define sipNameNr_SweetPeriod 38600
#define sipName_SweetPeriod &sipStrings_QtGui[38600]
#define sipNameNr_SwizzleBlue 38612
#define sipName_SwizzleBlue &sipStrings_QtGui[38612]
#define sipNameNr_TableFormat 21426
#define sipName_TableFormat &sipStrings_QtGui[21426]
#define sipNameNr_TableObject 38624
#define sipName_TableObject &sipStrings_QtGui[38624]
#define sipNameNr_TextOutline 29360
#define sipName_TextOutline &sipStrings_QtGui[29360]
#define sipNameNr_TextToolTip 38636
#define sipName_TextToolTip &sipStrings_QtGui[38636]
#define sipNameNr_ToolTipBase 38648
#define sipName_ToolTipBase &sipStrings_QtGui[38648]
#define sipNameNr_ToolTipText 38660
#define sipName_ToolTipText &sipStrings_QtGui[38660]
#define sipNameNr_TouchScreen 38672
#define sipName_TouchScreen &sipStrings_QtGui[38672]
#define sipNameNr_Transparent 31958
#define sipName_Transparent &sipStrings_QtGui[31958]
#define sipNameNr_TxTranslate 38684
#define sipName_TxTranslate &sipStrings_QtGui[38684]
#define sipNameNr_UInt8_RG3B2 38696
#define sipName_UInt8_RG3B2 &sipStrings_QtGui[38696]
#define sipNameNr_Unstretched 38708
#define sipName_Unstretched &sipStrings_QtGui[38708]
#define sipNameNr_WindingMode 38720
#define sipName_WindingMode &sipStrings_QtGui[38720]
#define sipNameNr_XFreeEraser 38732
#define sipName_XFreeEraser &sipStrings_QtGui[38732]
#define sipNameNr_ZeusMiracle 38744
#define sipName_ZeusMiracle &sipStrings_QtGui[38744]
#define sipNameNr___delitem__ 38756
#define sipName___delitem__ &sipStrings_QtGui[38756]
#define sipNameNr___getitem__ 38768
#define sipName___getitem__ &sipStrings_QtGui[38768]
#define sipNameNr___imatmul__ 38780
#define sipName___imatmul__ &sipStrings_QtGui[38780]
#define sipNameNr___setitem__ 38792
#define sipName___setitem__ &sipStrings_QtGui[38792]
#define sipNameNr___truediv__ 38804
#define sipName___truediv__ &sipStrings_QtGui[38804]
#define sipNameNr_addResource 38816
#define sipName_addResource &sipStrings_QtGui[38816]
#define sipNameNr_anchorNames 38828
#define sipName_anchorNames &sipStrings_QtGui[38828]
#define sipNameNr_beginLayout 38840
#define sipName_beginLayout &sipStrings_QtGui[38840]
#define sipNameNr_bindDefault 38852
#define sipName_bindDefault &sipStrings_QtGui[38852]
#define sipNameNr_blockFormat 38864
#define sipName_blockFormat &sipStrings_QtGui[38864]
#define sipNameNr_blockNumber 38876
#define sipName_blockNumber &sipStrings_QtGui[38876]
#define sipNameNr_borderBrush 38888
#define sipName_borderBrush &sipStrings_QtGui[38888]
#define sipNameNr_borderColor 38900
#define sipName_borderColor &sipStrings_QtGui[38900]
#define sipNameNr_borderStyle 38912
#define sipName_borderStyle &sipStrings_QtGui[38912]
#define sipNameNr_brushOrigin 38924
#define sipName_brushOrigin &sipStrings_QtGui[38924]
#define sipNameNr_cellPadding 38936
#define sipName_cellPadding &sipStrings_QtGui[38936]
#define sipNameNr_cellSpacing 38948
#define sipName_cellSpacing &sipStrings_QtGui[38948]
#define sipNameNr_characterAt 38960
#define sipName_characterAt &sipStrings_QtGui[38960]
#define sipNameNr_childFrames 38972
#define sipName_childFrames &sipStrings_QtGui[38972]
#define sipNameNr_clearLayout 38984
#define sipName_clearLayout &sipStrings_QtGui[38984]
#define sipNameNr_columnCount 38996
#define sipName_columnCount &sipStrings_QtGui[38996]
#define sipNameNr_compression 39008
#define sipName_compression &sipStrings_QtGui[39008]
#define sipNameNr_connectPath 39020
#define sipName_connectPath &sipStrings_QtGui[39020]
#define sipNameNr_currentList 39032
#define sipName_currentList &sipStrings_QtGui[39032]
#define sipNameNr_customEvent 39044
#define sipName_customEvent &sipStrings_QtGui[39044]
#define sipNameNr_darkmagenta 39056
#define sipName_darkmagenta &sipStrings_QtGui[39056]
#define sipNameNr_dashPattern 39068
#define sipName_dashPattern &sipStrings_QtGui[39068]
#define sipNameNr_dataChanged 39080
#define sipName_dataChanged &sipStrings_QtGui[39080]
#define sipNameNr_deepskyblue 39092
#define sipName_deepskyblue &sipStrings_QtGui[39092]
#define sipNameNr_defaultFont 39104
#define sipName_defaultFont &sipStrings_QtGui[39104]
#define sipNameNr_description 39116
#define sipName_description &sipStrings_QtGui[39116]
#define sipNameNr_determinant 39128
#define sipName_determinant &sipStrings_QtGui[39128]
#define sipNameNr_doneCurrent 39140
#define sipName_doneCurrent &sipStrings_QtGui[39140]
#define sipNameNr_drawEllipse 39152
#define sipName_drawEllipse &sipStrings_QtGui[39152]
#define sipNameNr_drawPicture 39164
#define sipName_drawPicture &sipStrings_QtGui[39164]
#define sipNameNr_drawPolygon 39176
#define sipName_drawPolygon &sipStrings_QtGui[39176]
#define sipNameNr_errorString 39188
#define sipName_errorString &sipStrings_QtGui[39188]
#define sipNameNr_eventFilter 39200
#define sipName_eventFilter &sipStrings_QtGui[39200]
#define sipNameNr_exposeEvent 39212
#define sipName_exposeEvent &sipStrings_QtGui[39212]
#define sipNameNr_floralwhite 39224
#define sipName_floralwhite &sipStrings_QtGui[39224]
#define sipNameNr_focalRadius 39236
#define sipName_focalRadius &sipStrings_QtGui[39236]
#define sipNameNr_focusObject 39248
#define sipName_focusObject &sipStrings_QtGui[39248]
#define sipNameNr_focusWindow 39260
#define sipName_focusWindow &sipStrings_QtGui[39260]
#define sipNameNr_fontChanged 39272
#define sipName_fontChanged &sipStrings_QtGui[39272]
#define sipNameNr_fontKerning 39284
#define sipName_fontKerning &sipStrings_QtGui[39284]
#define sipNameNr_fontMetrics 39296
#define sipName_fontMetrics &sipStrings_QtGui[39296]
#define sipNameNr_fontStretch 39308
#define sipName_fontStretch &sipStrings_QtGui[39308]
#define sipNameNr_forestgreen 39320
#define sipName_forestgreen &sipStrings_QtGui[39320]
#define sipNameNr_formatIndex 39332
#define sipName_formatIndex &sipStrings_QtGui[39332]
#define sipNameNr_frameFormat 39344
#define sipName_frameFormat &sipStrings_QtGui[39344]
#define sipNameNr_gestureType 39356
#define sipName_gestureType &sipStrings_QtGui[39356]
#define sipNameNr_greenyellow 39368
#define sipName_greenyellow &sipStrings_QtGui[39368]
#define sipNameNr_hasChildren 39380
#define sipName_hasChildren &sipStrings_QtGui[39380]
#define sipNameNr_hasClipping 39392
#define sipName_hasClipping &sipStrings_QtGui[39392]
#define sipNameNr_hasProfiles 39404
#define sipName_hasProfiles &sipStrings_QtGui[39404]
#define sipNameNr_hasProperty 39416
#define sipName_hasProperty &sipStrings_QtGui[39416]
#define sipNameNr_imageFormat 39428
#define sipName_imageFormat &sipStrings_QtGui[39428]
#define sipNameNr_imageHeight 39440
#define sipName_imageHeight &sipStrings_QtGui[39440]
#define sipNameNr_indentWidth 39452
#define sipName_indentWidth &sipStrings_QtGui[39452]
#define sipNameNr_inputMethod 39464
#define sipName_inputMethod &sipStrings_QtGui[39464]
#define sipNameNr_insertBlock 39476
#define sipName_insertBlock &sipStrings_QtGui[39476]
#define sipNameNr_insertFrame 39488
#define sipName_insertFrame &sipStrings_QtGui[39488]
#define sipNameNr_insertImage 39500
#define sipName_insertImage &sipStrings_QtGui[39500]
#define sipNameNr_insertTable 39512
#define sipName_insertTable &sipStrings_QtGui[39512]
#define sipNameNr_intProperty 39524
#define sipName_intProperty &sipStrings_QtGui[39524]
#define sipNameNr_intersected 39536
#define sipName_intersected &sipStrings_QtGui[39536]
#define sipNameNr_isAmbiguous 39548
#define sipName_isAmbiguous &sipStrings_QtGui[39548]
#define sipNameNr_isAnimating 39560
#define sipName_isAnimating &sipStrings_QtGui[39560]
#define sipNameNr_isCheckable 39572
#define sipName_isCheckable &sipStrings_QtGui[39572]
#define sipNameNr_isGrayscale 39584
#define sipName_isGrayscale &sipStrings_QtGui[39584]
#define sipNameNr_isLandscape 39596
#define sipName_isLandscape &sipStrings_QtGui[39596]
#define sipNameNr_itemChanged 39608
#define sipName_itemChanged &sipStrings_QtGui[39608]
#define sipNameNr_jumpToFrame 39620
#define sipName_jumpToFrame &sipStrings_QtGui[39620]
#define sipNameNr_jumpToImage 39632
#define sipName_jumpToImage &sipStrings_QtGui[39632]
#define sipNameNr_keyBindings 39644
#define sipName_keyBindings &sipStrings_QtGui[39644]
#define sipNameNr_lastIndexOf 39656
#define sipName_lastIndexOf &sipStrings_QtGui[39656]
#define sipNameNr_leftBearing 39668
#define sipName_leftBearing &sipStrings_QtGui[39668]
#define sipNameNr_leftPadding 39680
#define sipName_leftPadding &sipStrings_QtGui[39680]
#define sipNameNr_lightsalmon 39692
#define sipName_lightsalmon &sipStrings_QtGui[39692]
#define sipNameNr_lightyellow 39704
#define sipName_lightyellow &sipStrings_QtGui[39704]
#define sipNameNr_lineSpacing 39716
#define sipName_lineSpacing &sipStrings_QtGui[39716]
#define sipNameNr_linkVisited 39728
#define sipName_linkVisited &sipStrings_QtGui[39728]
#define sipNameNr_loggingMode 39740
#define sipName_loggingMode &sipStrings_QtGui[39740]
#define sipNameNr_logicalDpiX 39752
#define sipName_logicalDpiX &sipStrings_QtGui[39752]
#define sipNameNr_logicalDpiY 39764
#define sipName_logicalDpiY &sipStrings_QtGui[39764]
#define sipNameNr_magentaSize 39776
#define sipName_magentaSize &sipStrings_QtGui[39776]
#define sipNameNr_makeCurrent 39788
#define sipName_makeCurrent &sipStrings_QtGui[39788]
#define sipNameNr_mapToGlobal 39800
#define sipName_mapToGlobal &sipStrings_QtGui[39800]
#define sipNameNr_matchPolicy 39812
#define sipName_matchPolicy &sipStrings_QtGui[39812]
#define sipNameNr_maximumSize 39824
#define sipName_maximumSize &sipStrings_QtGui[39824]
#define sipNameNr_minimumSize 39836
#define sipName_minimumSize &sipStrings_QtGui[39836]
#define sipNameNr_mipMaxLevel 39848
#define sipName_mipMaxLevel &sipStrings_QtGui[39848]
#define sipNameNr_modalWindow 39860
#define sipName_modalWindow &sipStrings_QtGui[39860]
#define sipNameNr_moveColumns 32434
#define sipName_moveColumns &sipStrings_QtGui[32434]
#define sipNameNr_navajowhite 39872
#define sipName_navajowhite &sipStrings_QtGui[39872]
#define sipNameNr_objectIndex 39884
#define sipName_objectIndex &sipStrings_QtGui[39884]
#define sipNameNr_orientation 39896
#define sipName_orientation &sipStrings_QtGui[39896]
#define sipNameNr_overlinePos 39908
#define sipName_overlinePos &sipStrings_QtGui[39908]
#define sipNameNr_paintDevice 39920
#define sipName_paintDevice &sipStrings_QtGui[39920]
#define sipNameNr_paintEngine 39932
#define sipName_paintEngine &sipStrings_QtGui[39932]
#define sipNameNr_paintOverGL 39944
#define sipName_paintOverGL &sipStrings_QtGui[39944]
#define sipNameNr_parentFrame 39956
#define sipName_parentFrame &sipStrings_QtGui[39956]
#define sipNameNr_penProperty 39968
#define sipName_penProperty &sipStrings_QtGui[39968]
#define sipNameNr_perspective 39980
#define sipName_perspective &sipStrings_QtGui[39980]
#define sipNameNr_pixelFormat 39992
#define sipName_pixelFormat &sipStrings_QtGui[39992]
#define sipNameNr_pointerType 40004
#define sipName_pointerType &sipStrings_QtGui[40004]
#define sipNameNr_refreshRate 40016
#define sipName_refreshRate &sipStrings_QtGui[40016]
#define sipNameNr_rehighlight 40028
#define sipName_rehighlight &sipStrings_QtGui[40028]
#define sipNameNr_renderFlags 40040
#define sipName_renderFlags &sipStrings_QtGui[40040]
#define sipNameNr_renderHints 40052
#define sipName_renderHints &sipStrings_QtGui[40052]
#define sipNameNr_resizeEvent 40064
#define sipName_resizeEvent &sipStrings_QtGui[40064]
#define sipNameNr_restartHint 40076
#define sipName_restartHint &sipStrings_QtGui[40076]
#define sipNameNr_rightBorder 40088
#define sipName_rightBorder &sipStrings_QtGui[40088]
#define sipNameNr_rightMargin 40100
#define sipName_rightMargin &sipStrings_QtGui[40100]
#define sipNameNr_saddlebrown 40112
#define sipName_saddlebrown &sipStrings_QtGui[40112]
#define sipNameNr_sampleCount 40124
#define sipName_sampleCount &sipStrings_QtGui[40124]
#define sipNameNr_saturationF 40136
#define sipName_saturationF &sipStrings_QtGui[40136]
#define sipNameNr_screenAdded 40148
#define sipName_screenAdded &sipStrings_QtGui[40148]
#define sipNameNr_scrollState 40160
#define sipName_scrollState &sipStrings_QtGui[40160]
#define sipNameNr_setBaseSize 40172
#define sipName_setBaseSize &sipStrings_QtGui[40172]
#define sipNameNr_setCapStyle 40184
#define sipName_setCapStyle &sipStrings_QtGui[40184]
#define sipNameNr_setClipPath 40196
#define sipName_setClipPath &sipStrings_QtGui[40196]
#define sipNameNr_setClipRect 40208
#define sipName_setClipRect &sipStrings_QtGui[40208]
#define sipNameNr_setClipping 40220
#define sipName_setClipping &sipStrings_QtGui[40220]
#define sipNameNr_setCosmetic 40232
#define sipName_setCosmetic &sipStrings_QtGui[40232]
#define sipNameNr_setDecimals 40244
#define sipName_setDecimals &sipStrings_QtGui[40244]
#define sipNameNr_setDocument 40256
#define sipName_setDocument &sipStrings_QtGui[40256]
#define sipNameNr_setEditable 40268
#define sipName_setEditable &sipStrings_QtGui[40268]
#define sipNameNr_setFamilies 40280
#define sipName_setFamilies &sipStrings_QtGui[40280]
#define sipNameNr_setFileName 40292
#define sipName_setFileName &sipStrings_QtGui[40292]
#define sipNameNr_setFilePath 40304
#define sipName_setFilePath &sipStrings_QtGui[40304]
#define sipNameNr_setFillRule 40316
#define sipName_setFillRule &sipStrings_QtGui[40316]
#define sipNameNr_setGeometry 40328
#define sipName_setGeometry &sipStrings_QtGui[40328]
#define sipNameNr_setIODevice 40340
#define sipName_setIODevice &sipStrings_QtGui[40340]
#define sipNameNr_setItemData 40352
#define sipName_setItemData &sipStrings_QtGui[40352]
#define sipNameNr_setMarkdown 40364
#define sipName_setMarkdown &sipStrings_QtGui[40364]
#define sipNameNr_setMimeData 40376
#define sipName_setMimeData &sipStrings_QtGui[40376]
#define sipNameNr_setModality 40388
#define sipName_setModality &sipStrings_QtGui[40388]
#define sipNameNr_setModified 40400
#define sipName_setModified &sipStrings_QtGui[40400]
#define sipNameNr_setNotation 40412
#define sipName_setNotation &sipStrings_QtGui[40412]
#define sipNameNr_setOverline 40424
#define sipName_setOverline &sipStrings_QtGui[40424]
#define sipNameNr_setPageSize 40436
#define sipName_setPageSize &sipStrings_QtGui[40436]
#define sipNameNr_setPosition 40448
#define sipName_setPosition &sipStrings_QtGui[40448]
#define sipNameNr_setProperty 40460
#define sipName_setProperty &sipStrings_QtGui[40460]
#define sipNameNr_setRevision 40472
#define sipName_setRevision &sipStrings_QtGui[40472]
#define sipNameNr_setRowCount 40484
#define sipName_setRowCount &sipStrings_QtGui[40484]
#define sipNameNr_setSizeHint 40496
#define sipName_setSizeHint &sipStrings_QtGui[40496]
#define sipNameNr_setSkipRows 40508
#define sipName_setSkipRows &sipStrings_QtGui[40508]
#define sipNameNr_setSortRole 40520
#define sipName_setSortRole &sipStrings_QtGui[40520]
#define sipNameNr_setTabArray 40532
#define sipName_setTabArray &sipStrings_QtGui[40532]
#define sipNameNr_setTristate 40544
#define sipName_setTristate &sipStrings_QtGui[40544]
#define sipNameNr_setUserData 40556
#define sipName_setUserData &sipStrings_QtGui[40556]
#define sipNameNr_setViewport 40568
#define sipName_setViewport &sipStrings_QtGui[40568]
#define sipNameNr_setWrapMode 40580
#define sipName_setWrapMode &sipStrings_QtGui[40580]
#define sipNameNr_sizeInBytes 40592
#define sipName_sizeInBytes &sipStrings_QtGui[40592]
#define sipNameNr_smoothSizes 40604
#define sipName_smoothSizes &sipStrings_QtGui[40604]
#define sipNameNr_springgreen 19618
#define sipName_springgreen &sipStrings_QtGui[19618]
#define sipNameNr_stopLogging 40616
#define sipName_stopLogging &sipStrings_QtGui[40616]
#define sipNameNr_styleString 40628
#define sipName_styleString &sipStrings_QtGui[40628]
#define sipNameNr_substitutes 40640
#define sipName_substitutes &sipStrings_QtGui[40640]
#define sipNameNr_surfaceType 40652
#define sipName_surfaceType &sipStrings_QtGui[40652]
#define sipNameNr_swapBuffers 40664
#define sipName_swapBuffers &sipStrings_QtGui[40664]
#define sipNameNr_swizzleMask 40676
#define sipName_swizzleMask &sipStrings_QtGui[40676]
#define sipNameNr_tabletEvent 40688
#define sipName_tabletEvent &sipStrings_QtGui[40688]
#define sipNameNr_takeTexture 40700
#define sipName_takeTexture &sipStrings_QtGui[40700]
#define sipNameNr_textFormats 40712
#define sipName_textFormats &sipStrings_QtGui[40712]
#define sipNameNr_textOutline 40724
#define sipName_textOutline &sipStrings_QtGui[40724]
#define sipNameNr_toPlainText 40736
#define sipName_toPlainText &sipStrings_QtGui[40736]
#define sipNameNr_toTransform 22344
#define sipName_toTransform &sipStrings_QtGui[22344]
#define sipNameNr_toolTipBase 40748
#define sipName_toolTipBase &sipStrings_QtGui[40748]
#define sipNameNr_toolTipText 40760
#define sipName_toolTipText &sipStrings_QtGui[40760]
#define sipNameNr_touchPoints 40772
#define sipName_touchPoints &sipStrings_QtGui[40772]
#define sipNameNr_transformed 40784
#define sipName_transformed &sipStrings_QtGui[40784]
#define sipNameNr_unsetCursor 40796
#define sipName_unsetCursor &sipStrings_QtGui[40796]
#define sipNameNr_updateBlock 40808
#define sipName_updateBlock &sipStrings_QtGui[40808]
#define sipNameNr_updateState 40820
#define sipName_updateState &sipStrings_QtGui[40820]
#define sipNameNr_virtualSize 40832
#define sipName_virtualSize &sipStrings_QtGui[40832]
#define sipNameNr_windowState 40844
#define sipName_windowState &sipStrings_QtGui[40844]
#define sipNameNr_wordSpacing 40856
#define sipName_wordSpacing &sipStrings_QtGui[40856]
#define sipNameNr_yellowgreen 40868
#define sipName_yellowgreen &sipStrings_QtGui[40868]
#define sipNameNr_Acceptable 40880
#define sipName_Acceptable &sipStrings_QtGui[40880]
#define sipNameNr_AlphaBlend 40891
#define sipName_AlphaBlend &sipStrings_QtGui[40891]
#define sipNameNr_AlphaUsage 6994
#define sipName_AlphaUsage &sipStrings_QtGui[6994]
#define sipNameNr_AlphaValue 40902
#define sipName_AlphaValue &sipStrings_QtGui[40902]
#define sipNameNr_AmourAmour 40913
#define sipName_AmourAmour &sipStrings_QtGui[40913]
#define sipNameNr_AnchorHref 32547
#define sipName_AnchorHref &sipStrings_QtGui[32547]
#define sipNameNr_AnchorName 40924
#define sipName_AnchorName &sipStrings_QtGui[40924]
#define sipNameNr_AnyStretch 40935
#define sipName_AnyStretch &sipStrings_QtGui[40935]
#define sipNameNr_AquaSplash 40946
#define sipName_AquaSplash &sipStrings_QtGui[40946]
#define sipNameNr_Attachment 388
#define sipName_Attachment &sipStrings_QtGui[388]
#define sipNameNr_Background 23318
#define sipName_Background &sipStrings_QtGui[23318]
#define sipNameNr_BlendModes 40957
#define sipName_BlendModes &sipStrings_QtGui[40957]
#define sipNameNr_BrightText 40968
#define sipName_BrightText &sipStrings_QtGui[40968]
#define sipNameNr_ButtonText 40979
#define sipName_ButtonText &sipStrings_QtGui[40979]
#define sipNameNr_Capitalize 40990
#define sipName_Capitalize &sipStrings_QtGui[40990]
#define sipNameNr_CharFormat 12818
#define sipName_CharFormat &sipStrings_QtGui[12818]
#define sipNameNr_ColorGroup 12167
#define sipName_ColorGroup &sipStrings_QtGui[12167]
#define sipNameNr_ColorModel 7019
#define sipName_ColorModel &sipStrings_QtGui[7019]
#define sipNameNr_ColorSpace 3759
#define sipName_ColorSpace &sipStrings_QtGui[3759]
#define sipNameNr_ConvexMode 41001
#define sipName_ConvexMode &sipStrings_QtGui[41001]
#define sipNameNr_CursorMode 7954
#define sipName_CursorMode &sipStrings_QtGui[7954]
#define sipNameNr_DarkYellow 41012
#define sipName_DarkYellow &sipStrings_QtGui[41012]
#define sipNameNr_Decorative 41023
#define sipName_Decorative &sipStrings_QtGui[41023]
#define sipNameNr_DeepRelief 41034
#define sipName_DeepRelief &sipStrings_QtGui[41034]
#define sipNameNr_DenseWater 41045
#define sipName_DenseWater &sipStrings_QtGui[41045]
#define sipNameNr_DesertHump 41056
#define sipName_DesertHump &sipStrings_QtGui[41056]
#define sipNameNr_Devanagari 41067
#define sipName_Devanagari &sipStrings_QtGui[41067]
#define sipNameNr_DeviceType 7119
#define sipName_DeviceType &sipStrings_QtGui[7119]
#define sipNameNr_DirectionR 41078
#define sipName_DirectionR &sipStrings_QtGui[41078]
#define sipNameNr_DirectionS 41089
#define sipName_DirectionS &sipStrings_QtGui[41089]
#define sipNameNr_DirectionT 41100
#define sipName_DirectionT &sipStrings_QtGui[41100]
#define sipNameNr_DirtyBrush 41111
#define sipName_DirtyBrush &sipStrings_QtGui[41111]
#define sipNameNr_DirtyFlags 6944
#define sipName_DirtyFlags &sipStrings_QtGui[6944]
#define sipNameNr_DirtyHints 41122
#define sipName_DirtyHints &sipStrings_QtGui[41122]
#define sipNameNr_DustyGrass 41133
#define sipName_DustyGrass &sipStrings_QtGui[41133]
#define sipNameNr_EndOfBlock 21104
#define sipName_EndOfBlock &sipStrings_QtGui[21104]
#define sipNameNr_Endianness 41144
#define sipName_Endianness &sipStrings_QtGui[41144]
#define sipNameNr_Envelope10 41155
#define sipName_Envelope10 &sipStrings_QtGui[41155]
#define sipNameNr_Envelope11 41166
#define sipName_Envelope11 &sipStrings_QtGui[41166]
#define sipNameNr_Envelope12 41177
#define sipName_Envelope12 &sipStrings_QtGui[41177]
#define sipNameNr_Envelope14 41188
#define sipName_Envelope14 &sipStrings_QtGui[41188]
#define sipNameNr_EnvelopeB4 41199
#define sipName_EnvelopeB4 &sipStrings_QtGui[41199]
#define sipNameNr_EnvelopeB5 41210
#define sipName_EnvelopeB5 &sipStrings_QtGui[41210]
#define sipNameNr_EnvelopeB6 41221
#define sipName_EnvelopeB6 &sipStrings_QtGui[41221]
#define sipNameNr_EnvelopeC0 41232
#define sipName_EnvelopeC0 &sipStrings_QtGui[41232]
#define sipNameNr_EnvelopeC1 41243
#define sipName_EnvelopeC1 &sipStrings_QtGui[41243]
#define sipNameNr_EnvelopeC2 41254
#define sipName_EnvelopeC2 &sipStrings_QtGui[41254]
#define sipNameNr_EnvelopeC3 41265
#define sipName_EnvelopeC3 &sipStrings_QtGui[41265]
#define sipNameNr_EnvelopeC4 41276
#define sipName_EnvelopeC4 &sipStrings_QtGui[41276]
#define sipNameNr_EnvelopeC5 41287
#define sipName_EnvelopeC5 &sipStrings_QtGui[41287]
#define sipNameNr_EnvelopeC6 41298
#define sipName_EnvelopeC6 &sipStrings_QtGui[41298]
#define sipNameNr_EnvelopeC7 41309
#define sipName_EnvelopeC7 &sipStrings_QtGui[41309]
#define sipNameNr_EnvelopeDL 41320
#define sipName_EnvelopeDL &sipStrings_QtGui[41320]
#define sipNameNr_ExactMatch 41331
#define sipName_ExactMatch &sipStrings_QtGui[41331]
#define sipNameNr_ExtraLight 41342
#define sipName_ExtraLight &sipStrings_QtGui[41342]
#define sipNameNr_FindBuffer 17741
#define sipName_FindBuffer &sipStrings_QtGui[17741]
#define sipNameNr_Float16OES 41353
#define sipName_Float16OES &sipStrings_QtGui[41353]
#define sipNameNr_FloatRight 41364
#define sipName_FloatRight &sipStrings_QtGui[41364]
#define sipNameNr_FontFamily 32785
#define sipName_FontFamily &sipStrings_QtGui[32785]
#define sipNameNr_FontItalic 32799
#define sipName_FontItalic &sipStrings_QtGui[32799]
#define sipNameNr_FontWeight 32813
#define sipName_FontWeight &sipStrings_QtGui[32813]
#define sipNameNr_Foreground 24502
#define sipName_Foreground &sipStrings_QtGui[24502]
#define sipNameNr_ForestInei 41375
#define sipName_ForestInei &sipStrings_QtGui[41375]
#define sipNameNr_FormatType 7930
#define sipName_FormatType &sipStrings_QtGui[7930]
#define sipNameNr_FourDMouse 41386
#define sipName_FourDMouse &sipStrings_QtGui[41386]
#define sipNameNr_FrameWidth 41397
#define sipName_FrameWidth &sipStrings_QtGui[41397]
#define sipNameNr_FreshOasis 41408
#define sipName_FreshOasis &sipStrings_QtGui[41408]
#define sipNameNr_FrozenHeat 41419
#define sipName_FrozenHeat &sipStrings_QtGui[41419]
#define sipNameNr_FruitBlend 41430
#define sipName_FruitBlend &sipStrings_QtGui[41430]
#define sipNameNr_FullScreen 22753
#define sipName_FullScreen &sipStrings_QtGui[22753]
#define sipNameNr_FuzzyMatch 41441
#define sipName_FuzzyMatch &sipStrings_QtGui[41441]
#define sipNameNr_GentleCare 41452
#define sipName_GentleCare &sipStrings_QtGui[41452]
#define sipNameNr_GlassWater 41463
#define sipName_GlassWater &sipStrings_QtGui[41463]
#define sipNameNr_GreatWhale 41474
#define sipName_GreatWhale &sipStrings_QtGui[41474]
#define sipNameNr_GreenValue 41485
#define sipName_GreenValue &sipStrings_QtGui[41485]
#define sipNameNr_GrownEarly 41496
#define sipName_GrownEarly &sipStrings_QtGui[41496]
#define sipNameNr_HighFlight 41507
#define sipName_HighFlight &sipStrings_QtGui[41507]
#define sipNameNr_ImageTitle 41518
#define sipName_ImageTitle &sipStrings_QtGui[41518]
#define sipNameNr_ImageWidth 41529
#define sipName_ImageWidth &sipStrings_QtGui[41529]
#define sipNameNr_InvertMode 15822
#define sipName_InvertMode &sipStrings_QtGui[15822]
#define sipNameNr_InvertRgba 41540
#define sipName_InvertRgba &sipStrings_QtGui[41540]
#define sipNameNr_IsNullHook 41551
#define sipName_IsNullHook &sipStrings_QtGui[41551]
#define sipNameNr_JapanBlush 41562
#define sipName_JapanBlush &sipStrings_QtGui[41562]
#define sipNameNr_JuicyPeach 41573
#define sipName_JuicyPeach &sipStrings_QtGui[41573]
#define sipNameNr_KeepAnchor 41584
#define sipName_KeepAnchor &sipStrings_QtGui[41584]
#define sipNameNr_LayoutFlag 12188
#define sipName_LayoutFlag &sipStrings_QtGui[12188]
#define sipNameNr_LeCocktail 41595
#define sipName_LeCocktail &sipStrings_QtGui[41595]
#define sipNameNr_LegalExtra 41606
#define sipName_LegalExtra &sipStrings_QtGui[41606]
#define sipNameNr_LetterPlus 41617
#define sipName_LetterPlus &sipStrings_QtGui[41617]
#define sipNameNr_LilyMeadow 41628
#define sipName_LilyMeadow &sipStrings_QtGui[41628]
#define sipNameNr_LineHeight 32883
#define sipName_LineHeight &sipStrings_QtGui[32883]
#define sipNameNr_ListCircle 41639
#define sipName_ListCircle &sipStrings_QtGui[41639]
#define sipNameNr_ListFormat 24006
#define sipName_ListFormat &sipStrings_QtGui[24006]
#define sipNameNr_ListIndent 41650
#define sipName_ListIndent &sipStrings_QtGui[41650]
#define sipNameNr_ListSquare 41661
#define sipName_ListSquare &sipStrings_QtGui[41661]
#define sipNameNr_MacPrinter 41672
#define sipName_MacPrinter &sipStrings_QtGui[41672]
#define sipNameNr_ManualWrap 41683
#define sipName_ManualWrap &sipStrings_QtGui[41683]
#define sipNameNr_MarbleWall 41694
#define sipName_MarbleWall &sipStrings_QtGui[41694]
#define sipNameNr_MarkerType 4136
#define sipName_MarkerType &sipStrings_QtGui[4136]
#define sipNameNr_Millimeter 41705
#define sipName_Millimeter &sipStrings_QtGui[41705]
#define sipNameNr_MixedHopes 41716
#define sipName_MixedHopes &sipStrings_QtGui[41716]
#define sipNameNr_MoveAnchor 41727
#define sipName_MoveAnchor &sipStrings_QtGui[41727]
#define sipNameNr_MovieState 15860
#define sipName_MovieState &sipStrings_QtGui[15860]
#define sipNameNr_NPaperSize 41738
#define sipName_NPaperSize &sipStrings_QtGui[41738]
#define sipNameNr_NameFormat 15784
#define sipName_NameFormat &sipStrings_QtGui[15784]
#define sipNameNr_NativeText 41749
#define sipName_NativeText &sipStrings_QtGui[41749]
#define sipNameNr_NightParty 41760
#define sipName_NightParty &sipStrings_QtGui[41760]
#define sipNameNr_NoGradient 41771
#define sipName_NoGradient &sipStrings_QtGui[41771]
#define sipNameNr_NotRunning 41782
#define sipName_NotRunning &sipStrings_QtGui[41782]
#define sipNameNr_NumPresets 41793
#define sipName_NumPresets &sipStrings_QtGui[41793]
#define sipNameNr_ObjectMode 41804
#define sipName_ObjectMode &sipStrings_QtGui[41804]
#define sipNameNr_ObjectType 32939
#define sipName_ObjectType &sipStrings_QtGui[32939]
#define sipNameNr_OldEnglish 41815
#define sipName_OldEnglish &sipStrings_QtGui[41815]
#define sipNameNr_OpaqueHint 41826
#define sipName_OpaqueHint &sipStrings_QtGui[41826]
#define sipNameNr_OutlinePen 41837
#define sipName_OutlinePen &sipStrings_QtGui[41837]
#define sipNameNr_PageSizeId 10340
#define sipName_PageSizeId &sipStrings_QtGui[10340]
#define sipNameNr_PartyBliss 41848
#define sipName_PartyBliss &sipStrings_QtGui[41848]
#define sipNameNr_PdfVersion 3282
#define sipName_PdfVersion &sipStrings_QtGui[3282]
#define sipNameNr_PdmWidthMM 41859
#define sipName_PdmWidthMM &sipStrings_QtGui[41859]
#define sipNameNr_PorterDuff 41870
#define sipName_PorterDuff &sipStrings_QtGui[41870]
#define sipNameNr_PostScript 41881
#define sipName_PostScript &sipStrings_QtGui[41881]
#define sipNameNr_QClipboard 41892
#define sipName_QClipboard &sipStrings_QtGui[41892]
#define sipNameNr_QDropEvent 41903
#define sipName_QDropEvent &sipStrings_QtGui[41903]
#define sipNameNr_QHelpEvent 41914
#define sipName_QHelpEvent &sipStrings_QtGui[41914]
#define sipNameNr_QHideEvent 41925
#define sipName_QHideEvent &sipStrings_QtGui[41925]
#define sipNameNr_QMatrix2x2 41936
#define sipName_QMatrix2x2 &sipStrings_QtGui[41936]
#define sipNameNr_QMatrix2x3 41947
#define sipName_QMatrix2x3 &sipStrings_QtGui[41947]
#define sipNameNr_QMatrix2x4 41958
#define sipName_QMatrix2x4 &sipStrings_QtGui[41958]
#define sipNameNr_QMatrix3x2 41969
#define sipName_QMatrix3x2 &sipStrings_QtGui[41969]
#define sipNameNr_QMatrix3x3 41980
#define sipName_QMatrix3x3 &sipStrings_QtGui[41980]
#define sipNameNr_QMatrix3x4 41991
#define sipName_QMatrix3x4 &sipStrings_QtGui[41991]
#define sipNameNr_QMatrix4x2 42002
#define sipName_QMatrix4x2 &sipStrings_QtGui[42002]
#define sipNameNr_QMatrix4x3 42013
#define sipName_QMatrix4x3 &sipStrings_QtGui[42013]
#define sipNameNr_QMatrix4x4 42024
#define sipName_QMatrix4x4 &sipStrings_QtGui[42024]
#define sipNameNr_QMoveEvent 42035
#define sipName_QMoveEvent &sipStrings_QtGui[42035]
#define sipNameNr_QPdfWriter 42046
#define sipName_QPdfWriter &sipStrings_QtGui[42046]
#define sipNameNr_QPictureIO 42057
#define sipName_QPictureIO &sipStrings_QtGui[42057]
#define sipNameNr_QShowEvent 42068
#define sipName_QShowEvent &sipStrings_QtGui[42068]
#define sipNameNr_QTextBlock 42079
#define sipName_QTextBlock &sipStrings_QtGui[42079]
#define sipNameNr_QTextFrame 42090
#define sipName_QTextFrame &sipStrings_QtGui[42090]
#define sipNameNr_QTextTable 42101
#define sipName_QTextTable &sipStrings_QtGui[42101]
#define sipNameNr_QTransform 42112
#define sipName_QTransform &sipStrings_QtGui[42112]
#define sipNameNr_QValidator 42123
#define sipName_QValidator &sipStrings_QtGui[42123]
#define sipNameNr_RG16_SNorm 42134
#define sipName_RG16_SNorm &sipStrings_QtGui[42134]
#define sipNameNr_RG16_UNorm 42145
#define sipName_RG16_UNorm &sipStrings_QtGui[42145]
#define sipNameNr_RGB8_SNorm 42156
#define sipName_RGB8_SNorm &sipStrings_QtGui[42156]
#define sipNameNr_RGB8_UNorm 42167
#define sipName_RGB8_UNorm &sipStrings_QtGui[42167]
#define sipNameNr_RGBAFormat 42178
#define sipName_RGBAFormat &sipStrings_QtGui[42178]
#define sipNameNr_RG_Integer 42189
#define sipName_RG_Integer &sipStrings_QtGui[42189]
#define sipNameNr_RangeWrite 42200
#define sipName_RangeWrite &sipStrings_QtGui[42200]
#define sipNameNr_RegionType 14132
#define sipName_RegionType &sipStrings_QtGui[14132]
#define sipNameNr_RenderFlag 10560
#define sipName_RenderFlag &sipStrings_QtGui[10560]
#define sipNameNr_RenderHint 12146
#define sipName_RenderHint &sipStrings_QtGui[12146]
#define sipNameNr_SRGB8_ETC2 42211
#define sipName_SRGB8_ETC2 &sipStrings_QtGui[42211]
#define sipNameNr_SRgbLinear 42222
#define sipName_SRgbLinear &sipStrings_QtGui[42222]
#define sipNameNr_SandStrike 42233
#define sipName_SandStrike &sipStrings_QtGui[42233]
#define sipNameNr_ScaledSize 33065
#define sipName_ScaledSize &sipStrings_QtGui[33065]
#define sipNameNr_Severities 2080
#define sipName_Severities &sipStrings_QtGui[2080]
#define sipNameNr_ShaderType 6046
#define sipName_ShaderType &sipStrings_QtGui[6046]
#define sipNameNr_ShadyWater 42244
#define sipName_ShadyWater &sipStrings_QtGui[42244]
#define sipNameNr_SharpBlues 42255
#define sipName_SharpBlues &sipStrings_QtGui[42255]
#define sipNameNr_ShyRainbow 42266
#define sipName_ShyRainbow &sipStrings_QtGui[42266]
#define sipNameNr_SolidStone 42277
#define sipName_SolidStone &sipStrings_QtGui[42277]
#define sipNameNr_SpaceShift 42288
#define sipName_SpaceShift &sipStrings_QtGui[42288]
#define sipNameNr_StaticCopy 42299
#define sipName_StaticCopy &sipStrings_QtGui[42299]
#define sipNameNr_StaticDraw 42310
#define sipName_StaticDraw &sipStrings_QtGui[42310]
#define sipNameNr_StaticRead 42321
#define sipName_StaticRead &sipStrings_QtGui[42321]
#define sipNameNr_StreamCopy 42332
#define sipName_StreamCopy &sipStrings_QtGui[42332]
#define sipNameNr_StreamDraw 42343
#define sipName_StreamDraw &sipStrings_QtGui[42343]
#define sipNameNr_StreamRead 42354
#define sipName_StreamRead &sipStrings_QtGui[42354]
#define sipNameNr_SupremeSky 42365
#define sipName_SupremeSky &sipStrings_QtGui[42365]
#define sipNameNr_SwizzleRed 42376
#define sipName_SwizzleRed &sipStrings_QtGui[42376]
#define sipNameNr_SystemFont 5942
#define sipName_SystemFont &sipStrings_QtGui[5942]
#define sipNameNr_TextFormat 33121
#define sipName_TextFormat &sipStrings_QtGui[33121]
#define sipNameNr_TextIndent 33135
#define sipName_TextIndent &sipStrings_QtGui[33135]
#define sipNameNr_TouchPoint 7978
#define sipName_TouchPoint &sipStrings_QtGui[7978]
#define sipNameNr_TrueSunset 42387
#define sipName_TrueSunset &sipStrings_QtGui[42387]
#define sipNameNr_TypeWriter 42398
#define sipName_TypeWriter &sipStrings_QtGui[42398]
#define sipNameNr_UnknownKey 42409
#define sipName_UnknownKey &sipStrings_QtGui[42409]
#define sipNameNr_UserFormat 42420
#define sipName_UserFormat &sipStrings_QtGui[42420]
#define sipNameNr_UserObject 42431
#define sipName_UserObject &sipStrings_QtGui[42431]
#define sipNameNr_Vietnamese 42442
#define sipName_Vietnamese &sipStrings_QtGui[42442]
#define sipNameNr_Visibility 13572
#define sipName_Visibility &sipStrings_QtGui[13572]
#define sipNameNr_WideMatrix 42453
#define sipName_WideMatrix &sipStrings_QtGui[42453]
#define sipNameNr_WindowText 42464
#define sipName_WindowText &sipStrings_QtGui[42464]
#define sipNameNr_WinterNeva 42475
#define sipName_WinterNeva &sipStrings_QtGui[42475]
#define sipNameNr_WitchDance 42486
#define sipName_WitchDance &sipStrings_QtGui[42486]
#define sipNameNr_YoungGrass 42497
#define sipName_YoungGrass &sipStrings_QtGui[42497]
#define sipNameNr___invert__ 42508
#define sipName___invert__ &sipStrings_QtGui[42508]
#define sipNameNr___lshift__ 42519
#define sipName___lshift__ &sipStrings_QtGui[42519]
#define sipNameNr___matmul__ 42530
#define sipName___matmul__ &sipStrings_QtGui[42530]
#define sipNameNr___rshift__ 42541
#define sipName___rshift__ &sipStrings_QtGui[42541]
#define sipNameNr_actualSize 42552
#define sipName_actualSize &sipStrings_QtGui[42552]
#define sipNameNr_addEllipse 42563
#define sipName_addEllipse &sipStrings_QtGui[42563]
#define sipNameNr_addPolygon 42574
#define sipName_addPolygon &sipStrings_QtGui[42574]
#define sipNameNr_adjustSize 42585
#define sipName_adjustSize &sipStrings_QtGui[42585]
#define sipNameNr_allFormats 42596
#define sipName_allFormats &sipStrings_QtGui[42596]
#define sipNameNr_allWindows 42607
#define sipName_allWindows &sipStrings_QtGui[42607]
#define sipNameNr_alphaUsage 42618
#define sipName_alphaUsage &sipStrings_QtGui[42618]
#define sipNameNr_anchorHref 42629
#define sipName_anchorHref &sipStrings_QtGui[42629]
#define sipNameNr_angleDelta 42640
#define sipName_angleDelta &sipStrings_QtGui[42640]
#define sipNameNr_answerRect 42651
#define sipName_answerRect &sipStrings_QtGui[42651]
#define sipNameNr_appendRows 42662
#define sipName_appendRows &sipStrings_QtGui[42662]
#define sipNameNr_aquamarine 22056
#define sipName_aquamarine &sipStrings_QtGui[22056]
#define sipNameNr_areSharing 42673
#define sipName_areSharing &sipStrings_QtGui[42673]
#define sipNameNr_atBlockEnd 42684
#define sipName_atBlockEnd &sipStrings_QtGui[42684]
#define sipNameNr_attachment 42695
#define sipName_attachment &sipStrings_QtGui[42695]
#define sipNameNr_attributes 42706
#define sipName_attributes &sipStrings_QtGui[42706]
#define sipNameNr_background 42717
#define sipName_background &sipStrings_QtGui[42717]
#define sipNameNr_beginPaint 42728
#define sipName_beginPaint &sipStrings_QtGui[42728]
#define sipNameNr_blockCount 42739
#define sipName_blockCount &sipStrings_QtGui[42739]
#define sipNameNr_blueviolet 42750
#define sipName_blueviolet &sipStrings_QtGui[42750]
#define sipNameNr_brightText 42761
#define sipName_brightText &sipStrings_QtGui[42761]
#define sipNameNr_buttonText 42772
#define sipName_buttonText &sipStrings_QtGui[42772]
#define sipNameNr_cacheLimit 42783
#define sipName_cacheLimit &sipStrings_QtGui[42783]
#define sipNameNr_charFormat 42794
#define sipName_charFormat &sipStrings_QtGui[42794]
#define sipNameNr_chartreuse 42805
#define sipName_chartreuse &sipStrings_QtGui[42805]
#define sipNameNr_checkState 42816
#define sipName_checkState &sipStrings_QtGui[42816]
#define sipNameNr_childEvent 42827
#define sipName_childEvent &sipStrings_QtGui[42827]
#define sipNameNr_clipRegion 42838
#define sipName_clipRegion &sipStrings_QtGui[42838]
#define sipNameNr_colorCount 42849
#define sipName_colorCount &sipStrings_QtGui[42849]
#define sipNameNr_colorModel 42860
#define sipName_colorModel &sipStrings_QtGui[42860]
#define sipNameNr_colorNames 42871
#define sipName_colorNames &sipStrings_QtGui[42871]
#define sipNameNr_colorSpace 42882
#define sipName_colorSpace &sipStrings_QtGui[42882]
#define sipNameNr_colorTable 42893
#define sipName_colorTable &sipStrings_QtGui[42893]
#define sipNameNr_columnSpan 42904
#define sipName_columnSpan &sipStrings_QtGui[42904]
#define sipNameNr_conjugated 42915
#define sipName_conjugated &sipStrings_QtGui[42915]
#define sipNameNr_contentPos 42926
#define sipName_contentPos &sipStrings_QtGui[42926]
#define sipNameNr_copyDataTo 42937
#define sipName_copyDataTo &sipStrings_QtGui[42937]
#define sipNameNr_createLine 42948
#define sipName_createLine &sipStrings_QtGui[42948]
#define sipNameNr_createList 42959
#define sipName_createList &sipStrings_QtGui[42959]
#define sipNameNr_darkorange 42970
#define sipName_darkorange &sipStrings_QtGui[42970]
#define sipNameNr_darkorchid 42981
#define sipName_darkorchid &sipStrings_QtGui[42981]
#define sipNameNr_darksalmon 42992
#define sipName_darksalmon &sipStrings_QtGui[42992]
#define sipNameNr_darkviolet 43003
#define sipName_darkviolet &sipStrings_QtGui[43003]
#define sipNameNr_dashOffset 43014
#define sipName_dashOffset &sipStrings_QtGui[43014]
#define sipNameNr_deleteChar 43025
#define sipName_deleteChar &sipStrings_QtGui[43025]
#define sipNameNr_deviceType 43036
#define sipName_deviceType &sipStrings_QtGui[43036]
#define sipNameNr_dodgerblue 43047
#define sipName_dodgerblue &sipStrings_QtGui[43047]
#define sipNameNr_dotProduct 43058
#define sipName_dotProduct &sipStrings_QtGui[43058]
#define sipNameNr_dragCursor 43069
#define sipName_dragCursor &sipStrings_QtGui[43069]
#define sipNameNr_drawCursor 43080
#define sipName_drawCursor &sipStrings_QtGui[43080]
#define sipNameNr_drawObject 43091
#define sipName_drawObject &sipStrings_QtGui[43091]
#define sipNameNr_drawPixmap 43102
#define sipName_drawPixmap &sipStrings_QtGui[43102]
#define sipNameNr_drawPoints 43113
#define sipName_drawPoints &sipStrings_QtGui[43113]
#define sipNameNr_dropAction 43124
#define sipName_dropAction &sipStrings_QtGui[43124]
#define sipNameNr_elidedText 43135
#define sipName_elidedText &sipStrings_QtGui[43135]
#define sipNameNr_exactMatch 43146
#define sipName_exactMatch &sipStrings_QtGui[43146]
#define sipNameNr_extensions 43157
#define sipName_extensions &sipStrings_QtGui[43157]
#define sipNameNr_familyName 43168
#define sipName_familyName &sipStrings_QtGui[43168]
#define sipNameNr_firstBlock 43179
#define sipName_firstBlock &sipStrings_QtGui[43179]
#define sipNameNr_fixedPitch 43190
#define sipName_fixedPitch &sipStrings_QtGui[43190]
#define sipNameNr_focalPoint 43201
#define sipName_focalPoint &sipStrings_QtGui[43201]
#define sipNameNr_fontFamily 43212
#define sipName_fontFamily &sipStrings_QtGui[43212]
#define sipNameNr_fontItalic 43223
#define sipName_fontItalic &sipStrings_QtGui[43223]
#define sipNameNr_fontWeight 43234
#define sipName_fontWeight &sipStrings_QtGui[43234]
#define sipNameNr_foreground 43245
#define sipName_foreground &sipStrings_QtGui[43245]
#define sipNameNr_frameCount 43256
#define sipName_frameCount &sipStrings_QtGui[43256]
#define sipNameNr_fromArgb32 43267
#define sipName_fromArgb32 &sipStrings_QtGui[43267]
#define sipNameNr_fromRgba64 43278
#define sipName_fromRgba64 &sipStrings_QtGui[43278]
#define sipNameNr_fromString 43289
#define sipName_fromString &sipStrings_QtGui[43289]
#define sipNameNr_genMipMaps 43300
#define sipName_genMipMaps &sipStrings_QtGui[43300]
#define sipNameNr_ghostwhite 43311
#define sipName_ghostwhite &sipStrings_QtGui[43311]
#define sipNameNr_globalPosF 43322
#define sipName_globalPosF &sipStrings_QtGui[43322]
#define sipNameNr_grabWindow 43333
#define sipName_grabWindow &sipStrings_QtGui[43333]
#define sipNameNr_hasFeature 43344
#define sipName_hasFeature &sipStrings_QtGui[43344]
#define sipNameNr_headerData 43355
#define sipName_headerData &sipStrings_QtGui[43355]
#define sipNameNr_horizontal 43366
#define sipName_horizontal &sipStrings_QtGui[43366]
#define sipNameNr_iccProfile 43377
#define sipName_iccProfile &sipStrings_QtGui[43377]
#define sipNameNr_idealWidth 43388
#define sipName_idealWidth &sipStrings_QtGui[43388]
#define sipNameNr_imageCount 43399
#define sipName_imageCount &sipStrings_QtGui[43399]
#define sipNameNr_inFontUcs4 43410
#define sipName_inFontUcs4 &sipStrings_QtGui[43410]
#define sipNameNr_initialize 43421
#define sipName_initialize &sipStrings_QtGui[43421]
#define sipNameNr_insertHtml 43432
#define sipName_insertHtml &sipStrings_QtGui[43432]
#define sipNameNr_insertList 43443
#define sipName_insertList &sipStrings_QtGui[43443]
#define sipNameNr_insertRows 43454
#define sipName_insertRows &sipStrings_QtGui[43454]
#define sipNameNr_insertText 43465
#define sipName_insertText &sipStrings_QtGui[43465]
#define sipNameNr_intersects 43476
#define sipName_intersects &sipStrings_QtGui[43476]
#define sipNameNr_invertible 43487
#define sipName_invertible &sipStrings_QtGui[43487]
#define sipNameNr_isBrushSet 43498
#define sipName_isBrushSet &sipStrings_QtGui[43498]
#define sipNameNr_isCompiled 43509
#define sipName_isCompiled &sipStrings_QtGui[43509]
#define sipNameNr_isCosmetic 43520
#define sipName_isCosmetic &sipStrings_QtGui[43520]
#define sipNameNr_isDetached 43531
#define sipName_isDetached &sipStrings_QtGui[43531]
#define sipNameNr_isEditable 43542
#define sipName_isEditable &sipStrings_QtGui[43542]
#define sipNameNr_isIdentity 43553
#define sipName_isIdentity &sipStrings_QtGui[43553]
#define sipNameNr_isModified 43564
#define sipName_isModified &sipStrings_QtGui[43564]
#define sipNameNr_isOpenGLES 43575
#define sipName_isOpenGLES &sipStrings_QtGui[43575]
#define sipNameNr_isPortrait 43586
#define sipName_isPortrait &sipStrings_QtGui[43586]
#define sipNameNr_isRotating 43597
#define sipName_isRotating &sipStrings_QtGui[43597]
#define sipNameNr_isScalable 43608
#define sipName_isScalable &sipStrings_QtGui[43608]
#define sipNameNr_isTopLevel 43619
#define sipName_isTopLevel &sipStrings_QtGui[43619]
#define sipNameNr_isTristate 43630
#define sipName_isTristate &sipStrings_QtGui[43630]
#define sipNameNr_itemNumber 43641
#define sipName_itemNumber &sipStrings_QtGui[43641]
#define sipNameNr_leftBorder 43652
#define sipName_leftBorder &sipStrings_QtGui[43652]
#define sipNameNr_leftMargin 43663
#define sipName_leftMargin &sipStrings_QtGui[43663]
#define sipNameNr_lightcoral 43674
#define sipName_lightcoral &sipStrings_QtGui[43674]
#define sipNameNr_lightgreen 43685
#define sipName_lightgreen &sipStrings_QtGui[43685]
#define sipNameNr_lightnessF 43696
#define sipName_lightnessF &sipStrings_QtGui[43696]
#define sipNameNr_lineHeight 43707
#define sipName_lineHeight &sipStrings_QtGui[43707]
#define sipNameNr_lineNumber 43718
#define sipName_lineNumber &sipStrings_QtGui[43718]
#define sipNameNr_logMessage 43729
#define sipName_logMessage &sipStrings_QtGui[43729]
#define sipNameNr_mapBetween 43740
#define sipName_mapBetween &sipStrings_QtGui[43740]
#define sipNameNr_mediumblue 43751
#define sipName_mediumblue &sipStrings_QtGui[43751]
#define sipNameNr_mergeCells 43762
#define sipName_mergeCells &sipStrings_QtGui[43762]
#define sipNameNr_minMargins 43773
#define sipName_minMargins &sipStrings_QtGui[43773]
#define sipNameNr_miterLimit 43784
#define sipName_miterLimit &sipStrings_QtGui[43784]
#define sipNameNr_normalized 43795
#define sipName_normalized &sipStrings_QtGui[43795]
#define sipNameNr_objectType 43806
#define sipName_objectType &sipStrings_QtGui[43806]
#define sipNameNr_pageLayout 43817
#define sipName_pageLayout &sipStrings_QtGui[43817]
#define sipNameNr_pageSizeMM 43828
#define sipName_pageSizeMM &sipStrings_QtGui[43828]
#define sipNameNr_paintEvent 43839
#define sipName_paintEvent &sipStrings_QtGui[43839]
#define sipNameNr_papayawhip 43850
#define sipName_papayawhip &sipStrings_QtGui[43850]
#define sipNameNr_parameters 43861
#define sipName_parameters &sipStrings_QtGui[43861]
#define sipNameNr_pdfVersion 43872
#define sipName_pdfVersion &sipStrings_QtGui[43872]
#define sipNameNr_pixelColor 43883
#define sipName_pixelColor &sipStrings_QtGui[43883]
#define sipNameNr_pixelDelta 43894
#define sipName_pixelDelta &sipStrings_QtGui[43894]
#define sipNameNr_pixelIndex 43905
#define sipName_pixelIndex &sipStrings_QtGui[43905]
#define sipNameNr_pointSizeF 43916
#define sipName_pointSizeF &sipStrings_QtGui[43916]
#define sipNameNr_pointSizes 43927
#define sipName_pointSizes &sipStrings_QtGui[43927]
#define sipNameNr_powderblue 43938
#define sipName_powderblue &sipStrings_QtGui[43938]
#define sipNameNr_properties 43949
#define sipName_properties &sipStrings_QtGui[43949]
#define sipNameNr_quadToQuad 43960
#define sipName_quadToQuad &sipStrings_QtGui[43960]
#define sipNameNr_rectPixels 43971
#define sipName_rectPixels &sipStrings_QtGui[43971]
#define sipNameNr_rectPoints 43982
#define sipName_rectPoints &sipStrings_QtGui[43982]
#define sipNameNr_removeItem 43993
#define sipName_removeItem &sipStrings_QtGui[43993]
#define sipNameNr_removeRows 44004
#define sipName_removeRows &sipStrings_QtGui[44004]
#define sipNameNr_resolution 44015
#define sipName_resolution &sipStrings_QtGui[44015]
#define sipNameNr_rgbSwapped 44026
#define sipName_rgbSwapped &sipStrings_QtGui[44026]
#define sipNameNr_rotationTo 44037
#define sipName_rotationTo &sipStrings_QtGui[44037]
#define sipNameNr_sandybrown 44048
#define sipName_sandybrown &sipStrings_QtGui[44048]
#define sipNameNr_saturation 44059
#define sipName_saturation &sipStrings_QtGui[44059]
#define sipNameNr_scaledSize 44070
#define sipName_scaledSize &sipStrings_QtGui[44070]
#define sipNameNr_screenRect 44081
#define sipName_screenRect &sipStrings_QtGui[44081]
#define sipNameNr_selections 44092
#define sipName_selections &sipStrings_QtGui[44092]
#define sipNameNr_sessionKey 44103
#define sipName_sessionKey &sipStrings_QtGui[44103]
#define sipNameNr_setBaseUrl 44114
#define sipName_setBaseUrl &sipStrings_QtGui[44114]
#define sipNameNr_setColorAt 44125
#define sipName_setColorAt &sipStrings_QtGui[44125]
#define sipNameNr_setColumns 44136
#define sipName_setColumns &sipStrings_QtGui[44136]
#define sipNameNr_setCreator 44147
#define sipName_setCreator &sipStrings_QtGui[44147]
#define sipNameNr_setDescent 44158
#define sipName_setDescent &sipStrings_QtGui[44158]
#define sipNameNr_setEnabled 44169
#define sipName_setEnabled &sipStrings_QtGui[44169]
#define sipNameNr_setFormats 44180
#define sipName_setFormats &sipStrings_QtGui[44180]
#define sipNameNr_setHotSpot 44191
#define sipName_setHotSpot &sipStrings_QtGui[44191]
#define sipNameNr_setKerning 44202
#define sipName_setKerning &sipStrings_QtGui[44202]
#define sipNameNr_setMargins 44213
#define sipName_setMargins &sipStrings_QtGui[44213]
#define sipNameNr_setOpacity 44224
#define sipName_setOpacity &sipStrings_QtGui[44224]
#define sipNameNr_setOptions 44235
#define sipName_setOptions &sipStrings_QtGui[44235]
#define sipNameNr_setPadding 44246
#define sipName_setPadding &sipStrings_QtGui[44246]
#define sipNameNr_setPalette 44257
#define sipName_setPalette &sipStrings_QtGui[44257]
#define sipNameNr_setPicture 44268
#define sipName_setPicture &sipStrings_QtGui[44268]
#define sipNameNr_setProfile 44279
#define sipName_setProfile &sipStrings_QtGui[44279]
#define sipNameNr_setQuality 44290
#define sipName_setQuality &sipStrings_QtGui[44290]
#define sipNameNr_setRawFont 44301
#define sipName_setRawFont &sipStrings_QtGui[44301]
#define sipNameNr_setRawMode 44312
#define sipName_setRawMode &sipStrings_QtGui[44312]
#define sipNameNr_setRawName 44323
#define sipName_setRawName &sipStrings_QtGui[44323]
#define sipNameNr_setSamples 44334
#define sipName_setSamples &sipStrings_QtGui[44334]
#define sipNameNr_setStretch 44345
#define sipName_setStretch &sipStrings_QtGui[44345]
#define sipNameNr_setSubType 44356
#define sipName_setSubType &sipStrings_QtGui[44356]
#define sipNameNr_setTabStop 44367
#define sipName_setTabStop &sipStrings_QtGui[44367]
#define sipNameNr_setTexture 44378
#define sipName_setTexture &sipStrings_QtGui[44378]
#define sipNameNr_setToolTip 44389
#define sipName_setToolTip &sipStrings_QtGui[44389]
#define sipNameNr_setVersion 44400
#define sipName_setVersion &sipStrings_QtGui[44400]
#define sipNameNr_setVisible 44411
#define sipName_setVisible &sipStrings_QtGui[44411]
#define sipNameNr_severities 44422
#define sipName_severities &sipStrings_QtGui[44422]
#define sipNameNr_shaderType 44433
#define sipName_shaderType &sipStrings_QtGui[44433]
#define sipNameNr_shareGroup 44444
#define sipName_shareGroup &sipStrings_QtGui[44444]
#define sipNameNr_shortcutId 44455
#define sipName_shortcutId &sipStrings_QtGui[44455]
#define sipNameNr_showNormal 44466
#define sipName_showNormal &sipStrings_QtGui[44466]
#define sipNameNr_simplified 44477
#define sipName_simplified &sipStrings_QtGui[44477]
#define sipNameNr_sizePixels 44488
#define sipName_sizePixels &sipStrings_QtGui[44488]
#define sipNameNr_sizePoints 44499
#define sipName_sizePoints &sipStrings_QtGui[44499]
#define sipNameNr_skipImages 44510
#define sipName_skipImages &sipStrings_QtGui[44510]
#define sipNameNr_skipPixels 44521
#define sipName_skipPixels &sipStrings_QtGui[44521]
#define sipNameNr_sourceCode 44532
#define sipName_sourceCode &sipStrings_QtGui[44532]
#define sipNameNr_sourceLeft 44543
#define sipName_sourceLeft &sipStrings_QtGui[44543]
#define sipNameNr_strokePath 44554
#define sipName_strokePath &sipStrings_QtGui[44554]
#define sipNameNr_styleHints 44565
#define sipName_styleHints &sipStrings_QtGui[44565]
#define sipNameNr_substitute 44576
#define sipName_substitute &sipStrings_QtGui[44576]
#define sipNameNr_subtracted 44587
#define sipName_subtracted &sipStrings_QtGui[44587]
#define sipNameNr_systemFont 44598
#define sipName_systemFont &sipStrings_QtGui[44598]
#define sipNameNr_takeColumn 44609
#define sipName_takeColumn &sipStrings_QtGui[44609]
#define sipNameNr_testOption 44620
#define sipName_testOption &sipStrings_QtGui[44620]
#define sipNameNr_textFormat 44631
#define sipName_textFormat &sipStrings_QtGui[44631]
#define sipNameNr_textIndent 44642
#define sipName_textIndent &sipStrings_QtGui[44642]
#define sipNameNr_textLength 44653
#define sipName_textLength &sipStrings_QtGui[44653]
#define sipNameNr_textOption 44664
#define sipName_textOption &sipStrings_QtGui[44664]
#define sipNameNr_timerEvent 44675
#define sipName_timerEvent &sipStrings_QtGui[44675]
#define sipNameNr_toMarkdown 44686
#define sipName_toMarkdown &sipStrings_QtGui[44686]
#define sipNameNr_toReversed 44697
#define sipName_toReversed &sipStrings_QtGui[44697]
#define sipNameNr_toVector2D 44708
#define sipName_toVector2D &sipStrings_QtGui[44708]
#define sipNameNr_toVector3D 44719
#define sipName_toVector3D &sipStrings_QtGui[44719]
#define sipNameNr_toVector4D 44730
#define sipName_toVector4D &sipStrings_QtGui[44730]
#define sipNameNr_topLevelAt 44741
#define sipName_topLevelAt &sipStrings_QtGui[44741]
#define sipNameNr_topPadding 44752
#define sipName_topPadding &sipStrings_QtGui[44752]
#define sipNameNr_touchEvent 44763
#define sipName_touchEvent &sipStrings_QtGui[44763]
#define sipNameNr_translated 44774
#define sipName_translated &sipStrings_QtGui[44774]
#define sipNameNr_transposed 44785
#define sipName_transposed &sipStrings_QtGui[44785]
#define sipNameNr_trueMatrix 44796
#define sipName_trueMatrix &sipStrings_QtGui[44796]
#define sipNameNr_unitsPerEm 44807
#define sipName_unitsPerEm &sipStrings_QtGui[44807]
#define sipNameNr_visibility 44818
#define sipName_visibility &sipStrings_QtGui[44818]
#define sipNameNr_wheelEvent 44829
#define sipName_wheelEvent &sipStrings_QtGui[44829]
#define sipNameNr_whitesmoke 44840
#define sipName_whitesmoke &sipStrings_QtGui[44840]
#define sipNameNr_windowIcon 44851
#define sipName_windowIcon &sipStrings_QtGui[44851]
#define sipNameNr_windowText 44862
#define sipName_windowText &sipStrings_QtGui[44862]
#define sipNameNr_yellowSize 44873
#define sipName_yellowSize &sipStrings_QtGui[44873]
#define sipNameNr_APISource 44884
#define sipName_APISource &sipStrings_QtGui[44884]
#define sipNameNr_AngelCare 44894
#define sipName_AngelCare &sipStrings_QtGui[44894]
#define sipNameNr_Animation 20448
#define sipName_Animation &sipStrings_QtGui[20448]
#define sipNameNr_AnySource 44904
#define sipName_AnySource &sipStrings_QtGui[44904]
#define sipNameNr_Attribute 3847
#define sipName_Attribute &sipStrings_QtGui[3847]
#define sipNameNr_Backspace 44914
#define sipName_Backspace &sipStrings_QtGui[44914]
#define sipNameNr_BigEndian 44924
#define sipName_BigEndian &sipStrings_QtGui[44924]
#define sipNameNr_BlueValue 44934
#define sipName_BlueValue &sipStrings_QtGui[44934]
#define sipNameNr_ByteOrder 7811
#define sipName_ByteOrder &sipStrings_QtGui[7811]
#define sipNameNr_CacheMode 18450
#define sipName_CacheMode &sipStrings_QtGui[18450]
#define sipNameNr_CacheNone 44944
#define sipName_CacheNone &sipStrings_QtGui[44944]
#define sipNameNr_CenterTab 44954
#define sipName_CenterTab &sipStrings_QtGui[44954]
#define sipNameNr_ChildCare 44964
#define sipName_ChildCare &sipStrings_QtGui[44964]
#define sipNameNr_Clipboard 32268
#define sipName_Clipboard &sipStrings_QtGui[32268]
#define sipNameNr_ColorRole 14113
#define sipName_ColorRole &sipStrings_QtGui[14113]
#define sipNameNr_Condensed 26602
#define sipName_Condensed &sipStrings_QtGui[26602]
#define sipNameNr_D32FS8X24 44974
#define sipName_D32FS8X24 &sipStrings_QtGui[44974]
#define sipNameNr_DarkGreen 44984
#define sipName_DarkGreen &sipStrings_QtGui[44984]
#define sipNameNr_DepthMode 44994
#define sipName_DepthMode &sipStrings_QtGui[44994]
#define sipNameNr_DirtyFlag 7787
#define sipName_DirtyFlag &sipStrings_QtGui[7787]
#define sipNameNr_DirtyFont 45004
#define sipName_DirtyFont &sipStrings_QtGui[45004]
#define sipNameNr_DisplayP3 45014
#define sipName_DisplayP3 &sipStrings_QtGui[45014]
#define sipNameNr_EndOfLine 23287
#define sipName_EndOfLine &sipStrings_QtGui[23287]
#define sipNameNr_EndOfWord 23303
#define sipName_EndOfWord &sipStrings_QtGui[23303]
#define sipNameNr_Envelope9 45024
#define sipName_Envelope9 &sipStrings_QtGui[45024]
#define sipNameNr_ErrorType 45034
#define sipName_ErrorType &sipStrings_QtGui[45034]
#define sipNameNr_Executive 45044
#define sipName_Executive &sipStrings_QtGui[45044]
#define sipNameNr_ExtraBold 45054
#define sipName_ExtraBold &sipStrings_QtGui[45054]
#define sipNameNr_FanFoldUS 45064
#define sipName_FanFoldUS &sipStrings_QtGui[45064]
#define sipNameNr_FindFlags 7045
#define sipName_FindFlags &sipStrings_QtGui[7045]
#define sipNameNr_FixedFont 45074
#define sipName_FixedFont &sipStrings_QtGui[45074]
#define sipNameNr_FloatLeft 45084
#define sipName_FloatLeft &sipStrings_QtGui[45084]
#define sipNameNr_FreshMilk 45094
#define sipName_FreshMilk &sipStrings_QtGui[45094]
#define sipNameNr_Grayscale 11441
#define sipName_Grayscale &sipStrings_QtGui[11441]
#define sipNameNr_HappyAcid 45104
#define sipName_HappyAcid &sipStrings_QtGui[45104]
#define sipNameNr_HeavyRain 45114
#define sipName_HeavyRain &sipStrings_QtGui[45114]
#define sipNameNr_Helvetica 45124
#define sipName_Helvetica &sipStrings_QtGui[45124]
#define sipNameNr_Highlight 45134
#define sipName_Highlight &sipStrings_QtGui[45134]
#define sipNameNr_ImageName 45144
#define sipName_ImageName &sipStrings_QtGui[45144]
#define sipNameNr_InfoFlags 819
#define sipName_InfoFlags &sipStrings_QtGui[819]
#define sipNameNr_InvertRgb 45154
#define sipName_InvertRgb &sipStrings_QtGui[45154]
#define sipNameNr_JuicyCake 45164
#define sipName_JuicyCake &sipStrings_QtGui[45164]
#define sipNameNr_JungleDay 45174
#define sipName_JungleDay &sipStrings_QtGui[45174]
#define sipNameNr_KindSteel 45184
#define sipName_KindSteel &sipStrings_QtGui[45184]
#define sipNameNr_Landscape 39598
#define sipName_Landscape &sipStrings_QtGui[39598]
#define sipNameNr_LemonGate 45194
#define sipName_LemonGate &sipStrings_QtGui[45194]
#define sipNameNr_LightBlue 45204
#define sipName_LightBlue &sipStrings_QtGui[45204]
#define sipNameNr_LightGray 45214
#define sipName_LightGray &sipStrings_QtGui[45214]
#define sipNameNr_ListStyle 45224
#define sipName_ListStyle &sipStrings_QtGui[45224]
#define sipNameNr_Luminance 45234
#define sipName_Luminance &sipStrings_QtGui[45234]
#define sipNameNr_MagicLake 45244
#define sipName_MagicLake &sipStrings_QtGui[45244]
#define sipNameNr_Malayalam 45254
#define sipName_Malayalam &sipStrings_QtGui[45254]
#define sipNameNr_MarsParty 45264
#define sipName_MarsParty &sipStrings_QtGui[45264]
#define sipNameNr_Maximized 26215
#define sipName_Maximized &sipStrings_QtGui[26215]
#define sipNameNr_MeanFruit 45274
#define sipName_MeanFruit &sipStrings_QtGui[45274]
#define sipNameNr_MindCrawl 45284
#define sipName_MindCrawl &sipStrings_QtGui[45284]
#define sipNameNr_Minimized 33234
#define sipName_Minimized &sipStrings_QtGui[33234]
#define sipNameNr_MixedCase 45294
#define sipName_MixedCase &sipStrings_QtGui[45294]
#define sipNameNr_Monospace 45304
#define sipName_Monospace &sipStrings_QtGui[45304]
#define sipNameNr_NPageSize 45314
#define sipName_NPageSize &sipStrings_QtGui[45314]
#define sipNameNr_NextBlock 45324
#define sipName_NextBlock &sipStrings_QtGui[45324]
#define sipNameNr_NextChild 45334
#define sipName_NextChild &sipStrings_QtGui[45334]
#define sipNameNr_NightCall 45344
#define sipName_NightCall &sipStrings_QtGui[45344]
#define sipNameNr_NightFade 45354
#define sipName_NightFade &sipStrings_QtGui[45354]
#define sipNameNr_NoProfile 45364
#define sipName_NoProfile &sipStrings_QtGui[45364]
#define sipNameNr_Offscreen 45374
#define sipName_Offscreen &sipStrings_QtGui[45374]
#define sipNameNr_OtherType 45384
#define sipName_OtherType &sipStrings_QtGui[45384]
#define sipNameNr_PadSpread 45394
#define sipName_PadSpread &sipStrings_QtGui[45394]
#define sipNameNr_PdmHeight 45404
#define sipName_PdmHeight &sipStrings_QtGui[45404]
#define sipNameNr_PixelType 6073
#define sipName_PixelType &sipStrings_QtGui[6073]
#define sipNameNr_PlumPlate 45414
#define sipName_PlumPlate &sipStrings_QtGui[45414]
#define sipNameNr_Prc32KBig 45424
#define sipName_Prc32KBig &sipStrings_QtGui[45424]
#define sipNameNr_Primaries 9000
#define sipName_Primaries &sipStrings_QtGui[9000]
#define sipNameNr_QFontInfo 45434
#define sipName_QFontInfo &sipStrings_QtGui[45434]
#define sipNameNr_QGlyphRun 45444
#define sipName_QGlyphRun &sipStrings_QtGui[45444]
#define sipNameNr_QGradient 45454
#define sipName_QGradient &sipStrings_QtGui[45454]
#define sipNameNr_QKeyEvent 45464
#define sipName_QKeyEvent &sipStrings_QtGui[45464]
#define sipNameNr_QPageSize 45474
#define sipName_QPageSize &sipStrings_QtGui[45474]
#define sipNameNr_QPolygonF 45484
#define sipName_QPolygonF &sipStrings_QtGui[45484]
#define sipNameNr_QTextItem 45494
#define sipName_QTextItem &sipStrings_QtGui[45494]
#define sipNameNr_QTextLine 45504
#define sipName_QTextLine &sipStrings_QtGui[45504]
#define sipNameNr_QTextList 45514
#define sipName_QTextList &sipStrings_QtGui[45514]
#define sipNameNr_QVector2D 45524
#define sipName_QVector2D &sipStrings_QtGui[45524]
#define sipNameNr_QVector3D 45534
#define sipName_QVector3D &sipStrings_QtGui[45534]
#define sipNameNr_QVector4D 45544
#define sipName_QVector4D &sipStrings_QtGui[45544]
#define sipNameNr_QuickDraw 45554
#define sipName_QuickDraw &sipStrings_QtGui[45554]
#define sipNameNr_R16_SNorm 45564
#define sipName_R16_SNorm &sipStrings_QtGui[45564]
#define sipNameNr_R16_UNorm 45574
#define sipName_R16_UNorm &sipStrings_QtGui[45574]
#define sipNameNr_RG8_SNorm 45584
#define sipName_RG8_SNorm &sipStrings_QtGui[45584]
#define sipNameNr_RG8_UNorm 45594
#define sipName_RG8_UNorm &sipStrings_QtGui[45594]
#define sipNameNr_RGB8_ETC1 45604
#define sipName_RGB8_ETC1 &sipStrings_QtGui[45604]
#define sipNameNr_RGB8_ETC2 42212
#define sipName_RGB8_ETC2 &sipStrings_QtGui[42212]
#define sipNameNr_RGBA_DXT1 45614
#define sipName_RGBA_DXT1 &sipStrings_QtGui[45614]
#define sipNameNr_RGBA_DXT3 45624
#define sipName_RGBA_DXT3 &sipStrings_QtGui[45624]
#define sipNameNr_RGBA_DXT5 45634
#define sipName_RGBA_DXT5 &sipStrings_QtGui[45634]
#define sipNameNr_RGBFormat 45644
#define sipName_RGBFormat &sipStrings_QtGui[45644]
#define sipNameNr_RangeRead 45654
#define sipName_RangeRead &sipStrings_QtGui[45654]
#define sipNameNr_ReadWrite 45664
#define sipName_ReadWrite &sipStrings_QtGui[45664]
#define sipNameNr_Rectangle 8770
#define sipName_Rectangle &sipStrings_QtGui[8770]
#define sipNameNr_RedoStack 45674
#define sipName_RedoStack &sipStrings_QtGui[45674]
#define sipNameNr_RichMetal 45684
#define sipName_RichMetal &sipStrings_QtGui[45684]
#define sipNameNr_RiverCity 45694
#define sipName_RiverCity &sipStrings_QtGui[45694]
#define sipNameNr_SRGB_DXT1 45704
#define sipName_SRGB_DXT1 &sipStrings_QtGui[45704]
#define sipNameNr_SansSerif 45714
#define sipName_SansSerif &sipStrings_QtGui[45714]
#define sipNameNr_SeaStrike 45724
#define sipName_SeaStrike &sipStrings_QtGui[45724]
#define sipNameNr_SelectAll 45734
#define sipName_SelectAll &sipStrings_QtGui[45734]
#define sipNameNr_Selection 314
#define sipName_Selection &sipStrings_QtGui[314]
#define sipNameNr_SkipWords 45744
#define sipName_SkipWords &sipStrings_QtGui[45744]
#define sipNameNr_SkyGlider 45754
#define sipName_SkyGlider &sipStrings_QtGui[45754]
#define sipNameNr_SmallCaps 45764
#define sipName_SmallCaps &sipStrings_QtGui[45764]
#define sipNameNr_SnowAgain 45774
#define sipName_SnowAgain &sipStrings_QtGui[45774]
#define sipNameNr_SoftGrass 45784
#define sipName_SoftGrass &sipStrings_QtGui[45784]
#define sipNameNr_SpikyNaga 45794
#define sipName_SpikyNaga &sipStrings_QtGui[45794]
#define sipNameNr_Statement 45804
#define sipName_Statement &sipStrings_QtGui[45804]
#define sipNameNr_StrikeOut 22448
#define sipName_StrikeOut &sipStrings_QtGui[22448]
#define sipNameNr_StyleHint 21275
#define sipName_StyleHint &sipStrings_QtGui[21275]
#define sipNameNr_SunVeggie 45814
#define sipName_SunVeggie &sipStrings_QtGui[45814]
#define sipNameNr_TeenParty 45824
#define sipName_TeenParty &sipStrings_QtGui[45824]
#define sipNameNr_Texture1D 45834
#define sipName_Texture1D &sipStrings_QtGui[45834]
#define sipNameNr_Texture3D 45844
#define sipName_Texture3D &sipStrings_QtGui[45844]
#define sipNameNr_TitleFont 45854
#define sipName_TitleFont &sipStrings_QtGui[45854]
#define sipNameNr_TxProject 45864
#define sipName_TxProject &sipStrings_QtGui[45864]
#define sipNameNr_Unchecked 45874
#define sipName_Unchecked &sipStrings_QtGui[45874]
#define sipNameNr_Underline 14273
#define sipName_Underline &sipStrings_QtGui[14273]
#define sipNameNr_UndoStack 45884
#define sipName_UndoStack &sipStrings_QtGui[45884]
#define sipNameNr_UsesAlpha 45894
#define sipName_UsesAlpha &sipStrings_QtGui[45894]
#define sipNameNr_WarmFlame 45904
#define sipName_WarmFlame &sipStrings_QtGui[45904]
#define sipNameNr_WhatsThis 36974
#define sipName_WhatsThis &sipStrings_QtGui[36974]
#define sipNameNr_WildApple 45914
#define sipName_WildApple &sipStrings_QtGui[45914]
#define sipNameNr_WordRight 45924
#define sipName_WordRight &sipStrings_QtGui[45924]
#define sipNameNr_WriteOnly 45934
#define sipName_WriteOnly &sipStrings_QtGui[45934]
#define sipNameNr_YUVLayout 7835
#define sipName_YUVLayout &sipStrings_QtGui[7835]
#define sipNameNr_ZeroValue 45944
#define sipName_ZeroValue &sipStrings_QtGui[45944]
#define sipNameNr___enter__ 45954
#define sipName___enter__ &sipStrings_QtGui[45954]
#define sipNameNr___index__ 45964
#define sipName___index__ &sipStrings_QtGui[45964]
#define sipNameNr_addPixmap 45974
#define sipName_addPixmap &sipStrings_QtGui[45974]
#define sipNameNr_addRegion 45984
#define sipName_addRegion &sipStrings_QtGui[45984]
#define sipNameNr_addShader 45994
#define sipName_addShader &sipStrings_QtGui[45994]
#define sipNameNr_aliceblue 46004
#define sipName_aliceblue &sipStrings_QtGui[46004]
#define sipNameNr_alignment 46014
#define sipName_alignment &sipStrings_QtGui[46014]
#define sipNameNr_alphaSize 46024
#define sipName_alphaSize &sipStrings_QtGui[46024]
#define sipNameNr_ambiguous 46034
#define sipName_ambiguous &sipStrings_QtGui[46034]
#define sipNameNr_appendRow 46044
#define sipName_appendRow &sipStrings_QtGui[46044]
#define sipNameNr_arcMoveTo 46054
#define sipName_arcMoveTo &sipStrings_QtGui[46054]
#define sipNameNr_blackSize 46064
#define sipName_blackSize &sipStrings_QtGui[46064]
#define sipNameNr_blockList 46074
#define sipName_blockList &sipStrings_QtGui[46074]
#define sipNameNr_burlywood 46084
#define sipName_burlywood &sipStrings_QtGui[46084]
#define sipNameNr_byteCount 46094
#define sipName_byteCount &sipStrings_QtGui[46094]
#define sipNameNr_byteOrder 46104
#define sipName_byteOrder &sipStrings_QtGui[46104]
#define sipNameNr_cacheMode 46114
#define sipName_cacheMode &sipStrings_QtGui[46114]
#define sipNameNr_cadetblue 46124
#define sipName_cadetblue &sipStrings_QtGui[46124]
#define sipNameNr_capHeight 46134
#define sipName_capHeight &sipStrings_QtGui[46134]
#define sipNameNr_chocolate 46144
#define sipName_chocolate &sipStrings_QtGui[46144]
#define sipNameNr_clearData 46154
#define sipName_clearData &sipStrings_QtGui[46154]
#define sipNameNr_clipTight 46164
#define sipName_clipTight &sipStrings_QtGui[46164]
#define sipNameNr_clipboard 46174
#define sipName_clipboard &sipStrings_QtGui[46174]
#define sipNameNr_component 46184
#define sipName_component &sipStrings_QtGui[46184]
#define sipNameNr_conjugate 46194
#define sipName_conjugate &sipStrings_QtGui[46194]
#define sipNameNr_constBits 46204
#define sipName_constBits &sipStrings_QtGui[46204]
#define sipNameNr_convertTo 46214
#define sipName_convertTo &sipStrings_QtGui[46214]
#define sipNameNr_cursorToX 46224
#define sipName_cursorToX &sipStrings_QtGui[46224]
#define sipNameNr_darkgreen 46234
#define sipName_darkgreen &sipStrings_QtGui[46234]
#define sipNameNr_darkkhaki 46244
#define sipName_darkkhaki &sipStrings_QtGui[46244]
#define sipNameNr_delimiter 46254
#define sipName_delimiter &sipStrings_QtGui[46254]
#define sipNameNr_drawChord 46264
#define sipName_drawChord &sipStrings_QtGui[46264]
#define sipNameNr_drawImage 46274
#define sipName_drawImage &sipStrings_QtGui[46274]
#define sipNameNr_drawLines 46284
#define sipName_drawLines &sipStrings_QtGui[46284]
#define sipNameNr_drawPoint 46294
#define sipName_drawPoint &sipStrings_QtGui[46294]
#define sipNameNr_drawRects 46304
#define sipName_drawRects &sipStrings_QtGui[46304]
#define sipNameNr_elementAt 46314
#define sipName_elementAt &sipStrings_QtGui[46314]
#define sipNameNr_endLayout 46324
#define sipName_endLayout &sipStrings_QtGui[46324]
#define sipNameNr_eraseRect 46334
#define sipName_eraseRect &sipStrings_QtGui[46334]
#define sipNameNr_fetchMore 46344
#define sipName_fetchMore &sipStrings_QtGui[46344]
#define sipNameNr_finalStop 46354
#define sipName_finalStop &sipStrings_QtGui[46354]
#define sipNameNr_findBlock 46364
#define sipName_findBlock &sipStrings_QtGui[46364]
#define sipNameNr_findItems 46374
#define sipName_findItems &sipStrings_QtGui[46374]
#define sipNameNr_firebrick 46384
#define sipName_firebrick &sipStrings_QtGui[46384]
#define sipNameNr_fontTable 46394
#define sipName_fontTable &sipStrings_QtGui[46394]
#define sipNameNr_frameRect 46404
#define sipName_frameRect &sipStrings_QtGui[46404]
#define sipNameNr_fromCmykF 46414
#define sipName_fromCmykF &sipStrings_QtGui[46414]
#define sipNameNr_fromImage 46424
#define sipName_fromImage &sipStrings_QtGui[46424]
#define sipNameNr_fromScale 46434
#define sipName_fromScale &sipStrings_QtGui[46434]
#define sipNameNr_fromTheme 46444
#define sipName_fromTheme &sipStrings_QtGui[46444]
#define sipNameNr_fromWinId 46454
#define sipName_fromWinId &sipStrings_QtGui[46454]
#define sipNameNr_gainsboro 46464
#define sipName_gainsboro &sipStrings_QtGui[46464]
#define sipNameNr_globalPos 46474
#define sipName_globalPos &sipStrings_QtGui[46474]
#define sipNameNr_glyphRuns 46484
#define sipName_glyphRuns &sipStrings_QtGui[46484]
#define sipNameNr_goldenrod 31386
#define sipName_goldenrod &sipStrings_QtGui[31386]
#define sipNameNr_greenSize 46494
#define sipName_greenSize &sipStrings_QtGui[46494]
#define sipNameNr_hideEvent 46504
#define sipName_hideEvent &sipStrings_QtGui[46504]
#define sipNameNr_highlight 40030
#define sipName_highlight &sipStrings_QtGui[40030]
#define sipNameNr_indianred 46514
#define sipName_indianred &sipStrings_QtGui[46514]
#define sipNameNr_insertRow 46524
#define sipName_insertRow &sipStrings_QtGui[46524]
#define sipNameNr_isCreated 46534
#define sipName_isCreated &sipStrings_QtGui[46534]
#define sipNameNr_isCurveTo 46544
#define sipName_isCurveTo &sipStrings_QtGui[46544]
#define sipNameNr_isEnabled 46554
#define sipName_isEnabled &sipStrings_QtGui[46554]
#define sipNameNr_isExposed 46564
#define sipName_isExposed &sipStrings_QtGui[46564]
#define sipNameNr_isLogging 46574
#define sipName_isLogging &sipStrings_QtGui[46574]
#define sipNameNr_isQBitmap 46584
#define sipName_isQBitmap &sipStrings_QtGui[46584]
#define sipNameNr_isScaling 46594
#define sipName_isScaling &sipStrings_QtGui[46594]
#define sipNameNr_isVisible 46604
#define sipName_isVisible &sipStrings_QtGui[46604]
#define sipNameNr_joinStyle 46614
#define sipName_joinStyle &sipStrings_QtGui[46614]
#define sipNameNr_lastBlock 46624
#define sipName_lastBlock &sipStrings_QtGui[46624]
#define sipNameNr_lastError 46634
#define sipName_lastError &sipStrings_QtGui[46634]
#define sipNameNr_lawngreen 46644
#define sipName_lawngreen &sipStrings_QtGui[46644]
#define sipNameNr_lightblue 46654
#define sipName_lightblue &sipStrings_QtGui[46654]
#define sipNameNr_lightcyan 46664
#define sipName_lightcyan &sipStrings_QtGui[46664]
#define sipNameNr_lightgray 46674
#define sipName_lightgray &sipStrings_QtGui[46674]
#define sipNameNr_lightgrey 46684
#define sipName_lightgrey &sipStrings_QtGui[46684]
#define sipNameNr_lightness 46694
#define sipName_lightness &sipStrings_QtGui[46694]
#define sipNameNr_lightpink 46704
#define sipName_lightpink &sipStrings_QtGui[46704]
#define sipNameNr_limegreen 46714
#define sipName_limegreen &sipStrings_QtGui[46714]
#define sipNameNr_lineCount 46724
#define sipName_lineCount &sipStrings_QtGui[46724]
#define sipNameNr_lineWidth 46734
#define sipName_lineWidth &sipStrings_QtGui[46734]
#define sipNameNr_loopCount 46744
#define sipName_loopCount &sipStrings_QtGui[46744]
#define sipNameNr_lostFocus 46754
#define sipName_lostFocus &sipStrings_QtGui[46754]
#define sipNameNr_mapVector 46764
#define sipName_mapVector &sipStrings_QtGui[46764]
#define sipNameNr_mimeTypes 46774
#define sipName_mimeTypes &sipStrings_QtGui[46774]
#define sipNameNr_mintcream 46784
#define sipName_mintcream &sipStrings_QtGui[46784]
#define sipNameNr_mipLevels 46794
#define sipName_mipLevels &sipStrings_QtGui[46794]
#define sipNameNr_mistyrose 46804
#define sipName_mistyrose &sipStrings_QtGui[46804]
#define sipNameNr_modifiers 46814
#define sipName_modifiers &sipStrings_QtGui[46814]
#define sipNameNr_moveEvent 46824
#define sipName_moveEvent &sipStrings_QtGui[46824]
#define sipNameNr_nearPlane 46834
#define sipName_nearPlane &sipStrings_QtGui[46834]
#define sipNameNr_normalize 46844
#define sipName_normalize &sipStrings_QtGui[46844]
#define sipNameNr_numericId 46854
#define sipName_numericId &sipStrings_QtGui[46854]
#define sipNameNr_objectIds 46864
#define sipName_objectIds &sipStrings_QtGui[46864]
#define sipNameNr_olivedrab 46874
#define sipName_olivedrab &sipStrings_QtGui[46874]
#define sipNameNr_operation 46884
#define sipName_operation &sipStrings_QtGui[46884]
#define sipNameNr_orangered 46894
#define sipName_orangered &sipStrings_QtGui[46894]
#define sipNameNr_pageCount 46904
#define sipName_pageCount &sipStrings_QtGui[46904]
#define sipNameNr_paintRect 46914
#define sipName_paintRect &sipStrings_QtGui[46914]
#define sipNameNr_palegreen 46924
#define sipName_palegreen &sipStrings_QtGui[46924]
#define sipNameNr_peachpuff 46934
#define sipName_peachpuff &sipStrings_QtGui[46934]
#define sipNameNr_pixelSize 46944
#define sipName_pixelSize &sipStrings_QtGui[46944]
#define sipNameNr_pointSize 46954
#define sipName_pointSize &sipStrings_QtGui[46954]
#define sipNameNr_positions 46964
#define sipName_positions &sipStrings_QtGui[46964]
#define sipNameNr_primaries 46974
#define sipName_primaries &sipStrings_QtGui[46974]
#define sipNameNr_programId 46984
#define sipName_programId &sipStrings_QtGui[46984]
#define sipNameNr_pushGroup 46994
#define sipName_pushGroup &sipStrings_QtGui[46994]
#define sipNameNr_putPoints 47004
#define sipName_putPoints &sipStrings_QtGui[47004]
#define sipNameNr_rectCount 47014
#define sipName_rectCount &sipStrings_QtGui[47014]
#define sipNameNr_removeRow 47024
#define sipName_removeRow &sipStrings_QtGui[47024]
#define sipNameNr_roleNames 47034
#define sipName_roleNames &sipStrings_QtGui[47034]
#define sipNameNr_rootFrame 47044
#define sipName_rootFrame &sipStrings_QtGui[47044]
#define sipNameNr_rosybrown 47054
#define sipName_rosybrown &sipStrings_QtGui[47054]
#define sipNameNr_rowLength 47064
#define sipName_rowLength &sipStrings_QtGui[47064]
#define sipNameNr_royalblue 47074
#define sipName_royalblue &sipStrings_QtGui[47074]
#define sipNameNr_sceneRect 47084
#define sipName_sceneRect &sipStrings_QtGui[47084]
#define sipNameNr_screenPos 47094
#define sipName_screenPos &sipStrings_QtGui[47094]
#define sipNameNr_selection 47104
#define sipName_selection &sipStrings_QtGui[47104]
#define sipNameNr_sessionId 47114
#define sipName_sessionId &sipStrings_QtGui[47114]
#define sipNameNr_setActive 47124
#define sipName_setActive &sipStrings_QtGui[47124]
#define sipNameNr_setAlphaF 47134
#define sipName_setAlphaF &sipStrings_QtGui[47134]
#define sipNameNr_setAnchor 47144
#define sipName_setAnchor &sipStrings_QtGui[47144]
#define sipNameNr_setAscent 47154
#define sipName_setAscent &sipStrings_QtGui[47154]
#define sipNameNr_setBorder 47164
#define sipName_setBorder &sipStrings_QtGui[47164]
#define sipNameNr_setBottom 47174
#define sipName_setBottom &sipStrings_QtGui[47174]
#define sipNameNr_setCenter 47184
#define sipName_setCenter &sipStrings_QtGui[47184]
#define sipNameNr_setColumn 47194
#define sipName_setColumn &sipStrings_QtGui[47194]
#define sipNameNr_setCursor 40798
#define sipName_setCursor &sipStrings_QtGui[40798]
#define sipNameNr_setDevice 47204
#define sipName_setDevice &sipStrings_QtGui[47204]
#define sipNameNr_setFamily 47214
#define sipName_setFamily &sipStrings_QtGui[47214]
#define sipNameNr_setFormat 47224
#define sipName_setFormat &sipStrings_QtGui[47224]
#define sipNameNr_setGreenF 47234
#define sipName_setGreenF &sipStrings_QtGui[47234]
#define sipNameNr_setHeight 47244
#define sipName_setHeight &sipStrings_QtGui[47244]
#define sipNameNr_setIndent 47254
#define sipName_setIndent &sipStrings_QtGui[47254]
#define sipNameNr_setIsMask 47264
#define sipName_setIsMask &sipStrings_QtGui[47264]
#define sipNameNr_setItalic 47274
#define sipName_setItalic &sipStrings_QtGui[47274]
#define sipNameNr_setLayers 47284
#define sipName_setLayers &sipStrings_QtGui[47284]
#define sipNameNr_setLocale 47294
#define sipName_setLocale &sipStrings_QtGui[47294]
#define sipNameNr_setMargin 47304
#define sipName_setMargin &sipStrings_QtGui[47304]
#define sipNameNr_setMarker 47314
#define sipName_setMarker &sipStrings_QtGui[47314]
#define sipNameNr_setMatrix 47324
#define sipName_setMatrix &sipStrings_QtGui[47324]
#define sipNameNr_setMipmap 47334
#define sipName_setMipmap &sipStrings_QtGui[47334]
#define sipNameNr_setOffset 47344
#define sipName_setOffset &sipStrings_QtGui[47344]
#define sipNameNr_setOption 47354
#define sipName_setOption &sipStrings_QtGui[47354]
#define sipNameNr_setParent 47364
#define sipName_setParent &sipStrings_QtGui[47364]
#define sipNameNr_setPaused 47374
#define sipName_setPaused &sipStrings_QtGui[47374]
#define sipNameNr_setPixmap 47384
#define sipName_setPixmap &sipStrings_QtGui[47384]
#define sipNameNr_setPoints 47394
#define sipName_setPoints &sipStrings_QtGui[47394]
#define sipNameNr_setRadius 47404
#define sipName_setRadius &sipStrings_QtGui[47404]
#define sipNameNr_setRegExp 47414
#define sipName_setRegExp &sipStrings_QtGui[47414]
#define sipNameNr_setRgba64 47424
#define sipName_setRgba64 &sipStrings_QtGui[47424]
#define sipNameNr_setScalar 47434
#define sipName_setScalar &sipStrings_QtGui[47434]
#define sipNameNr_setScreen 47444
#define sipName_setScreen &sipStrings_QtGui[47444]
#define sipNameNr_setSpread 47454
#define sipName_setSpread &sipStrings_QtGui[47454]
#define sipNameNr_setStatus 47464
#define sipName_setStatus &sipStrings_QtGui[47464]
#define sipNameNr_setStereo 47474
#define sipName_setStereo &sipStrings_QtGui[47474]
#define sipNameNr_setVector 47484
#define sipName_setVector &sipStrings_QtGui[47484]
#define sipNameNr_setWeight 47494
#define sipName_setWeight &sipStrings_QtGui[47494]
#define sipNameNr_setWidthF 47504
#define sipName_setWidthF &sipStrings_QtGui[47504]
#define sipNameNr_setWindow 47514
#define sipName_setWindow &sipStrings_QtGui[47514]
#define sipNameNr_showEvent 47524
#define sipName_showEvent &sipStrings_QtGui[47524]
#define sipNameNr_slateblue 25255
#define sipName_slateblue &sipStrings_QtGui[25255]
#define sipNameNr_slategray 28312
#define sipName_slategray &sipStrings_QtGui[28312]
#define sipNameNr_slategrey 28327
#define sipName_slategrey &sipStrings_QtGui[28327]
#define sipNameNr_sourceTop 47534
#define sipName_sourceTop &sipStrings_QtGui[47534]
#define sipNameNr_splitCell 47544
#define sipName_splitCell &sipStrings_QtGui[47544]
#define sipNameNr_statusTip 47554
#define sipName_statusTip &sipStrings_QtGui[47554]
#define sipNameNr_steelblue 28342
#define sipName_steelblue &sipStrings_QtGui[28342]
#define sipNameNr_strikeOut 47564
#define sipName_strikeOut &sipStrings_QtGui[47564]
#define sipNameNr_styleHint 47574
#define sipName_styleHint &sipStrings_QtGui[47574]
#define sipNameNr_styleName 47584
#define sipName_styleName &sipStrings_QtGui[47584]
#define sipNameNr_takeChild 47594
#define sipName_takeChild &sipStrings_QtGui[47594]
#define sipNameNr_textStart 47604
#define sipName_textStart &sipStrings_QtGui[47604]
#define sipNameNr_textWidth 47614
#define sipName_textWidth &sipStrings_QtGui[47614]
#define sipNameNr_textureId 47624
#define sipName_textureId &sipStrings_QtGui[47624]
#define sipNameNr_themeName 47634
#define sipName_themeName &sipStrings_QtGui[47634]
#define sipNameNr_timestamp 47644
#define sipName_timestamp &sipStrings_QtGui[47644]
#define sipNameNr_toPolygon 47654
#define sipName_toPolygon &sipStrings_QtGui[47654]
#define sipNameNr_toRawText 47664
#define sipName_toRawText &sipStrings_QtGui[47664]
#define sipNameNr_topBorder 47674
#define sipName_topBorder &sipStrings_QtGui[47674]
#define sipNameNr_topMargin 47684
#define sipName_topMargin &sipStrings_QtGui[47684]
#define sipNameNr_transform 47694
#define sipName_transform &sipStrings_QtGui[47694]
#define sipNameNr_translate 47704
#define sipName_translate &sipStrings_QtGui[47704]
#define sipNameNr_turquoise 25271
#define sipName_turquoise &sipStrings_QtGui[25271]
#define sipNameNr_underline 47714
#define sipName_underline &sipStrings_QtGui[47714]
#define sipNameNr_unproject 47724
#define sipName_unproject &sipStrings_QtGui[47724]
#define sipNameNr_userState 47734
#define sipName_userState &sipStrings_QtGui[47734]
#define sipNameNr_whatsThis 47744
#define sipName_whatsThis &sipStrings_QtGui[47744]
#define sipNameNr_widthChar 47754
#define sipName_widthChar &sipStrings_QtGui[47754]
#define sipNameNr_windowPos 47764
#define sipName_windowPos &sipStrings_QtGui[47764]
#define sipNameNr_windowsId 47774
#define sipName_windowsId &sipStrings_QtGui[47774]
#define sipNameNr_xToCursor 47784
#define sipName_xToCursor &sipStrings_QtGui[47784]
#define sipNameNr_yuvLayout 47794
#define sipName_yuvLayout &sipStrings_QtGui[47794]
#define sipNameNr_AdobeRgb 47804
#define sipName_AdobeRgb &sipStrings_QtGui[47804]
#define sipNameNr_Airbrush 47813
#define sipName_Airbrush &sipStrings_QtGui[47813]
#define sipNameNr_AlignTop 47822
#define sipName_AlignTop &sipStrings_QtGui[47822]
#define sipNameNr_AllDirty 47831
#define sipName_AllDirty &sipStrings_QtGui[47831]
#define sipNameNr_AmyCrisp 47840
#define sipName_AmyCrisp &sipStrings_QtGui[47840]
#define sipNameNr_AnyStyle 47849
#define sipName_AnyStyle &sipStrings_QtGui[47849]
#define sipNameNr_Armenian 47858
#define sipName_Armenian &sipStrings_QtGui[47858]
#define sipNameNr_BigMango 47867
#define sipName_BigMango &sipStrings_QtGui[47867]
#define sipNameNr_BlackSea 47876
#define sipName_BlackSea &sipStrings_QtGui[47876]
#define sipNameNr_Blessing 47885
#define sipName_Blessing &sipStrings_QtGui[47885]
#define sipNameNr_CacheAll 47894
#define sipName_CacheAll &sipStrings_QtGui[47894]
#define sipNameNr_ClipRect 20197
#define sipName_ClipRect &sipStrings_QtGui[20197]
#define sipNameNr_CssFloat 47903
#define sipName_CssFloat &sipStrings_QtGui[47903]
#define sipNameNr_Cyrillic 47912
#define sipName_Cyrillic &sipStrings_QtGui[47912]
#define sipNameNr_DarkBlue 47921
#define sipName_DarkBlue &sipStrings_QtGui[47921]
#define sipNameNr_DarkCyan 47930
#define sipName_DarkCyan &sipStrings_QtGui[47930]
#define sipNameNr_DarkGray 47939
#define sipName_DarkGray &sipStrings_QtGui[47939]
#define sipNameNr_DciP3D65 47948
#define sipName_DciP3D65 &sipStrings_QtGui[47948]
#define sipNameNr_DeepBlue 47957
#define sipName_DeepBlue &sipStrings_QtGui[47957]
#define sipNameNr_DemiBold 47966
#define sipName_DemiBold &sipStrings_QtGui[47966]
#define sipNameNr_Deselect 47975
#define sipName_Deselect &sipStrings_QtGui[47975]
#define sipNameNr_Direct2D 47984
#define sipName_Direct2D &sipStrings_QtGui[47984]
#define sipNameNr_Direct3D 47993
#define sipName_Direct3D &sipStrings_QtGui[47993]
#define sipNameNr_DirtyPen 48002
#define sipName_DirtyPen &sipStrings_QtGui[48002]
#define sipNameNr_Disabled 48011
#define sipName_Disabled &sipStrings_QtGui[48011]
#define sipNameNr_Document 10122
#define sipName_Document &sipStrings_QtGui[10122]
#define sipNameNr_Expanded 29903
#define sipName_Expanded &sipStrings_QtGui[29903]
#define sipNameNr_Features 1062
#define sipName_Features &sipStrings_QtGui[1062]
#define sipNameNr_FindFlag 7908
#define sipName_FindFlag &sipStrings_QtGui[7908]
#define sipNameNr_FindNext 48020
#define sipName_FindNext &sipStrings_QtGui[48020]
#define sipNameNr_Fragment 6971
#define sipName_Fragment &sipStrings_QtGui[6971]
#define sipNameNr_Geometry 7221
#define sipName_Geometry &sipStrings_QtGui[7221]
#define sipNameNr_Georgian 48029
#define sipName_Georgian &sipStrings_QtGui[48029]
#define sipNameNr_Gujarati 48038
#define sipName_Gujarati &sipStrings_QtGui[48038]
#define sipNameNr_Gurmukhi 48047
#define sipName_Gurmukhi &sipStrings_QtGui[48047]
#define sipNameNr_Inactive 48056
#define sipName_Inactive &sipStrings_QtGui[48056]
#define sipNameNr_InfoFlag 1130
#define sipName_InfoFlag &sipStrings_QtGui[1130]
#define sipNameNr_IsAnchor 48065
#define sipName_IsAnchor &sipStrings_QtGui[48065]
#define sipNameNr_ItemType 7884
#define sipName_ItemType &sipStrings_QtGui[7884]
#define sipNameNr_Japanese 48074
#define sipName_Japanese &sipStrings_QtGui[48074]
#define sipNameNr_Keyboard 48083
#define sipName_Keyboard &sipStrings_QtGui[48083]
#define sipNameNr_LadyLips 48092
#define sipName_LadyLips &sipStrings_QtGui[48092]
#define sipNameNr_Language 17929
#define sipName_Language &sipStrings_QtGui[17929]
#define sipNameNr_ListDisc 48101
#define sipName_ListDisc &sipStrings_QtGui[48101]
#define sipNameNr_LoveKiss 48110
#define sipName_LoveKiss &sipStrings_QtGui[48110]
#define sipNameNr_MagicRay 48119
#define sipName_MagicRay &sipStrings_QtGui[48119]
#define sipNameNr_Midlight 48128
#define sipName_Midlight &sipStrings_QtGui[48128]
#define sipNameNr_MoleHall 48137
#define sipName_MoleHall &sipStrings_QtGui[48137]
#define sipNameNr_MoveMode 10474
#define sipName_MoveMode &sipStrings_QtGui[10474]
#define sipNameNr_NearMoon 48146
#define sipName_NearMoon &sipStrings_QtGui[48146]
#define sipNameNr_NextCell 48155
#define sipName_NextCell &sipStrings_QtGui[48155]
#define sipNameNr_NextWord 26903
#define sipName_NextWord &sipStrings_QtGui[26903]
#define sipNameNr_NightSky 48164
#define sipName_NightSky &sipStrings_QtGui[48164]
#define sipNameNr_NoDevice 48173
#define sipName_NoDevice &sipStrings_QtGui[48173]
#define sipNameNr_NoFormat 48182
#define sipName_NoFormat &sipStrings_QtGui[48182]
#define sipNameNr_NoMarker 48191
#define sipName_NoMarker &sipStrings_QtGui[48191]
#define sipNameNr_NoObject 48200
#define sipName_NoObject &sipStrings_QtGui[48200]
#define sipNameNr_Notation 5118
#define sipName_Notation &sipStrings_QtGui[5118]
#define sipNameNr_OneValue 48209
#define sipName_OneValue &sipStrings_QtGui[48209]
#define sipNameNr_OpenGLES 43577
#define sipName_OpenGLES &sipStrings_QtGui[43577]
#define sipNameNr_Overline 25848
#define sipName_Overline &sipStrings_QtGui[25848]
#define sipNameNr_PageSize 4732
#define sipName_PageSize &sipStrings_QtGui[4732]
#define sipNameNr_PaloAlto 48218
#define sipName_PaloAlto &sipStrings_QtGui[48218]
#define sipNameNr_PdmDepth 48227
#define sipName_PdmDepth &sipStrings_QtGui[48227]
#define sipNameNr_PdmWidth 48236
#define sipName_PdmWidth &sipStrings_QtGui[48236]
#define sipNameNr_PlumBath 48245
#define sipName_PlumBath &sipStrings_QtGui[48245]
#define sipNameNr_Portrait 43588
#define sipName_Portrait &sipStrings_QtGui[43588]
#define sipNameNr_Position 4760
#define sipName_Position &sipStrings_QtGui[4760]
#define sipNameNr_Postcard 26558
#define sipName_Postcard &sipStrings_QtGui[26558]
#define sipNameNr_Pressure 17762
#define sipName_Pressure &sipStrings_QtGui[17762]
#define sipNameNr_Property 10540
#define sipName_Property &sipStrings_QtGui[10540]
#define sipNameNr_QPainter 48254
#define sipName_QPainter &sipStrings_QtGui[48254]
#define sipNameNr_QPalette 48263
#define sipName_QPalette &sipStrings_QtGui[48263]
#define sipNameNr_QPicture 48272
#define sipName_QPicture &sipStrings_QtGui[48272]
#define sipNameNr_QPolygon 48281
#define sipName_QPolygon &sipStrings_QtGui[48281]
#define sipNameNr_QRawFont 48290
#define sipName_QRawFont &sipStrings_QtGui[48290]
#define sipNameNr_QSurface 48299
#define sipName_QSurface &sipStrings_QtGui[48299]
#define sipNameNr_R8_SNorm 48308
#define sipName_R8_SNorm &sipStrings_QtGui[48308]
#define sipNameNr_R8_UNorm 48317
#define sipName_R8_UNorm &sipStrings_QtGui[48317]
#define sipNameNr_RG11B10F 24232
#define sipName_RG11B10F &sipStrings_QtGui[24232]
#define sipNameNr_RGB_DXT1 45705
#define sipName_RGB_DXT1 &sipStrings_QtGui[45705]
#define sipNameNr_RareWind 48326
#define sipName_RareWind &sipStrings_QtGui[48326]
#define sipNameNr_ReadOnly 48335
#define sipName_ReadOnly &sipStrings_QtGui[48335]
#define sipNameNr_RedValue 48344
#define sipName_RedValue &sipStrings_QtGui[48344]
#define sipNameNr_RightTab 48353
#define sipName_RightTab &sipStrings_QtGui[48353]
#define sipNameNr_Seashore 48362
#define sipName_Seashore &sipStrings_QtGui[48362]
#define sipNameNr_Selected 48371
#define sipName_Selected &sipStrings_QtGui[48371]
#define sipNameNr_Severity 3134
#define sipName_Severity &sipStrings_QtGui[3134]
#define sipNameNr_StarWine 48380
#define sipName_StarWine &sipStrings_QtGui[48380]
#define sipNameNr_Target1D 23160
#define sipName_Target1D &sipStrings_QtGui[23160]
#define sipNameNr_Target2D 23176
#define sipName_Target2D &sipStrings_QtGui[23176]
#define sipNameNr_Target3D 23192
#define sipName_Target3D &sipStrings_QtGui[23192]
#define sipNameNr_TouchPad 48389
#define sipName_TouchPad &sipStrings_QtGui[48389]
#define sipNameNr_Trailing 48398
#define sipName_Trailing &sipStrings_QtGui[48398]
#define sipNameNr_TxRotate 48407
#define sipName_TxRotate &sipStrings_QtGui[48407]
#define sipNameNr_UserType 48416
#define sipName_UserType &sipStrings_QtGui[48416]
#define sipNameNr_Velocity 20377
#define sipName_Velocity &sipStrings_QtGui[20377]
#define sipNameNr_Windowed 48425
#define sipName_Windowed &sipStrings_QtGui[48425]
#define sipNameNr_WordLeft 48434
#define sipName_WordLeft &sipStrings_QtGui[48434]
#define sipNameNr_WordWrap 48443
#define sipName_WordWrap &sipStrings_QtGui[48443]
#define sipNameNr_WrapMode 6871
#define sipName_WrapMode &sipStrings_QtGui[6871]
#define sipNameNr_YUV420SP 48452
#define sipName_YUV420SP &sipStrings_QtGui[48452]
#define sipNameNr___bool__ 48461
#define sipName___bool__ &sipStrings_QtGui[48461]
#define sipNameNr___exit__ 48470
#define sipName___exit__ &sipStrings_QtGui[48470]
#define sipNameNr___hash__ 48479
#define sipName___hash__ &sipStrings_QtGui[48479]
#define sipNameNr___iadd__ 48488
#define sipName___iadd__ &sipStrings_QtGui[48488]
#define sipNameNr___iand__ 48497
#define sipName___iand__ &sipStrings_QtGui[48497]
#define sipNameNr___imul__ 48506
#define sipName___imul__ &sipStrings_QtGui[48506]
#define sipNameNr___isub__ 48515
#define sipName___isub__ &sipStrings_QtGui[48515]
#define sipNameNr___ixor__ 48524
#define sipName___ixor__ &sipStrings_QtGui[48524]
#define sipNameNr___repr__ 48533
#define sipName___repr__ &sipStrings_QtGui[48533]
#define sipNameNr_allocate 48542
#define sipName_allocate &sipStrings_QtGui[48542]
#define sipNameNr_anchorAt 48551
#define sipName_anchorAt &sipStrings_QtGui[48551]
#define sipNameNr_baseSize 48560
#define sipName_baseSize &sipStrings_QtGui[48560]
#define sipNameNr_blueSize 48569
#define sipName_blueSize &sipStrings_QtGui[48569]
#define sipNameNr_bufferId 48578
#define sipName_bufferId &sipStrings_QtGui[48578]
#define sipNameNr_cacheKey 48587
#define sipName_cacheKey &sipStrings_QtGui[48587]
#define sipNameNr_canWrite 8628
#define sipName_canWrite &sipStrings_QtGui[8628]
#define sipNameNr_capStyle 48596
#define sipName_capStyle &sipStrings_QtGui[48596]
#define sipNameNr_capacity 48605
#define sipName_capacity &sipStrings_QtGui[48605]
#define sipNameNr_clipPath 48614
#define sipName_clipPath &sipStrings_QtGui[48614]
#define sipNameNr_clipRect 48623
#define sipName_clipRect &sipStrings_QtGui[48623]
#define sipNameNr_contains 48632
#define sipName_contains &sipStrings_QtGui[48632]
#define sipNameNr_cornsilk 48641
#define sipName_cornsilk &sipStrings_QtGui[48641]
#define sipNameNr_cyanSize 48650
#define sipName_cyanSize &sipStrings_QtGui[48650]
#define sipNameNr_darkblue 48659
#define sipName_darkblue &sipStrings_QtGui[48659]
#define sipNameNr_darkcyan 48668
#define sipName_darkcyan &sipStrings_QtGui[48668]
#define sipNameNr_darkgray 48677
#define sipName_darkgray &sipStrings_QtGui[48677]
#define sipNameNr_darkgrey 48686
#define sipName_darkgrey &sipStrings_QtGui[48686]
#define sipNameNr_decimals 48695
#define sipName_decimals &sipStrings_QtGui[48695]
#define sipNameNr_deeppink 48704
#define sipName_deeppink &sipStrings_QtGui[48704]
#define sipNameNr_document 48713
#define sipName_document &sipStrings_QtGui[48713]
#define sipNameNr_drawLine 48722
#define sipName_drawLine &sipStrings_QtGui[48722]
#define sipNameNr_drawPath 48731
#define sipName_drawPath &sipStrings_QtGui[48731]
#define sipNameNr_drawRect 48740
#define sipName_drawRect &sipStrings_QtGui[48740]
#define sipNameNr_drawText 48749
#define sipName_drawText &sipStrings_QtGui[48749]
#define sipNameNr_encoding 48758
#define sipName_encoding &sipStrings_QtGui[48758]
#define sipNameNr_endPaint 48767
#define sipName_endPaint &sipStrings_QtGui[48767]
#define sipNameNr_families 48776
#define sipName_families &sipStrings_QtGui[48776]
#define sipNameNr_farPlane 48785
#define sipName_farPlane &sipStrings_QtGui[48785]
#define sipNameNr_features 48794
#define sipName_features &sipStrings_QtGui[48794]
#define sipNameNr_fileName 48803
#define sipName_fileName &sipStrings_QtGui[48803]
#define sipNameNr_filePath 48812
#define sipName_filePath &sipStrings_QtGui[48812]
#define sipNameNr_fillPath 48821
#define sipName_fillPath &sipStrings_QtGui[48821]
#define sipNameNr_fillRect 48830
#define sipName_fillRect &sipStrings_QtGui[48830]
#define sipNameNr_fillRule 48839
#define sipName_fillRule &sipStrings_QtGui[48839]
#define sipNameNr_finished 48848
#define sipName_finished &sipStrings_QtGui[48848]
#define sipNameNr_fontInfo 48857
#define sipName_fontInfo &sipStrings_QtGui[48857]
#define sipNameNr_formatAt 48866
#define sipName_formatAt &sipStrings_QtGui[48866]
#define sipNameNr_fragment 48875
#define sipName_fragment &sipStrings_QtGui[48875]
#define sipNameNr_fromAxes 48884
#define sipName_fromAxes &sipStrings_QtGui[48884]
#define sipNameNr_fromCmyk 48893
#define sipName_fromCmyk &sipStrings_QtGui[48893]
#define sipNameNr_fromData 48902
#define sipName_fromData &sipStrings_QtGui[48902]
#define sipNameNr_fromFont 48911
#define sipName_fromFont &sipStrings_QtGui[48911]
#define sipNameNr_fromHslF 48920
#define sipName_fromHslF &sipStrings_QtGui[48920]
#define sipNameNr_fromHsvF 48929
#define sipName_fromHsvF &sipStrings_QtGui[48929]
#define sipNameNr_fromHtml 48938
#define sipName_fromHtml &sipStrings_QtGui[48938]
#define sipNameNr_fromRgbF 48947
#define sipName_fromRgbF &sipStrings_QtGui[48947]
#define sipNameNr_fromRgba 48956
#define sipName_fromRgba &sipStrings_QtGui[48956]
#define sipNameNr_fullRect 48965
#define sipName_fullRect &sipStrings_QtGui[48965]
#define sipNameNr_geometry 48974
#define sipName_geometry &sipStrings_QtGui[48974]
#define sipNameNr_getCmykF 48983
#define sipName_getCmykF &sipStrings_QtGui[48983]
#define sipNameNr_gotFocus 48992
#define sipName_gotFocus &sipStrings_QtGui[48992]
#define sipNameNr_gradient 49001
#define sipName_gradient &sipStrings_QtGui[49001]
#define sipNameNr_hasAlpha 49010
#define sipName_hasAlpha &sipStrings_QtGui[49010]
#define sipNameNr_heightMM 49019
#define sipName_heightMM &sipStrings_QtGui[49019]
#define sipNameNr_honeydew 49028
#define sipName_honeydew &sipStrings_QtGui[49028]
#define sipNameNr_iconName 49037
#define sipName_iconName &sipStrings_QtGui[49037]
#define sipNameNr_inverted 49046
#define sipName_inverted &sipStrings_QtGui[49046]
#define sipNameNr_ioDevice 49055
#define sipName_ioDevice &sipStrings_QtGui[49055]
#define sipNameNr_isActive 49064
#define sipName_isActive &sipStrings_QtGui[49064]
#define sipNameNr_isAffine 49073
#define sipName_isAffine &sipStrings_QtGui[49073]
#define sipNameNr_isAnchor 49082
#define sipName_isAnchor &sipStrings_QtGui[49082]
#define sipNameNr_isClosed 49091
#define sipName_isClosed &sipStrings_QtGui[49091]
#define sipNameNr_isCopyOf 49100
#define sipName_isCopyOf &sipStrings_QtGui[49100]
#define sipNameNr_isLineTo 49109
#define sipName_isLineTo &sipStrings_QtGui[49109]
#define sipNameNr_isLinked 49118
#define sipName_isLinked &sipStrings_QtGui[49118]
#define sipNameNr_isMoveTo 49127
#define sipName_isMoveTo &sipStrings_QtGui[49127]
#define sipNameNr_isOpaque 49136
#define sipName_isOpaque &sipStrings_QtGui[49136]
#define sipNameNr_isPhase2 49145
#define sipName_isPhase2 &sipStrings_QtGui[49145]
#define sipNameNr_itemData 49154
#define sipName_itemData &sipStrings_QtGui[49154]
#define sipNameNr_itemText 49163
#define sipName_itemText &sipStrings_QtGui[49163]
#define sipNameNr_iterator 12211
#define sipName_iterator &sipStrings_QtGui[12211]
#define sipNameNr_lavender 49172
#define sipName_lavender &sipStrings_QtGui[49172]
#define sipNameNr_localPos 49181
#define sipName_localPos &sipStrings_QtGui[49181]
#define sipNameNr_magentaF 49190
#define sipName_magentaF &sipStrings_QtGui[49190]
#define sipNameNr_mapRange 49199
#define sipName_mapRange &sipStrings_QtGui[49199]
#define sipNameNr_maxWidth 49208
#define sipName_maxWidth &sipStrings_QtGui[49208]
#define sipNameNr_midlight 49217
#define sipName_midlight &sipStrings_QtGui[49217]
#define sipNameNr_mimeData 49226
#define sipName_mimeData &sipStrings_QtGui[49226]
#define sipNameNr_mimeType 49235
#define sipName_mimeType &sipStrings_QtGui[49235]
#define sipNameNr_mirrored 49244
#define sipName_mirrored &sipStrings_QtGui[49244]
#define sipNameNr_mnemonic 3644
#define sipName_mnemonic &sipStrings_QtGui[3644]
#define sipNameNr_moccasin 49253
#define sipName_moccasin &sipStrings_QtGui[49253]
#define sipNameNr_modality 49262
#define sipName_modality &sipStrings_QtGui[49262]
#define sipNameNr_moveRows 44006
#define sipName_moveRows &sipStrings_QtGui[44006]
#define sipNameNr_notation 49271
#define sipName_notation &sipStrings_QtGui[49271]
#define sipNameNr_objectId 49280
#define sipName_objectId &sipStrings_QtGui[49280]
#define sipNameNr_oldState 49289
#define sipName_oldState &sipStrings_QtGui[49289]
#define sipNameNr_openFile 49298
#define sipName_openFile &sipStrings_QtGui[49298]
#define sipNameNr_optimize 49307
#define sipName_optimize &sipStrings_QtGui[49307]
#define sipNameNr_overline 49316
#define sipName_overline &sipStrings_QtGui[49316]
#define sipNameNr_pageSize 49325
#define sipName_pageSize &sipStrings_QtGui[49325]
#define sipNameNr_popGroup 49334
#define sipName_popGroup &sipStrings_QtGui[49334]
#define sipNameNr_position 49343
#define sipName_position &sipStrings_QtGui[49343]
#define sipNameNr_pressure 49352
#define sipName_pressure &sipStrings_QtGui[49352]
#define sipNameNr_previous 49361
#define sipName_previous &sipStrings_QtGui[49361]
#define sipNameNr_property 49370
#define sipName_property &sipStrings_QtGui[49370]
#define sipNameNr_rawValue 49379
#define sipName_rawValue &sipStrings_QtGui[49379]
#define sipNameNr_resizeGL 49388
#define sipName_resizeGL &sipStrings_QtGui[49388]
#define sipNameNr_resource 49397
#define sipName_resource &sipStrings_QtGui[49397]
#define sipNameNr_revision 49406
#define sipName_revision &sipStrings_QtGui[49406]
#define sipNameNr_rotation 49415
#define sipName_rotation &sipStrings_QtGui[49415]
#define sipNameNr_rowCount 49424
#define sipName_rowCount &sipStrings_QtGui[49424]
#define sipNameNr_rowStart 49433
#define sipName_rowStart &sipStrings_QtGui[49433]
#define sipNameNr_scanLine 49442
#define sipName_scanLine &sipStrings_QtGui[49442]
#define sipNameNr_scenePos 49451
#define sipName_scenePos &sipStrings_QtGui[49451]
#define sipNameNr_screenAt 49460
#define sipName_screenAt &sipStrings_QtGui[49460]
#define sipNameNr_seagreen 28418
#define sipName_seagreen &sipStrings_QtGui[28418]
#define sipNameNr_seashell 49469
#define sipName_seashell &sipStrings_QtGui[49469]
#define sipNameNr_setAlpha 49478
#define sipName_setAlpha &sipStrings_QtGui[49478]
#define sipNameNr_setAngle 49487
#define sipName_setAngle &sipStrings_QtGui[49487]
#define sipNameNr_setBlueF 49496
#define sipName_setBlueF &sipStrings_QtGui[49496]
#define sipNameNr_setBrush 49505
#define sipName_setBrush &sipStrings_QtGui[49505]
#define sipNameNr_setChild 49514
#define sipName_setChild &sipStrings_QtGui[49514]
#define sipNameNr_setCmykF 49523
#define sipName_setCmykF &sipStrings_QtGui[49523]
#define sipNameNr_setCodec 49532
#define sipName_setCodec &sipStrings_QtGui[49532]
#define sipNameNr_setColor 49541
#define sipName_setColor &sipStrings_QtGui[49541]
#define sipNameNr_setFlags 49550
#define sipName_setFlags &sipStrings_QtGui[49550]
#define sipNameNr_setGamma 49559
#define sipName_setGamma &sipStrings_QtGui[49559]
#define sipNameNr_setGreen 49568
#define sipName_setGreen &sipStrings_QtGui[49568]
#define sipNameNr_setImage 49577
#define sipName_setImage &sipStrings_QtGui[49577]
#define sipNameNr_setPixel 49586
#define sipName_setPixel &sipStrings_QtGui[49586]
#define sipNameNr_setPoint 49595
#define sipName_setPoint &sipStrings_QtGui[49595]
#define sipNameNr_setRange 49604
#define sipName_setRange &sipStrings_QtGui[49604]
#define sipNameNr_setRects 49613
#define sipName_setRects &sipStrings_QtGui[49613]
#define sipNameNr_setShape 49622
#define sipName_setShape &sipStrings_QtGui[49622]
#define sipNameNr_setSpeed 49631
#define sipName_setSpeed &sipStrings_QtGui[49631]
#define sipNameNr_setStart 49640
#define sipName_setStart &sipStrings_QtGui[49640]
#define sipNameNr_setStops 49649
#define sipName_setStops &sipStrings_QtGui[49649]
#define sipNameNr_setStyle 49658
#define sipName_setStyle &sipStrings_QtGui[49658]
#define sipNameNr_setTitle 49667
#define sipName_setTitle &sipStrings_QtGui[49667]
#define sipNameNr_setUnits 49676
#define sipName_setUnits &sipStrings_QtGui[49676]
#define sipNameNr_setValue 49685
#define sipName_setValue &sipStrings_QtGui[49685]
#define sipNameNr_setWidth 49694
#define sipName_setWidth &sipStrings_QtGui[49694]
#define sipNameNr_severity 49703
#define sipName_severity &sipStrings_QtGui[49703]
#define sipNameNr_shaderId 49712
#define sipName_shaderId &sipStrings_QtGui[49712]
#define sipNameNr_sizeHint 49721
#define sipName_sizeHint &sipStrings_QtGui[49721]
#define sipNameNr_skipRows 49730
#define sipName_skipRows &sipStrings_QtGui[49730]
#define sipNameNr_sortRole 49739
#define sipName_sortRole &sipStrings_QtGui[49739]
#define sipNameNr_startPos 49748
#define sipName_startPos &sipStrings_QtGui[49748]
#define sipNameNr_strategy 49757
#define sipName_strategy &sipStrings_QtGui[49757]
#define sipNameNr_tabArray 49766
#define sipName_tabArray &sipStrings_QtGui[49766]
#define sipNameNr_tabStops 49775
#define sipName_tabStops &sipStrings_QtGui[49775]
#define sipNameNr_takeItem 49784
#define sipName_takeItem &sipStrings_QtGui[49784]
#define sipNameNr_textKeys 49793
#define sipName_textKeys &sipStrings_QtGui[49793]
#define sipNameNr_textList 49802
#define sipName_textList &sipStrings_QtGui[49802]
#define sipNameNr_textures 49811
#define sipName_textures &sipStrings_QtGui[49811]
#define sipNameNr_toArgb32 49820
#define sipName_toArgb32 &sipStrings_QtGui[49820]
#define sipNameNr_toPointF 49829
#define sipName_toPointF &sipStrings_QtGui[49829]
#define sipNameNr_toString 49838
#define sipName_toString &sipStrings_QtGui[49838]
#define sipNameNr_uniqueId 49847
#define sipName_uniqueId &sipStrings_QtGui[49847]
#define sipNameNr_userData 49856
#define sipName_userData &sipStrings_QtGui[49856]
#define sipNameNr_validate 24088
#define sipName_validate &sipStrings_QtGui[24088]
#define sipNameNr_velocity 49865
#define sipName_velocity &sipStrings_QtGui[49865]
#define sipNameNr_vertical 49874
#define sipName_vertical &sipStrings_QtGui[49874]
#define sipNameNr_viewport 49883
#define sipName_viewport &sipStrings_QtGui[49883]
#define sipNameNr_wrapMode 49892
#define sipName_wrapMode &sipStrings_QtGui[49892]
#define sipNameNr_xChanged 49901
#define sipName_xChanged &sipStrings_QtGui[49901]
#define sipNameNr_yChanged 7196
#define sipName_yChanged &sipStrings_QtGui[7196]
#define sipNameNr_A3Extra 49910
#define sipName_A3Extra &sipStrings_QtGui[49910]
#define sipNameNr_A4Extra 49918
#define sipName_A4Extra &sipStrings_QtGui[49918]
#define sipNameNr_A4Small 49926
#define sipName_A4Small &sipStrings_QtGui[49926]
#define sipNameNr_A5Extra 49934
#define sipName_A5Extra &sipStrings_QtGui[49934]
#define sipNameNr_AnyType 49942
#define sipName_AnyType &sipStrings_QtGui[49942]
#define sipNameNr_B5Extra 49950
#define sipName_B5Extra &sipStrings_QtGui[49950]
#define sipNameNr_Bengali 49958
#define sipName_Bengali &sipStrings_QtGui[49958]
#define sipNameNr_Blitter 10299
#define sipName_Blitter &sipStrings_QtGui[10299]
#define sipNameNr_Checked 49966
#define sipName_Checked &sipStrings_QtGui[49966]
#define sipNameNr_Comm10E 49974
#define sipName_Comm10E &sipStrings_QtGui[49974]
#define sipNameNr_Compute 49982
#define sipName_Compute &sipStrings_QtGui[49982]
#define sipNameNr_Courier 49990
#define sipName_Courier &sipStrings_QtGui[49990]
#define sipNameNr_Current 39144
#define sipName_Current &sipStrings_QtGui[39144]
#define sipNameNr_Cursive 49998
#define sipName_Cursive &sipStrings_QtGui[49998]
#define sipNameNr_DarkRed 50006
#define sipName_DarkRed &sipStrings_QtGui[50006]
#define sipNameNr_DotLine 26529
#define sipName_DotLine &sipStrings_QtGui[26529]
#define sipNameNr_Element 10387
#define sipName_Element &sipStrings_QtGui[10387]
#define sipNameNr_Ellipse 39156
#define sipName_Ellipse &sipStrings_QtGui[39156]
#define sipNameNr_Fantasy 50014
#define sipName_Fantasy &sipStrings_QtGui[50014]
#define sipNameNr_Feature 1530
#define sipName_Feature &sipStrings_QtGui[1530]
#define sipNameNr_Float16 50022
#define sipName_Float16 &sipStrings_QtGui[50022]
#define sipNameNr_Float32 50030
#define sipName_Float32 &sipStrings_QtGui[50030]
#define sipNameNr_FlyHigh 50038
#define sipName_FlyHigh &sipStrings_QtGui[50038]
#define sipNameNr_Forward 50046
#define sipName_Forward &sipStrings_QtGui[50046]
#define sipNameNr_HexArgb 50054
#define sipName_HexArgb &sipStrings_QtGui[50054]
#define sipNameNr_Indexed 50062
#define sipName_Indexed &sipStrings_QtGui[50062]
#define sipNameNr_Invalid 26634
#define sipName_Invalid &sipStrings_QtGui[26634]
#define sipNameNr_Kannada 50070
#define sipName_Kannada &sipStrings_QtGui[50070]
#define sipNameNr_Leading 50078
#define sipName_Leading &sipStrings_QtGui[50078]
#define sipNameNr_LeftTab 50086
#define sipName_LeftTab &sipStrings_QtGui[50086]
#define sipNameNr_LibGLES 50094
#define sipName_LibGLES &sipStrings_QtGui[50094]
#define sipNameNr_Magenta 37512
#define sipName_Magenta &sipStrings_QtGui[37512]
#define sipNameNr_Margins 5227
#define sipName_Margins &sipStrings_QtGui[5227]
#define sipNameNr_MaxUser 50102
#define sipName_MaxUser &sipStrings_QtGui[50102]
#define sipNameNr_Myanmar 50110
#define sipName_Myanmar &sipStrings_QtGui[50110]
#define sipNameNr_Nearest 11960
#define sipName_Nearest &sipStrings_QtGui[11960]
#define sipNameNr_NewLife 50118
#define sipName_NewLife &sipStrings_QtGui[50118]
#define sipNameNr_NewYork 50126
#define sipName_NewYork &sipStrings_QtGui[50126]
#define sipNameNr_NextRow 50134
#define sipName_NextRow &sipStrings_QtGui[50134]
#define sipNameNr_NoMatch 50142
#define sipName_NoMatch &sipStrings_QtGui[50142]
#define sipNameNr_OpenGL2 50150
#define sipName_OpenGL2 &sipStrings_QtGui[50150]
#define sipNameNr_OverSun 50158
#define sipName_OverSun &sipStrings_QtGui[50158]
#define sipNameNr_PdmDpiX 50166
#define sipName_PdmDpiX &sipStrings_QtGui[50166]
#define sipNameNr_PdmDpiY 50174
#define sipName_PdmDpiY &sipStrings_QtGui[50174]
#define sipNameNr_Picture 39168
#define sipName_Picture &sipStrings_QtGui[39168]
#define sipNameNr_QAction 50182
#define sipName_QAction &sipStrings_QtGui[50182]
#define sipNameNr_QBitmap 46586
#define sipName_QBitmap &sipStrings_QtGui[46586]
#define sipNameNr_QCursor 50190
#define sipName_QCursor &sipStrings_QtGui[50190]
#define sipNameNr_QPixmap 50198
#define sipName_QPixmap &sipStrings_QtGui[50198]
#define sipNameNr_QRegion 50206
#define sipName_QRegion &sipStrings_QtGui[50206]
#define sipNameNr_QRgba64 50214
#define sipName_QRgba64 &sipStrings_QtGui[50214]
#define sipNameNr_QScreen 50222
#define sipName_QScreen &sipStrings_QtGui[50222]
#define sipNameNr_QWindow 50230
#define sipName_QWindow &sipStrings_QtGui[50230]
#define sipNameNr_Quality 30394
#define sipName_Quality &sipStrings_QtGui[30394]
#define sipNameNr_RGB10A2 27519
#define sipName_RGB10A2 &sipStrings_QtGui[27519]
#define sipNameNr_RGBA16F 50238
#define sipName_RGBA16F &sipStrings_QtGui[50238]
#define sipNameNr_RGBA16I 50246
#define sipName_RGBA16I &sipStrings_QtGui[50246]
#define sipNameNr_RGBA16U 50254
#define sipName_RGBA16U &sipStrings_QtGui[50254]
#define sipNameNr_RGBA32F 50262
#define sipName_RGBA32F &sipStrings_QtGui[50262]
#define sipNameNr_RGBA32I 50270
#define sipName_RGBA32I &sipStrings_QtGui[50270]
#define sipNameNr_RGBA32U 50278
#define sipName_RGBA32U &sipStrings_QtGui[50278]
#define sipNameNr_Refresh 50286
#define sipName_Refresh &sipStrings_QtGui[50286]
#define sipNameNr_Replace 50294
#define sipName_Replace &sipStrings_QtGui[50294]
#define sipNameNr_Running 21447
#define sipName_Running &sipStrings_QtGui[21447]
#define sipNameNr_SeaLord 50302
#define sipName_SeaLord &sipStrings_QtGui[50302]
#define sipNameNr_Sinhala 50310
#define sipName_Sinhala &sipStrings_QtGui[50310]
#define sipNameNr_Sources 3907
#define sipName_Sources &sipStrings_QtGui[3907]
#define sipNameNr_Stencil 11834
#define sipName_Stencil &sipStrings_QtGui[11834]
#define sipNameNr_Stretch 27054
#define sipName_Stretch &sipStrings_QtGui[27054]
#define sipNameNr_SubType 44359
#define sipName_SubType &sipStrings_QtGui[44359]
#define sipNameNr_Swizzle 20144
#define sipName_Swizzle &sipStrings_QtGui[20144]
#define sipNameNr_TabType 12275
#define sipName_TabType &sipStrings_QtGui[12275]
#define sipNameNr_Tabloid 50318
#define sipName_Tabloid &sipStrings_QtGui[50318]
#define sipNameNr_Tibetan 50326
#define sipName_Tibetan &sipStrings_QtGui[50326]
#define sipNameNr_TxScale 50334
#define sipName_TxScale &sipStrings_QtGui[50334]
#define sipNameNr_TxShear 50342
#define sipName_TxShear &sipStrings_QtGui[50342]
#define sipNameNr_Windows 26297
#define sipName_Windows &sipStrings_QtGui[26297]
#define sipNameNr_YUV420P 50350
#define sipName_YUV420P &sipStrings_QtGui[50350]
#define sipNameNr_ZoomOut 50358
#define sipName_ZoomOut &sipStrings_QtGui[50358]
#define sipNameNr___add__ 50366
#define sipName___add__ &sipStrings_QtGui[50366]
#define sipNameNr___and__ 50374
#define sipName___and__ &sipStrings_QtGui[50374]
#define sipNameNr___int__ 50382
#define sipName___int__ &sipStrings_QtGui[50382]
#define sipNameNr___ior__ 50390
#define sipName___ior__ &sipStrings_QtGui[50390]
#define sipNameNr___len__ 50398
#define sipName___len__ &sipStrings_QtGui[50398]
#define sipNameNr___mul__ 50406
#define sipName___mul__ &sipStrings_QtGui[50406]
#define sipNameNr___neg__ 50414
#define sipName___neg__ &sipStrings_QtGui[50414]
#define sipNameNr___sub__ 50422
#define sipName___sub__ &sipStrings_QtGui[50422]
#define sipNameNr___xor__ 50430
#define sipName___xor__ &sipStrings_QtGui[50430]
#define sipNameNr_addFile 50438
#define sipName_addFile &sipStrings_QtGui[50438]
#define sipNameNr_addPath 50446
#define sipName_addPath &sipStrings_QtGui[50446]
#define sipNameNr_addRect 50454
#define sipName_addRect &sipStrings_QtGui[50454]
#define sipNameNr_addText 50462
#define sipName_addText &sipStrings_QtGui[50462]
#define sipNameNr_adjoint 50470
#define sipName_adjoint &sipStrings_QtGui[50470]
#define sipNameNr_allGray 50478
#define sipName_allGray &sipStrings_QtGui[50478]
#define sipNameNr_atStart 50486
#define sipName_atStart &sipStrings_QtGui[50486]
#define sipNameNr_autorep 50494
#define sipName_autorep &sipStrings_QtGui[50494]
#define sipNameNr_baseUrl 50502
#define sipName_baseUrl &sipStrings_QtGui[50502]
#define sipNameNr_buffers 50510
#define sipName_buffers &sipStrings_QtGui[50510]
#define sipNameNr_buttons 50518
#define sipName_buttons &sipStrings_QtGui[50518]
#define sipNameNr_canRead 50526
#define sipName_canRead &sipStrings_QtGui[50526]
#define sipNameNr_changed 50534
#define sipName_changed &sipStrings_QtGui[50534]
#define sipNameNr_cleanup 50542
#define sipName_cleanup &sipStrings_QtGui[50542]
#define sipNameNr_columns 50550
#define sipName_columns &sipStrings_QtGui[50550]
#define sipNameNr_combine 50558
#define sipName_combine &sipStrings_QtGui[50558]
#define sipNameNr_context 50566
#define sipName_context &sipStrings_QtGui[50566]
#define sipNameNr_creator 50574
#define sipName_creator &sipStrings_QtGui[50574]
#define sipNameNr_crimson 50582
#define sipName_crimson &sipStrings_QtGui[50582]
#define sipNameNr_cubicTo 50590
#define sipName_cubicTo &sipStrings_QtGui[50590]
#define sipNameNr_darkred 50598
#define sipName_darkred &sipStrings_QtGui[50598]
#define sipNameNr_descent 50606
#define sipName_descent &sipStrings_QtGui[50606]
#define sipNameNr_destroy 50614
#define sipName_destroy &sipStrings_QtGui[50614]
#define sipNameNr_devType 50622
#define sipName_devType &sipStrings_QtGui[50622]
#define sipNameNr_devices 50630
#define sipName_devices &sipStrings_QtGui[50630]
#define sipNameNr_dimgray 50638
#define sipName_dimgray &sipStrings_QtGui[50638]
#define sipNameNr_dimgrey 50646
#define sipName_dimgrey &sipStrings_QtGui[50646]
#define sipNameNr_drawArc 50654
#define sipName_drawArc &sipStrings_QtGui[50654]
#define sipNameNr_drawPie 50662
#define sipName_drawPie &sipStrings_QtGui[50662]
#define sipNameNr_enabled 50670
#define sipName_enabled &sipStrings_QtGui[50670]
#define sipNameNr_exposed 50678
#define sipName_exposed &sipStrings_QtGui[50678]
#define sipNameNr_fontDpi 50686
#define sipName_fontDpi &sipStrings_QtGui[50686]
#define sipNameNr_formats 50694
#define sipName_formats &sipStrings_QtGui[50694]
#define sipNameNr_fromHsl 50702
#define sipName_fromHsl &sipStrings_QtGui[50702]
#define sipNameNr_fromHsv 50710
#define sipName_fromHsv &sipStrings_QtGui[50710]
#define sipNameNr_fromRgb 50718
#define sipName_fromRgb &sipStrings_QtGui[50718]
#define sipNameNr_frustum 50726
#define sipName_frustum &sipStrings_QtGui[50726]
#define sipNameNr_fuchsia 50734
#define sipName_fuchsia &sipStrings_QtGui[50734]
#define sipNameNr_getAxes 50742
#define sipName_getAxes &sipStrings_QtGui[50742]
#define sipNameNr_getCmyk 50750
#define sipName_getCmyk &sipStrings_QtGui[50750]
#define sipNameNr_getHslF 50758
#define sipName_getHslF &sipStrings_QtGui[50758]
#define sipNameNr_getHsvF 50766
#define sipName_getHsvF &sipStrings_QtGui[50766]
#define sipNameNr_getRgbF 50774
#define sipName_getRgbF &sipStrings_QtGui[50774]
#define sipNameNr_globalX 50782
#define sipName_globalX &sipStrings_QtGui[50782]
#define sipNameNr_globalY 50790
#define sipName_globalY &sipStrings_QtGui[50790]
#define sipNameNr_hitTest 50798
#define sipName_hitTest &sipStrings_QtGui[50798]
#define sipNameNr_hotSpot 50806
#define sipName_hotSpot &sipStrings_QtGui[50806]
#define sipNameNr_hotpink 50814
#define sipName_hotpink &sipStrings_QtGui[50814]
#define sipNameNr_hslHueF 50822
#define sipName_hslHueF &sipStrings_QtGui[50822]
#define sipNameNr_hsvHueF 50830
#define sipName_hsvHueF &sipStrings_QtGui[50830]
#define sipNameNr_hueSize 50838
#define sipName_hueSize &sipStrings_QtGui[50838]
#define sipNameNr_imageAt 50846
#define sipName_imageAt &sipStrings_QtGui[50846]
#define sipNameNr_indexOf 50854
#define sipName_indexOf &sipStrings_QtGui[50854]
#define sipNameNr_isBound 50862
#define sipName_isBound &sipStrings_QtGui[50862]
#define sipNameNr_isEmpty 50870
#define sipName_isEmpty &sipStrings_QtGui[50870]
#define sipNameNr_isEqual 50878
#define sipName_isEqual &sipStrings_QtGui[50878]
#define sipNameNr_isModal 50886
#define sipName_isModal &sipStrings_QtGui[50886]
#define sipNameNr_isSolid 50894
#define sipName_isSolid &sipStrings_QtGui[50894]
#define sipNameNr_isValid 50902
#define sipName_isValid &sipStrings_QtGui[50902]
#define sipNameNr_kerning 50910
#define sipName_kerning &sipStrings_QtGui[50910]
#define sipNameNr_lastPos 50918
#define sipName_lastPos &sipStrings_QtGui[50918]
#define sipNameNr_leading 50926
#define sipName_leading &sipStrings_QtGui[50926]
#define sipNameNr_lighter 16015
#define sipName_lighter &sipStrings_QtGui[16015]
#define sipNameNr_magenta 39060
#define sipName_magenta &sipStrings_QtGui[39060]
#define sipNameNr_mapRect 50934
#define sipName_mapRect &sipStrings_QtGui[50934]
#define sipNameNr_margins 50942
#define sipName_margins &sipStrings_QtGui[50942]
#define sipNameNr_matches 50950
#define sipName_matches &sipStrings_QtGui[50950]
#define sipNameNr_message 50958
#define sipName_message &sipStrings_QtGui[50958]
#define sipNameNr_newPage 50966
#define sipName_newPage &sipStrings_QtGui[50966]
#define sipNameNr_oldPosF 50974
#define sipName_oldPosF &sipStrings_QtGui[50974]
#define sipNameNr_oldSize 50982
#define sipName_oldSize &sipStrings_QtGui[50982]
#define sipNameNr_oldlace 50990
#define sipName_oldlace &sipStrings_QtGui[50990]
#define sipNameNr_opacity 50998
#define sipName_opacity &sipStrings_QtGui[50998]
#define sipNameNr_openUrl 51006
#define sipName_openUrl &sipStrings_QtGui[51006]
#define sipNameNr_options 51014
#define sipName_options &sipStrings_QtGui[51014]
#define sipNameNr_padding 51022
#define sipName_padding &sipStrings_QtGui[51022]
#define sipNameNr_paintGL 51030
#define sipName_paintGL &sipStrings_QtGui[51030]
#define sipNameNr_painter 51038
#define sipName_painter &sipStrings_QtGui[51038]
#define sipNameNr_palette 51046
#define sipName_palette &sipStrings_QtGui[51046]
#define sipNameNr_picture 51054
#define sipName_picture &sipStrings_QtGui[51054]
#define sipNameNr_prepare 51062
#define sipName_prepare &sipStrings_QtGui[51062]
#define sipNameNr_prepend 51070
#define sipName_prepend &sipStrings_QtGui[51070]
#define sipNameNr_profile 51078
#define sipName_profile &sipStrings_QtGui[51078]
#define sipNameNr_project 47726
#define sipName_project &sipStrings_QtGui[47726]
#define sipNameNr_qIsGray 51086
#define sipName_qIsGray &sipStrings_QtGui[51086]
#define sipNameNr_qRgba64 51094
#define sipName_qRgba64 &sipStrings_QtGui[51094]
#define sipNameNr_quality 51102
#define sipName_quality &sipStrings_QtGui[51102]
#define sipNameNr_queries 51110
#define sipName_queries &sipStrings_QtGui[51110]
#define sipNameNr_rawFont 51118
#define sipName_rawFont &sipStrings_QtGui[51118]
#define sipNameNr_rawMode 3315
#define sipName_rawMode &sipStrings_QtGui[3315]
#define sipNameNr_rawName 51126
#define sipName_rawName &sipStrings_QtGui[51126]
#define sipNameNr_redSize 51134
#define sipName_redSize &sipStrings_QtGui[51134]
#define sipNameNr_release 51142
#define sipName_release &sipStrings_QtGui[51142]
#define sipNameNr_replace 51150
#define sipName_replace &sipStrings_QtGui[51150]
#define sipNameNr_reserve 51158
#define sipName_reserve &sipStrings_QtGui[51158]
#define sipNameNr_resized 51166
#define sipName_resized &sipStrings_QtGui[51166]
#define sipNameNr_resolve 51174
#define sipName_resolve &sipStrings_QtGui[51174]
#define sipNameNr_restore 51182
#define sipName_restore &sipStrings_QtGui[51182]
#define sipNameNr_rowSpan 51190
#define sipName_rowSpan &sipStrings_QtGui[51190]
#define sipNameNr_samples 51198
#define sipName_samples &sipStrings_QtGui[51198]
#define sipNameNr_scaling 51206
#define sipName_scaling &sipStrings_QtGui[51206]
#define sipNameNr_screens 51214
#define sipName_screens &sipStrings_QtGui[51214]
#define sipNameNr_setBlue 51222
#define sipName_setBlue &sipStrings_QtGui[51222]
#define sipNameNr_setBold 51230
#define sipName_setBold &sipStrings_QtGui[51230]
#define sipNameNr_setCmyk 51238
#define sipName_setCmyk &sipStrings_QtGui[51238]
#define sipNameNr_setData 51246
#define sipName_setData &sipStrings_QtGui[51246]
#define sipNameNr_setFlag 51254
#define sipName_setFlag &sipStrings_QtGui[51254]
#define sipNameNr_setFont 51262
#define sipName_setFont &sipStrings_QtGui[51262]
#define sipNameNr_setHslF 51270
#define sipName_setHslF &sipStrings_QtGui[51270]
#define sipNameNr_setHsvF 51278
#define sipName_setHsvF &sipStrings_QtGui[51278]
#define sipNameNr_setHtml 51286
#define sipName_setHtml &sipStrings_QtGui[51286]
#define sipNameNr_setIcon 51294
#define sipName_setIcon &sipStrings_QtGui[51294]
#define sipNameNr_setItem 51302
#define sipName_setItem &sipStrings_QtGui[51302]
#define sipNameNr_setMask 51310
#define sipName_setMask &sipStrings_QtGui[51310]
#define sipNameNr_setMode 51318
#define sipName_setMode &sipStrings_QtGui[51318]
#define sipNameNr_setName 51326
#define sipName_setName &sipStrings_QtGui[51326]
#define sipNameNr_setRedF 51334
#define sipName_setRedF &sipStrings_QtGui[51334]
#define sipNameNr_setRgbF 51342
#define sipName_setRgbF &sipStrings_QtGui[51342]
#define sipNameNr_setRgba 51350
#define sipName_setRgba &sipStrings_QtGui[51350]
#define sipNameNr_setSize 51358
#define sipName_setSize &sipStrings_QtGui[51358]
#define sipNameNr_setTabs 51366
#define sipName_setTabs &sipStrings_QtGui[51366]
#define sipNameNr_setText 51374
#define sipName_setText &sipStrings_QtGui[51374]
#define sipNameNr_setType 51382
#define sipName_setType &sipStrings_QtGui[51382]
#define sipNameNr_shaders 51390
#define sipName_shaders &sipStrings_QtGui[51390]
#define sipNameNr_sibling 51398
#define sipName_sibling &sipStrings_QtGui[51398]
#define sipNameNr_skyblue 36131
#define sipName_skyblue &sipStrings_QtGui[36131]
#define sipNameNr_sources 51406
#define sipName_sources &sipStrings_QtGui[51406]
#define sipNameNr_started 51414
#define sipName_started &sipStrings_QtGui[51414]
#define sipNameNr_stretch 51422
#define sipName_stretch &sipStrings_QtGui[51422]
#define sipNameNr_subEnum 51430
#define sipName_subEnum &sipStrings_QtGui[51430]
#define sipNameNr_subType 51438
#define sipName_subType &sipStrings_QtGui[51438]
#define sipNameNr_surface 51446
#define sipName_surface &sipStrings_QtGui[51446]
#define sipNameNr_tabStop 51454
#define sipName_tabStop &sipStrings_QtGui[51454]
#define sipNameNr_takeRow 51462
#define sipName_takeRow &sipStrings_QtGui[51462]
#define sipNameNr_texture 51470
#define sipName_texture &sipStrings_QtGui[51470]
#define sipNameNr_thistle 51478
#define sipName_thistle &sipStrings_QtGui[51478]
#define sipNameNr_toImage 51486
#define sipName_toImage &sipStrings_QtGui[51486]
#define sipNameNr_toPoint 51494
#define sipName_toPoint &sipStrings_QtGui[51494]
#define sipNameNr_toRgb16 51502
#define sipName_toRgb16 &sipStrings_QtGui[51502]
#define sipNameNr_toolTip 51510
#define sipName_toolTip &sipStrings_QtGui[51510]
#define sipNameNr_updated 51518
#define sipName_updated &sipStrings_QtGui[51518]
#define sipNameNr_version 51526
#define sipName_version &sipStrings_QtGui[51526]
#define sipNameNr_widthMM 51534
#define sipName_widthMM &sipStrings_QtGui[51534]
#define sipNameNr_xHeight 51542
#define sipName_xHeight &sipStrings_QtGui[51542]
#define sipNameNr_yellowF 51550
#define sipName_yellowF &sipStrings_QtGui[51550]
#define sipNameNr_A4Plus 51558
#define sipName_A4Plus &sipStrings_QtGui[51558]
#define sipNameNr_Access 10278
#define sipName_Access &sipStrings_QtGui[10278]
#define sipNameNr_Action 12087
#define sipName_Action &sipStrings_QtGui[12087]
#define sipNameNr_Active 28585
#define sipName_Active &sipStrings_QtGui[28585]
#define sipNameNr_AddTab 51565
#define sipName_AddTab &sipStrings_QtGui[51565]
#define sipNameNr_Arabic 51572
#define sipName_Arabic &sipStrings_QtGui[51572]
#define sipNameNr_Binder 1498
#define sipName_Binder &sipStrings_QtGui[1498]
#define sipNameNr_Button 51579
#define sipName_Button &sipStrings_QtGui[51579]
#define sipNameNr_Cancel 51586
#define sipName_Cancel &sipStrings_QtGui[51586]
#define sipNameNr_Cicero 51593
#define sipName_Cicero &sipStrings_QtGui[51593]
#define sipNameNr_Color0 51600
#define sipName_Color0 &sipStrings_QtGui[51600]
#define sipNameNr_Color1 51607
#define sipName_Color1 &sipStrings_QtGui[51607]
#define sipNameNr_Cursor 11488
#define sipName_Cursor &sipStrings_QtGui[11488]
#define sipNameNr_Custom 51614
#define sipName_Custom &sipStrings_QtGui[51614]
#define sipNameNr_Delete 51621
#define sipName_Delete &sipStrings_QtGui[51621]
#define sipNameNr_Eraser 38737
#define sipName_Eraser &sipStrings_QtGui[38737]
#define sipNameNr_Filter 9072
#define sipName_Filter &sipStrings_QtGui[9072]
#define sipNameNr_Format 2494
#define sipName_Format &sipStrings_QtGui[2494]
#define sipNameNr_Hebrew 51628
#define sipName_Hebrew &sipStrings_QtGui[51628]
#define sipNameNr_HexRgb 51635
#define sipName_HexRgb &sipStrings_QtGui[51635]
#define sipNameNr_Hidden 51642
#define sipName_Hidden &sipStrings_QtGui[51642]
#define sipNameNr_InFlow 51649
#define sipName_InFlow &sipStrings_QtGui[51649]
#define sipNameNr_Italic 32803
#define sipName_Italic &sipStrings_QtGui[32803]
#define sipNameNr_JisB10 51656
#define sipName_JisB10 &sipStrings_QtGui[51656]
#define sipNameNr_Korean 51663
#define sipName_Korean &sipStrings_QtGui[51663]
#define sipNameNr_Ledger 51670
#define sipName_Ledger &sipStrings_QtGui[51670]
#define sipNameNr_Letter 51677
#define sipName_Letter &sipStrings_QtGui[51677]
#define sipNameNr_Linear 13936
#define sipName_Linear &sipStrings_QtGui[13936]
#define sipNameNr_Medium 51684
#define sipName_Medium &sipStrings_QtGui[51684]
#define sipNameNr_NoMove 51691
#define sipName_NoMove &sipStrings_QtGui[51691]
#define sipNameNr_NoRole 51698
#define sipName_NoRole &sipStrings_QtGui[51698]
#define sipNameNr_NoWrap 51705
#define sipName_NoWrap &sipStrings_QtGui[51705]
#define sipNameNr_Normal 37285
#define sipName_Normal &sipStrings_QtGui[37285]
#define sipNameNr_OldHat 51712
#define sipName_OldHat &sipStrings_QtGui[51712]
#define sipNameNr_OpenGL 9900
#define sipName_OpenGL &sipStrings_QtGui[9900]
#define sipNameNr_OpenVG 51719
#define sipName_OpenVG &sipStrings_QtGui[51719]
#define sipNameNr_Origin 3226
#define sipName_Origin &sipStrings_QtGui[3226]
#define sipNameNr_Paused 47377
#define sipName_Paused &sipStrings_QtGui[47377]
#define sipNameNr_Prc16K 51726
#define sipName_Prc16K &sipStrings_QtGui[51726]
#define sipNameNr_Prc32K 51733
#define sipName_Prc32K &sipStrings_QtGui[51733]
#define sipNameNr_Preset 18381
#define sipName_Preset &sipStrings_QtGui[18381]
#define sipNameNr_QBrush 51740
#define sipName_QBrush &sipStrings_QtGui[51740]
#define sipNameNr_QColor 51747
#define sipName_QColor &sipStrings_QtGui[51747]
#define sipNameNr_QImage 51754
#define sipName_QImage &sipStrings_QtGui[51754]
#define sipNameNr_QMovie 51761
#define sipName_QMovie &sipStrings_QtGui[51761]
#define sipNameNr_Quarto 51768
#define sipName_Quarto &sipStrings_QtGui[51768]
#define sipNameNr_R5G6B5 31039
#define sipName_R5G6B5 &sipStrings_QtGui[31039]
#define sipNameNr_RGB16F 51775
#define sipName_RGB16F &sipStrings_QtGui[51775]
#define sipNameNr_RGB16I 51782
#define sipName_RGB16I &sipStrings_QtGui[51782]
#define sipNameNr_RGB16U 51789
#define sipName_RGB16U &sipStrings_QtGui[51789]
#define sipNameNr_RGB32F 51796
#define sipName_RGB32F &sipStrings_QtGui[51796]
#define sipNameNr_RGB32I 51803
#define sipName_RGB32I &sipStrings_QtGui[51803]
#define sipNameNr_RGB32U 51810
#define sipName_RGB32U &sipStrings_QtGui[51810]
#define sipNameNr_RGB5A1 31053
#define sipName_RGB5A1 &sipStrings_QtGui[31053]
#define sipNameNr_RGB9E5 51817
#define sipName_RGB9E5 &sipStrings_QtGui[51817]
#define sipNameNr_RGBA8I 51824
#define sipName_RGBA8I &sipStrings_QtGui[51824]
#define sipNameNr_RGBA8U 51831
#define sipName_RGBA8U &sipStrings_QtGui[51831]
#define sipNameNr_Raster 51838
#define sipName_Raster &sipStrings_QtGui[51838]
#define sipNameNr_Reason 5920
#define sipName_Reason &sipStrings_QtGui[5920]
#define sipNameNr_Repeat 18255
#define sipName_Repeat &sipStrings_QtGui[18255]
#define sipNameNr_SaveAs 51845
#define sipName_SaveAs &sipStrings_QtGui[51845]
#define sipNameNr_Shadow 51852
#define sipName_Shadow &sipStrings_QtGui[51852]
#define sipNameNr_Source 4622
#define sipName_Source &sipStrings_QtGui[4622]
#define sipNameNr_Spread 18399
#define sipName_Spread &sipStrings_QtGui[18399]
#define sipNameNr_Stacks 10498
#define sipName_Stacks &sipStrings_QtGui[10498]
#define sipNameNr_Stylus 27355
#define sipName_Stylus &sipStrings_QtGui[27355]
#define sipNameNr_SuperA 51859
#define sipName_SuperA &sipStrings_QtGui[51859]
#define sipNameNr_SuperB 51866
#define sipName_SuperB &sipStrings_QtGui[51866]
#define sipNameNr_Symbol 51873
#define sipName_Symbol &sipStrings_QtGui[51873]
#define sipNameNr_Syriac 51880
#define sipName_Syriac &sipStrings_QtGui[51880]
#define sipNameNr_System 3792
#define sipName_System &sipStrings_QtGui[3792]
#define sipNameNr_Target 3166
#define sipName_Target &sipStrings_QtGui[3166]
#define sipNameNr_Telugu 51887
#define sipName_Telugu &sipStrings_QtGui[51887]
#define sipNameNr_Thaana 51894
#define sipName_Thaana &sipStrings_QtGui[51894]
#define sipNameNr_TxNone 51901
#define sipName_TxNone &sipStrings_QtGui[51901]
#define sipNameNr_UInt16 51908
#define sipName_UInt16 &sipStrings_QtGui[51908]
#define sipNameNr_UInt32 51915
#define sipName_UInt32 &sipStrings_QtGui[51915]
#define sipNameNr_Vertex 51922
#define sipName_Vertex &sipStrings_QtGui[51922]
#define sipNameNr_Weight 30451
#define sipName_Weight &sipStrings_QtGui[30451]
#define sipNameNr_Window 15940
#define sipName_Window &sipStrings_QtGui[15940]
#define sipNameNr_YUV411 51929
#define sipName_YUV411 &sipStrings_QtGui[51929]
#define sipNameNr_YUV422 51936
#define sipName_YUV422 &sipStrings_QtGui[51936]
#define sipNameNr_YUV444 51943
#define sipName_YUV444 &sipStrings_QtGui[51943]
#define sipNameNr_Yellow 41016
#define sipName_Yellow &sipStrings_QtGui[41016]
#define sipNameNr_ZoomIn 51950
#define sipName_ZoomIn &sipStrings_QtGui[51950]
#define sipNameNr___eq__ 51957
#define sipName___eq__ &sipStrings_QtGui[51957]
#define sipNameNr___ge__ 51964
#define sipName___ge__ &sipStrings_QtGui[51964]
#define sipNameNr___gt__ 51971
#define sipName___gt__ &sipStrings_QtGui[51971]
#define sipNameNr___le__ 51978
#define sipName___le__ &sipStrings_QtGui[51978]
#define sipNameNr___lt__ 51985
#define sipName___lt__ &sipStrings_QtGui[51985]
#define sipNameNr___ne__ 51992
#define sipName___ne__ &sipStrings_QtGui[51992]
#define sipNameNr___or__ 51999
#define sipName___or__ &sipStrings_QtGui[51999]
#define sipNameNr_accept 52006
#define sipName_accept &sipStrings_QtGui[52006]
#define sipNameNr_action 9394
#define sipName_action &sipStrings_QtGui[9394]
#define sipNameNr_alpha8 52013
#define sipName_alpha8 &sipStrings_QtGui[52013]
#define sipNameNr_alphaF 52020
#define sipName_alphaF &sipStrings_QtGui[52020]
#define sipNameNr_anchor 52027
#define sipName_anchor &sipStrings_QtGui[52027]
#define sipNameNr_append 52034
#define sipName_append &sipStrings_QtGui[52034]
#define sipNameNr_ascent 52041
#define sipName_ascent &sipStrings_QtGui[52041]
#define sipNameNr_before 52048
#define sipName_before &sipStrings_QtGui[52048]
#define sipNameNr_bisque 52055
#define sipName_bisque &sipStrings_QtGui[52055]
#define sipNameNr_bitmap 52062
#define sipName_bitmap &sipStrings_QtGui[52062]
#define sipNameNr_blackF 52069
#define sipName_blackF &sipStrings_QtGui[52069]
#define sipNameNr_border 52076
#define sipName_border &sipStrings_QtGui[52076]
#define sipNameNr_bottom 52083
#define sipName_bottom &sipStrings_QtGui[52083]
#define sipNameNr_button 52090
#define sipName_button &sipStrings_QtGui[52090]
#define sipNameNr_cancel 52097
#define sipName_cancel &sipStrings_QtGui[52097]
#define sipNameNr_cellAt 52104
#define sipName_cellAt &sipStrings_QtGui[52104]
#define sipNameNr_center 52111
#define sipName_center &sipStrings_QtGui[52111]
#define sipNameNr_closed 52118
#define sipName_closed &sipStrings_QtGui[52118]
#define sipNameNr_column 52125
#define sipName_column &sipStrings_QtGui[52125]
#define sipNameNr_commit 52132
#define sipName_commit &sipStrings_QtGui[52132]
#define sipNameNr_create 52139
#define sipName_create &sipStrings_QtGui[52139]
#define sipNameNr_cursor 52146
#define sipName_cursor &sipStrings_QtGui[52146]
#define sipNameNr_darker 52153
#define sipName_darker &sipStrings_QtGui[52153]
#define sipNameNr_detach 52160
#define sipName_detach &sipStrings_QtGui[52160]
#define sipNameNr_device 52167
#define sipName_device &sipStrings_QtGui[52167]
#define sipNameNr_factor 52174
#define sipName_factor &sipStrings_QtGui[52174]
#define sipNameNr_family 52181
#define sipName_family &sipStrings_QtGui[52181]
#define sipNameNr_filter 52188
#define sipName_filter &sipStrings_QtGui[52188]
#define sipNameNr_format 25034
#define sipName_format &sipStrings_QtGui[25034]
#define sipNameNr_getHsl 52195
#define sipName_getHsl &sipStrings_QtGui[52195]
#define sipNameNr_getHsv 52202
#define sipName_getHsv &sipStrings_QtGui[52202]
#define sipNameNr_getRgb 52209
#define sipName_getRgb &sipStrings_QtGui[52209]
#define sipNameNr_green8 52216
#define sipName_green8 &sipStrings_QtGui[52216]
#define sipNameNr_greenF 52223
#define sipName_greenF &sipStrings_QtGui[52223]
#define sipNameNr_handle 52230
#define sipName_handle &sipStrings_QtGui[52230]
#define sipNameNr_height 52237
#define sipName_height &sipStrings_QtGui[52237]
#define sipNameNr_hslHue 52244
#define sipName_hslHue &sipStrings_QtGui[52244]
#define sipNameNr_hsvHue 52251
#define sipName_hsvHue &sipStrings_QtGui[52251]
#define sipNameNr_ignore 52258
#define sipName_ignore &sipStrings_QtGui[52258]
#define sipNameNr_inFont 52265
#define sipName_inFont &sipStrings_QtGui[52265]
#define sipNameNr_indent 52272
#define sipName_indent &sipStrings_QtGui[52272]
#define sipNameNr_indigo 52279
#define sipName_indigo &sipStrings_QtGui[52279]
#define sipNameNr_insert 52286
#define sipName_insert &sipStrings_QtGui[52286]
#define sipNameNr_isMask 52293
#define sipName_isMask &sipStrings_QtGui[52293]
#define sipNameNr_isNull 52300
#define sipName_isNull &sipStrings_QtGui[52300]
#define sipNameNr_italic 52307
#define sipName_italic &sipStrings_QtGui[52307]
#define sipNameNr_layers 52314
#define sipName_layers &sipStrings_QtGui[52314]
#define sipNameNr_layout 52321
#define sipName_layout &sipStrings_QtGui[52321]
#define sipNameNr_length 52328
#define sipName_length &sipStrings_QtGui[52328]
#define sipNameNr_lineAt 52335
#define sipName_lineAt &sipStrings_QtGui[52335]
#define sipNameNr_lineTo 52342
#define sipName_lineTo &sipStrings_QtGui[52342]
#define sipNameNr_locale 52349
#define sipName_locale &sipStrings_QtGui[52349]
#define sipNameNr_lookAt 52356
#define sipName_lookAt &sipStrings_QtGui[52356]
#define sipNameNr_margin 52363
#define sipName_margin &sipStrings_QtGui[52363]
#define sipNameNr_marker 52370
#define sipName_marker &sipStrings_QtGui[52370]
#define sipNameNr_maroon 52377
#define sipName_maroon &sipStrings_QtGui[52377]
#define sipNameNr_matrix 52384
#define sipName_matrix &sipStrings_QtGui[52384]
#define sipNameNr_metric 52391
#define sipName_metric &sipStrings_QtGui[52391]
#define sipNameNr_mipmap 52398
#define sipName_mipmap &sipStrings_QtGui[52398]
#define sipNameNr_moveTo 52405
#define sipName_moveTo &sipStrings_QtGui[52405]
#define sipNameNr_normal 52412
#define sipName_normal &sipStrings_QtGui[52412]
#define sipNameNr_notify 52419
#define sipName_notify &sipStrings_QtGui[52419]
#define sipNameNr_object 52426
#define sipName_object &sipStrings_QtGui[52426]
#define sipNameNr_offset 52433
#define sipName_offset &sipStrings_QtGui[52433]
#define sipNameNr_oldPos 52440
#define sipName_oldPos &sipStrings_QtGui[52440]
#define sipNameNr_option 52447
#define sipName_option &sipStrings_QtGui[52447]
#define sipNameNr_orange 42974
#define sipName_orange &sipStrings_QtGui[42974]
#define sipNameNr_orchid 36262
#define sipName_orchid &sipStrings_QtGui[36262]
#define sipNameNr_parent 31963
#define sipName_parent &sipStrings_QtGui[31963]
#define sipNameNr_pixmap 52454
#define sipName_pixmap &sipStrings_QtGui[52454]
#define sipNameNr_print_ 52461
#define sipName_print_ &sipStrings_QtGui[52461]
#define sipNameNr_purple 36275
#define sipName_purple &sipStrings_QtGui[36275]
#define sipNameNr_qAlpha 52468
#define sipName_qAlpha &sipStrings_QtGui[52468]
#define sipNameNr_qGreen 52475
#define sipName_qGreen &sipStrings_QtGui[52475]
#define sipNameNr_quadTo 52482
#define sipName_quadTo &sipStrings_QtGui[52482]
#define sipNameNr_radius 52489
#define sipName_radius &sipStrings_QtGui[52489]
#define sipNameNr_raise_ 52496
#define sipName_raise_ &sipStrings_QtGui[52496]
#define sipNameNr_reason 52503
#define sipName_reason &sipStrings_QtGui[52503]
#define sipNameNr_rebind 52510
#define sipName_rebind &sipStrings_QtGui[52510]
#define sipNameNr_regExp 52517
#define sipName_regExp &sipStrings_QtGui[52517]
#define sipNameNr_region 52524
#define sipName_region &sipStrings_QtGui[52524]
#define sipNameNr_remove 52531
#define sipName_remove &sipStrings_QtGui[52531]
#define sipNameNr_resize 52538
#define sipName_resize &sipStrings_QtGui[52538]
#define sipNameNr_revert 52545
#define sipName_revert &sipStrings_QtGui[52545]
#define sipNameNr_rgba64 52552
#define sipName_rgba64 &sipStrings_QtGui[52552]
#define sipNameNr_rotate 52559
#define sipName_rotate &sipStrings_QtGui[52559]
#define sipNameNr_rowEnd 52566
#define sipName_rowEnd &sipStrings_QtGui[52566]
#define sipNameNr_salmon 39697
#define sipName_salmon &sipStrings_QtGui[39697]
#define sipNameNr_scalar 52573
#define sipName_scalar &sipStrings_QtGui[52573]
#define sipNameNr_scaleX 52580
#define sipName_scaleX &sipStrings_QtGui[52580]
#define sipNameNr_scaleY 52587
#define sipName_scaleY &sipStrings_QtGui[52587]
#define sipNameNr_scaled 52594
#define sipName_scaled &sipStrings_QtGui[52594]
#define sipNameNr_screen 45377
#define sipName_screen &sipStrings_QtGui[45377]
#define sipNameNr_scroll 52601
#define sipName_scroll &sipStrings_QtGui[52601]
#define sipNameNr_select 47977
#define sipName_select &sipStrings_QtGui[47977]
#define sipNameNr_setHsl 52608
#define sipName_setHsl &sipStrings_QtGui[52608]
#define sipNameNr_setHsv 52615
#define sipName_setHsv &sipStrings_QtGui[52615]
#define sipNameNr_setPen 52622
#define sipName_setPen &sipStrings_QtGui[52622]
#define sipNameNr_setPos 52629
#define sipName_setPos &sipStrings_QtGui[52629]
#define sipNameNr_setRed 52636
#define sipName_setRed &sipStrings_QtGui[52636]
#define sipNameNr_setRgb 52643
#define sipName_setRgb &sipStrings_QtGui[52643]
#define sipNameNr_setRow 52650
#define sipName_setRow &sipStrings_QtGui[52650]
#define sipNameNr_setTop 52657
#define sipName_setTop &sipStrings_QtGui[52657]
#define sipNameNr_shadow 52664
#define sipName_shadow &sipStrings_QtGui[52664]
#define sipNameNr_shares 52671
#define sipName_shares &sipStrings_QtGui[52671]
#define sipNameNr_sienna 52678
#define sipName_sienna &sipStrings_QtGui[52678]
#define sipNameNr_silver 52685
#define sipName_silver &sipStrings_QtGui[52685]
#define sipNameNr_source 16263
#define sipName_source &sipStrings_QtGui[16263]
#define sipNameNr_spread 52692
#define sipName_spread &sipStrings_QtGui[52692]
#define sipNameNr_stacks 52699
#define sipName_stacks &sipStrings_QtGui[52699]
#define sipNameNr_status 52706
#define sipName_status &sipStrings_QtGui[52706]
#define sipNameNr_stereo 52713
#define sipName_stereo &sipStrings_QtGui[52713]
#define sipNameNr_stride 52720
#define sipName_stride &sipStrings_QtGui[52720]
#define sipNameNr_styles 52727
#define sipName_styles &sipStrings_QtGui[52727]
#define sipNameNr_submit 52734
#define sipName_submit &sipStrings_QtGui[52734]
#define sipNameNr_target 52741
#define sipName_target &sipStrings_QtGui[52741]
#define sipNameNr_toCmyk 52748
#define sipName_toCmyk &sipStrings_QtGui[52748]
#define sipNameNr_toHtml 52755
#define sipName_toHtml &sipStrings_QtGui[52755]
#define sipNameNr_tomato 52762
#define sipName_tomato &sipStrings_QtGui[52762]
#define sipNameNr_united 52769
#define sipName_united &sipStrings_QtGui[52769]
#define sipNameNr_update 52776
#define sipName_update &sipStrings_QtGui[52776]
#define sipNameNr_valueF 52783
#define sipName_valueF &sipStrings_QtGui[52783]
#define sipNameNr_vector 52790
#define sipName_vector &sipStrings_QtGui[52790]
#define sipNameNr_violet 42754
#define sipName_violet &sipStrings_QtGui[42754]
#define sipNameNr_weight 52797
#define sipName_weight &sipStrings_QtGui[52797]
#define sipNameNr_widthF 52804
#define sipName_widthF &sipStrings_QtGui[52804]
#define sipNameNr_window 52811
#define sipName_window &sipStrings_QtGui[52811]
#define sipNameNr_yellow 12738
#define sipName_yellow &sipStrings_QtGui[12738]
#define sipNameNr_Alpha 19750
#define sipName_Alpha &sipStrings_QtGui[19750]
#define sipNameNr_AnsiA 52818
#define sipName_AnsiA &sipStrings_QtGui[52818]
#define sipNameNr_AnsiB 52824
#define sipName_AnsiB &sipStrings_QtGui[52824]
#define sipNameNr_AnsiC 52830
#define sipName_AnsiC &sipStrings_QtGui[52830]
#define sipNameNr_AnsiD 52836
#define sipName_AnsiD &sipStrings_QtGui[52836]
#define sipNameNr_AnsiE 52842
#define sipName_AnsiE &sipStrings_QtGui[52842]
#define sipNameNr_ArchA 52848
#define sipName_ArchA &sipStrings_QtGui[52848]
#define sipNameNr_ArchB 52854
#define sipName_ArchB &sipStrings_QtGui[52854]
#define sipNameNr_ArchC 52860
#define sipName_ArchC &sipStrings_QtGui[52860]
#define sipNameNr_ArchD 52866
#define sipName_ArchD &sipStrings_QtGui[52866]
#define sipNameNr_ArchE 52872
#define sipName_ArchE &sipStrings_QtGui[52872]
#define sipNameNr_AtEnd 52878
#define sipName_AtEnd &sipStrings_QtGui[52878]
#define sipNameNr_Black 52884
#define sipName_Black &sipStrings_QtGui[52884]
#define sipNameNr_Click 52890
#define sipName_Click &sipStrings_QtGui[52890]
#define sipNameNr_Close 52896
#define sipName_Close &sipStrings_QtGui[52896]
#define sipNameNr_D24S8 35132
#define sipName_D24S8 &sipStrings_QtGui[35132]
#define sipNameNr_Depth 35639
#define sipName_Depth &sipStrings_QtGui[35639]
#define sipNameNr_Didot 52902
#define sipName_Didot &sipStrings_QtGui[52902]
#define sipNameNr_Flags 823
#define sipName_Flags &sipStrings_QtGui[823]
#define sipNameNr_Folio 52908
#define sipName_Folio &sipStrings_QtGui[52908]
#define sipNameNr_Gamma 16777
#define sipName_Gamma &sipStrings_QtGui[16777]
#define sipNameNr_Greek 52914
#define sipName_Greek &sipStrings_QtGui[52914]
#define sipNameNr_Green 35054
#define sipName_Green &sipStrings_QtGui[35054]
#define sipNameNr_Int16 51909
#define sipName_Int16 &sipStrings_QtGui[51909]
#define sipNameNr_Int32 51916
#define sipName_Int32 &sipStrings_QtGui[51916]
#define sipNameNr_JisB0 52920
#define sipName_JisB0 &sipStrings_QtGui[52920]
#define sipNameNr_JisB1 52926
#define sipName_JisB1 &sipStrings_QtGui[52926]
#define sipNameNr_JisB2 52932
#define sipName_JisB2 &sipStrings_QtGui[52932]
#define sipNameNr_JisB3 52938
#define sipName_JisB3 &sipStrings_QtGui[52938]
#define sipNameNr_JisB4 52944
#define sipName_JisB4 &sipStrings_QtGui[52944]
#define sipNameNr_JisB5 52950
#define sipName_JisB5 &sipStrings_QtGui[52950]
#define sipNameNr_JisB6 52956
#define sipName_JisB6 &sipStrings_QtGui[52956]
#define sipNameNr_JisB7 52962
#define sipName_JisB7 &sipStrings_QtGui[52962]
#define sipNameNr_JisB8 52968
#define sipName_JisB8 &sipStrings_QtGui[52968]
#define sipNameNr_JisB9 52974
#define sipName_JisB9 &sipStrings_QtGui[52974]
#define sipNameNr_Khmer 52980
#define sipName_Khmer &sipStrings_QtGui[52980]
#define sipNameNr_Latin 52986
#define sipName_Latin &sipStrings_QtGui[52986]
#define sipNameNr_Legal 15447
#define sipName_Legal &sipStrings_QtGui[15447]
#define sipNameNr_LibGL 52992
#define sipName_LibGL &sipStrings_QtGui[52992]
#define sipNameNr_Light 5765
#define sipName_Light &sipStrings_QtGui[5765]
#define sipNameNr_Mouse 41391
#define sipName_Mouse &sipStrings_QtGui[41391]
#define sipNameNr_Ogham 52998
#define sipName_Ogham &sipStrings_QtGui[52998]
#define sipNameNr_Oriya 53004
#define sipName_Oriya &sipStrings_QtGui[53004]
#define sipNameNr_Other 53010
#define sipName_Other &sipStrings_QtGui[53010]
#define sipNameNr_Paste 53016
#define sipName_Paste &sipStrings_QtGui[53016]
#define sipNameNr_Point 7983
#define sipName_Point &sipStrings_QtGui[7983]
#define sipNameNr_Print 53022
#define sipName_Print &sipStrings_QtGui[53022]
#define sipNameNr_QDrag 53028
#define sipName_QDrag &sipStrings_QtGui[53028]
#define sipNameNr_QFont 53034
#define sipName_QFont &sipStrings_QtGui[53034]
#define sipNameNr_QIcon 53040
#define sipName_QIcon &sipStrings_QtGui[53040]
#define sipNameNr_RG16F 53046
#define sipName_RG16F &sipStrings_QtGui[53046]
#define sipNameNr_RG16I 53052
#define sipName_RG16I &sipStrings_QtGui[53052]
#define sipNameNr_RG16U 53058
#define sipName_RG16U &sipStrings_QtGui[53058]
#define sipNameNr_RG32F 53064
#define sipName_RG32F &sipStrings_QtGui[53064]
#define sipNameNr_RG32I 53070
#define sipName_RG32I &sipStrings_QtGui[53070]
#define sipNameNr_RG32U 53076
#define sipName_RG32U &sipStrings_QtGui[53076]
#define sipNameNr_RG3B2 38702
#define sipName_RG3B2 &sipStrings_QtGui[38702]
#define sipNameNr_RGB8I 53082
#define sipName_RGB8I &sipStrings_QtGui[53082]
#define sipNameNr_RGB8U 53088
#define sipName_RGB8U &sipStrings_QtGui[53088]
#define sipNameNr_RGBA4 35119
#define sipName_RGBA4 &sipStrings_QtGui[35119]
#define sipNameNr_Right 31894
#define sipName_Right &sipStrings_QtGui[31894]
#define sipNameNr_Runic 53094
#define sipName_Runic &sipStrings_QtGui[53094]
#define sipNameNr_SRGB8 53100
#define sipName_SRGB8 &sipStrings_QtGui[53100]
#define sipNameNr_Serif 45718
#define sipName_Serif &sipStrings_QtGui[45718]
#define sipNameNr_Start 22265
#define sipName_Start &sipStrings_QtGui[22265]
#define sipNameNr_State 6155
#define sipName_State &sipStrings_QtGui[6155]
#define sipNameNr_Style 2149
#define sipName_Style &sipStrings_QtGui[2149]
#define sipNameNr_Tamil 53106
#define sipName_Tamil &sipStrings_QtGui[53106]
#define sipNameNr_Times 53112
#define sipName_Times &sipStrings_QtGui[53112]
#define sipNameNr_Token 53118
#define sipName_Token &sipStrings_QtGui[53118]
#define sipNameNr_Types 1099
#define sipName_Types &sipStrings_QtGui[1099]
#define sipNameNr_UInt8 53124
#define sipName_UInt8 &sipStrings_QtGui[53124]
#define sipNameNr_White 34430
#define sipName_White &sipStrings_QtGui[34430]
#define sipNameNr_alert 53130
#define sipName_alert &sipStrings_QtGui[53130]
#define sipNameNr_alpha 53136
#define sipName_alpha &sipStrings_QtGui[53136]
#define sipNameNr_angle 8774
#define sipName_angle &sipStrings_QtGui[8774]
#define sipNameNr_arcTo 53142
#define sipName_arcTo &sipStrings_QtGui[53142]
#define sipNameNr_atEnd 53148
#define sipName_atEnd &sipStrings_QtGui[53148]
#define sipNameNr_azure 53154
#define sipName_azure &sipStrings_QtGui[53154]
#define sipNameNr_begin 53160
#define sipName_begin &sipStrings_QtGui[53160]
#define sipNameNr_beige 53166
#define sipName_beige &sipStrings_QtGui[53166]
#define sipNameNr_black 53172
#define sipName_black &sipStrings_QtGui[53172]
#define sipNameNr_block 53178
#define sipName_block &sipStrings_QtGui[53178]
#define sipNameNr_blue8 53184
#define sipName_blue8 &sipStrings_QtGui[53184]
#define sipNameNr_blueF 53190
#define sipName_blueF &sipStrings_QtGui[53190]
#define sipNameNr_brown 40118
#define sipName_brown &sipStrings_QtGui[40118]
#define sipNameNr_brush 47816
#define sipName_brush &sipStrings_QtGui[47816]
#define sipNameNr_buddy 53196
#define sipName_buddy &sipStrings_QtGui[53196]
#define sipNameNr_child 53202
#define sipName_child &sipStrings_QtGui[53202]
#define sipNameNr_clear 53208
#define sipName_clear &sipStrings_QtGui[53208]
#define sipNameNr_clone 53214
#define sipName_clone &sipStrings_QtGui[53214]
#define sipNameNr_close 53220
#define sipName_close &sipStrings_QtGui[53220]
#define sipNameNr_codec 53226
#define sipName_codec &sipStrings_QtGui[53226]
#define sipNameNr_color 53232
#define sipName_color &sipStrings_QtGui[53232]
#define sipNameNr_coral 43679
#define sipName_coral &sipStrings_QtGui[43679]
#define sipNameNr_count 53238
#define sipName_count &sipStrings_QtGui[53238]
#define sipNameNr_cyanF 53244
#define sipName_cyanF &sipStrings_QtGui[53244]
#define sipNameNr_delim 53250
#define sipName_delim &sipStrings_QtGui[53250]
#define sipNameNr_depth 53256
#define sipName_depth &sipStrings_QtGui[53256]
#define sipNameNr_error 53262
#define sipName_error &sipStrings_QtGui[53262]
#define sipNameNr_event 53268
#define sipName_event &sipStrings_QtGui[53268]
#define sipNameNr_exec_ 53274
#define sipName_exec_ &sipStrings_QtGui[53274]
#define sipNameNr_faces 53280
#define sipName_faces &sipStrings_QtGui[53280]
#define sipNameNr_first 53286
#define sipName_first &sipStrings_QtGui[53286]
#define sipNameNr_fixup 53292
#define sipName_fixup &sipStrings_QtGui[53292]
#define sipNameNr_flags 53298
#define sipName_flags &sipStrings_QtGui[53298]
#define sipNameNr_flush 53304
#define sipName_flush &sipStrings_QtGui[53304]
#define sipNameNr_gamma 53310
#define sipName_gamma &sipStrings_QtGui[53310]
#define sipNameNr_green 19624
#define sipName_green &sipStrings_QtGui[19624]
#define sipNameNr_hints 53316
#define sipName_hints &sipStrings_QtGui[53316]
#define sipNameNr_image 53322
#define sipName_image &sipStrings_QtGui[53322]
#define sipNameNr_index 53328
#define sipName_index &sipStrings_QtGui[53328]
#define sipNameNr_ivory 53334
#define sipName_ivory &sipStrings_QtGui[53334]
#define sipNameNr_khaki 46248
#define sipName_khaki &sipStrings_QtGui[46248]
#define sipNameNr_light 40034
#define sipName_light &sipStrings_QtGui[40034]
#define sipNameNr_linen 53340
#define sipName_linen &sipStrings_QtGui[53340]
#define sipNameNr_lower 53346
#define sipName_lower &sipStrings_QtGui[53346]
#define sipNameNr_match 53352
#define sipName_match &sipStrings_QtGui[53352]
#define sipNameNr_merge 53358
#define sipName_merge &sipStrings_QtGui[53358]
#define sipNameNr_model 53364
#define sipName_model &sipStrings_QtGui[53364]
#define sipNameNr_nlerp 53370
#define sipName_nlerp &sipStrings_QtGui[53370]
#define sipNameNr_olive 53376
#define sipName_olive &sipStrings_QtGui[53376]
#define sipNameNr_order 10939
#define sipName_order &sipStrings_QtGui[10939]
#define sipNameNr_ortho 53382
#define sipName_ortho &sipStrings_QtGui[53382]
#define sipNameNr_paint 53388
#define sipName_paint &sipStrings_QtGui[53388]
#define sipNameNr_phase 53394
#define sipName_phase &sipStrings_QtGui[53394]
#define sipNameNr_pixel 53400
#define sipName_pixel &sipStrings_QtGui[53400]
#define sipNameNr_point 53406
#define sipName_point &sipStrings_QtGui[53406]
#define sipNameNr_print 53412
#define sipName_print &sipStrings_QtGui[53412]
#define sipNameNr_qBlue 53418
#define sipName_qBlue &sipStrings_QtGui[53418]
#define sipNameNr_qGray 53424
#define sipName_qGray &sipStrings_QtGui[53424]
#define sipNameNr_qRgba 53430
#define sipName_qRgba &sipStrings_QtGui[53430]
#define sipNameNr_rects 53436
#define sipName_rects &sipStrings_QtGui[53436]
#define sipNameNr_reset 18382
#define sipName_reset &sipStrings_QtGui[18382]
#define sipNameNr_right 53442
#define sipName_right &sipStrings_QtGui[53442]
#define sipNameNr_scale 11445
#define sipName_scale &sipStrings_QtGui[11445]
#define sipNameNr_shape 53448
#define sipName_shape &sipStrings_QtGui[53448]
#define sipNameNr_shear 53454
#define sipName_shear &sipStrings_QtGui[53454]
#define sipNameNr_sizes 53460
#define sipName_sizes &sipStrings_QtGui[53460]
#define sipNameNr_slerp 53466
#define sipName_slerp &sipStrings_QtGui[53466]
#define sipNameNr_speed 53472
#define sipName_speed &sipStrings_QtGui[53472]
#define sipNameNr_start 53478
#define sipName_start &sipStrings_QtGui[53478]
#define sipNameNr_state 25707
#define sipName_state &sipStrings_QtGui[25707]
#define sipNameNr_stops 53484
#define sipName_stops &sipStrings_QtGui[53484]
#define sipNameNr_style 53490
#define sipName_style &sipStrings_QtGui[53490]
#define sipNameNr_title 53496
#define sipName_title &sipStrings_QtGui[53496]
#define sipNameNr_toHsl 53502
#define sipName_toHsl &sipStrings_QtGui[53502]
#define sipNameNr_toHsv 53508
#define sipName_toHsv &sipStrings_QtGui[53508]
#define sipNameNr_toRgb 38126
#define sipName_toRgb &sipStrings_QtGui[38126]
#define sipNameNr_types 53514
#define sipName_types &sipStrings_QtGui[53514]
#define sipNameNr_units 53520
#define sipName_units &sipStrings_QtGui[53520]
#define sipNameNr_unmap 53526
#define sipName_unmap &sipStrings_QtGui[53526]
#define sipNameNr_valid 26636
#define sipName_valid &sipStrings_QtGui[26636]
#define sipNameNr_value 53532
#define sipName_value &sipStrings_QtGui[53532]
#define sipNameNr_wheat 53538
#define sipName_wheat &sipStrings_QtGui[53538]
#define sipNameNr_white 35288
#define sipName_white &sipStrings_QtGui[35288]
#define sipNameNr_width 53544
#define sipName_width &sipStrings_QtGui[53544]
#define sipNameNr_winId 53550
#define sipName_winId &sipStrings_QtGui[53550]
#define sipNameNr_write 53556
#define sipName_write &sipStrings_QtGui[53556]
#define sipNameNr_xTilt 53562
#define sipName_xTilt &sipStrings_QtGui[53562]
#define sipNameNr_xored 53568
#define sipName_xored &sipStrings_QtGui[53568]
#define sipNameNr_yTilt 53574
#define sipName_yTilt &sipStrings_QtGui[53574]
#define sipNameNr_Area 29232
#define sipName_Area &sipStrings_QtGui[29232]
#define sipNameNr_BGRA 53580
#define sipName_BGRA &sipStrings_QtGui[53580]
#define sipNameNr_Back 53585
#define sipName_Back &sipStrings_QtGui[53585]
#define sipNameNr_Base 29725
#define sipName_Base &sipStrings_QtGui[29725]
#define sipNameNr_Blue 38067
#define sipName_Blue &sipStrings_QtGui[38067]
#define sipNameNr_Bold 45059
#define sipName_Bold &sipStrings_QtGui[45059]
#define sipNameNr_CMYK 53590
#define sipName_CMYK &sipStrings_QtGui[53590]
#define sipNameNr_Cmyk 22181
#define sipName_Cmyk &sipStrings_QtGui[22181]
#define sipNameNr_Copy 37587
#define sipName_Copy &sipStrings_QtGui[37587]
#define sipNameNr_Cyan 47934
#define sipName_Cyan &sipStrings_QtGui[47934]
#define sipNameNr_D32F 53595
#define sipName_D32F &sipStrings_QtGui[53595]
#define sipNameNr_Dark 38103
#define sipName_Dark &sipStrings_QtGui[38103]
#define sipNameNr_Down 53600
#define sipName_Down &sipStrings_QtGui[53600]
#define sipNameNr_Edge 23996
#define sipName_Edge &sipStrings_QtGui[23996]
#define sipNameNr_Find 53605
#define sipName_Find &sipStrings_QtGui[53605]
#define sipNameNr_Flag 1134
#define sipName_Flag &sipStrings_QtGui[1134]
#define sipNameNr_Gray 45219
#define sipName_Gray &sipStrings_QtGui[45219]
#define sipNameNr_IMC1 53610
#define sipName_IMC1 &sipStrings_QtGui[53610]
#define sipNameNr_IMC2 53615
#define sipName_IMC2 &sipStrings_QtGui[53615]
#define sipNameNr_IMC3 53620
#define sipName_IMC3 &sipStrings_QtGui[53620]
#define sipNameNr_IMC4 53625
#define sipName_IMC4 &sipStrings_QtGui[53625]
#define sipNameNr_Inch 14878
#define sipName_Inch &sipStrings_QtGui[14878]
#define sipNameNr_Int8 53125
#define sipName_Int8 &sipStrings_QtGui[53125]
#define sipNameNr_Left 21161
#define sipName_Left &sipStrings_QtGui[21161]
#define sipNameNr_Link 53630
#define sipName_Link &sipStrings_QtGui[53630]
#define sipNameNr_Mode 1368
#define sipName_Mode &sipStrings_QtGui[1368]
#define sipNameNr_NV12 53635
#define sipName_NV12 &sipStrings_QtGui[53635]
#define sipNameNr_NV21 53640
#define sipName_NV21 &sipStrings_QtGui[53640]
#define sipNameNr_Name 6520
#define sipName_Name &sipStrings_QtGui[6520]
#define sipNameNr_Nega 53645
#define sipName_Nega &sipStrings_QtGui[53645]
#define sipNameNr_Note 53650
#define sipName_Note &sipStrings_QtGui[53650]
#define sipNameNr_Open 53655
#define sipName_Open &sipStrings_QtGui[53655]
#define sipNameNr_Pica 53660
#define sipName_Pica &sipStrings_QtGui[53660]
#define sipNameNr_Puck 53665
#define sipName_Puck &sipStrings_QtGui[53665]
#define sipNameNr_QPen 53670
#define sipName_QPen &sipStrings_QtGui[53670]
#define sipNameNr_Quit 53675
#define sipName_Quit &sipStrings_QtGui[53675]
#define sipNameNr_R16F 53680
#define sipName_R16F &sipStrings_QtGui[53680]
#define sipNameNr_R16I 53685
#define sipName_R16I &sipStrings_QtGui[53685]
#define sipNameNr_R16U 53690
#define sipName_R16U &sipStrings_QtGui[53690]
#define sipNameNr_R32F 53695
#define sipName_R32F &sipStrings_QtGui[53695]
#define sipNameNr_R32I 53700
#define sipName_R32I &sipStrings_QtGui[53700]
#define sipNameNr_R32U 53705
#define sipName_R32U &sipStrings_QtGui[53705]
#define sipNameNr_RG8I 53710
#define sipName_RG8I &sipStrings_QtGui[53710]
#define sipNameNr_RG8U 53715
#define sipName_RG8U &sipStrings_QtGui[53715]
#define sipNameNr_RGBA 53720
#define sipName_RGBA &sipStrings_QtGui[53720]
#define sipNameNr_Redo 53725
#define sipName_Redo &sipStrings_QtGui[53725]
#define sipNameNr_Ruby 53730
#define sipName_Ruby &sipStrings_QtGui[53730]
#define sipNameNr_SRgb 53735
#define sipName_SRgb &sipStrings_QtGui[53735]
#define sipNameNr_Save 53740
#define sipName_Save &sipStrings_QtGui[53740]
#define sipNameNr_Size 4736
#define sipName_Size &sipStrings_QtGui[4736]
#define sipNameNr_Spec 34561
#define sipName_Spec &sipStrings_QtGui[34561]
#define sipNameNr_Text 12593
#define sipName_Text &sipStrings_QtGui[12593]
#define sipNameNr_Thai 53745
#define sipName_Thai &sipStrings_QtGui[53745]
#define sipNameNr_Thin 53750
#define sipName_Thin &sipStrings_QtGui[53750]
#define sipNameNr_Type 280
#define sipName_Type &sipStrings_QtGui[280]
#define sipNameNr_UYVY 53755
#define sipName_UYVY &sipStrings_QtGui[53755]
#define sipNameNr_Undo 53760
#define sipName_Undo &sipStrings_QtGui[53760]
#define sipNameNr_Unit 11921
#define sipName_Unit &sipStrings_QtGui[11921]
#define sipNameNr_User 50105
#define sipName_User &sipStrings_QtGui[50105]
#define sipNameNr_YUYV 53765
#define sipName_YUYV &sipStrings_QtGui[53765]
#define sipNameNr_YV12 53770
#define sipName_YV12 &sipStrings_QtGui[53770]
#define sipNameNr_aqua 53775
#define sipName_aqua &sipStrings_QtGui[53775]
#define sipNameNr_axis 53780
#define sipName_axis &sipStrings_QtGui[53780]
#define sipNameNr_base 30467
#define sipName_base &sipStrings_QtGui[30467]
#define sipNameNr_bind 52512
#define sipName_bind &sipStrings_QtGui[52512]
#define sipNameNr_bits 53785
#define sipName_bits &sipStrings_QtGui[53785]
#define sipNameNr_blit 53790
#define sipName_blit &sipStrings_QtGui[53790]
#define sipNameNr_blue 25260
#define sipName_blue &sipStrings_QtGui[25260]
#define sipNameNr_bold 53795
#define sipName_bold &sipStrings_QtGui[53795]
#define sipNameNr_clip 53800
#define sipName_clip &sipStrings_QtGui[53800]
#define sipNameNr_copy 53805
#define sipName_copy &sipStrings_QtGui[53805]
#define sipNameNr_cyan 46669
#define sipName_cyan &sipStrings_QtGui[46669]
#define sipNameNr_dark 53810
#define sipName_dark &sipStrings_QtGui[53810]
#define sipNameNr_data 9764
#define sipName_data &sipStrings_QtGui[9764]
#define sipNameNr_draw 53815
#define sipName_draw &sipStrings_QtGui[53815]
#define sipNameNr_edge 53820
#define sipName_edge &sipStrings_QtGui[53820]
#define sipNameNr_exec 53825
#define sipName_exec &sipStrings_QtGui[53825]
#define sipNameNr_file 431
#define sipName_file &sipStrings_QtGui[431]
#define sipNameNr_fill 53830
#define sipName_fill &sipStrings_QtGui[53830]
#define sipNameNr_find 53835
#define sipName_find &sipStrings_QtGui[53835]
#define sipNameNr_font 53840
#define sipName_font &sipStrings_QtGui[53840]
#define sipNameNr_from 53845
#define sipName_from &sipStrings_QtGui[53845]
#define sipNameNr_gold 53850
#define sipName_gold &sipStrings_QtGui[53850]
#define sipNameNr_gray 28317
#define sipName_gray &sipStrings_QtGui[28317]
#define sipNameNr_grey 28332
#define sipName_grey &sipStrings_QtGui[28332]
#define sipNameNr_hide 53855
#define sipName_hide &sipStrings_QtGui[53855]
#define sipNameNr_hotX 53860
#define sipName_hotX &sipStrings_QtGui[53860]
#define sipNameNr_hotY 53865
#define sipName_hotY &sipStrings_QtGui[53865]
#define sipNameNr_href 53870
#define sipName_href &sipStrings_QtGui[53870]
#define sipNameNr_hueF 53875
#define sipName_hueF &sipStrings_QtGui[53875]
#define sipNameNr_icon 53880
#define sipName_icon &sipStrings_QtGui[53880]
#define sipNameNr_item 53885
#define sipName_item &sipStrings_QtGui[53885]
#define sipNameNr_join 53890
#define sipName_join &sipStrings_QtGui[53890]
#define sipNameNr_key2 53895
#define sipName_key2 &sipStrings_QtGui[53895]
#define sipNameNr_key3 53900
#define sipName_key3 &sipStrings_QtGui[53900]
#define sipNameNr_key4 53905
#define sipName_key4 &sipStrings_QtGui[53905]
#define sipNameNr_last 53910
#define sipName_last &sipStrings_QtGui[53910]
#define sipNameNr_left 53915
#define sipName_left &sipStrings_QtGui[53915]
#define sipNameNr_lime 53920
#define sipName_lime &sipStrings_QtGui[53920]
#define sipNameNr_link 53925
#define sipName_link &sipStrings_QtGui[53925]
#define sipNameNr_load 53930
#define sipName_load &sipStrings_QtGui[53930]
#define sipNameNr_mask 53935
#define sipName_mask &sipStrings_QtGui[53935]
#define sipNameNr_mode 53940
#define sipName_mode &sipStrings_QtGui[53940]
#define sipNameNr_name 53945
#define sipName_name &sipStrings_QtGui[53945]
#define sipNameNr_navy 53950
#define sipName_navy &sipStrings_QtGui[53950]
#define sipNameNr_next 53955
#define sipName_next &sipStrings_QtGui[53955]
#define sipNameNr_peru 53960
#define sipName_peru &sipStrings_QtGui[53960]
#define sipNameNr_pink 46709
#define sipName_pink &sipStrings_QtGui[46709]
#define sipNameNr_play 53965
#define sipName_play &sipStrings_QtGui[53965]
#define sipNameNr_plum 53970
#define sipName_plum &sipStrings_QtGui[53970]
#define sipNameNr_posF 53975
#define sipName_posF &sipStrings_QtGui[53975]
#define sipNameNr_qRed 53980
#define sipName_qRed &sipStrings_QtGui[53980]
#define sipNameNr_qRgb 53985
#define sipName_qRgb &sipStrings_QtGui[53985]
#define sipNameNr_read 18401
#define sipName_read &sipStrings_QtGui[18401]
#define sipNameNr_rect 53990
#define sipName_rect &sipStrings_QtGui[53990]
#define sipNameNr_red8 53995
#define sipName_red8 &sipStrings_QtGui[53995]
#define sipNameNr_redF 54000
#define sipName_redF &sipStrings_QtGui[54000]
#define sipNameNr_redo 54005
#define sipName_redo &sipStrings_QtGui[54005]
#define sipNameNr_rgba 54010
#define sipName_rgba &sipStrings_QtGui[54010]
#define sipNameNr_role 54015
#define sipName_role &sipStrings_QtGui[54015]
#define sipNameNr_rows 54020
#define sipName_rows &sipStrings_QtGui[54020]
#define sipNameNr_save 54025
#define sipName_save &sipStrings_QtGui[54025]
#define sipNameNr_setW 54030
#define sipName_setW &sipStrings_QtGui[54030]
#define sipNameNr_setX 54035
#define sipName_setX &sipStrings_QtGui[54035]
#define sipNameNr_setY 54040
#define sipName_setY &sipStrings_QtGui[54040]
#define sipNameNr_setZ 54045
#define sipName_setZ &sipStrings_QtGui[54045]
#define sipNameNr_show 54050
#define sipName_show &sipStrings_QtGui[54050]
#define sipNameNr_size 20399
#define sipName_size &sipStrings_QtGui[20399]
#define sipNameNr_snow 54055
#define sipName_snow &sipStrings_QtGui[54055]
#define sipNameNr_sort 54060
#define sipName_sort &sipStrings_QtGui[54060]
#define sipNameNr_span 54065
#define sipName_span &sipStrings_QtGui[54065]
#define sipNameNr_spec 54070
#define sipName_spec &sipStrings_QtGui[54070]
#define sipNameNr_stop 54075
#define sipName_stop &sipStrings_QtGui[54075]
#define sipNameNr_swap 54080
#define sipName_swap &sipStrings_QtGui[54080]
#define sipNameNr_sync 54085
#define sipName_sync &sipStrings_QtGui[54085]
#define sipNameNr_tabs 54090
#define sipName_tabs &sipStrings_QtGui[54090]
#define sipNameNr_teal 54095
#define sipName_teal &sipStrings_QtGui[54095]
#define sipNameNr_text 240
#define sipName_text &sipStrings_QtGui[240]
#define sipNameNr_type 22538
#define sipName_type &sipStrings_QtGui[22538]
#define sipNameNr_undo 54100
#define sipName_undo &sipStrings_QtGui[54100]
#define sipNameNr_A10 54105
#define sipName_A10 &sipStrings_QtGui[54105]
#define sipNameNr_All 18132
#define sipName_All &sipStrings_QtGui[18132]
#define sipNameNr_Any 54109
#define sipName_Any &sipStrings_QtGui[54109]
#define sipNameNr_B10 51659
#define sipName_B10 &sipStrings_QtGui[51659]
#define sipNameNr_BGR 54113
#define sipName_BGR &sipStrings_QtGui[54113]
#define sipNameNr_C5E 54117
#define sipName_C5E &sipStrings_QtGui[54117]
#define sipNameNr_Cut 54121
#define sipName_Cut &sipStrings_QtGui[54121]
#define sipNameNr_D16 54125
#define sipName_D16 &sipStrings_QtGui[54125]
#define sipNameNr_D24 54129
#define sipName_D24 &sipStrings_QtGui[54129]
#define sipNameNr_D32 54133
#define sipName_D32 &sipStrings_QtGui[54133]
#define sipNameNr_DLE 54137
#define sipName_DLE &sipStrings_QtGui[54137]
#define sipNameNr_End 36629
#define sipName_End &sipStrings_QtGui[36629]
#define sipNameNr_HSL 54141
#define sipName_HSL &sipStrings_QtGui[54141]
#define sipNameNr_HSV 54145
#define sipName_HSV &sipStrings_QtGui[54145]
#define sipNameNr_Hsl 25597
#define sipName_Hsl &sipStrings_QtGui[25597]
#define sipNameNr_Hsv 25613
#define sipName_Hsv &sipStrings_QtGui[25613]
#define sipNameNr_Key 6001
#define sipName_Key &sipStrings_QtGui[6001]
#define sipNameNr_Lao 54149
#define sipName_Lao &sipStrings_QtGui[54149]
#define sipNameNr_Mid 54153
#define sipName_Mid &sipStrings_QtGui[54153]
#define sipNameNr_New 54157
#define sipName_New &sipStrings_QtGui[54157]
#define sipNameNr_Nko 54161
#define sipName_Nko &sipStrings_QtGui[54161]
#define sipNameNr_Off 54165
#define sipName_Off &sipStrings_QtGui[54165]
#define sipNameNr_Pdf 54169
#define sipName_Pdf &sipStrings_QtGui[54169]
#define sipNameNr_Pen 10149
#define sipName_Pen &sipStrings_QtGui[10149]
#define sipNameNr_R8I 54173
#define sipName_R8I &sipStrings_QtGui[54173]
#define sipNameNr_R8U 54177
#define sipName_R8U &sipStrings_QtGui[54177]
#define sipNameNr_RGB 54181
#define sipName_RGB &sipStrings_QtGui[54181]
#define sipNameNr_Red 42383
#define sipName_Red &sipStrings_QtGui[42383]
#define sipNameNr_Rgb 33422
#define sipName_Rgb &sipStrings_QtGui[33422]
#define sipNameNr_SVG 54185
#define sipName_SVG &sipStrings_QtGui[54185]
#define sipNameNr_Svg 12048
#define sipName_Svg &sipStrings_QtGui[12048]
#define sipNameNr_Tab 21417
#define sipName_Tab &sipStrings_QtGui[21417]
#define sipNameNr_X11 54189
#define sipName_X11 &sipStrings_QtGui[54189]
#define sipNameNr_Y16 54193
#define sipName_Y16 &sipStrings_QtGui[54193]
#define sipNameNr_YUV 54197
#define sipName_YUV &sipStrings_QtGui[54197]
#define sipNameNr_add 54201
#define sipName_add &sipStrings_QtGui[54201]
#define sipNameNr_cap 54205
#define sipName_cap &sipStrings_QtGui[54205]
#define sipNameNr_end 15734
#define sipName_end &sipStrings_QtGui[15734]
#define sipNameNr_hue 54209
#define sipName_hue &sipStrings_QtGui[54209]
#define sipNameNr_key 54213
#define sipName_key &sipStrings_QtGui[54213]
#define sipNameNr_log 54217
#define sipName_log &sipStrings_QtGui[54217]
#define sipNameNr_m11 54221
#define sipName_m11 &sipStrings_QtGui[54221]
#define sipNameNr_m12 54225
#define sipName_m12 &sipStrings_QtGui[54225]
#define sipNameNr_m13 54229
#define sipName_m13 &sipStrings_QtGui[54229]
#define sipNameNr_m21 54233
#define sipName_m21 &sipStrings_QtGui[54233]
#define sipNameNr_m22 54237
#define sipName_m22 &sipStrings_QtGui[54237]
#define sipNameNr_m23 54241
#define sipName_m23 &sipStrings_QtGui[54241]
#define sipNameNr_m31 54245
#define sipName_m31 &sipStrings_QtGui[54245]
#define sipNameNr_m32 54249
#define sipName_m32 &sipStrings_QtGui[54249]
#define sipNameNr_m33 54253
#define sipName_m33 &sipStrings_QtGui[54253]
#define sipNameNr_map 24829
#define sipName_map &sipStrings_QtGui[24829]
#define sipNameNr_mid 54257
#define sipName_mid &sipStrings_QtGui[54257]
#define sipNameNr_pen 53656
#define sipName_pen &sipStrings_QtGui[53656]
#define sipNameNr_pos 54261
#define sipName_pos &sipStrings_QtGui[54261]
#define sipNameNr_red 19428
#define sipName_red &sipStrings_QtGui[19428]
#define sipNameNr_rgb 50058
#define sipName_rgb &sipStrings_QtGui[50058]
#define sipNameNr_row 54265
#define sipName_row &sipStrings_QtGui[54265]
#define sipNameNr_tan 50330
#define sipName_tan &sipStrings_QtGui[50330]
#define sipNameNr_tip 54269
#define sipName_tip &sipStrings_QtGui[54269]
#define sipNameNr_top 1895
#define sipName_top &sipStrings_QtGui[1895]
#define sipNameNr_url 54273
#define sipName_url &sipStrings_QtGui[54273]
#define sipNameNr_A0 54277
#define sipName_A0 &sipStrings_QtGui[54277]
#define sipNameNr_A1 31057
#define sipName_A1 &sipStrings_QtGui[31057]
#define sipNameNr_A2 27524
#define sipName_A2 &sipStrings_QtGui[27524]
#define sipNameNr_A3 54280
#define sipName_A3 &sipStrings_QtGui[54280]
#define sipNameNr_A4 35122
#define sipName_A4 &sipStrings_QtGui[35122]
#define sipNameNr_A5 54283
#define sipName_A5 &sipStrings_QtGui[54283]
#define sipNameNr_A6 54286
#define sipName_A6 &sipStrings_QtGui[54286]
#define sipNameNr_A7 54289
#define sipName_A7 &sipStrings_QtGui[54289]
#define sipNameNr_A8 35148
#define sipName_A8 &sipStrings_QtGui[35148]
#define sipNameNr_A9 54292
#define sipName_A9 &sipStrings_QtGui[54292]
#define sipNameNr_B0 52923
#define sipName_B0 &sipStrings_QtGui[52923]
#define sipNameNr_B1 52929
#define sipName_B1 &sipStrings_QtGui[52929]
#define sipNameNr_B2 38705
#define sipName_B2 &sipStrings_QtGui[38705]
#define sipNameNr_B3 52941
#define sipName_B3 &sipStrings_QtGui[52941]
#define sipNameNr_B4 41207
#define sipName_B4 &sipStrings_QtGui[41207]
#define sipNameNr_B5 31043
#define sipName_B5 &sipStrings_QtGui[31043]
#define sipNameNr_B6 41229
#define sipName_B6 &sipStrings_QtGui[41229]
#define sipNameNr_B7 52965
#define sipName_B7 &sipStrings_QtGui[52965]
#define sipNameNr_B8 52971
#define sipName_B8 &sipStrings_QtGui[52971]
#define sipNameNr_B9 52977
#define sipName_B9 &sipStrings_QtGui[52977]
#define sipNameNr_On 54295
#define sipName_On &sipStrings_QtGui[54295]
#define sipNameNr_Qt 54298
#define sipName_Qt &sipStrings_QtGui[54298]
#define sipNameNr_RG 54301
#define sipName_RG &sipStrings_QtGui[54301]
#define sipNameNr_S8 35135
#define sipName_S8 &sipStrings_QtGui[35135]
#define sipNameNr_Up 54304
#define sipName_Up &sipStrings_QtGui[54304]
#define sipNameNr_Y8 54307
#define sipName_Y8 &sipStrings_QtGui[54307]
#define sipNameNr_at 2498
#define sipName_at &sipStrings_QtGui[2498]
#define sipNameNr_dx 54310
#define sipName_dx &sipStrings_QtGui[54310]
#define sipNameNr_dy 53199
#define sipName_dy &sipStrings_QtGui[53199]
#define sipNameNr_id 17989
#define sipName_id &sipStrings_QtGui[17989]
#define sipNameNr_on 321
#define sipName_on &sipStrings_QtGui[321]
#define sipNameNr_sh 5475
#define sipName_sh &sipStrings_QtGui[5475]
#define sipNameNr_sw 54313
#define sipName_sw &sipStrings_QtGui[54313]
#define sipNameNr_sx 54316
#define sipName_sx &sipStrings_QtGui[54316]
#define sipNameNr_sy 50019
#define sipName_sy &sipStrings_QtGui[50019]
#define sipNameNr_n 322
#define sipName_n &sipStrings_QtGui[322]
#define sipNameNr_w 12743
#define sipName_w &sipStrings_QtGui[12743]
#define sipNameNr_x 13499
#define sipName_x &sipStrings_QtGui[13499]
#define sipNameNr_y 102
#define sipName_y &sipStrings_QtGui[102]
#define sipNameNr_z 54319
#define sipName_z &sipStrings_QtGui[54319]

#define sipMalloc                   sipAPI_QtGui->api_malloc
#define sipFree                     sipAPI_QtGui->api_free
#define sipBuildResult              sipAPI_QtGui->api_build_result
#define sipCallMethod               sipAPI_QtGui->api_call_method
#define sipCallProcedureMethod      sipAPI_QtGui->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtGui->api_call_error_handler
#define sipParseResultEx            sipAPI_QtGui->api_parse_result_ex
#define sipParseResult              sipAPI_QtGui->api_parse_result
#define sipParseArgs                sipAPI_QtGui->api_parse_args
#define sipParseKwdArgs             sipAPI_QtGui->api_parse_kwd_args
#define sipParsePair                sipAPI_QtGui->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtGui->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtGui->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtGui->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtGui->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtGui->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtGui->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtGui->api_add_exception
#define sipNoFunction               sipAPI_QtGui->api_no_function
#define sipNoMethod                 sipAPI_QtGui->api_no_method
#define sipAbstractMethod           sipAPI_QtGui->api_abstract_method
#define sipBadClass                 sipAPI_QtGui->api_bad_class
#define sipBadCatcherResult         sipAPI_QtGui->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtGui->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtGui->api_bad_operator_arg
#define sipTrace                    sipAPI_QtGui->api_trace
#define sipTransferBack             sipAPI_QtGui->api_transfer_back
#define sipTransferTo               sipAPI_QtGui->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtGui->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtGui->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtGui->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtGui->api_voidptr_type
#define sipGetPyObject              sipAPI_QtGui->api_get_pyobject
#define sipGetAddress               sipAPI_QtGui->api_get_address
#define sipGetMixinAddress          sipAPI_QtGui->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtGui->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtGui->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtGui->api_call_hook
#define sipEndThread                sipAPI_QtGui->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtGui->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtGui->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtGui->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtGui->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtGui->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtGui->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtGui->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtGui->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtGui->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtGui->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtGui->api_convert_to_bool
#define sipReleaseType              sipAPI_QtGui->api_release_type
#define sipConvertFromType          sipAPI_QtGui->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtGui->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtGui->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtGui->api_convert_from_enum
#define sipGetState                 sipAPI_QtGui->api_get_state
#define sipExportSymbol             sipAPI_QtGui->api_export_symbol
#define sipImportSymbol             sipAPI_QtGui->api_import_symbol
#define sipFindType                 sipAPI_QtGui->api_find_type
#define sipBytes_AsChar             sipAPI_QtGui->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtGui->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtGui->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtGui->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtGui->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtGui->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtGui->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtGui->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtGui->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtGui->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtGui->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtGui->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtGui->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtGui->api_get_reference
#define sipKeepReference            sipAPI_QtGui->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtGui->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtGui->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtGui->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtGui->api_type_scope
#define sipResolveTypedef           sipAPI_QtGui->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtGui->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtGui->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtGui->api_init_mixin
#define sipExportModule             sipAPI_QtGui->api_export_module
#define sipInitModule               sipAPI_QtGui->api_init_module
#define sipGetInterpreter           sipAPI_QtGui->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtGui->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtGui->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtGui->api_py_type_dict
#define sipPyTypeName               sipAPI_QtGui->api_py_type_name
#define sipGetCFunction             sipAPI_QtGui->api_get_c_function
#define sipGetMethod                sipAPI_QtGui->api_get_method
#define sipFromMethod               sipAPI_QtGui->api_from_method
#define sipGetDate                  sipAPI_QtGui->api_get_date
#define sipFromDate                 sipAPI_QtGui->api_from_date
#define sipGetDateTime              sipAPI_QtGui->api_get_datetime
#define sipFromDateTime             sipAPI_QtGui->api_from_datetime
#define sipGetTime                  sipAPI_QtGui->api_get_time
#define sipFromTime                 sipAPI_QtGui->api_from_time
#define sipIsUserType               sipAPI_QtGui->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtGui->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtGui->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtGui->api_unicode_write
#define sipUnicodeData              sipAPI_QtGui->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtGui->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtGui->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtGui->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtGui->api_is_derived_class
#define sipGetUserObject            sipAPI_QtGui->api_get_user_object
#define sipSetUserObject            sipAPI_QtGui->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtGui->api_register_event_handler
#define sipConvertToArray           sipAPI_QtGui->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtGui->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtGui->api_enable_gc
#define sipPrintObject              sipAPI_QtGui->api_print_object
#define sipLong_AsChar              sipAPI_QtGui->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtGui->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtGui->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtGui->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtGui->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtGui->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtGui->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtGui->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtGui->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtGui->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtGui->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtGui->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtGui->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtGui->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtGui->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtGui->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtGui->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtGui->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtGui->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtGui->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtGui->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtGui->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtGui->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtGui->api_connect_rx
#define sipConvertRx                sipAPI_QtGui->api_convert_rx
#define sipDisconnectRx             sipAPI_QtGui->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtGui->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtGui->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtGui->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtGui->api_same_slot
#define sipSaveSlot                 sipAPI_QtGui->api_save_slot
#define sipVisitSlot                sipAPI_QtGui->api_visit_slot
#define sipIsPyMethod               sipAPI_QtGui->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtGui[];

#define sipType_QAbstractTextDocumentLayout sipExportedTypes_QtGui[1]

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractTextDocumentLayout;

#define sipType_QAbstractTextDocumentLayout_Selection sipExportedTypes_QtGui[3]

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractTextDocumentLayout_Selection;

#define sipType_QAbstractTextDocumentLayout_PaintContext sipExportedTypes_QtGui[2]

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractTextDocumentLayout_PaintContext;

#define sipType_QTextObjectInterface sipExportedTypes_QtGui[345]

extern sipClassTypeDef sipTypeDef_QtGui_QTextObjectInterface;

#define sipType_QBackingStore sipExportedTypes_QtGui[6]

extern sipClassTypeDef sipTypeDef_QtGui_QBackingStore;

#define sipType_QPaintDevice sipExportedTypes_QtGui[200]

#define sipType_QPaintDevice_PaintDeviceMetric sipExportedTypes_QtGui[201]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintDevice;

#define sipType_QPixmap sipExportedTypes_QtGui[240]

extern sipClassTypeDef sipTypeDef_QtGui_QPixmap;

#define sipType_QBitmap sipExportedTypes_QtGui[7]

extern sipClassTypeDef sipTypeDef_QtGui_QBitmap;

#define sipType_QColor sipExportedTypes_QtGui[12]

#define sipType_QColor_NameFormat sipExportedTypes_QtGui[13]

#define sipType_QColor_Spec sipExportedTypes_QtGui[14]

extern sipClassTypeDef sipTypeDef_QtGui_QColor;

#define sipType_QColorConstants sipExportedTypes_QtGui[15]

extern sipClassTypeDef sipTypeDef_QtGui_QColorConstants;

#define sipType_QColorConstants_Svg sipExportedTypes_QtGui[16]

extern sipClassTypeDef sipTypeDef_QtGui_QColorConstants_Svg;

#define sipType_QBrush sipExportedTypes_QtGui[8]

extern sipClassTypeDef sipTypeDef_QtGui_QBrush;

#define sipType_QGradient sipExportedTypes_QtGui[56]

#define sipType_QGradient_Preset sipExportedTypes_QtGui[58]

#define sipType_QGradient_Spread sipExportedTypes_QtGui[59]

#define sipType_QGradient_Type sipExportedTypes_QtGui[60]

#define sipType_QGradient_CoordinateMode sipExportedTypes_QtGui[57]

extern sipClassTypeDef sipTypeDef_QtGui_QGradient;

#define sipType_QLinearGradient sipExportedTypes_QtGui[97]

extern sipClassTypeDef sipTypeDef_QtGui_QLinearGradient;

#define sipType_QRadialGradient sipExportedTypes_QtGui[249]

extern sipClassTypeDef sipTypeDef_QtGui_QRadialGradient;

#define sipType_QConicalGradient sipExportedTypes_QtGui[22]

extern sipClassTypeDef sipTypeDef_QtGui_QConicalGradient;

#define sipType_QClipboard sipExportedTypes_QtGui[9]

#define sipType_QClipboard_Mode sipExportedTypes_QtGui[10]

extern sipClassTypeDef sipTypeDef_QtGui_QClipboard;

#define sipType_QColorSpace sipExportedTypes_QtGui[17]

#define sipType_QColorSpace_TransferFunction sipExportedTypes_QtGui[20]

#define sipType_QColorSpace_Primaries sipExportedTypes_QtGui[19]

#define sipType_QColorSpace_NamedColorSpace sipExportedTypes_QtGui[18]

extern sipClassTypeDef sipTypeDef_QtGui_QColorSpace;

#define sipType_QColorTransform sipExportedTypes_QtGui[21]

extern sipClassTypeDef sipTypeDef_QtGui_QColorTransform;

#define sipType_QCursor sipExportedTypes_QtGui[25]

extern sipClassTypeDef sipTypeDef_QtGui_QCursor;

#define sipType_QDesktopServices sipExportedTypes_QtGui[26]

extern sipClassTypeDef sipTypeDef_QtGui_QDesktopServices;

#define sipType_QDrag sipExportedTypes_QtGui[29]

extern sipClassTypeDef sipTypeDef_QtGui_QDrag;

#define sipType_QInputEvent sipExportedTypes_QtGui[84]

extern sipClassTypeDef sipTypeDef_QtGui_QInputEvent;

#define sipType_QMouseEvent sipExportedTypes_QtGui[125]

extern sipClassTypeDef sipTypeDef_QtGui_QMouseEvent;

#define sipType_QHoverEvent sipExportedTypes_QtGui[64]

extern sipClassTypeDef sipTypeDef_QtGui_QHoverEvent;

#define sipType_QWheelEvent sipExportedTypes_QtGui[384]

extern sipClassTypeDef sipTypeDef_QtGui_QWheelEvent;

#define sipType_QTabletEvent sipExportedTypes_QtGui[288]

#define sipType_QTabletEvent_PointerType sipExportedTypes_QtGui[289]

#define sipType_QTabletEvent_TabletDevice sipExportedTypes_QtGui[290]

extern sipClassTypeDef sipTypeDef_QtGui_QTabletEvent;

#define sipType_QKeyEvent sipExportedTypes_QtGui[92]

extern sipClassTypeDef sipTypeDef_QtGui_QKeyEvent;

#define sipType_QFocusEvent sipExportedTypes_QtGui[37]

extern sipClassTypeDef sipTypeDef_QtGui_QFocusEvent;

#define sipType_QPaintEvent sipExportedTypes_QtGui[211]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEvent;

#define sipType_QMoveEvent sipExportedTypes_QtGui[126]

extern sipClassTypeDef sipTypeDef_QtGui_QMoveEvent;

#define sipType_QResizeEvent sipExportedTypes_QtGui[259]

extern sipClassTypeDef sipTypeDef_QtGui_QResizeEvent;

#define sipType_QCloseEvent sipExportedTypes_QtGui[11]

extern sipClassTypeDef sipTypeDef_QtGui_QCloseEvent;

#define sipType_QIconDragEvent sipExportedTypes_QtGui[68]

extern sipClassTypeDef sipTypeDef_QtGui_QIconDragEvent;

#define sipType_QShowEvent sipExportedTypes_QtGui[269]

extern sipClassTypeDef sipTypeDef_QtGui_QShowEvent;

#define sipType_QHideEvent sipExportedTypes_QtGui[63]

extern sipClassTypeDef sipTypeDef_QtGui_QHideEvent;

#define sipType_QContextMenuEvent sipExportedTypes_QtGui[23]

#define sipType_QContextMenuEvent_Reason sipExportedTypes_QtGui[24]

extern sipClassTypeDef sipTypeDef_QtGui_QContextMenuEvent;

#define sipType_QInputMethodEvent sipExportedTypes_QtGui[87]

#define sipType_QInputMethodEvent_AttributeType sipExportedTypes_QtGui[89]

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethodEvent;

#define sipType_QInputMethodEvent_Attribute sipExportedTypes_QtGui[88]

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethodEvent_Attribute;

#define sipType_QInputMethodQueryEvent sipExportedTypes_QtGui[90]

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethodQueryEvent;

#define sipType_QDropEvent sipExportedTypes_QtGui[33]

extern sipClassTypeDef sipTypeDef_QtGui_QDropEvent;

#define sipType_QDragMoveEvent sipExportedTypes_QtGui[32]

extern sipClassTypeDef sipTypeDef_QtGui_QDragMoveEvent;

#define sipType_QDragEnterEvent sipExportedTypes_QtGui[30]

extern sipClassTypeDef sipTypeDef_QtGui_QDragEnterEvent;

#define sipType_QDragLeaveEvent sipExportedTypes_QtGui[31]

extern sipClassTypeDef sipTypeDef_QtGui_QDragLeaveEvent;

#define sipType_QHelpEvent sipExportedTypes_QtGui[62]

extern sipClassTypeDef sipTypeDef_QtGui_QHelpEvent;

#define sipType_QStatusTipEvent sipExportedTypes_QtGui[275]

extern sipClassTypeDef sipTypeDef_QtGui_QStatusTipEvent;

#define sipType_QWhatsThisClickedEvent sipExportedTypes_QtGui[383]

extern sipClassTypeDef sipTypeDef_QtGui_QWhatsThisClickedEvent;

#define sipType_QActionEvent sipExportedTypes_QtGui[5]

extern sipClassTypeDef sipTypeDef_QtGui_QActionEvent;

#define sipType_QFileOpenEvent sipExportedTypes_QtGui[36]

extern sipClassTypeDef sipTypeDef_QtGui_QFileOpenEvent;

#define sipType_QShortcutEvent sipExportedTypes_QtGui[268]

extern sipClassTypeDef sipTypeDef_QtGui_QShortcutEvent;

#define sipType_QWindowStateChangeEvent sipExportedTypes_QtGui[388]

extern sipClassTypeDef sipTypeDef_QtGui_QWindowStateChangeEvent;

#define sipType_QTouchEvent sipExportedTypes_QtGui[360]

extern sipClassTypeDef sipTypeDef_QtGui_QTouchEvent;

#define sipType_QTouchEvent_TouchPoint sipExportedTypes_QtGui[361]

#define sipType_QTouchEvent_TouchPoint_InfoFlag sipExportedTypes_QtGui[362]

extern sipClassTypeDef sipTypeDef_QtGui_QTouchEvent_TouchPoint;

#define sipType_QTouchEvent_TouchPoint_InfoFlags sipExportedTypes_QtGui[363]

extern sipClassTypeDef sipTypeDef_QtGui_QTouchEvent_TouchPoint_InfoFlags;

#define sipType_QExposeEvent sipExportedTypes_QtGui[35]

extern sipClassTypeDef sipTypeDef_QtGui_QExposeEvent;

#define sipType_QScrollPrepareEvent sipExportedTypes_QtGui[264]

extern sipClassTypeDef sipTypeDef_QtGui_QScrollPrepareEvent;

#define sipType_QScrollEvent sipExportedTypes_QtGui[262]

#define sipType_QScrollEvent_ScrollState sipExportedTypes_QtGui[263]

extern sipClassTypeDef sipTypeDef_QtGui_QScrollEvent;

#define sipType_QEnterEvent sipExportedTypes_QtGui[34]

extern sipClassTypeDef sipTypeDef_QtGui_QEnterEvent;

#define sipType_QAction sipExportedTypes_QtGui[4]

#define sipType_QNativeGestureEvent sipExportedTypes_QtGui[130]

extern sipClassTypeDef sipTypeDef_QtGui_QNativeGestureEvent;

#define sipType_QPlatformSurfaceEvent sipExportedTypes_QtGui[243]

#define sipType_QPlatformSurfaceEvent_SurfaceEventType sipExportedTypes_QtGui[244]

extern sipClassTypeDef sipTypeDef_QtGui_QPlatformSurfaceEvent;

#define sipType_QPointingDeviceUniqueId sipExportedTypes_QtGui[245]

extern sipClassTypeDef sipTypeDef_QtGui_QPointingDeviceUniqueId;

#define sipType_QFont sipExportedTypes_QtGui[38]

#define sipType_QFont_HintingPreference sipExportedTypes_QtGui[40]

#define sipType_QFont_SpacingType sipExportedTypes_QtGui[41]

#define sipType_QFont_Capitalization sipExportedTypes_QtGui[39]

#define sipType_QFont_Stretch sipExportedTypes_QtGui[42]

#define sipType_QFont_Style sipExportedTypes_QtGui[43]

#define sipType_QFont_Weight sipExportedTypes_QtGui[46]

#define sipType_QFont_StyleStrategy sipExportedTypes_QtGui[45]

#define sipType_QFont_StyleHint sipExportedTypes_QtGui[44]

extern sipClassTypeDef sipTypeDef_QtGui_QFont;

#define sipType_QFontDatabase sipExportedTypes_QtGui[47]

#define sipType_QFontDatabase_SystemFont sipExportedTypes_QtGui[48]

#define sipType_QFontDatabase_WritingSystem sipExportedTypes_QtGui[49]

extern sipClassTypeDef sipTypeDef_QtGui_QFontDatabase;

#define sipType_QFontInfo sipExportedTypes_QtGui[50]

extern sipClassTypeDef sipTypeDef_QtGui_QFontInfo;

#define sipType_QFontMetrics sipExportedTypes_QtGui[51]

extern sipClassTypeDef sipTypeDef_QtGui_QFontMetrics;

#define sipType_QFontMetricsF sipExportedTypes_QtGui[52]

extern sipClassTypeDef sipTypeDef_QtGui_QFontMetricsF;

#define sipType_QMatrix4x3 sipExportedTypes_QtGui[123]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix4x3;

#define sipType_QMatrix4x2 sipExportedTypes_QtGui[122]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix4x2;

#define sipType_QMatrix3x4 sipExportedTypes_QtGui[121]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix3x4;

#define sipType_QMatrix3x3 sipExportedTypes_QtGui[120]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix3x3;

#define sipType_QMatrix3x2 sipExportedTypes_QtGui[119]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix3x2;

#define sipType_QMatrix2x4 sipExportedTypes_QtGui[118]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix2x4;

#define sipType_QMatrix2x3 sipExportedTypes_QtGui[117]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix2x3;

#define sipType_QMatrix2x2 sipExportedTypes_QtGui[116]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix2x2;

#define sipType_QGlyphRun sipExportedTypes_QtGui[53]

#define sipType_QGlyphRun_GlyphRunFlag sipExportedTypes_QtGui[54]

extern sipClassTypeDef sipTypeDef_QtGui_QGlyphRun;

#define sipType_QGlyphRun_GlyphRunFlags sipExportedTypes_QtGui[55]

extern sipClassTypeDef sipTypeDef_QtGui_QGlyphRun_GlyphRunFlags;

#define sipType_QGuiApplication sipExportedTypes_QtGui[61]

extern sipClassTypeDef sipTypeDef_QtGui_QGuiApplication;

#define sipType_QIcon sipExportedTypes_QtGui[65]

#define sipType_QIcon_State sipExportedTypes_QtGui[67]

#define sipType_QIcon_Mode sipExportedTypes_QtGui[66]

extern sipClassTypeDef sipTypeDef_QtGui_QIcon;

#define sipType_QIconEngine sipExportedTypes_QtGui[69]

#define sipType_QIconEngine_IconEngineHook sipExportedTypes_QtGui[71]

extern sipClassTypeDef sipTypeDef_QtGui_QIconEngine;

#define sipType_QIconEngine_AvailableSizesArgument sipExportedTypes_QtGui[70]

extern sipClassTypeDef sipTypeDef_QtGui_QIconEngine_AvailableSizesArgument;

#define sipType_QIconEngine_ScaledPixmapArgument sipExportedTypes_QtGui[72]

extern sipClassTypeDef sipTypeDef_QtGui_QIconEngine_ScaledPixmapArgument;

#define sipType_QImage sipExportedTypes_QtGui[73]

#define sipType_QImage_Format sipExportedTypes_QtGui[74]

#define sipType_QImage_InvertMode sipExportedTypes_QtGui[75]

extern sipClassTypeDef sipTypeDef_QtGui_QImage;

#define sipType_QImageIOHandler sipExportedTypes_QtGui[76]

#define sipType_QImageIOHandler_Transformation sipExportedTypes_QtGui[78]

#define sipType_QImageIOHandler_ImageOption sipExportedTypes_QtGui[77]

extern sipClassTypeDef sipTypeDef_QtGui_QImageIOHandler;

#define sipType_QImageIOHandler_Transformations sipExportedTypes_QtGui[79]

extern sipClassTypeDef sipTypeDef_QtGui_QImageIOHandler_Transformations;

#define sipType_QImageReader sipExportedTypes_QtGui[80]

#define sipType_QImageReader_ImageReaderError sipExportedTypes_QtGui[81]

extern sipClassTypeDef sipTypeDef_QtGui_QImageReader;

#define sipType_QImageWriter sipExportedTypes_QtGui[82]

#define sipType_QImageWriter_ImageWriterError sipExportedTypes_QtGui[83]

extern sipClassTypeDef sipTypeDef_QtGui_QImageWriter;

#define sipType_QInputMethod sipExportedTypes_QtGui[85]

#define sipType_QInputMethod_Action sipExportedTypes_QtGui[86]

extern sipClassTypeDef sipTypeDef_QtGui_QInputMethod;

#define sipType_QKeySequence sipExportedTypes_QtGui[93]

#define sipType_QKeySequence_StandardKey sipExportedTypes_QtGui[96]

#define sipType_QKeySequence_SequenceMatch sipExportedTypes_QtGui[95]

#define sipType_QKeySequence_SequenceFormat sipExportedTypes_QtGui[94]

extern sipClassTypeDef sipTypeDef_QtGui_QKeySequence;

#define sipType_QMatrix4x4 sipExportedTypes_QtGui[124]

extern sipClassTypeDef sipTypeDef_QtGui_QMatrix4x4;

#define sipType_QMovie sipExportedTypes_QtGui[127]

#define sipType_QMovie_CacheMode sipExportedTypes_QtGui[128]

#define sipType_QMovie_MovieState sipExportedTypes_QtGui[129]

extern sipClassTypeDef sipTypeDef_QtGui_QMovie;

#define sipType_QSurface sipExportedTypes_QtGui[277]

#define sipType_QSurface_SurfaceType sipExportedTypes_QtGui[279]

#define sipType_QSurface_SurfaceClass sipExportedTypes_QtGui[278]

extern sipClassTypeDef sipTypeDef_QtGui_QSurface;

#define sipType_QOffscreenSurface sipExportedTypes_QtGui[131]

extern sipClassTypeDef sipTypeDef_QtGui_QOffscreenSurface;

#define sipType_QOpenGLBuffer sipExportedTypes_QtGui[132]

#define sipType_QOpenGLBuffer_RangeAccessFlag sipExportedTypes_QtGui[134]

#define sipType_QOpenGLBuffer_Access sipExportedTypes_QtGui[133]

#define sipType_QOpenGLBuffer_UsagePattern sipExportedTypes_QtGui[137]

#define sipType_QOpenGLBuffer_Type sipExportedTypes_QtGui[136]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLBuffer;

#define sipType_QOpenGLBuffer_RangeAccessFlags sipExportedTypes_QtGui[135]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLBuffer_RangeAccessFlags;

#define sipType_QOpenGLContextGroup sipExportedTypes_QtGui[140]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLContextGroup;

#define sipType_QOpenGLContext sipExportedTypes_QtGui[138]

#define sipType_QOpenGLContext_OpenGLModuleType sipExportedTypes_QtGui[139]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLContext;

#define sipType_QOpenGLVersionProfile sipExportedTypes_QtGui[183]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLVersionProfile;

#define sipType_QOpenGLDebugMessage sipExportedTypes_QtGui[143]

#define sipType_QOpenGLDebugMessage_Severity sipExportedTypes_QtGui[145]

#define sipType_QOpenGLDebugMessage_Type sipExportedTypes_QtGui[148]

#define sipType_QOpenGLDebugMessage_Source sipExportedTypes_QtGui[146]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugMessage;

#define sipType_QOpenGLDebugMessage_Sources sipExportedTypes_QtGui[147]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugMessage_Sources;

#define sipType_QOpenGLDebugMessage_Types sipExportedTypes_QtGui[149]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugMessage_Types;

#define sipType_QOpenGLDebugMessage_Severities sipExportedTypes_QtGui[144]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugMessage_Severities;

#define sipType_QOpenGLDebugLogger sipExportedTypes_QtGui[141]

#define sipType_QOpenGLDebugLogger_LoggingMode sipExportedTypes_QtGui[142]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLDebugLogger;

#define sipType_QOpenGLFramebufferObject sipExportedTypes_QtGui[150]

#define sipType_QOpenGLFramebufferObject_FramebufferRestorePolicy sipExportedTypes_QtGui[152]

#define sipType_QOpenGLFramebufferObject_Attachment sipExportedTypes_QtGui[151]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLFramebufferObject;

#define sipType_QOpenGLFramebufferObjectFormat sipExportedTypes_QtGui[153]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLFramebufferObjectFormat;

#define sipType_QOpenGLPaintDevice sipExportedTypes_QtGui[154]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLPaintDevice;

#define sipType_QOpenGLPixelTransferOptions sipExportedTypes_QtGui[155]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLPixelTransferOptions;

#define sipType_QOpenGLShader sipExportedTypes_QtGui[156]

#define sipType_QOpenGLShader_ShaderTypeBit sipExportedTypes_QtGui[158]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLShader;

#define sipType_QOpenGLShader_ShaderType sipExportedTypes_QtGui[157]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLShader_ShaderType;

#define sipType_QOpenGLShaderProgram sipExportedTypes_QtGui[159]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLShaderProgram;

#define sipType_QOpenGLTexture sipExportedTypes_QtGui[160]

#define sipType_QOpenGLTexture_ComparisonMode sipExportedTypes_QtGui[163]

#define sipType_QOpenGLTexture_ComparisonFunction sipExportedTypes_QtGui[162]

#define sipType_QOpenGLTexture_CoordinateDirection sipExportedTypes_QtGui[164]

#define sipType_QOpenGLTexture_WrapMode sipExportedTypes_QtGui[178]

#define sipType_QOpenGLTexture_Filter sipExportedTypes_QtGui[169]

#define sipType_QOpenGLTexture_DepthStencilMode sipExportedTypes_QtGui[166]

#define sipType_QOpenGLTexture_SwizzleValue sipExportedTypes_QtGui[174]

#define sipType_QOpenGLTexture_SwizzleComponent sipExportedTypes_QtGui[173]

#define sipType_QOpenGLTexture_Feature sipExportedTypes_QtGui[167]

#define sipType_QOpenGLTexture_PixelType sipExportedTypes_QtGui[172]

#define sipType_QOpenGLTexture_PixelFormat sipExportedTypes_QtGui[171]

#define sipType_QOpenGLTexture_CubeMapFace sipExportedTypes_QtGui[165]

#define sipType_QOpenGLTexture_TextureFormat sipExportedTypes_QtGui[176]

#define sipType_QOpenGLTexture_TextureUnitReset sipExportedTypes_QtGui[177]

#define sipType_QOpenGLTexture_MipMapGeneration sipExportedTypes_QtGui[170]

#define sipType_QOpenGLTexture_BindingTarget sipExportedTypes_QtGui[161]

#define sipType_QOpenGLTexture_Target sipExportedTypes_QtGui[175]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLTexture;

#define sipType_QOpenGLTexture_Features sipExportedTypes_QtGui[168]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLTexture_Features;

#define sipType_QOpenGLTextureBlitter sipExportedTypes_QtGui[179]

#define sipType_QOpenGLTextureBlitter_Origin sipExportedTypes_QtGui[180]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLTextureBlitter;

#define sipType_QOpenGLTimerQuery sipExportedTypes_QtGui[182]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLTimerQuery;

#define sipType_QOpenGLTimeMonitor sipExportedTypes_QtGui[181]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLTimeMonitor;

#define sipType_QAbstractOpenGLFunctions sipExportedTypes_QtGui[0]

extern sipClassTypeDef sipTypeDef_QtGui_QAbstractOpenGLFunctions;

#define sipType_QOpenGLVertexArrayObject sipExportedTypes_QtGui[184]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLVertexArrayObject;

#define sipType_QOpenGLVertexArrayObject_Binder sipExportedTypes_QtGui[185]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLVertexArrayObject_Binder;

#define sipType_QWindow sipExportedTypes_QtGui[385]

#define sipType_QWindow_Visibility sipExportedTypes_QtGui[387]

#define sipType_QWindow_AncestorMode sipExportedTypes_QtGui[386]

extern sipClassTypeDef sipTypeDef_QtGui_QWindow;

#define sipType_QPaintDeviceWindow sipExportedTypes_QtGui[202]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintDeviceWindow;

#define sipType_QOpenGLWindow sipExportedTypes_QtGui[186]

#define sipType_QOpenGLWindow_UpdateBehavior sipExportedTypes_QtGui[187]

extern sipClassTypeDef sipTypeDef_QtGui_QOpenGLWindow;

#define sipType_QPagedPaintDevice sipExportedTypes_QtGui[196]

#define sipType_QPagedPaintDevice_PdfVersion sipExportedTypes_QtGui[199]

#define sipType_QPagedPaintDevice_PageSize sipExportedTypes_QtGui[198]

extern sipClassTypeDef sipTypeDef_QtGui_QPagedPaintDevice;

#define sipType_QPagedPaintDevice_Margins sipExportedTypes_QtGui[197]

extern sipClassTypeDef sipTypeDef_QtGui_QPagedPaintDevice_Margins;

#define sipType_QPageLayout sipExportedTypes_QtGui[188]

#define sipType_QPageLayout_Mode sipExportedTypes_QtGui[189]

#define sipType_QPageLayout_Orientation sipExportedTypes_QtGui[190]

#define sipType_QPageLayout_Unit sipExportedTypes_QtGui[191]

extern sipClassTypeDef sipTypeDef_QtGui_QPageLayout;

#define sipType_QPageSize sipExportedTypes_QtGui[192]

#define sipType_QPageSize_SizeMatchPolicy sipExportedTypes_QtGui[194]

#define sipType_QPageSize_Unit sipExportedTypes_QtGui[195]

#define sipType_QPageSize_PageSizeId sipExportedTypes_QtGui[193]

extern sipClassTypeDef sipTypeDef_QtGui_QPageSize;

#define sipType_QPainter sipExportedTypes_QtGui[212]

#define sipType_QPainter_PixmapFragmentHint sipExportedTypes_QtGui[215]

#define sipType_QPainter_CompositionMode sipExportedTypes_QtGui[213]

#define sipType_QPainter_RenderHint sipExportedTypes_QtGui[217]

extern sipClassTypeDef sipTypeDef_QtGui_QPainter;

#define sipType_QPainter_RenderHints sipExportedTypes_QtGui[218]

extern sipClassTypeDef sipTypeDef_QtGui_QPainter_RenderHints;

#define sipType_QPainter_PixmapFragment sipExportedTypes_QtGui[214]

extern sipClassTypeDef sipTypeDef_QtGui_QPainter_PixmapFragment;

#define sipType_QPainter_PixmapFragmentHints sipExportedTypes_QtGui[216]

extern sipClassTypeDef sipTypeDef_QtGui_QPainter_PixmapFragmentHints;

#define sipType_QTextItem sipExportedTypes_QtGui[330]

#define sipType_QTextItem_RenderFlag sipExportedTypes_QtGui[331]

extern sipClassTypeDef sipTypeDef_QtGui_QTextItem;

#define sipType_QTextItem_RenderFlags sipExportedTypes_QtGui[332]

extern sipClassTypeDef sipTypeDef_QtGui_QTextItem_RenderFlags;

#define sipType_QPaintEngine sipExportedTypes_QtGui[203]

#define sipType_QPaintEngine_Type sipExportedTypes_QtGui[209]

#define sipType_QPaintEngine_PolygonDrawMode sipExportedTypes_QtGui[208]

#define sipType_QPaintEngine_DirtyFlag sipExportedTypes_QtGui[204]

#define sipType_QPaintEngine_PaintEngineFeature sipExportedTypes_QtGui[206]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEngine;

#define sipType_QPaintEngine_PaintEngineFeatures sipExportedTypes_QtGui[207]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEngine_PaintEngineFeatures;

#define sipType_QPaintEngine_DirtyFlags sipExportedTypes_QtGui[205]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEngine_DirtyFlags;

#define sipType_QPaintEngineState sipExportedTypes_QtGui[210]

extern sipClassTypeDef sipTypeDef_QtGui_QPaintEngineState;

#define sipType_QPainterPath sipExportedTypes_QtGui[219]

#define sipType_QPainterPath_ElementType sipExportedTypes_QtGui[221]

extern sipClassTypeDef sipTypeDef_QtGui_QPainterPath;

#define sipType_QPainterPath_Element sipExportedTypes_QtGui[220]

extern sipClassTypeDef sipTypeDef_QtGui_QPainterPath_Element;

#define sipType_QPainterPathStroker sipExportedTypes_QtGui[222]

extern sipClassTypeDef sipTypeDef_QtGui_QPainterPathStroker;

#define sipType_QPalette sipExportedTypes_QtGui[225]

#define sipType_QPalette_ColorRole sipExportedTypes_QtGui[227]

#define sipType_QPalette_ColorGroup sipExportedTypes_QtGui[226]

extern sipClassTypeDef sipTypeDef_QtGui_QPalette;

#define sipType_QPdfWriter sipExportedTypes_QtGui[228]

extern sipClassTypeDef sipTypeDef_QtGui_QPdfWriter;

#define sipType_QPen sipExportedTypes_QtGui[229]

extern sipClassTypeDef sipTypeDef_QtGui_QPen;

#define sipType_QPicture sipExportedTypes_QtGui[230]

extern sipClassTypeDef sipTypeDef_QtGui_QPicture;

#define sipType_QPictureIO sipExportedTypes_QtGui[231]

extern sipClassTypeDef sipTypeDef_QtGui_QPictureIO;

#define sipType_QPixelFormat sipExportedTypes_QtGui[232]

#define sipType_QPixelFormat_ByteOrder sipExportedTypes_QtGui[236]

#define sipType_QPixelFormat_YUVLayout sipExportedTypes_QtGui[239]

#define sipType_QPixelFormat_TypeInterpretation sipExportedTypes_QtGui[238]

#define sipType_QPixelFormat_AlphaPremultiplied sipExportedTypes_QtGui[234]

#define sipType_QPixelFormat_AlphaPosition sipExportedTypes_QtGui[233]

#define sipType_QPixelFormat_AlphaUsage sipExportedTypes_QtGui[235]

#define sipType_QPixelFormat_ColorModel sipExportedTypes_QtGui[237]

extern sipClassTypeDef sipTypeDef_QtGui_QPixelFormat;

#define sipType_QPixmapCache sipExportedTypes_QtGui[241]

extern sipClassTypeDef sipTypeDef_QtGui_QPixmapCache;

#define sipType_QPixmapCache_Key sipExportedTypes_QtGui[242]

extern sipClassTypeDef sipTypeDef_QtGui_QPixmapCache_Key;

#define sipType_QPolygon sipExportedTypes_QtGui[246]

extern sipClassTypeDef sipTypeDef_QtGui_QPolygon;

#define sipType_QPolygonF sipExportedTypes_QtGui[247]

extern sipClassTypeDef sipTypeDef_QtGui_QPolygonF;

#define sipType_QQuaternion sipExportedTypes_QtGui[248]

extern sipClassTypeDef sipTypeDef_QtGui_QQuaternion;

#define sipType_QRasterWindow sipExportedTypes_QtGui[250]

extern sipClassTypeDef sipTypeDef_QtGui_QRasterWindow;

#define sipType_QRawFont sipExportedTypes_QtGui[251]

#define sipType_QRawFont_LayoutFlag sipExportedTypes_QtGui[253]

#define sipType_QRawFont_AntialiasingType sipExportedTypes_QtGui[252]

extern sipClassTypeDef sipTypeDef_QtGui_QRawFont;

#define sipType_QRawFont_LayoutFlags sipExportedTypes_QtGui[254]

extern sipClassTypeDef sipTypeDef_QtGui_QRawFont_LayoutFlags;

#define sipType_QRegion sipExportedTypes_QtGui[256]

#define sipType_QRegion_RegionType sipExportedTypes_QtGui[257]

extern sipClassTypeDef sipTypeDef_QtGui_QRegion;

#define sipType_QRgba64 sipExportedTypes_QtGui[260]

extern sipClassTypeDef sipTypeDef_QtGui_QRgba64;

#define sipType_QScreen sipExportedTypes_QtGui[261]

extern sipClassTypeDef sipTypeDef_QtGui_QScreen;

#define sipType_QSessionManager sipExportedTypes_QtGui[265]

#define sipType_QSessionManager_RestartHint sipExportedTypes_QtGui[266]

extern sipClassTypeDef sipTypeDef_QtGui_QSessionManager;

#define sipType_QStandardItemModel sipExportedTypes_QtGui[272]

extern sipClassTypeDef sipTypeDef_QtGui_QStandardItemModel;

#define sipType_QStandardItem sipExportedTypes_QtGui[270]

#define sipType_QStandardItem_ItemType sipExportedTypes_QtGui[271]

extern sipClassTypeDef sipTypeDef_QtGui_QStandardItem;

#define sipType_QStaticText sipExportedTypes_QtGui[273]

#define sipType_QStaticText_PerformanceHint sipExportedTypes_QtGui[274]

extern sipClassTypeDef sipTypeDef_QtGui_QStaticText;

#define sipType_QStyleHints sipExportedTypes_QtGui[276]

extern sipClassTypeDef sipTypeDef_QtGui_QStyleHints;

#define sipType_QSurfaceFormat sipExportedTypes_QtGui[280]

#define sipType_QSurfaceFormat_ColorSpace sipExportedTypes_QtGui[281]

#define sipType_QSurfaceFormat_OpenGLContextProfile sipExportedTypes_QtGui[284]

#define sipType_QSurfaceFormat_RenderableType sipExportedTypes_QtGui[285]

#define sipType_QSurfaceFormat_SwapBehavior sipExportedTypes_QtGui[286]

#define sipType_QSurfaceFormat_FormatOption sipExportedTypes_QtGui[282]

extern sipClassTypeDef sipTypeDef_QtGui_QSurfaceFormat;

#define sipType_QSurfaceFormat_FormatOptions sipExportedTypes_QtGui[283]

extern sipClassTypeDef sipTypeDef_QtGui_QSurfaceFormat_FormatOptions;

#define sipType_QSyntaxHighlighter sipExportedTypes_QtGui[287]

extern sipClassTypeDef sipTypeDef_QtGui_QSyntaxHighlighter;

#define sipType_QTextCursor sipExportedTypes_QtGui[302]

#define sipType_QTextCursor_SelectionType sipExportedTypes_QtGui[305]

#define sipType_QTextCursor_MoveOperation sipExportedTypes_QtGui[304]

#define sipType_QTextCursor_MoveMode sipExportedTypes_QtGui[303]

extern sipClassTypeDef sipTypeDef_QtGui_QTextCursor;


extern sipClassTypeDef sipTypeDef_QtGui_Qt;

#define sipType_QTextDocument sipExportedTypes_QtGui[306]

#define sipType_QTextDocument_MarkdownFeature sipExportedTypes_QtGui[309]

#define sipType_QTextDocument_Stacks sipExportedTypes_QtGui[313]

#define sipType_QTextDocument_ResourceType sipExportedTypes_QtGui[312]

#define sipType_QTextDocument_FindFlag sipExportedTypes_QtGui[307]

#define sipType_QTextDocument_MetaInformation sipExportedTypes_QtGui[311]

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocument;

#define sipType_QTextDocument_FindFlags sipExportedTypes_QtGui[308]

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocument_FindFlags;

#define sipType_QTextDocument_MarkdownFeatures sipExportedTypes_QtGui[310]

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocument_MarkdownFeatures;

#define sipType_QTextDocumentFragment sipExportedTypes_QtGui[314]

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocumentFragment;

#define sipType_QTextDocumentWriter sipExportedTypes_QtGui[315]

extern sipClassTypeDef sipTypeDef_QtGui_QTextDocumentWriter;

#define sipType_QTextLength sipExportedTypes_QtGui[336]

#define sipType_QTextLength_Type sipExportedTypes_QtGui[337]

extern sipClassTypeDef sipTypeDef_QtGui_QTextLength;

#define sipType_QTextFormat sipExportedTypes_QtGui[316]

#define sipType_QTextFormat_Property sipExportedTypes_QtGui[321]

#define sipType_QTextFormat_PageBreakFlag sipExportedTypes_QtGui[319]

#define sipType_QTextFormat_ObjectTypes sipExportedTypes_QtGui[318]

#define sipType_QTextFormat_FormatType sipExportedTypes_QtGui[317]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFormat;

#define sipType_QTextFormat_PageBreakFlags sipExportedTypes_QtGui[320]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFormat_PageBreakFlags;

#define sipType_QTextCharFormat sipExportedTypes_QtGui[298]

#define sipType_QTextCharFormat_FontPropertiesInheritanceBehavior sipExportedTypes_QtGui[299]

#define sipType_QTextCharFormat_UnderlineStyle sipExportedTypes_QtGui[300]

#define sipType_QTextCharFormat_VerticalAlignment sipExportedTypes_QtGui[301]

extern sipClassTypeDef sipTypeDef_QtGui_QTextCharFormat;

#define sipType_QTextBlockFormat sipExportedTypes_QtGui[293]

#define sipType_QTextBlockFormat_MarkerType sipExportedTypes_QtGui[295]

#define sipType_QTextBlockFormat_LineHeightTypes sipExportedTypes_QtGui[294]

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlockFormat;

#define sipType_QTextListFormat sipExportedTypes_QtGui[342]

#define sipType_QTextListFormat_Style sipExportedTypes_QtGui[343]

extern sipClassTypeDef sipTypeDef_QtGui_QTextListFormat;

#define sipType_QTextImageFormat sipExportedTypes_QtGui[328]

extern sipClassTypeDef sipTypeDef_QtGui_QTextImageFormat;

#define sipType_QTextFrameFormat sipExportedTypes_QtGui[325]

#define sipType_QTextFrameFormat_BorderStyle sipExportedTypes_QtGui[326]

#define sipType_QTextFrameFormat_Position sipExportedTypes_QtGui[327]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFrameFormat;

#define sipType_QTextTableFormat sipExportedTypes_QtGui[355]

extern sipClassTypeDef sipTypeDef_QtGui_QTextTableFormat;

#define sipType_QTextTableCellFormat sipExportedTypes_QtGui[354]

extern sipClassTypeDef sipTypeDef_QtGui_QTextTableCellFormat;

#define sipType_QTextInlineObject sipExportedTypes_QtGui[329]

extern sipClassTypeDef sipTypeDef_QtGui_QTextInlineObject;

#define sipType_QTextLayout sipExportedTypes_QtGui[333]

#define sipType_QTextLayout_CursorMode sipExportedTypes_QtGui[334]

extern sipClassTypeDef sipTypeDef_QtGui_QTextLayout;

#define sipType_QTextLayout_FormatRange sipExportedTypes_QtGui[335]

extern sipClassTypeDef sipTypeDef_QtGui_QTextLayout_FormatRange;

#define sipType_QTextLine sipExportedTypes_QtGui[338]

#define sipType_QTextLine_CursorPosition sipExportedTypes_QtGui[339]

#define sipType_QTextLine_Edge sipExportedTypes_QtGui[340]

extern sipClassTypeDef sipTypeDef_QtGui_QTextLine;

#define sipType_QTextObject sipExportedTypes_QtGui[344]

extern sipClassTypeDef sipTypeDef_QtGui_QTextObject;

#define sipType_QTextBlockGroup sipExportedTypes_QtGui[296]

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlockGroup;

#define sipType_QTextList sipExportedTypes_QtGui[341]

extern sipClassTypeDef sipTypeDef_QtGui_QTextList;

#define sipType_QTextFrame sipExportedTypes_QtGui[323]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFrame;

#define sipType_QTextFrame_iterator sipExportedTypes_QtGui[324]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFrame_iterator;

#define sipType_QTextBlock sipExportedTypes_QtGui[291]

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlock;

#define sipType_QTextBlock_iterator sipExportedTypes_QtGui[292]

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlock_iterator;

#define sipType_QTextFragment sipExportedTypes_QtGui[322]

extern sipClassTypeDef sipTypeDef_QtGui_QTextFragment;

#define sipType_QTextBlockUserData sipExportedTypes_QtGui[297]

extern sipClassTypeDef sipTypeDef_QtGui_QTextBlockUserData;

#define sipType_QTextOption sipExportedTypes_QtGui[346]

#define sipType_QTextOption_TabType sipExportedTypes_QtGui[350]

#define sipType_QTextOption_Flag sipExportedTypes_QtGui[347]

#define sipType_QTextOption_WrapMode sipExportedTypes_QtGui[351]

extern sipClassTypeDef sipTypeDef_QtGui_QTextOption;

#define sipType_QTextOption_Flags sipExportedTypes_QtGui[348]

extern sipClassTypeDef sipTypeDef_QtGui_QTextOption_Flags;

#define sipType_QTextOption_Tab sipExportedTypes_QtGui[349]

extern sipClassTypeDef sipTypeDef_QtGui_QTextOption_Tab;

#define sipType_QTextTableCell sipExportedTypes_QtGui[353]

extern sipClassTypeDef sipTypeDef_QtGui_QTextTableCell;

#define sipType_QTextTable sipExportedTypes_QtGui[352]

extern sipClassTypeDef sipTypeDef_QtGui_QTextTable;

#define sipType_QTouchDevice sipExportedTypes_QtGui[356]

#define sipType_QTouchDevice_CapabilityFlag sipExportedTypes_QtGui[358]

#define sipType_QTouchDevice_DeviceType sipExportedTypes_QtGui[359]

extern sipClassTypeDef sipTypeDef_QtGui_QTouchDevice;

#define sipType_QTouchDevice_Capabilities sipExportedTypes_QtGui[357]

extern sipClassTypeDef sipTypeDef_QtGui_QTouchDevice_Capabilities;

#define sipType_QTransform sipExportedTypes_QtGui[364]

#define sipType_QTransform_TransformationType sipExportedTypes_QtGui[365]

extern sipClassTypeDef sipTypeDef_QtGui_QTransform;

#define sipType_QValidator sipExportedTypes_QtGui[366]

#define sipType_QValidator_State sipExportedTypes_QtGui[367]

extern sipClassTypeDef sipTypeDef_QtGui_QValidator;

#define sipType_QIntValidator sipExportedTypes_QtGui[91]

extern sipClassTypeDef sipTypeDef_QtGui_QIntValidator;

#define sipType_QDoubleValidator sipExportedTypes_QtGui[27]

#define sipType_QDoubleValidator_Notation sipExportedTypes_QtGui[28]

extern sipClassTypeDef sipTypeDef_QtGui_QDoubleValidator;

#define sipType_QRegExpValidator sipExportedTypes_QtGui[255]

extern sipClassTypeDef sipTypeDef_QtGui_QRegExpValidator;

#define sipType_QRegularExpressionValidator sipExportedTypes_QtGui[258]

extern sipClassTypeDef sipTypeDef_QtGui_QRegularExpressionValidator;

#define sipType_QVector2D sipExportedTypes_QtGui[368]

extern sipClassTypeDef sipTypeDef_QtGui_QVector2D;

#define sipType_QVector3D sipExportedTypes_QtGui[369]

extern sipClassTypeDef sipTypeDef_QtGui_QVector3D;

#define sipType_QVector4D sipExportedTypes_QtGui[370]

extern sipClassTypeDef sipTypeDef_QtGui_QVector4D;

#define sipType_QList_0111QTouchDevice sipExportedTypes_QtGui[113]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0111QTouchDevice;

#define sipType_QList_0101QTextFrame sipExportedTypes_QtGui[110]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QTextFrame;

#define sipType_QList_0100QTextBlock sipExportedTypes_QtGui[109]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTextBlock;

#define sipType_QList_0100QGlyphRun sipExportedTypes_QtGui[99]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QGlyphRun;

#define sipType_QVector_0100QTextLayout_FormatRange sipExportedTypes_QtGui[378]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QTextLayout_FormatRange;

#define sipType_QList_0100QTextLayout_FormatRange sipExportedTypes_QtGui[111]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTextLayout_FormatRange;

#define sipType_QList_0100QTextOption_Tab sipExportedTypes_QtGui[112]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTextOption_Tab;

#define sipType_QVector_0100QTextLength sipExportedTypes_QtGui[379]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QTextLength;

#define sipType_QVector_0100QTextFormat sipExportedTypes_QtGui[377]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QTextFormat;

#define sipType_QList_0101QStandardItem sipExportedTypes_QtGui[108]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QStandardItem;

#define sipType_QVector_0100QRect sipExportedTypes_QtGui[375]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QRect;

#define sipType_QVector_0100QPoint sipExportedTypes_QtGui[374]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QPoint;

#define sipType_QList_0100QPolygonF sipExportedTypes_QtGui[105]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QPolygonF;

#define sipType_QList_0101QOpenGLShader sipExportedTypes_QtGui[104]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QOpenGLShader;

#define sipType_QVector_0100QSize sipExportedTypes_QtGui[376]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QSize;

#define sipType_QList_0100QOpenGLDebugMessage sipExportedTypes_QtGui[103]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QOpenGLDebugMessage;

#define sipType_QSet_0100QByteArray sipExportedTypes_QtGui[267]

extern sipMappedTypeDef sipTypeDef_QtGui_QSet_0100QByteArray;

#define sipType_QList_0101QOpenGLContext sipExportedTypes_QtGui[102]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QOpenGLContext;

#define sipType_QList_0100QKeySequence sipExportedTypes_QtGui[101]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QKeySequence;

#define sipType_QList_0101QScreen sipExportedTypes_QtGui[106]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QScreen;

#define sipType_QList_0100QTouchEvent_TouchPoint sipExportedTypes_QtGui[114]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QTouchEvent_TouchPoint;

#define sipType_QList_0100QInputMethodEvent_Attribute sipExportedTypes_QtGui[100]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QInputMethodEvent_Attribute;

#define sipType_QList_0100QSize sipExportedTypes_QtGui[107]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QSize;

#define sipType_QVector_0100QAbstractTextDocumentLayout_Selection sipExportedTypes_QtGui[372]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0100QAbstractTextDocumentLayout_Selection;

#define sipType_QList_0101QWindow sipExportedTypes_QtGui[115]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0101QWindow;

#define sipType_QVector_0600QPair_2400_0100QColor sipExportedTypes_QtGui[373]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_0600QPair_2400_0100QColor;

#define sipType_QVector_3900 sipExportedTypes_QtGui[371]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_3900;

#define sipType_QVector_2400 sipExportedTypes_QtGui[381]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_2400;

#define sipType_QVector_2200 sipExportedTypes_QtGui[380]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_2200;

#define sipType_QVector_1900 sipExportedTypes_QtGui[382]

extern sipMappedTypeDef sipTypeDef_QtGui_QVector_1900;

#define sipType_QList_0100QFontDatabase_WritingSystem sipExportedTypes_QtGui[98]

extern sipMappedTypeDef sipTypeDef_QtGui_QList_0100QFontDatabase_WritingSystem;

#define sipType_QPair_2200_2200 sipExportedTypes_QtGui[224]

extern sipMappedTypeDef sipTypeDef_QtGui_QPair_2200_2200;

#define sipType_QPair_0100QOpenGLTexture_Filter_0100QOpenGLTexture_Filter sipExportedTypes_QtGui[223]

extern sipMappedTypeDef sipTypeDef_QtGui_QPair_0100QOpenGLTexture_Filter_0100QOpenGLTexture_Filter;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtGui;
extern sipExportedModuleDef sipModuleAPI_QtGui;
extern sipTypeDef *sipExportedTypes_QtGui[];

#if !defined(sipType_Qt)
#define sipType_Qt sipImportedTypes_QtGui_QtCore[42].it_td
#endif

#define sipType_Qt_HighDpiScaleFactorRoundingPolicy sipImportedTypes_QtGui_QtCore[59].it_td

#define sipType_Qt_TabFocusBehavior sipImportedTypes_QtGui_QtCore[83].it_td

#define sipType_Qt_MouseEventSource sipImportedTypes_QtGui_QtCore[72].it_td

#define sipType_Qt_ScrollPhase sipImportedTypes_QtGui_QtCore[80].it_td

#define sipType_Qt_NativeGestureType sipImportedTypes_QtGui_QtCore[73].it_td

#define sipType_Qt_ApplicationState sipImportedTypes_QtGui_QtCore[44].it_td

#define sipType_Qt_HitTestAccuracy sipImportedTypes_QtGui_QtCore[60].it_td

#define sipType_Qt_WhiteSpaceMode sipImportedTypes_QtGui_QtCore[89].it_td

#define sipType_Qt_ScreenOrientation sipImportedTypes_QtGui_QtCore[78].it_td

#define sipType_Qt_CursorMoveStyle sipImportedTypes_QtGui_QtCore[51].it_td

#define sipType_Qt_TouchPointState sipImportedTypes_QtGui_QtCore[86].it_td

#define sipType_Qt_SizeMode sipImportedTypes_QtGui_QtCore[81].it_td

#define sipType_Qt_Axis sipImportedTypes_QtGui_QtCore[46].it_td

#define sipType_Qt_MaskMode sipImportedTypes_QtGui_QtCore[67].it_td

#define sipType_Qt_WindowModality sipImportedTypes_QtGui_QtCore[91].it_td

#define sipType_Qt_CheckState sipImportedTypes_QtGui_QtCore[49].it_td

#define sipType_Qt_DropAction sipImportedTypes_QtGui_QtCore[53].it_td

#define sipType_Qt_LayoutDirection sipImportedTypes_QtGui_QtCore[66].it_td

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtGui_QtCore[63].it_td

#define sipType_Qt_FocusReason sipImportedTypes_QtGui_QtCore[57].it_td

#define sipType_Qt_TransformationMode sipImportedTypes_QtGui_QtCore[88].it_td

#define sipType_Qt_ClipOperation sipImportedTypes_QtGui_QtCore[50].it_td

#define sipType_Qt_FillRule sipImportedTypes_QtGui_QtCore[56].it_td

#define sipType_Qt_AspectRatioMode sipImportedTypes_QtGui_QtCore[45].it_td

#define sipType_Qt_TextFormat sipImportedTypes_QtGui_QtCore[85].it_td

#define sipType_Qt_CursorShape sipImportedTypes_QtGui_QtCore[52].it_td

#define sipType_Qt_BrushStyle sipImportedTypes_QtGui_QtCore[48].it_td

#define sipType_Qt_PenJoinStyle sipImportedTypes_QtGui_QtCore[76].it_td

#define sipType_Qt_PenCapStyle sipImportedTypes_QtGui_QtCore[75].it_td

#define sipType_Qt_PenStyle sipImportedTypes_QtGui_QtCore[77].it_td

#define sipType_Qt_BGMode sipImportedTypes_QtGui_QtCore[47].it_td

#define sipType_Qt_WindowState sipImportedTypes_QtGui_QtCore[92].it_td

#define sipType_Qt_WindowType sipImportedTypes_QtGui_QtCore[94].it_td

#define sipType_Qt_TextElideMode sipImportedTypes_QtGui_QtCore[84].it_td

#define sipType_Qt_SortOrder sipImportedTypes_QtGui_QtCore[82].it_td

#define sipType_Qt_Orientation sipImportedTypes_QtGui_QtCore[74].it_td

#define sipType_Qt_MouseButton sipImportedTypes_QtGui_QtCore[69].it_td

#define sipType_Qt_GlobalColor sipImportedTypes_QtGui_QtCore[58].it_td

#define sipType_Qt_KeyboardModifiers sipImportedTypes_QtGui_QtCore[65].it_td

#define sipType_Qt_MouseButtons sipImportedTypes_QtGui_QtCore[70].it_td

#define sipType_Qt_Alignment sipImportedTypes_QtGui_QtCore[43].it_td

#define sipType_Qt_WindowFlags sipImportedTypes_QtGui_QtCore[90].it_td

#define sipType_Qt_WindowStates sipImportedTypes_QtGui_QtCore[93].it_td

#define sipType_Qt_ImageConversionFlags sipImportedTypes_QtGui_QtCore[61].it_td

#define sipType_Qt_InputMethodQueries sipImportedTypes_QtGui_QtCore[62].it_td

#define sipType_Qt_DropActions sipImportedTypes_QtGui_QtCore[54].it_td

#define sipType_Qt_ItemFlags sipImportedTypes_QtGui_QtCore[64].it_td

#define sipType_Qt_MatchFlags sipImportedTypes_QtGui_QtCore[68].it_td

#define sipType_Qt_TouchPointStates sipImportedTypes_QtGui_QtCore[87].it_td

#define sipType_Qt_ScreenOrientations sipImportedTypes_QtGui_QtCore[79].it_td

#define sipType_Qt_Edges sipImportedTypes_QtGui_QtCore[55].it_td

#define sipType_Qt_MouseEventFlags sipImportedTypes_QtGui_QtCore[71].it_td

#define sipType_QObject sipImportedTypes_QtGui_QtCore[25].it_td

#define sipType_QModelIndex sipImportedTypes_QtGui_QtCore[24].it_td

#define sipType_QAbstractItemModel sipImportedTypes_QtGui_QtCore[0].it_td

#define sipType_QIODevice sipImportedTypes_QtGui_QtCore[10].it_td

#define sipType_QByteArray sipImportedTypes_QtGui_QtCore[1].it_td

#define sipType_QCoreApplication sipImportedTypes_QtGui_QtCore[4].it_td

#define sipType_QEvent sipImportedTypes_QtGui_QtCore[6].it_td

#define sipType_QEvent_Type sipImportedTypes_QtGui_QtCore[7].it_td

#define sipType_QTimerEvent sipImportedTypes_QtGui_QtCore[38].it_td

#define sipType_QChildEvent sipImportedTypes_QtGui_QtCore[3].it_td

#define sipType_QDataStream sipImportedTypes_QtGui_QtCore[5].it_td

#define sipType_QFile sipImportedTypes_QtGui_QtCore[8].it_td

#define sipType_QIODevice_OpenMode sipImportedTypes_QtGui_QtCore[11].it_td

#define sipType_QLine sipImportedTypes_QtGui_QtCore[12].it_td

#define sipType_QLineF sipImportedTypes_QtGui_QtCore[13].it_td

#define sipType_QLocale sipImportedTypes_QtGui_QtCore[18].it_td

#define sipType_QMargins sipImportedTypes_QtGui_QtCore[20].it_td

#define sipType_QMarginsF sipImportedTypes_QtGui_QtCore[21].it_td

#define sipType_QMetaMethod sipImportedTypes_QtGui_QtCore[22].it_td

#define sipType_QMimeData sipImportedTypes_QtGui_QtCore[23].it_td

#define sipType_QPoint sipImportedTypes_QtGui_QtCore[27].it_td

#define sipType_QPointF sipImportedTypes_QtGui_QtCore[28].it_td

#define sipType_QRect sipImportedTypes_QtGui_QtCore[29].it_td

#define sipType_QRectF sipImportedTypes_QtGui_QtCore[30].it_td

#define sipType_QRegExp sipImportedTypes_QtGui_QtCore[31].it_td

#define sipType_QRegularExpression sipImportedTypes_QtGui_QtCore[32].it_td

#define sipType_QSize sipImportedTypes_QtGui_QtCore[33].it_td

#define sipType_QSizeF sipImportedTypes_QtGui_QtCore[34].it_td

#define sipType_QTextCodec sipImportedTypes_QtGui_QtCore[37].it_td

#define sipType_QUrl sipImportedTypes_QtGui_QtCore[39].it_td

#define sipType_QVariant sipImportedTypes_QtGui_QtCore[40].it_td

#define sipType_QVector_0100QPointF sipImportedTypes_QtGui_QtCore[41].it_td

#define sipType_QHash_1800_0100QByteArray sipImportedTypes_QtGui_QtCore[9].it_td

#define sipType_QMap_1800_0100QVariant sipImportedTypes_QtGui_QtCore[19].it_td

#define sipType_QList_0100QByteArray sipImportedTypes_QtGui_QtCore[14].it_td

#define sipType_QList_0100QModelIndex sipImportedTypes_QtGui_QtCore[15].it_td

#define sipType_QPair_1800_1800 sipImportedTypes_QtGui_QtCore[26].it_td

#define sipType_QStringList sipImportedTypes_QtGui_QtCore[36].it_td

#define sipType_QList_2400 sipImportedTypes_QtGui_QtCore[17].it_td

#define sipType_QList_1800 sipImportedTypes_QtGui_QtCore[16].it_td

#define sipType_QString sipImportedTypes_QtGui_QtCore[35].it_td

#define sipType_QChar sipImportedTypes_QtGui_QtCore[2].it_td

#define sipType_quintptr sipImportedTypes_QtGui_QtCore[95].it_td
extern sipImportedTypeDef sipImportedTypes_QtGui_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtGui_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtGui_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtGui_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtGui_qt_metacast;
#line 173 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qfontmetrics.sip"
// Used by QFontMetrics and QFontMetricsF.
int *qtgui_tabarray(PyObject *l);
#line 321 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qguiapplication.sip"
// Imports from QtCore.
typedef void (*pyqt5_qtgui_cleanup_qobjects_t)();
extern pyqt5_qtgui_cleanup_qobjects_t pyqt5_qtgui_cleanup_qobjects;

typedef char **(*pyqt5_qtgui_from_argv_list_t)(PyObject *, int &);
extern pyqt5_qtgui_from_argv_list_t pyqt5_qtgui_from_argv_list;

typedef void (*pyqt5_qtgui_update_argv_list_t)(PyObject *, int, char **);
extern pyqt5_qtgui_update_argv_list_t pyqt5_qtgui_update_argv_list;
#line 268 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qimage.sip"
const char **QtGui_ListToArray(PyObject *lst);
void QtGui_DeleteArray(const char **arr);
#line 216 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qmatrix4x4.sip"
// Helpers for the matrix classes.
typedef float PYQT_FLOAT;

sipErrorState qtgui_matrixParseIndex(PyObject *tup, int nr_rows,
        int nr_columns, int *row, int *column);
sipErrorState qtgui_matrixDataFromSequence(PyObject *seq, int nr_values,
        PYQT_FLOAT *values);
sipErrorState qtgui_matrixDataAsList(int nr_values, const PYQT_FLOAT *values,
        PyObject **list);
#line 335 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qopenglshaderprogram.sip"
#include "qpyopengl_api.h"
#line 256 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qtextobject.sip"
PyObject *qtgui_wrap_ancestors(QObject *obj, const sipTypeDef *td);
#line 10433 "/build/pyqt5/src/PyQt5-5.15.11/build/QtGui/sipAPIQtGui.h"

#endif
